(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     68258,       1847]*)
(*NotebookOutlinePosition[     69141,       1875]*)
(*  CellTagsIndexPosition[     69097,       1871]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["An example", "SubsectionIcon"],

Cell[TextData[{
  "The lists ",
  StyleBox["nl",
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      FormBox[
        StyleBox["dl",
          FontSlant->"Italic"], TraditionalForm]]],
  " store lists of the actual numbers and perceived densities over time; \
samples are taken every ",
  StyleBox["dt",
    FontSlant->"Italic"],
  "=1000 iterations, after an initial warm-up period of ",
  StyleBox["tw",
    FontSlant->"Italic"],
  "=5000 events.  There are total of ",
  StyleBox["tm",
    FontSlant->"Italic"],
  "=30000 births.  "
}], "Text"],

Cell[TextData[{
  "The population is arranged on a two-dimensional torus of size R\[Times]R, \
where R=60.  Dispersal is Gaussian with standard deviation \[Sigma]=1.  \
Fecundity is constant at 2, and mortality increases linearly with density (M=\
\[Mu]+\[Alpha] \[Rho], where \[Mu]=1, \[Alpha] =5). The carrying capacity in \
a homogeneous population would therefore be \[Rho]= ",
  Cell[BoxData[
      \(TraditionalForm\`\((f - \[Mu])\)\/\[Alpha] = 0.2\)]],
  ", giving  ",
  Cell[BoxData[
      \(TraditionalForm\`n = \[Rho]\ R\^2\)]],
  "=720  individuals.  The perceived density will equilibrate at this value, \
but the actual census density will be reduced below this value."
}], "Text"],

Cell[TextData[{
  "Density is averaged over a Gaussian function ",
  Cell[BoxData[
      \(TraditionalForm\`U[]\)]],
  " with scale \[Gamma]=1.  Therefore, individuals more than \
\[CapitalDelta]=3 away have a negligible effect, and so the population can be \
arranged into boxes of size \[CapitalDelta]=3.  The speed of the simulation \
is determined primarily by the numbers of neighbours that must be counted at \
each iteration."
}], "Text"],

Cell[BoxData[
    \(R = 60; \[CapitalDelta] = 3; \[Sigma] = 1. ; \ndt = 1000; dm = 10; 
    \[Delta]d = 0.1; tw = 5000; tm = 30000; \n
    tz = CovarianceMidPoints[{dm, \[Delta]d}]; \)], "Input",
  CellLabel->"In[25]:="],

Cell[BoxData[{
    \(U[\[Gamma]_] := \(1\/\(\(2\)  \(\[Pi]\)\(\ \)\(\[Gamma]\)\(\ \)\)\) 
          Exp[\(-\(DistanceSquared[#1, #2, R]\/\(2  \[Gamma]\)\)\)] &; 
    M[\[Mu]_, \[Alpha]_] := \((\[Mu] + \[Alpha]*#)\) &\ ; 
    F[f_] := f &;\), "\[IndentingNewLine]", 
    \(\(Disp[\[Sigma]_] := 
        RandomArray[NormalDistribution[0, \[Sigma]], {2}] &;\)\)}], "Input",
  CellLabel->"In[26]:="],

Cell[CellGroupData[{

Cell[BoxData[{
    \(InitialiseContinuum[p1, 100, R, \[CapitalDelta], 2, U[1], M[1, 5], 
      F[2]]; bc = InitialiseCovariance[{dm, \[Delta]d}]; ns = 0;\), "\n", 
    \(nl = {{T[p1], NumberOfIndividuals[p1]}}; 
    dl = {{T[p1], 
          Mean[\(Density[p1, #] &\) /@ ExtantIndividuals[p1]]}};\), "\n", 
    \(Timing[
      While[\((NumberOfIndividuals[p1] > 0)\) && \((TotalNumber[p1] < 
              tm)\), \n\t
        Do[IterateContinuum[p1, R, \[CapitalDelta], U[1], M[1, 5], F[2], 
            Disp[1]], {dt}]; \n\t
        If[TotalNumber[p1] > tw, \n\t\t\tns += 1; 
          bc += SampleCovariance[p1, 
              R, {dm, \[Delta]d}]]; \n\ \ Print["\<T=\>", T[p1], 
          Tab, "\<n=\>", NumberOfIndividuals[p1]]; \n\t\tAppendTo[
          nl, {T[p1], NumberOfIndividuals[p1]}]; \n\t
        AppendTo[
          dl, {T[p1], 
            Mean[\(Density[p1, #] &\) /@ 
                ExtantIndividuals[p1]]}];]]\)}], "Input",
  CellLabel->"In[27]:="],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]1.80313585518059724`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]176\),
      SequenceForm[ "T=", 1.8031358551805972, "\t", "n=", 176],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]3.34219921796730456`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]180\),
      SequenceForm[ "T=", 3.3421992179673046, "\t", "n=", 180],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]4.65760147523464329`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]214\),
      SequenceForm[ "T=", 4.6576014752346433, "\t", "n=", 214],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]5.8527827741566627`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]188\),
      SequenceForm[ "T=", 5.8527827741566627, "\t", "n=", 188],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]7.23176041644663136`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]168\),
      SequenceForm[ "T=", 7.2317604164466314, "\t", "n=", 168],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]8.54826455977947574`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]168\),
      SequenceForm[ "T=", 8.5482645597794757, "\t", "n=", 168],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]10.1613909661358947`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]150\),
      SequenceForm[ "T=", 10.161390966135896, "\t", "n=", 150],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]11.6586029202832275`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]180\),
      SequenceForm[ "T=", 11.658602920283228, "\t", "n=", 180],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]13.1672167169850418`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]164\),
      SequenceForm[ "T=", 13.167216716985042, "\t", "n=", 164],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]15.0109834594452129`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]136\),
      SequenceForm[ "T=", 15.010983459445214, "\t", "n=", 136],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]17.0540214086026375`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]104\),
      SequenceForm[ "T=", 17.054021408602637, "\t", "n=", 104],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]19.113736262321737`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]158\),
      SequenceForm[ "T=", 19.113736262321737, "\t", "n=", 158],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]20.6849300720863649`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]192\),
      SequenceForm[ "T=", 20.684930072086363, "\t", "n=", 192],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]22.1416598683227361`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]172\),
      SequenceForm[ "T=", 22.141659868322737, "\t", "n=", 172],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]23.6500766968295428`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]158\),
      SequenceForm[ "T=", 23.650076696829544, "\t", "n=", 158],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]25.0533835128196713`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]184\),
      SequenceForm[ "T=", 25.053383512819671, "\t", "n=", 184],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]26.2802954062293636`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]228\),
      SequenceForm[ "T=", 26.280295406229364, "\t", "n=", 228],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]27.5107054723847088`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]210\),
      SequenceForm[ "T=", 27.510705472384711, "\t", "n=", 210],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]28.8655668385059893`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]168\),
      SequenceForm[ "T=", 28.865566838505991, "\t", "n=", 168],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]30.390222994147833`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]150\),
      SequenceForm[ "T=", 30.390222994147834, "\t", "n=", 150],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]32.1842071585450639`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]136\),
      SequenceForm[ "T=", 32.184207158545064, "\t", "n=", 136],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]33.8777504783544225`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]194\),
      SequenceForm[ "T=", 33.877750478354422, "\t", "n=", 194],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]35.2167659253309484`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]184\),
      SequenceForm[ "T=", 35.216765925330947, "\t", "n=", 184],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]36.5539903936507926`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]146\),
      SequenceForm[ "T=", 36.553990393650793, "\t", "n=", 146],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]38.1637601589708808`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]158\),
      SequenceForm[ "T=", 38.163760158970881, "\t", "n=", 158],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]39.9420119678877796`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]144\),
      SequenceForm[ "T=", 39.94201196788778, "\t", "n=", 144],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]41.5129918568886413`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]184\),
      SequenceForm[ "T=", 41.51299185688864, "\t", "n=", 184],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]42.8991597643474165`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]174\),
      SequenceForm[ "T=", 42.899159764347417, "\t", "n=", 174],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]44.1981608585863572`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]214\),
      SequenceForm[ "T=", 44.198160858586355, "\t", "n=", 214],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]45.4926116879145148`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]152\),
      SequenceForm[ "T=", 45.492611687914511, "\t", "n=", 152],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]47.1938590942171831`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]154\),
      SequenceForm[ "T=", 47.193859094217181, "\t", "n=", 154],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]48.786869918740745`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]176\),
      SequenceForm[ "T=", 48.786869918740749, "\t", "n=", 176],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]50.3384272229706475`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]154\),
      SequenceForm[ "T=", 50.338427222970644, "\t", "n=", 154],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]51.9492534111156523`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]154\),
      SequenceForm[ "T=", 51.949253411115656, "\t", "n=", 154],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]53.6303065298984815`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]146\),
      SequenceForm[ "T=", 53.630306529898483, "\t", "n=", 146],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]55.4875573753127326`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]144\),
      SequenceForm[ "T=", 55.487557375312733, "\t", "n=", 144],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]57.4698608934889332`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]102\),
      SequenceForm[ "T=", 57.469860893488935, "\t", "n=", 102],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]59.5512007460139702`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]116\),
      SequenceForm[ "T=", 59.551200746013969, "\t", "n=", 116],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]61.4839725911877454`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]122\),
      SequenceForm[ "T=", 61.483972591187744, "\t", "n=", 122],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]63.4649522762970352`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]140\),
      SequenceForm[ "T=", 63.464952276297034, "\t", "n=", 140],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]65.1210147341083445`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]162\),
      SequenceForm[ "T=", 65.121014734108343, "\t", "n=", 162],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]66.5983531640196702`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]168\),
      SequenceForm[ "T=", 66.59835316401967, "\t", "n=", 168],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]68.1543494499912405`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]142\),
      SequenceForm[ "T=", 68.154349449991244, "\t", "n=", 142],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]69.9411089967364141`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]116\),
      SequenceForm[ "T=", 69.941108996736418, "\t", "n=", 116],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]71.8069387235642331`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]118\),
      SequenceForm[ "T=", 71.80693872356423, "\t", "n=", 118],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]73.9315587166285848`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]122\),
      SequenceForm[ "T=", 73.931558716628587, "\t", "n=", 122],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]75.9130811895029911`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]136\),
      SequenceForm[ "T=", 75.913081189502989, "\t", "n=", 136],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]78.0076073664839686`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]118\),
      SequenceForm[ "T=", 78.007607366483967, "\t", "n=", 118],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]79.8763229703265942`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]168\),
      SequenceForm[ "T=", 79.876322970326598, "\t", "n=", 168],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]81.4107618260669951`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]158\),
      SequenceForm[ "T=", 81.410761826067002, "\t", "n=", 158],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]83.0027028875190353`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]134\),
      SequenceForm[ "T=", 83.002702887519035, "\t", "n=", 134],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]85.0593692256626709`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]124\),
      SequenceForm[ "T=", 85.059369225662664, "\t", "n=", 124],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]87.0669449107497328`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]108\),
      SequenceForm[ "T=", 87.066944910749726, "\t", "n=", 108],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]88.7969179758155391`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]140\),
      SequenceForm[ "T=", 88.796917975815532, "\t", "n=", 140],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]90.6333192691498013`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]150\),
      SequenceForm[ "T=", 90.633319269149794, "\t", "n=", 150],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]92.4159590322531343`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]174\),
      SequenceForm[ "T=", 92.415959032253141, "\t", "n=", 174],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]93.7501144138608388`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]192\),
      SequenceForm[ "T=", 93.750114413860842, "\t", "n=", 192],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]95.033024093655829`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]194\),
      SequenceForm[ "T=", 95.033024093655825, "\t", "n=", 194],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]96.324496703373601`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]186\),
      SequenceForm[ "T=", 96.324496703373597, "\t", "n=", 186],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]97.6162294061078661`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]182\),
      SequenceForm[ "T=", 97.616229406107863, "\t", "n=", 182],
      Editable->False]], "Print"],

Cell[BoxData[
    \({1481.81666666666655`\ Second, Null}\)], "Output",
  CellLabel->"Out[27]="]
}, Closed]],

Cell[TextData[{
  "The upper curve is the perceived density, the lower curve the overall mean \
density, which remains steady.  The mean census density is 0.0432, while the \
mean perceived density is 0.203, close to the predicted value ",
  Cell[BoxData[
      \(TraditionalForm\`\((f - \[Mu])\)\/\[Alpha] = 0.2\)]],
  ".  (These values are accumulated over ",
  StyleBox["ns",
    FontSlant->"Italic"],
  "=51 samples, taken after the initial warm-up period.  Note that there are \
fluctuations in density over long timescales, so that longer runs would be \
needed for accurate results."
}], "Text"],

Cell[BoxData[
    \(\(<< Graphics`Graphics`; \)\)], "Input",
  CellLabel->"In[31]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(DisplayTogether[
      ListPlot[nl /. {{t_, n_} :> {t, n\/R\^2}}, PlotJoined \[Rule] True], \n
      ListPlot[dl, PlotJoined \[Rule] True], 
      PlotRange \[Rule] {{0, T[p1]}, {0, 0.3}}]; \n
    nbar = Mean[Transpose[Take[nl, \(-ns\)]] // Last]/R\^2; {nbar\ R\^2, 
        nbar, Mean[Transpose[Take[dl, \(-ns\)]] // Last]} // N\)], "Input",
  CellLabel->"In[32]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.0102442 0 2.06011 [
[.20488 -0.0125 -6 -9 ]
[.20488 -0.0125 6 0 ]
[.40977 -0.0125 -6 -9 ]
[.40977 -0.0125 6 0 ]
[.61465 -0.0125 -6 -9 ]
[.61465 -0.0125 6 0 ]
[.81954 -0.0125 -6 -9 ]
[.81954 -0.0125 6 0 ]
[-0.0125 .10301 -24 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -18 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -24 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -18 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.20488 0 m
.20488 .00625 L
s
[(20)] .20488 -0.0125 0 1 Mshowa
.40977 0 m
.40977 .00625 L
s
[(40)] .40977 -0.0125 0 1 Mshowa
.61465 0 m
.61465 .00625 L
s
[(60)] .61465 -0.0125 0 1 Mshowa
.81954 0 m
.81954 .00625 L
s
[(80)] .81954 -0.0125 0 1 Mshowa
.125 Mabswid
.05122 0 m
.05122 .00375 L
s
.10244 0 m
.10244 .00375 L
s
.15366 0 m
.15366 .00375 L
s
.2561 0 m
.2561 .00375 L
s
.30733 0 m
.30733 .00375 L
s
.35855 0 m
.35855 .00375 L
s
.46099 0 m
.46099 .00375 L
s
.51221 0 m
.51221 .00375 L
s
.56343 0 m
.56343 .00375 L
s
.66587 0 m
.66587 .00375 L
s
.71709 0 m
.71709 .00375 L
s
.76831 0 m
.76831 .00375 L
s
.87076 0 m
.87076 .00375 L
s
.92198 0 m
.92198 .00375 L
s
.9732 0 m
.9732 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .10301 m
.00625 .10301 L
s
[(0.05)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(0.1)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.15)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.2)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.25)] -0.0125 .51503 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .05723 m
.01847 .10072 L
.03424 .10301 L
.04771 .12246 L
.05996 .10758 L
.07408 .09614 L
.08757 .09614 L
.1041 .08584 L
.11943 .10301 L
.13489 .09385 L
.15378 .07783 L
.1747 .05951 L
.1958 .09042 L
.2119 .10987 L
.22682 .09843 L
.24228 .09042 L
.25665 .10529 L
.26922 .13047 L
.28183 .12017 L
.2957 .09614 L
.31132 .08584 L
.3297 .07783 L
.34705 .11102 L
.36077 .10529 L
.37447 .08355 L
.39096 .09042 L
.40917 .0824 L
.42527 .10529 L
.43947 .09957 L
.45277 .12246 L
.46604 .08698 L
.48346 .08813 L
.49978 .10072 L
.51568 .08813 L
.53218 .08813 L
.5494 .08355 L
.56843 .0824 L
.58873 .05837 L
.61005 .06638 L
.62985 .06981 L
.65015 .08012 L
.66711 .09271 L
.68225 .09614 L
.69819 .08126 L
.71649 .06638 L
.7356 .06753 L
.75737 .06981 L
.77767 .07783 L
.79913 .06753 L
.81827 .09614 L
Mistroke
.83399 .09042 L
.8503 .07668 L
.87137 .07096 L
.89193 .0618 L
.90965 .08012 L
.92847 .08584 L
.94673 .09957 L
.96039 .10987 L
.97354 .11102 L
.98677 .10644 L
1 .10415 L
Mfstroke
0 .02252 m
.01847 .35594 L
.03424 .42137 L
.04771 .47856 L
.05996 .37914 L
.07408 .38194 L
.08757 .46106 L
.1041 .40077 L
.11943 .48471 L
.13489 .47418 L
.15378 .38666 L
.1747 .41607 L
.1958 .50378 L
.2119 .48074 L
.22682 .42615 L
.24228 .44673 L
.25665 .44165 L
.26922 .53216 L
.28183 .49095 L
.2957 .448 L
.31132 .43437 L
.3297 .34678 L
.34705 .5615 L
.36077 .46547 L
.37447 .37009 L
.39096 .41684 L
.40917 .35051 L
.42527 .39718 L
.43947 .35762 L
.45277 .53001 L
.46604 .34781 L
.48346 .44642 L
.49978 .42697 L
.51568 .34304 L
.53218 .42619 L
.5494 .408 L
.56843 .50248 L
.58873 .31029 L
.61005 .35778 L
.62985 .38411 L
.65015 .48361 L
.66711 .44056 L
.68225 .45927 L
.69819 .39248 L
.71649 .35337 L
.7356 .4194 L
.75737 .39699 L
.77767 .42446 L
.79913 .41537 L
.81827 .4477 L
Mistroke
.83399 .36735 L
.8503 .3609 L
.87137 .39124 L
.89193 .2857 L
.90965 .45218 L
.92847 .37596 L
.94673 .4617 L
.96039 .41075 L
.97354 .39209 L
.98677 .36937 L
1 .42144 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[32]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo001;Ool40003Ool2000]Ool30003Ool2000]Ool20004Ool2000^Ool2
0004Ool2000/Ool004aoo`03001oogoo009oo`04001oogoo000]Ool01@00Oomoogoo00000Woo00<0
07ooOol0:Goo00@007ooOol0009oo`04001oogoo000/Ool01000Oomoo`000Woo00@007ooOol002]o
o`00CGoo00D007ooOomoo`00009oo`03001oogoo02Uoo`@0009oo`04001oogoo000[Ool01000Oomo
o`000Woo00@007ooOol002aoo`04001oogoo0002Ool01000Oomoo`00:goo001>Ool01000Oomoo`00
0Woo00<007ooOol0:Goo00<007oo00000goo00@007ooOol002]oo`<000=oo`04001oogoo000]Ool2
0003Ool01000Oomoo`00:goo001;Ool01000Oomoo`000Woo00@007ooOol002]oo`03001oo`0000=o
o`04001oogoo000[Ool00`00Oomoo`03Ool01000Oomoo`00;7oo00@007ooOol0009oo`04001oogoo
000[Ool004aoo`8000Aoo`8002eoo`8000Aoo`8002eoo`<000=oo`8002ioo`8000Aoo`8002aoo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo000KOooo0006000001]oo`03001oogoo00Yoo`03
001oogoo00Yoo`03001oogoo00]oo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00]oo`03
001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo00Yoo`03
001oogoo00Yoo`03001oogoo00]oo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00]oo`03
001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo00Eoo`006goo00<007ooOol0
<Woo00<007ooOol0<Woo00<007ooOol0<Woo00<007ooOol0<goo00<007ooOol0;Goo000KOol00`00
Oomoo`3oOol3Ool001]oo`03001oogoo0?moo`=oo`006goo0P00ogoo17oo000KOol00`00Oomoo`3o
Ool3Ool001]oo`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3o
Ool3Ool001]oo`03001oogoo0?moo`=oo`006goo0P00ogoo17oo000KOol00`00Oomoo`3oOol3Ool0
01]oo`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`0ZOol00`00
Oomoo`1YOol2001ZOol001]oo`8002Yoo`8006Yoo`03001oogoo00<004Qoo`8001eoo`006goo0P00
:Goo00@007ooOol006Qoo`03001oogoo00Aoo`@001Moo`X000]oo`8001=oo`<0009oo`03001oogoo
01Yoo`006goo0P00:7oo00<007ooOol00Woo00<007ooOol0I7oo00<007ooOol02Goo0`004goo00<0
07ooOol027oo10001Goo0P0000=oo`00Ool047oo0P001Woo00<007ooOol06Goo000KOol3000VOol0
0`00Oomoo`04Ool00`00Oomoo`1ROol00`00Oomoo`0=Ool2000@Ool00`00Oomoo`0=Ool300000goo
001oo`03Ool00`00Oomoo`0;Ool30009Ool00`00Oomoo`0HOol001]oo`<002Aoo`8000Moo`03001o
ogoo025oo`8003ioo`03001oogoo011oo`8000eoo`03001oogoo015oo`03001oogoo00Aoo`03001o
ogoo00Qoo`8000eoo`03001oogoo01Moo`006goo0P0000=oo`00Ool08Goo00<007ooOol027oo00<0
07ooOol07Woo0P0000=oo`00Ool04Woo0P009Woo0`005Goo0P002Woo00<007ooOol06Goo00<007oo
Ool01Woo0P0047oo10005Goo000KOol200000goo001oo`0EOol20009Ool00`00Oomoo`0:Ool00`00
Oomoo`0KOol20004Ool00`00Oomoo`08Ool30002Ool300000goo001oo`0=Ool3000@Ool5000JOol0
0`00Oomoo`06Ool00`00Oomoo`0KOol00`00Oomoo`04Ool00`00Oomoo`0DOol3000BOol001]oo`80
0003Ool007oo01=oo`800003Ool007oo00Moo`03001oogoo00aoo`03001oogoo00Qoo`8000moo`03
001oogoo00Aoo`03001oogoo00Qoo`03001oogoo008000Eoo`03001oogoo00]oo`03001oogoo00<0
00Ioo`L0021oo`03001oogoo00Aoo`03001oogoo01aoo`03001oogoo009oo`8001Yoo`03001oogoo
00moo`006goo0P000Woo00<007ooOol047oo00<007ooOol00Woo00<007ooOol00goo0P003goo00<0
07ooOol01Woo0P0000=oo`00Ool03Goo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol02Goo
00<007ooOol02Goo00<007ooOol017oo0P000goo00<007ooOol09Woo0`000Woo00<007ooOol07Woo
00@007oo000001eoo`03001oogoo00ioo`000Woo0P0017oo0P0017oo0P000goo0`001Goo0P000Woo
00<007ooOol02goo1@001Woo00D007ooOomoo`00019oo`03001oogoo00=oo`8000Aoo`03001oogoo
00Yoo`03001oogoo00Qoo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo
00Ioo`03001oo`0002aoo`80029oo`03001oogoo01ioo`03001oogoo00eoo`0000Eoo`00Oomoo`00
00=oo`8000=oo`04001oogoo0005Ool00`00Oomoo`02Ool20003Ool30009Ool00`00Oomoo`0:Ool0
0`00Ool0000DOol01@00Oomoogoo00001goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol0
0goo00<007ooOol037oo00<007ooOol00`001Goo00<007ooOol01goo00<007ooOol0LGoo0P003Goo
00001Goo001oogoo000027oo00@007ooOol000Eoo`03001oogoo009oo`8000Ioo`8000Ioo`03001o
ogoo00aoo`03001oogoo01Aoo`03001oo`0000Uoo`03001oogoo00Moo`03001oogoo00Yoo`03001o
ogoo0080011oo`80009oo`03001oogoo009oo`03001oogoo07ioo`03001oogoo00Moo`<0000000Eo
o`00Oomoo`0000Qoo`04001oogoo0002Ool30005Ool20007Ool00`00Oomoo`03Ool00`00Oomoo`0U
Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Ool0000GOol01@00Oomoogoo
0000PGoo0`000goo0`000goo00001Goo001oogoo000027oo00@007ooOol0009oo`03001oogoo00Eo
o`8000Qoo`03001oogoo009oo`03001oogoo035oo`03001oogoo00Eoo`03001oogoo00aoo`03001o
ogoo01Ioo`04001oogoo0025Ool30006Ool0009oo`8000Yoo`8000=oo`@000Aoo`8000Uoo`04001o
ogoo000dOol00`00Oomoo`04Ool00`00Oomoo`0WOol00`00Ool0002>Ool001]oo`8000Uoo`03001o
o`0003Ioo`03001oogoo009oo`03001oogoo02Qoo`03001oo`0008ioo`006goo0P002Woo00<007oo
Ool0=Woo00@007ooOol002aoo`03001oogoo08eoo`006goo00<007oo0000@Woo00<007oo0000_Goo
000KOol00`00Ool00013Ool00`00Oomoo`2lOol001]oo`03001oo`000?moo`=oo`006goo00<007oo
0000ogoo0goo000KOol3003oOol3Ool001]oo`03001oo`000?moo`=oo`006goo00<007oo0000ogoo
0goo000KOol00`00Ool0003oOol3Ool001]oo`03001oo`000?moo`=oo`006goo00<007oo0000ogoo
0goo000KOol3003oOol3Ool001]oo`03001oo`000?moo`=oo`006goo00<007oo0000ogoo0goo000K
Ool00`00Ool0003oOol3Ool001]oo`03001oo`000?moo`=oo`006goo0`00ogoo0goo000KOol00`00
Ool0003oOol3Ool001]oo`04001oogoo003oOol2Ool000Qoo`8000Aoo`8000=oo`<000Eoo`04001o
ogoo003oOol2Ool000Moo`04001oogoo0003Ool20004Ool00`00Oomoo`04Ool01000Oomoo`00ogoo
0Woo0007Ool01000Oomoo`002Goo00<007ooOol017oo0P0000=oo`00Ool0ogoo0Goo0007Ool01000
Oomoo`002Goo00<007ooOol017oo00@007ooOol00?moo`9oo`001goo00@007ooOol000Uoo`03001o
ogoo00Aoo`04001oogoo003oOol2Ool000Qoo`8000Uoo`8000Ioo`04001oogoo003oOol2Ool001]o
o`04001oogoo003oOol2Ool001]oo`04001oogoo003oOol2Ool001]oo`800003Ool007oo0?moo`5o
o`006goo00@007ooOol00?moo`9oo`006goo00@007ooOol00?moo`9oo`006goo00@007ooOol00?mo
o`9oo`006goo00@007ooOol00?moo`9oo`006goo0P0000=oo`00Ool0ogoo0Goo000KOol01000Oomo
o`00ogoo0Woo000KOol01000Oomoo`00ogoo0Woo000KOol01@00Oomoogoo0000ogoo0Goo000KOol0
1@00Oomoogoo0000ogoo0Goo000KOol20002Ool00`00Oomoo`3nOol001]oo`05001oogooOol0003o
Ool1Ool001]oo`05001oogooOol0003oOol1Ool001]oo`05001oogooOol0003oOol1Ool001]oo`05
001oogooOol0003oOol1Ool001]oo`05001oogooOol0003ROol00`00Oomoo`0KOol001]oo`80009o
o`03001oogoo0>1oo`03001oogoo01]oo`006goo00D007ooOomoo`000>9oo`03001oogoo01]oo`00
6goo00D007ooOomoo`000>9oo`03001oogoo01]oo`000Woo0P0017oo0P000goo0`000goo0`001Goo
00D007ooOomoo`000>5oo`8001eoo`0000Eoo`00Oomoo`0000=oo`8000Aoo`03001oogoo00Eoo`03
001oogoo009oo`05001oogooOol0003QOol00`00Ool0000LOol00005Ool007ooOol00009Ool00`00
Oomoo`05Ool00`00Oomoo`02Ool20002Ool00`00Oomoo`2BOol00`00Oomoo`1:Ool00`00Ool0000L
Ool00005Ool007ooOol00009Ool00`00Oomoo`02Ool30005Ool01@00Oomoogoo0000U7oo00<007oo
Ool0BWoo00<007oo000077oo00001Goo001oogoo00002Goo00<007ooOol00Woo00<007ooOol01Goo
00D007ooOomoo`0009Aoo`8004]oo`03001oo`0001aoo`000Woo0P002Goo0P0017oo100017oo00D0
07ooOomoo`0009Aoo`8004Yoo`04001oogoo000LOol001]oo`03001oogoo009oo`03001oogoo095o
o`8004Yoo`04001oogoo000LOol001]oo`03001oogoo009oo`03001oogoo091oo`04001oogoo0019
Ool01000Oomoo`0077oo000KOol20003Ool00`00Oomoo`2@Ool01000Oomoo`00BGoo00@007ooOol0
01aoo`006goo00<007ooOol00Woo00<007ooOol0T7oo00D007ooOomoo`0004Qoo`04001oogoo000L
Ool001]oo`03001oogoo009oo`03001oogoo091oo`05001oogooOol00018Ool01@00Oomoogoo0000
6goo000KOol00`00Oomoo`02Ool00`00Oomoo`1nOol00`00Oomoo`0?Ool01@00Oomoogoo0000Agoo
00<007ooOol00Woo00<007ooOol06Goo000KOol00`00Oomoo`02Ool00`00Oomoo`1=Ool00`00Oomo
o`0QOol00`00Oomoo`0:Ool00`00Oomoo`0?Ool00`00Oomoo`02Ool00`00Oomoo`14Ool00`00Oomo
o`02Ool00`00Oomoo`0IOol001]oo`8000=oo`03001oogoo04eoo`03001oogoo019oo`03001oogoo
00aoo`03001oogoo00Yoo`03001oogoo00moo`03001oogoo009oo`03001oogoo04Aoo`03001oogoo
009oo`03001oogoo01Uoo`006goo00<007ooOol00Woo00<007ooOol0CGoo00<007ooOol04Woo00<0
07ooOol037oo00<007ooOol02Woo00<007ooOol03goo00<007ooOol00Woo00<007ooOol06Woo00<0
07ooOol09goo00<007ooOol00Woo00<007ooOol06Goo000KOol00`00Oomoo`02Ool00`00Oomoo`1=
Ool00`00Oomoo`0BOol20006Ool00`00Oomoo`04Ool00`00Oomoo`09Ool00`00Ool0000?Ool00`00
Oomoo`04Ool00`00Oomoo`0IOol00`00Oomoo`0WOol00`00Oomoo`02Ool00`00Oomoo`0IOol001]o
o`03001oogoo009oo`03001oogoo04aoo`8001=oo`03001oo`0000Ioo`03001oogoo00Aoo`8000Yo
o`03001oo`0000moo`03001oogoo00Aoo`03001oogoo01Qoo`80021oo`<000Ioo`03001oogoo009o
o`03001oogoo01Uoo`006goo00<007ooOol00goo00<007ooOol0Bgoo0P004goo00<007oo00001Goo
0P001Woo0P002Woo00<007oo00003goo00<007ooOol01Goo00<007ooOol05goo00<007oo000077oo
0`000Woo00<007ooOol00goo00<007ooOol00goo00<007ooOol06Goo000KOol20004Ool00`00Oomo
o`1;Ool2000;Ool00`00Oomoo`05Ool01000Oomoo`0017oo0P001Woo0P002Woo00<007oo00003goo
00<007ooOol01Woo00<007ooOol05Goo00@007ooOol001aoo`03001oogoo00=oo`03001oogoo009o
o`03001oogoo00Aoo`03001oogoo01=oo`03001oogoo009oo`006goo00<007ooOol00goo00<007oo
Ool0Bgoo00<007oo00002Woo00<007ooOol017oo00D007ooOomoo`0000Aoo`8000Eoo`03001oo`00
00Yoo`03001oo`0000moo`03001oogoo00Moo`03001oogoo01Aoo`04001oogoo000LOol00`00Oomo
o`04Ool01@00Oomoogoo00001Woo00<007ooOol04goo00<007ooOol00Woo000KOol00`00Oomoo`03
Ool00`00Oomoo`06Ool30012Ool00`00Ool0000:Ool20005Ool01@00Oomoogoo00000goo00<007oo
00001Goo00<007oo00002Goo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo01=oo`03
001oogoo009oo`03001oogoo01Uoo`03001oogoo00Aoo`05001oogooOol00006Ool00`00Oomoo`04
Ool00`00Oomoo`0;Ool20004Ool001]oo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo0080
041oo`03001oo`0000Yoo`8000Eoo`03001oogoo009oo`06001oogoo001oo`001Goo00<007oo0000
2Goo00D007ooOomoo`0000ioo`03001oogoo00Qoo`03001oogoo019oo`03001oogoo009oo`03001o
ogoo01Qoo`03001oogoo00Ioo`04001oogoo0006Ool00`00Oomoo`04Ool00`00Oomoo`0;Ool00`00
Ool00003Ool001]oo`03001oogoo00Aoo`03001oogoo00Eoo`05001oogooOol0000DOol00`00Oomo
o`0XOol01000Oomoo`002Goo00<007oo000017oo00<007ooOol00goo00<007oo00000Woo00<007oo
Ool00goo00<007oo00002Goo00D007ooOomoo`0000ioo`03001oogoo00Uoo`03001oogoo011oo`03
001oogoo00=oo`03001oogoo01Qoo`03001oogoo00Ioo`03001oo`0000Moo`03001oogoo00Aoo`03
001oogoo00Yoo`04001oogoo0003Ool001]oo`03001oogoo00Aoo`03001oogoo00Eoo`05001oogoo
Ool0000DOol00`00Oomoo`0XOol01000Oomoo`002Goo00@007ooOol000=oo`03001oogoo00=oo`03
001oo`0000=oo`03001oogoo009oo`04001oogoo0008Ool01@00Oomoogoo00003Woo00<007ooOol0
2Goo00<007ooOol047oo00<007ooOol017oo00<007ooOol05goo00<007ooOol01goo0P001goo00<0
07ooOol00goo00<007oo00002goo00@007ooOol000=oo`006goo0P001Goo00<007ooOol01Goo00D0
07ooOomoo`0001Aoo`8002Uoo`04001oogoo0009Ool01000Oomoo`000goo00<007ooOol017oo0P00
0goo00<007ooOol00Woo00@007ooOol000Qoo`05001oogooOol0000=Ool00`00Oomoo`0:Ool00`00
Oomoo`0?Ool00`00Oomoo`05Ool00`00Oomoo`0GOol00`00Oomoo`08Ool00`00Oomoo`05Ool00`00
Oomoo`03Ool00`00Ool0000:Ool00`00Oomoo`02Ool10001Ool1Ool001]oo`03001oogoo00Aoo`03
001oogoo00Aoo`03001oogoo00=oo`03001oogoo011oo`04001oogoo000XOol01000Oomoo`002Goo
00@007ooOol000=oo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo009oo`04001oogoo0008
Ool01@00Oomoogoo00003Goo00<007ooOol02goo00<007ooOol03Woo00<007ooOol01Goo00<007oo
Ool017oo00<007ooOol047oo00<007ooOol047oo00<007ooOol00goo00<007oo00002Woo00<007oo
Ool00Woo0@000Goo0Goo000KOol00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00
Oomoo`04Ool00`00Oomoo`09Ool01000Oomoo`00:7oo00@007ooOol000Uoo`07001oogooOol007oo
000037oo00<007ooOol00Woo00@007ooOol000Moo`03001oogoo00=oo`03001oogoo00Yoo`03001o
ogoo00]oo`03001oogoo00ioo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00moo`03001o
ogoo015oo`03001oogoo00=oo`03001oo`0000Uoo`03001oogoo00=oo`40005oo`5oo`0027oo0P00
17oo0P000goo100017oo00<007ooOol01Goo00<007ooOol00goo00<007ooOol00goo00<007ooOol0
17oo00<007ooOol02Goo00D007ooOomoo`0002Ioo`05001oogooOol00009Ool01`00Oomoogoo001o
o`0000aoo`03001oogoo009oo`04001oogoo0007Ool00`00Oomoo`03Ool00`00Oomoo`0:Ool00`00
Oomoo`0;Ool00`00Oomoo`0=Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Ool0000@Ool00`00
Oomoo`0BOol01@00Oomoogoo00000Woo00<007ooOol01Woo00<007ooOol01Goo0@000Goo0007Ool0
1000Oomoo`000goo0P0017oo00<007ooOol017oo00<007ooOol01Goo00<007ooOol00goo00<007oo
Ool00goo00<007ooOol017oo00<007ooOol02Goo00D007ooOomoo`0002Ioo`05001oogooOol00008
Ool00`00Oomoo`02Ool00`00Ool0000<Ool00`00Oomoo`02Ool01000Oomoo`001goo00<007ooOol0
0goo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol02goo00<007ooOol03Goo00<007ooOol0
1goo00D007ooOomoo`0000=oo`03001oogoo00eoo`03001oogoo019oo`05001oogooOol00003Ool0
0`00Oomoo`04Ool00`00Oomoo`06Ool10001Ool000Moo`04001oogoo000:Ool00`00Oomoo`03Ool2
0006Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool2000;Ool00`00Oomoo`02Ool0
0`00Oomoo`0SOol01@00Oomoogoo000027oo00<007ooOol00goo00<007ooOol02goo00<007ooOol0
0Woo00D007ooOomoo`0000Ioo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00Eoo`03001o
ogoo00aoo`03001oogoo00aoo`03001oogoo00Moo`04001oogoo0005Ool00`00Oomoo`0<Ool00`00
Oomoo`0BOol01@00Oomoogoo00000goo00<007ooOol00goo00<007ooOol01goo0@000Goo0007Ool0
1000Oomoo`002goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol00Woo00<007ooOol00goo
00<007ooOol00goo00<007oo00002Goo00<007ooOol017oo00<007ooOol08Woo00<007ooOol00Woo
00<007ooOol01Goo00<007ooOol00goo00<007ooOol02goo00<007ooOol00Woo00D007ooOomoo`00
00Ioo`03001oogoo00=oo`04001oogooOol20007Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00
Oomoo`08Ool20007Ool00`00Oomoo`03Ool20006Ool00`00Oomoo`0BOol01000Oomoo`0017oo00<0
07ooOol00goo00<007ooOol027oo0@000007Ool01000Oomoo`0027oo00@007ooOol000Aoo`03001o
ogoo00Ioo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00=oo`03001oo`0000Uoo`03001o
ogoo00Aoo`03001oogoo029oo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo015oo`05001o
ogooOol00004Ool00`00Oomoo`03Ool00`00Oomoo`05Ool00`00Ool00002Ool00`00Oomoo`04Ool0
0`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`09Ool00`00Oomoo`07Ool00`00Ool000020000
0goo001oo`04Ool00`00Oomoo`0COol01000Oomoo`0017oo00<007ooOol00goo00<007ooOol027oo
0@000008Ool2000:Ool20005Ool00`00Oomoo`06Ool00`00Oomoo`02Ool00`00Oomoo`04Ool01@00
Oomoogoo00000Woo00<007ooOol01goo00<007ooOol017oo00<007ooOol08Woo00<007ooOol00Woo
00<007ooOol01Goo00<007ooOol04Goo00D007ooOomoo`0000Aoo`03001oogoo00=oo`03001oogoo
00Eoo`8000=oo`03001oogoo00=oo`03001oogoo00eoo`03001oogoo00]oo`03001oogoo01Aoo`03
001oogoo00=oo`03001oogoo009oo`03001oogoo01=oo`04001oogoo0005Ool01@00Oomoogoo0000
37oo000KOol00`00Oomoo`06Ool00`00Oomoo`02Ool00`00Oomoo`04Ool01@00Oomoogoo00000Woo
00<007ooOol01goo00<007ooOol01Goo00<007ooOol02Woo00<007ooOol04goo00<007ooOol00goo
00<007ooOol01Goo00<007ooOol04Goo00D007ooOomoo`0000Aoo`03001oogoo00=oo`03001oogoo
00Eoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00eoo`03001oogoo00]oo`03001oogoo
01]oo`05001oogooOol0000EOol01000Oomoo`001Goo00D007ooOomoo`0000aoo`006goo0P0027oo
00@007ooOol000Moo`05001oogooOol00002Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomo
o`0:Ool00`00Oomoo`0COol00`00Oomoo`03Ool00`00Oomoo`05Ool00`00Oomoo`0AOol01@00Oomo
ogoo000017oo00<007ooOol00Woo00<007ooOol02goo00<007ooOol00goo00<007ooOol03Woo00<0
07ooOol02Woo00<007ooOol06goo00D007ooOomoo`0001Eoo`03001oo`0000Ioo`05001oogooOol0
000<Ool001]oo`03001oogoo00Moo`04001oogoo0007Ool01000Oomoo`0017oo00<007ooOol01Goo
00<007ooOol01Woo00<007ooOol02Woo0P004goo0P001Goo00<007ooOol017oo00<007ooOol04Woo
00D007ooOomoo`0000Aoo`05001oogooOol0000>Ool00`00Oomoo`03Ool00`00Oomoo`0>Ool00`00
Oomoo`0:Ool00`00Oomoo`0LOol01000Oomoo`005Goo00<007oo00001Woo00D007ooOomoo`0000ao
o`006goo00<007ooOol01goo00@007ooOol000Moo`04001oogoo0004Ool00`00Oomoo`05Ool00`00
Oomoo`06Ool00`00Oomoo`09Ool01000Oomoo`004Goo00<007ooOol01Goo00<007ooOol017oo00<0
07ooOol04Woo00D007ooOomoo`0000Eoo`03001oo`00011oo`03001oogoo009oo`03001oogoo00io
o`03001oogoo00Aoo`03001oogoo009oo`03001oogoo01eoo`03001oo`0001Moo`8000Moo`03001o
o`0000eoo`006goo00<007ooOol01goo00@007ooOol000Moo`04001oogoo0004Ool00`00Oomoo`05
Ool00`00Oomoo`07Ool00`00Oomoo`08Ool01@00Oomoogoo00000Woo0P002goo00<007ooOol01Woo
00<007ooOol017oo00<007ooOol04Woo00D007ooOomoo`0000Eoo`80015oo`03001oogoo009oo`03
001oogoo00ioo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo01ioo`8001Moo`8000Moo`03
001oo`0000eoo`006goo00<007ooOol01goo00@007ooOol000Moo`03001oo`0000Eoo`03001oogoo
00Eoo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo009oo`800003Ool007oo00Uoo`03001o
ogoo00Moo`03001oogoo00Aoo`03001oogoo01=oo`04001oogoo0005Ool00`00Oomoo`0@Ool00`00
Oomoo`02Ool00`00Oomoo`0?Ool00`00Oomoo`02Ool00`00Ool00003Ool00`00Oomoo`0OOol00`00
Oomoo`0EOol00`00Oomoo`06Ool00`00Ool0000=Ool001]oo`03001oogoo00Qoo`03001oo`0000Qo
o`8000Eoo`03001oogoo00Aoo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Ioo`03001o
ogoo00Qoo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo01=oo`04001oogoo000HOol00`00
Oomoo`02Ool00`00Oomoo`0?Ool00`00Oomoo`02Ool01000Oomoo`000Woo00<007ooOol0=goo00<0
07ooOol01Woo00<007oo00003Goo000KOol20009Ool00`00Ool00008Ool20005Ool00`00Oomoo`04
Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`08
Ool00`00Oomoo`04Ool00`00Oomoo`0COol01000Oomoo`0067oo00D007ooOomoo`00019oo`03001o
ogoo009oo`04001oogooOol20013Ool00`00Ool0000=Ool001]oo`03001oogoo00Qoo`03001oo`00
00Qoo`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo00Uoo`03001oogoo00Ioo`03001oogoo
00Moo`03001oogoo00Ioo`03001oogoo00Uoo`03001oogoo009oo`03001oogoo01Aoo`04001oogoo
000IOol01000Oomoo`004Woo00D007ooOomoo`0000Eoo`03001oogoo049oo`03001oogoo00aoo`00
6goo00<007ooOol027oo00<007oo000027oo00<007ooOol01Goo00<007ooOol00goo00<007ooOol0
2Goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol0
0Woo00<007ooOol057oo00@007ooOol001Uoo`04001oogoo000COol01000Oomoo`00BWoo00<007oo
Ool037oo000KOol00`00Oomoo`08Ool2000AOol00`00Oomoo`03Ool00`00Oomoo`09Ool00`00Oomo
o`05Ool00`00Oomoo`08Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool00`00Oomo
o`0DOol00`00Ool0000JOol01000Oomoo`004goo00@007ooOol005Uoo`006goo00<007ooOol02Goo
00<007ooOol03goo00<007ooOol00Woo00<007ooOol02goo00<007ooOol017oo00<007ooOol027oo
00<007ooOol01Goo00<007ooOol02Woo00<007ooOol00Woo00<007ooOol057oo00<007oo00006Woo
00@007ooOol001=oo`03001oo`0005Yoo`006goo0P002Woo00<007ooOol03goo00@007ooOomoo`80
00eoo`03001oogoo00Aoo`03001oogoo00Qoo`03001oogoo00Eoo`03001oogoo00Yoo`03001oogoo
009oo`03001oogoo01Aoo`03001oo`0001Yoo`04001oogoo000COol00`00Ool0001JOol001]oo`03
001oogoo00Uoo`03001oogoo011oo`03001oo`0000moo`03001oogoo00=oo`03001oogoo00Uoo`03
001oogoo00Aoo`03001oogoo00]oo`03001oogoo009oo`03001oogoo01Aoo`03001oo`0001]oo`03
001oo`0001=oo`03001oo`0005Yoo`006goo00<007ooOol077oo0P0047oo00<007ooOol00goo00<0
07ooOol02Woo00<007ooOol00goo00<007ooOol02goo00<007ooOol00Woo00<007ooOol057oo00<0
07oo00006goo00<007oo000057oo00<007ooOol0FGoo000KOol00`00Oomoo`0LOol00`00Oomoo`0@
Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool01@00Oomoogoo
00005goo00<007oo00006goo00<007oo000057oo00<007ooOol0FGoo000KOol00`00Oomoo`0_Ool0
1@00Oomoogoo00003Goo00<007ooOol00Woo00<007ooOol037oo00D007ooOomoo`0001Moo`03001o
o`0001]oo`80075oo`006goo0P00<7oo00@007ooOol000ioo`03001oogoo009oo`03001oogoo00ao
o`05001oogooOol0000GOol00`00Ool0000KOol2001aOol001]oo`03001oogoo02moo`04001oogoo
000>Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool01@00Oomoogoo00005goo00<007oo000077oo00<0
07ooOol0Kgoo000KOol00`00Oomoo`0`Ool2000@Ool01000Oomoo`0047oo00@007ooOol001Moo`03
001oo`0001aoo`03001oogoo06moo`006goo00<007ooOol0<7oo00<007ooOol03goo00@007ooOol0
011oo`04001oogoo000HOol2002>Ool0009oo`8000Aoo`8000=oo`@0009oo`<000Eoo`03001oogoo
049oo`04001oogoo000@Ool01000Oomoo`0067oo0P00SWoo00001Goo001oogoo00000goo0P0017oo
00<007ooOol01Goo00<007ooOol00Woo00<007ooOol0@Woo00<007oo00004Goo00@007ooOol001Qo
o`03001oogoo08eoo`0000Eoo`00Oomoo`0000Yoo`03001oogoo00Aoo`03001oogoo009oo`8004=o
o`03001oo`00015oo`03001oo`0001Uoo`03001oogoo08eoo`0000Eoo`00Oomoo`0000]oo`03001o
ogoo00<000Eoo`03001oogoo049oo`03001oo`00015oo`03001oo`0001Uoo`03001oogoo08eoo`00
00Eoo`00Oomoo`0000Qoo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`13Ool2000AOol0
0`00Ool0000IOol00`00Oomoo`2=Ool0009oo`8000Yoo`8000=oo`@000Aoo`03001oogoo04=oo`03
001oogoo011oo`03001oo`0001Uoo`03001oogoo08eoo`006goo00<007ooOol0@goo00<007ooOol0
47oo00<007oo00006Goo00<007ooOol0SGoo000KOol2001GOol00`00Ool0002YOol001]oo`03001o
ogoo05Ioo`03001oo`000:Uoo`006goo00<007ooOol0Egoo0P00ZGoo000KOol00`00Oomoo`1GOol2
002YOol001]oo`03001oogoo05Moo`03001oogoo0:Qoo`006goo0P00F7oo00<007ooOol0Z7oo000K
Ool00`00Oomoo`1GOol00`00Oomoo`2XOol001]oo`03001oogoo05Moo`03001oogoo0:Qoo`006goo
00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3Ool001]oo`03001oogoo0?moo`=oo`006goo
0P00ogoo17oo000KOol00`00Oomoo`3oOol3Ool001]oo`03001oogoo0?moo`=oo`006goo00<007oo
Ool0ogoo0goo000KOol00`00Oomoo`3oOol3Ool001]oo`800?moo`Aoo`006goo00<007ooOol0ogoo
0goo000KOol00`00Oomoo`3oOol3Ool001]oo`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo
0goo000KOol00`00Oomoo`3oOol3Ool00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-10.2401, -0.0267707, 
  0.375808, 0.00186876}}],

Cell[BoxData[
    \({155.803921568627457`, 0.0432788671023965143`, 0.202522927574263666`}
      \)], "Output",
  CellLabel->"Out[32]="]
}, Open  ]],

Cell["There is strong spatial clustering.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[ExtractExtant[Location, p1], PlotRange -> {{0, R}, {0, R}}, 
      AspectRatio -> 1]; \)\)], "Input",
  CellLabel->"In[33]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.0166667 0 0.0166667 [
[.16667 -0.0125 -6 -9 ]
[.16667 -0.0125 6 0 ]
[.33333 -0.0125 -6 -9 ]
[.33333 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.66667 -0.0125 -6 -9 ]
[.66667 -0.0125 6 0 ]
[.83333 -0.0125 -6 -9 ]
[.83333 -0.0125 6 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[-0.0125 .16667 -12 -4.5 ]
[-0.0125 .16667 0 4.5 ]
[-0.0125 .33333 -12 -4.5 ]
[-0.0125 .33333 0 4.5 ]
[-0.0125 .5 -12 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .66667 -12 -4.5 ]
[-0.0125 .66667 0 4.5 ]
[-0.0125 .83333 -12 -4.5 ]
[-0.0125 .83333 0 4.5 ]
[-0.0125 1 -12 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
[(10)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(20)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(30)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(40)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(50)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(60)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .16667 m
.00625 .16667 L
s
[(10)] -0.0125 .16667 1 0 Mshowa
0 .33333 m
.00625 .33333 L
s
[(20)] -0.0125 .33333 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(30)] -0.0125 .5 1 0 Mshowa
0 .66667 m
.00625 .66667 L
s
[(40)] -0.0125 .66667 1 0 Mshowa
0 .83333 m
.00625 .83333 L
s
[(50)] -0.0125 .83333 1 0 Mshowa
0 1 m
.00625 1 L
s
[(60)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .03333 m
.00375 .03333 L
s
0 .06667 m
.00375 .06667 L
s
0 .1 m
.00375 .1 L
s
0 .13333 m
.00375 .13333 L
s
0 .2 m
.00375 .2 L
s
0 .23333 m
.00375 .23333 L
s
0 .26667 m
.00375 .26667 L
s
0 .3 m
.00375 .3 L
s
0 .36667 m
.00375 .36667 L
s
0 .4 m
.00375 .4 L
s
0 .43333 m
.00375 .43333 L
s
0 .46667 m
.00375 .46667 L
s
0 .53333 m
.00375 .53333 L
s
0 .56667 m
.00375 .56667 L
s
0 .6 m
.00375 .6 L
s
0 .63333 m
.00375 .63333 L
s
0 .7 m
.00375 .7 L
s
0 .73333 m
.00375 .73333 L
s
0 .76667 m
.00375 .76667 L
s
0 .8 m
.00375 .8 L
s
0 .86667 m
.00375 .86667 L
s
0 .9 m
.00375 .9 L
s
0 .93333 m
.00375 .93333 L
s
0 .96667 m
.00375 .96667 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.80552 .49046 Mdot
.71845 .14967 Mdot
.5465 .5356 Mdot
.81999 .28994 Mdot
.37454 .7154 Mdot
.16374 .40516 Mdot
.30753 .51357 Mdot
.27877 .43742 Mdot
.63175 .29982 Mdot
.8218 .35774 Mdot
.67009 .62291 Mdot
.17999 .29315 Mdot
.68191 .10391 Mdot
.15769 .19063 Mdot
.86935 .3407 Mdot
.26846 .5303 Mdot
.4073 .03581 Mdot
.51545 .97717 Mdot
.72211 .28831 Mdot
.87288 .29622 Mdot
.3544 .44965 Mdot
.90224 .31548 Mdot
.69358 .12752 Mdot
.83663 .18279 Mdot
.80754 .43687 Mdot
.00134 .39714 Mdot
.69111 .95975 Mdot
.5749 .0401 Mdot
.65208 .15634 Mdot
.44499 .9698 Mdot
.04673 .23617 Mdot
.71321 .31462 Mdot
.83683 .43935 Mdot
.72683 .34262 Mdot
.68165 .5014 Mdot
.42833 .01866 Mdot
.91737 .25106 Mdot
.87144 .34563 Mdot
.1365 .30938 Mdot
.82669 .37251 Mdot
.22069 .54891 Mdot
.94496 .5825 Mdot
.293 .4617 Mdot
.35296 .81344 Mdot
.11053 .40368 Mdot
.50295 .55399 Mdot
.90224 .5509 Mdot
.63437 .92933 Mdot
.69286 .58304 Mdot
.65971 .53746 Mdot
.61889 .91992 Mdot
.16587 .50408 Mdot
.80775 .3427 Mdot
.16451 .44695 Mdot
.64327 .98898 Mdot
.63545 .46935 Mdot
.67193 .63574 Mdot
.54986 .96396 Mdot
.35235 .46153 Mdot
.66957 .53961 Mdot
.17712 .43091 Mdot
.7413 .08237 Mdot
.76656 .08881 Mdot
.79295 .16455 Mdot
.6141 .10442 Mdot
.27708 .52553 Mdot
.82096 .2591 Mdot
.17873 .37194 Mdot
.22117 .56827 Mdot
.48157 .7474 Mdot
.48535 .74536 Mdot
.77927 .24072 Mdot
.61344 .00833 Mdot
.76943 .35619 Mdot
.64513 .50926 Mdot
.80695 .48088 Mdot
.39513 .80396 Mdot
.78751 .43065 Mdot
.66984 .64638 Mdot
.19961 .34308 Mdot
.70787 .11989 Mdot
.78069 .51161 Mdot
.2973 .56917 Mdot
.78375 .31953 Mdot
.29655 .51237 Mdot
.59887 .82926 Mdot
.57774 .83981 Mdot
.57328 .78322 Mdot
.73206 .28417 Mdot
.13918 .17106 Mdot
.13632 .46088 Mdot
.88755 .5361 Mdot
.25843 .5572 Mdot
.72571 .14249 Mdot
.81036 .38529 Mdot
.6942 .19658 Mdot
.37051 .80325 Mdot
.4943 .72082 Mdot
.53009 .9518 Mdot
.72923 .22555 Mdot
.56136 .93956 Mdot
.6363 .08128 Mdot
.90237 .41322 Mdot
.9058 .56108 Mdot
.18708 .41133 Mdot
.72873 .20446 Mdot
.88473 .58387 Mdot
.80621 .37112 Mdot
.73573 .23458 Mdot
.65561 .49205 Mdot
.2488 .52488 Mdot
.09848 .43535 Mdot
.58887 .05619 Mdot
.72565 .36532 Mdot
.57893 .02893 Mdot
.11118 .46336 Mdot
.62715 .54841 Mdot
.18448 .32629 Mdot
.30269 .44756 Mdot
.65484 .54896 Mdot
.28633 .54913 Mdot
.61718 .08257 Mdot
.32188 .4602 Mdot
.42003 .02944 Mdot
.7514 .49914 Mdot
.88954 .57652 Mdot
.17038 .17773 Mdot
.19024 .57502 Mdot
.80953 .44431 Mdot
.07299 .40084 Mdot
.64332 .86696 Mdot
.68314 .18159 Mdot
.87306 .56836 Mdot
.43704 .02708 Mdot
.18882 .58064 Mdot
.44054 .02816 Mdot
.20511 .43963 Mdot
.19051 .48439 Mdot
.12002 .4241 Mdot
.5647 .82739 Mdot
.55559 .96593 Mdot
.67164 .07458 Mdot
.8728 .29903 Mdot
.17786 .28848 Mdot
.67532 .48778 Mdot
.42319 .04125 Mdot
.25043 .51294 Mdot
.73151 .37503 Mdot
.89975 .55587 Mdot
.63445 .11638 Mdot
.90586 .28419 Mdot
.29598 .48639 Mdot
.8267 .36248 Mdot
.20866 .54034 Mdot
.68789 .11605 Mdot
.90044 .56764 Mdot
.8077 .18864 Mdot
.8296 .48079 Mdot
.5456 .9424 Mdot
.27792 .55594 Mdot
.18098 .41892 Mdot
.26531 .62474 Mdot
.48454 .71386 Mdot
.24403 .56418 Mdot
.51005 .70581 Mdot
.25876 .50481 Mdot
.60854 .55054 Mdot
.61103 .30706 Mdot
.789 .17077 Mdot
.90373 .32234 Mdot
.69876 .13794 Mdot
.16887 .28376 Mdot
.38776 .8062 Mdot
.55879 .77801 Mdot
.27146 .42472 Mdot
.318 .45172 Mdot
.79656 .16903 Mdot
.36866 .70128 Mdot
.28458 .57219 Mdot
.66964 .0719 Mdot
.85116 .36286 Mdot
.82666 .36224 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[33]:=",
  ImageSize->{366, 366},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005^0001KQ000`40O003h00OogooKgoo003oOom_
Ool00?moofmoo`00ogooKgoo003oOom_Ool004Aoo`<000Aoo`80031oo`@000=oo`80031oo`<000Ao
o`80035oo`<000=oo`80031oo`<000Aoo`80039oo`8000Aoo`8000=oo`00AGoo00<007ooOol00Woo
00@007ooOol0031oo`03001oogoo009oo`04001oogoo000bOol01000Oomoo`000Woo00<007ooOol0
;goo00D007ooOomoo`00009oo`03001oogoo031oo`04001oogoo0002Ool00`00Oomoo`0^Ool01000
Oomoo`000Woo00@007ooOol0009oo`00AGoo00<007ooOol00Woo00@007ooOol0035oo`05001oogoo
Ool00002Ool00`00Oomoo`0`Ool01000Oomoo`000Woo00<007ooOol0;Goo10000Woo00@007ooOol0
039oo`04001oogoo0002Ool00`00Oomoo`0^Ool01000Oomoo`000Woo00@007ooOol0009oo`00AGoo
00<007ooOol00Woo00@007ooOol0039oo`04001oogoo0002Ool00`00Oomoo`0^Ool20003Ool01000
Oomoo`00;goo00<007oo00000goo00@007ooOol002moo`<000=oo`04001oogoo000`Ool30003Ool0
1000Oomoo`000Woo0015Ool00`00Oomoo`02Ool01000Oomoo`00;goo00@007ooOol0009oo`04001o
ogoo000bOol01000Oomoo`000Woo00<007ooOol0;Goo00<007oo00000goo00@007ooOol002moo`03
001oogoo00=oo`04001oogoo000`Ool00`00Oomoo`03Ool01000Oomoo`000Woo0014Ool20005Ool2
000aOol20004Ool2000`Ool30004Ool2000aOol20004Ool2000`Ool40003Ool2000bOol30003Ool2
0003Ool00?moofmoo`00ogooKgoo003oOom_Ool00?moofmoo`00ogooKgoo000@Oooo001I0006Ool0
011oo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo
00Uoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo
00Qoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo
00Qoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo
00Qoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo
00Qoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo
00Uoo`03001oogoo00Aoo`0047oo00<007ooOol0=Woo00<007ooOol0=Woo00<007ooOol0=Woo00<0
07ooOol0=Woo00<007ooOol0=Woo00<007ooOol0=goo00<007ooOol017oo000@Ool00`00Oomoo`3>
Ool2002;Ool0011oo`03001oogoo0<ioo`8008]oo`0047oo00<007ooOol0ogooG7oo000@Ool00`00
Oomoo`2?Ool2003:Ool0011oo`03001oogoo08moo`800<Yoo`0047oo00<007ooOol0ogooG7oo000@
Ool00`00Oomoo`2BOol30036Ool0011oo`03001oogoo08aoo`8000Aoo`<002eoo`8009Moo`0047oo
0P00SGoo0P00=7oo0P00Ugoo000@Ool00`00Oomoo`28Ool2003AOol0011oo`03001oogoo08Qoo`80
0=5oo`0047oo00<007ooOol0SGoo0P00<Woo0P00V7oo000@Ool00`00Oomoo`2=Ool2000bOol2002H
Ool0011oo`03001oogoo0?mooeaoo`0047oo00<007ooOol0ogooG7oo000@Ool00`00Oomoo`3oOomL
Ool0011oo`03001oogoo0<Ioo`8009=oo`0047oo00<007ooOol0aWoo0P00Tgoo000@Ool00`00Oomo
o`3oOomLOol0011oo`03001oogoo0?mooeaoo`0047oo0P00ogooGGoo000@Ool00`00Oomoo`3QOol2
001hOol0011oo`03001oogoo0>5oo`<007Moo`0047oo00<007ooOol0hWoo0P00Mgoo000@Ool00`00
Oomoo`3oOomLOol0011oo`03001oogoo0<moo`8000Eoo`80029oo`8005moo`0047oo00<007ooOol0
cgoo0P001Goo0P008Woo0P00Ggoo000@Ool00`00Oomoo`3oOol4Ool2001FOol0011oo`03001oogoo
0?moo`Aoo`8005Ioo`0047oo00<007ooOol0ogooG7oo000@Ool00`00Oomoo`3oOomLOol0011oo`80
0?mooeeoo`0047oo00<007ooOol0iWoo0P00Lgoo000@Ool00`00Oomoo`3>Ool2000FOol2001cOol0
011oo`03001oogoo0<ioo`8008]oo`0047oo00<007ooOol0ogooG7oo000@Ool00`00Oomoo`3oOomL
Ool0011oo`03001oogoo0=Eoo`80015oo`80075oo`0047oo00<007ooOol0eGoo0P004Goo0P001Goo
0P00JWoo000@Ool00`00Oomoo`3_Ool2001ZOol0011oo`03001oogoo0?mooeaoo`0047oo00<007oo
Ool0jWoo0P00Kgoo000@Ool00`00Oomoo`3ZOol2001_Ool0011oo`800?mooeeoo`0047oo00<007oo
Ool0jgoo0P00KWoo000@Ool00`00Oomoo`3[Ool2001^Ool0011oo`03001oogoo0?Eoo`8006Aoo`00
47oo00<007ooOol0mGoo0P00I7oo000@Ool00`00Oomoo`3bOol2001WOol0011oo`03001oogoo0?9o
o`8006Moo`0047oo00<007ooOol0fgoo0P00OWoo000@Ool00`00Oomoo`3KOol2001nOol00004Ool0
00000004Ool20006Ool00`00Oomoo`3oOomLOol0009oo`03001oogoo009oo`04001oogoo0005Ool0
0`00Oomoo`3oOol=Ool2001=Ool0009oo`03001oogoo009oo`04001oogoo0005Ool3003oOol=Ool2
001=Ool0009oo`03001oogoo009oo`04001oogoo0005Ool00`00Oomoo`0/Ool2003LOol200000goo
0000001<Ool0009oo`03001oogoo009oo`04001oogoo0005Ool00`00Oomoo`0/Ool2003LOol20000
0goo0000001<Ool00003Ool0000000Eoo`8000Ioo`03001oogoo0?mooeaoo`0047oo00<007ooOol0
=Woo0P00ogoo97oo000@Ool00`00Oomoo`0fOol2002^Ool2000cOol2000nOol0011oo`03001oogoo
0>Ioo`8003=oo`8003ioo`0047oo00<007ooOol0ogoo4Woo0P00B7oo000@Ool00`00Oomoo`0bOol2
003MOol20018Ool0011oo`03001oogoo039oo`800?moobQoo`0047oo00<007ooOol0jWoo0P00Kgoo
000@Ool00`00Oomoo`3ZOol2001_Ool0011oo`800?mooeeoo`0047oo00<007ooOol0mWoo0P00Hgoo
000@Ool00`00Oomoo`3fOol2001SOol0011oo`03001oogoo0?mooeaoo`0047oo00<007ooOol0ogoo
G7oo000@Ool00`00Oomoo`3oOomLOol0011oo`03001oogoo0?mooeaoo`0047oo00<007ooOol0ogoo
G7oo000@Ool00`00Oomoo`3fOol2001SOol0011oo`03001oogoo0?Ioo`8006=oo`0047oo00<007oo
Ool0ogooG7oo000@Ool2003iOol2001QOol0011oo`03001oogoo00aoo`800>Yoo`80065oo`0047oo
00<007ooOol037oo0P00nGoo0P00DWoo000@Ool00`00Oomoo`3oOol8Ool2001BOol0011oo`03001o
ogoo0?mooeaoo`0047oo00<007ooOol0ogooG7oo000@Ool00`00Oomoo`3oOolgOol2000SOol0011o
o`03001oogoo0?moocMoo`8002=oo`0047oo00<007ooOol0ogooG7oo000@Ool00`00Oomoo`3oOolF
Ool20014Ool0011oo`03001oogoo0?mooaIoo`8004Aoo`0047oo0P00ogooGGoo000@Ool00`00Oomo
o`3oOomLOol0011oo`03001oogoo0?mooeaoo`0047oo00<007ooOol0ogooG7oo000@Ool00`00Oomo
o`3oOomLOol0011oo`03001oogoo0?mooeaoo`0047oo00<007ooOol0=Woo0P00_goo0P00>Goo0P00
9goo000@Ool00`00Oomoo`0fOol2002oOol2000iOol2000WOol0011oo`03001oogoo03Uoo`800;Qo
o`80021oo`8004Aoo`0047oo00<007ooOol0>Goo0`00]goo0P0087oo0P00A7oo000@Ool00`00Oomo
o`0jOol2003[Ool2000bOol0011oo`03001oogoo0?moobQoo`80039oo`0047oo0P00eGoo0P00DGoo
0P00<Woo000@Ool00`00Oomoo`3DOol20025Ool0011oo`03001oogoo0<eoo`8008aoo`0047oo00<0
07ooOol0:goo0P00X7oo0P00S7oo000@Ool00`00Oomoo`0[Ool2003oOol_Ool0011oo`03001oogoo
0?1oo`8003moo`8002Qoo`0047oo00<007ooOol0l7oo0P005goo0P009Woo0P00:7oo000@Ool00`00
Oomoo`3oOol:Ool2000WOol2000WOol0011oo`03001oogoo0?mooc=oo`8002Moo`0000=oo`000000
0P000goo0P001Woo00<007ooOol0>goo0P00ogoo7goo0002Ool00`00Oomoo`02Ool01000Oomoo`00
1Goo00<007ooOol0>goo0P00ogoo7goo0003Ool01@00Oomoogoo00000Woo00<007ooOol00goo0`00
ogooG7oo0004Ool01000Oomoo`000Woo00<007ooOol00goo00<007ooOol0ogooG7oo00001Goo001o
ogoo00000Woo00@007ooOol000Eoo`03001oogoo0?mooeaoo`000Woo0P0017oo0P001Woo00<007oo
Ool0@7oo0P00/goo0P006Woo0P004goo0P00<goo000@Ool00`00Oomoo`10Ool2002cOol2000JOol2
000COol3000bOol0011oo`03001oogoo0?moobQoo`80039oo`0047oo00<007ooOol0ogooG7oo000@
Ool00`00Oomoo`3oOomLOol0011oo`03001oogoo0?moo`Eoo`80011oo`8004=oo`0047oo00<007oo
Ool0ogoo1Goo0P0047oo0P00@goo000@Ool00`00Oomoo`3oOolHOol20007Ool2000iOol0011oo`03
001oogoo0?Eoo`80021oo`8000Moo`8003Uoo`0047oo0P00mWoo0P00I7oo000@Ool00`00Oomoo`0i
Ool2003EOol20019Ool0011oo`03001oogoo03Uoo`800;aoo`8001Moo`8000Eoo`80049oo`0047oo
00<007ooOol0mgoo0P007Woo0P00@Woo000@Ool00`00Oomoo`3oOomLOol0011oo`03001oogoo0?mo
oeaoo`0047oo00<007ooOol0ogoo4goo0P00Agoo000@Ool00`00Oomoo`3oOolCOol20017Ool0011o
o`03001oogoo0?mooeaoo`0047oo00<007ooOol0ogooG7oo000?Ool2003oOomNOol000moo`<001Io
o`800?moodEoo`0047oo00<007ooOol05Goo0P002goo0P00ogoo>7oo000@Ool00`00Oomoo`0ROol2
000@Ool2003oOolVOol0011oo`03001oogoo03Aoo`800?moobIoo`0047oo00<007ooOol0?7oo0P00
lgoo0P00:7oo000@Ool00`00Oomoo`0lOol2003cOol2000XOol0011oo`03001oogoo03Yoo`800?mo
ob1oo`0047oo00<007ooOol0>Woo0P00ogoo87oo000@Ool00`00Oomoo`0UOol2000bOol2003oOol1
Ool0011oo`03001oogoo02Eoo`80039oo`800?moo`5oo`0047oo00<007ooOol0ogoo2goo0P00Cgoo
000@Ool00`00Oomoo`0iOol2003?Ool2001?Ool0011oo`8001moo`8001Uoo`800?moob5oo`0047oo
00<007ooOol07Woo0P00?7oo0P00/goo0P0027oo0P00?Woo000@Ool00`00Oomoo`12Ool2000HOol2
002cOol20008Ool2000nOol0011oo`03001oogoo049oo`800<eoo`8004Qoo`0047oo00<007ooOol0
=7oo0P00;Woo0P00Zgoo0P00B7oo000@Ool00`00Oomoo`0dOol2000^Ool2000?Ool2003TOol0011o
o`03001oogoo06Uoo`8000Yoo`800>Aoo`0047oo00<007ooOol0JGoo0P00l7oo000@Ool00`00Oomo
o`3oOomLOol0011oo`03001oogoo02]oo`8003=oo`8000Qoo`8000Uoo`800>Aoo`0047oo00<007oo
Ool08Woo0P001goo0P00<goo0P0027oo0P002Goo0P00i7oo000@Ool2000SOol2003oOolhOol0011o
o`03001oogoo0=Ioo`8008=oo`0047oo00<007ooOol0eWoo0P00Pgoo000@Ool00`00Oomoo`3oOomL
Ool0011oo`03001oogoo0?mooeaoo`0047oo00<007ooOol0ogoo4Woo0P001Goo0P00@Goo000@Ool0
0`00Oomoo`0mOol2003BOol20005Ool20011Ool0011oo`03001oogoo03eoo`80029oo`80081oo`80
07Ioo`0047oo00<007ooOol0HGoo0P00NWoo0P0017oo0P00:goo0P00BGoo000017oo0000000017oo
0P001Woo00<007ooOol0gGoo0P00<Goo0P00BGoo0004Ool01000Oomoo`000Woo00<007ooOol00goo
00<007ooOol0ogooG7oo0004Ool01000Oomoo`000Woo00<007ooOol00goo0`00oGoo0P00G7oo0002
Ool20003Ool01000Oomoo`001Goo00<007ooOol0iWoo0P005Goo0P00G7oo0004Ool01000Oomoo`00
0Woo00<007ooOol00goo00<007ooOol0=Goo0P007Woo0P00Sgoo0P00Lgoo000017oo0000000017oo
0P001Woo00<007ooOol0=Goo0P007Woo0P00PWoo0P00P7oo000@Ool00`00Oomoo`1ROol2001eOol2
000]Ool2001AOol0011oo`03001oogoo059oo`8000ioo`800003Ool000000:5oo`80055oo`0047oo
00<007ooOol0DWoo0P004Goo0P00m7oo000@Ool00`00Oomoo`3oOomLOol0011oo`03001oogoo0?mo
oeaoo`0047oo00<007ooOol0DGoo0P0027oo0P00oWoo000@Ool00`00Oomoo`1AOol20008Ool2003n
Ool0011oo`03001oogoo05Qoo`800?moo`9oo`0047oo0P00FGoo0P00GGoo0P00XWoo000@Ool00`00
Oomoo`2gOol2000UOol2001<Ool2000]Ool0011oo`03001oogoo04=oo`8009Uoo`800003Ool00000
04Uoo`8002eoo`0047oo00<007ooOol0@goo0P00W7oo0P00N7oo000@Ool00`00Oomoo`3oOomLOol0
011oo`03001oogoo04Qoo`8001Aoo`8007=oo`8000Moo`8007eoo`0047oo00<007ooOol0B7oo0P00
57oo0P00KGoo0P0017oo0P001goo0P00Dgoo0P00:7oo000@Ool00`00Oomoo`1KOol2001;Ool2000S
Ool2001QOol3000XOol0011oo`03001oogoo05Eoo`8000Aoo`8004]oo`8008Ioo`8002Uoo`0047oo
00<007ooOol0EGoo0P00fgoo0P009goo000@Ool00`00Oomoo`1@Ool2003POol2000WOol0011oo`80
055oo`800=moo`8002Qoo`0047oo00<007ooOol0B7oo0P0067oo0P00`goo0P0027oo0P00:7oo000@
Ool00`00Oomoo`18Ool2000DOol20002Ool20033Ool2000bOol0011oo`03001oogoo03eoo`8001mo
o`800<eoo`8002aoo`0047oo00<007ooOol0?Goo0P00kWoo0P00;7oo000@Ool00`00Oomoo`0mOol2
003oOol2Ool2000IOol0011oo`03001oogoo03eoo`800:Yoo`80041oo`8001=oo`8001Uoo`0047oo
00<007ooOol0jGoo0P00@7oo0P00;Woo000@Ool00`00Oomoo`3oOomLOol0011oo`03001oogoo0?mo
oeaoo`0047oo00<007ooOol0ogooG7oo000@Ool00`00Oomoo`3oOomLOol0011oo`800?mooeeoo`00
47oo00<007ooOol0ogooG7oo000@Ool00`00Oomoo`3oOomLOol0011oo`03001oogoo0?mooeaoo`00
47oo00<007ooOol0ogooG7oo000@Ool00`00Oomoo`3oOomLOol0011oo`03001oogoo0?mooeaoo`00
47oo00<007ooOol0hWoo0P00Mgoo000@Ool00`00Oomoo`1GOol20029Ool2001gOol0011oo`03001o
ogoo05Moo`800?moo`=oo`0047oo00<007ooOol0ogooG7oo000@Ool2003oOomMOol0011oo`03001o
ogoo0>9oo`8007Moo`0047oo00<007ooOol0hWoo0P00Mgoo000@Ool00`00Oomoo`3oOomLOol0011o
o`03001oogoo0>9oo`8007Moo`0047oo00<007ooOol0hWoo0P00Mgoo000@Ool00`00Oomoo`3oOomL
Ool0011oo`03001oogoo0?mooeaoo`0047oo00<007ooOol0ogooG7oo000@Ool00`00Oomoo`3oOomL
Ool0009oo`<000=oo`8000Ioo`03001oogoo0?mooeaoo`000goo00D007ooOomoo`00009oo`03001o
ogoo00=oo`03001oogoo0?mooeaoo`0000=oo`0000000P000Woo00@007ooOol000Eoo`<00?mooeao
o`0000Aoo`00Ool000=oo`04001oogoo0005Ool00`00Oomoo`3oOomLOol00004Ool007oo0003Ool0
1000Oomoo`001Goo00<007ooOol0ogooG7oo0002Ool20004Ool20006Ool00`00Oomoo`3oOomLOol0
011oo`03001oogoo0?mooeaoo`0047oo00<007ooOol0ogooG7oo000@Ool00`00Oomoo`3oOomLOol0
011oo`03001oogoo0?mooeaoo`0047oo00<007ooOol0ogooG7oo000@Ool00`00Oomoo`3oOomLOol0
011oo`03001oogoo0?mooeaoo`0047oo0P00Ngoo0P00ggoo000@Ool00`00Oomoo`1jOol2003OOol0
011oo`03001oogoo0:]oo`800:ioo`0047oo00<007ooOol0Zgoo0P00[Woo000@Ool00`00Oomoo`2R
Ool2002gOol0011oo`03001oogoo07aoo`8002Aoo`800;Moo`0047oo00<007ooOol0O7oo0P00gGoo
000@Ool00`00Oomoo`2UOol2002dOol0011oo`03001oogoo0:Eoo`800;Aoo`0047oo00<007ooOol0
ogooG7oo000@Ool00`00Oomoo`3oOomLOol0011oo`800?mooeeoo`0047oo00<007ooOol0ogooG7oo
000@Ool00`00Oomoo`3oOomLOol0011oo`03001oogoo0?mooeaoo`0047oo00<007ooOol0XWoo0P00
]goo000@Ool00`00Oomoo`2QOol3002gOol0011oo`03001oogoo0:5oo`800;Qoo`0047oo00<007oo
Ool0ogooG7oo000@Ool00`00Oomoo`3oOomLOol0011oo`03001oogoo0?mooeaoo`0047oo00<007oo
Ool0ogooG7oo000@Ool00`00Oomoo`3oOomLOol0011oo`800?mooeeoo`0047oo00<007ooOol0ogoo
G7oo000@Ool00`00Oomoo`3oOomLOol0011oo`03001oogoo0;]oo`8009ioo`0047oo00<007ooOol0
^goo0P00WWoo000@Ool00`00Oomoo`30Ool2002IOol0011oo`03001oogoo0<1oo`8009Uoo`0047oo
00<007ooOol0ogooG7oo000@Ool00`00Oomoo`3oOomLOol0011oo`03001oogoo0?mooeaoo`0047oo
00<007ooOol0ogooG7oo000@Ool2003oOomMOol0011oo`03001oogoo07]oo`8000Ioo`800=Ioo`00
47oo00<007ooOol0Ngoo0P0017oo1000eWoo000@Ool00`00Oomoo`21Ool2003HOol0011oo`03001o
ogoo0?mooeaoo`0047oo00<007ooOol0MGoo0P00i7oo000@Ool00`00Oomoo`1eOol2003TOol0011o
o`03001oogoo0?mooeaoo`0047oo00<007ooOol0ogooG7oo000@Ool00`00Oomoo`2nOol2002KOol0
0004Ool000000004Ool20006Ool00`00Oomoo`2nOol20009Ool2002@Ool000Aoo`04001oogoo0002
Ool00`00Oomoo`03Ool00`00Oomoo`39Ool2002@Ool000Aoo`04001oogoo0002Ool00`00Oomoo`03
Ool3003oOomLOol00004Ool000000003Ool01000Oomoo`001Goo00<007ooOol0ogooG7oo00000goo
001oo`04Ool01000Oomoo`001Goo00<007ooOol0`Woo0P00Ugoo00000goo000000020003Ool20006
Ool00`00Oomoo`32Ool2002GOol0011oo`03001oogoo0?mooeaoo`0047oo00<007ooOol0ogooG7oo
000@Ool00`00Oomoo`3oOomLOol0011oo`03001oogoo0?mooeaoo`0047oo00<007ooOol0ogooG7oo
000@Ool00`00Oomoo`3oOomLOol0011oo`03001oogoo0?mooeaoo`0047oo0P00fGoo0P00PGoo000@
Ool00`00Oomoo`3HOol20021Ool0011oo`03001oogoo0?mooeaoo`0047oo00<007ooOol0ogooG7oo
000@Ool00`00Oomoo`3oOomLOol0011oo`03001oogoo0?mooeaoo`0047oo00<007ooOol0ogooG7oo
000@Ool00`00Oomoo`3oOomLOol0011oo`03001oogoo0?mooeaoo`0047oo00<007ooOol0ogooG7oo
000@Ool00`00Oomoo`3oOomLOol0011oo`800?mooeeoo`0047oo00<007ooOol0ogooG7oo000@Ool0
0`00Oomoo`3oOomLOol0011oo`03001oogoo0?mooeaoo`0047oo00<007ooOol0ogooG7oo000@Ool0
0`00Oomoo`3oOomLOol0011oo`03001oogoo0?mooeaoo`0047oo00<007ooOol0d7oo0P00RGoo000@
Ool00`00Oomoo`3@Ool20029Ool0011oo`03001oogoo0?mooeaoo`0047oo00<007ooOol0eGoo0P00
Q7oo000@Ool00`00Oomoo`3EOol20024Ool0011oo`800?mooeeoo`0047oo00<007ooOol0ogooG7oo
000@Ool00`00Oomoo`2lOol2002MOol0011oo`03001oogoo0;Moo`8000=oo`8009eoo`0047oo00<0
07ooOol0]goo0P00XWoo000@Ool00`00Oomoo`3oOomLOol0011oo`03001oogoo0;9oo`800:Moo`00
47oo00<007ooOol0/Woo0P00Ygoo000@Ool00`00Oomoo`3oOomLOol0011oo`03001oogoo0>Uoo`80
071oo`0047oo00<007ooOol0^7oo0P00;goo0P00L7oo000@Ool2002iOol4002OOol0011oo`03001o
ogoo09Aoo`8002Aoo`8009moo`0047oo00<007ooOol0U7oo0P00aGoo000@Ool00`00Oomoo`3oOomL
Ool0011oo`03001oogoo0:eoo`800:aoo`0047oo00<007ooOol0[Goo0P00[7oo000@Ool00`00Oomo
o`3oOomLOol0011oo`03001oogoo0?mooeaoo`0047oo00<007ooOol0f7oo0P00PGoo000@Ool00`00
Oomoo`3HOol20021Ool0009oo`8000Aoo`8000Ioo`03001oogoo0?mooeaoo`0000Eoo`00Oomoo`00
009oo`04001oogoo0005Ool00`00Oomoo`3oOomLOol00005Ool007ooOol00002Ool01000Oomoo`00
1Goo0`00ogooG7oo000017oo000000000goo00@007ooOol00?moofAoo`0000=oo`00Ool017oo00@0
07ooOol00?moofAoo`000Woo0`000goo0P00ogooIGoo003oOom_Ool00?moofmoo`00ogooKgoo0000
\
\>"],
  ImageRangeCache->{{{0, 365}, {365, 0}} -> {-2.85118, -2.71988, 0.175073, 
  0.175073}}]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
WindowSize->{1084, 721},
WindowMargins->{{-2, Automatic}, {Automatic, 1}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00`0001804P000000_02@?o/onh3109BI085:0?l0@00005X0FP000003[0;@001
0000I00100000@0000000BL?0040000000000000000000000000000000000?nL
ojH?50^J00P100000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 36, 0, 36, "SubsectionIcon"],
Cell[1778, 53, 551, 20, 24, "Text"],
Cell[2332, 75, 694, 13, 56, "Text"],
Cell[3029, 90, 445, 9, 36, "Text"],
Cell[3477, 101, 220, 4, 58, "Input"],
Cell[3700, 107, 395, 7, 61, "Input"],

Cell[CellGroupData[{
Cell[4120, 118, 966, 20, 154, "Input"],
Cell[5089, 140, 258, 5, 20, "Print"],
Cell[5350, 147, 258, 5, 20, "Print"],
Cell[5611, 154, 258, 5, 20, "Print"],
Cell[5872, 161, 257, 5, 20, "Print"],
Cell[6132, 168, 258, 5, 20, "Print"],
Cell[6393, 175, 258, 5, 20, "Print"],
Cell[6654, 182, 258, 5, 20, "Print"],
Cell[6915, 189, 258, 5, 20, "Print"],
Cell[7176, 196, 258, 5, 20, "Print"],
Cell[7437, 203, 258, 5, 20, "Print"],
Cell[7698, 210, 258, 5, 20, "Print"],
Cell[7959, 217, 257, 5, 20, "Print"],
Cell[8219, 224, 258, 5, 20, "Print"],
Cell[8480, 231, 258, 5, 20, "Print"],
Cell[8741, 238, 258, 5, 20, "Print"],
Cell[9002, 245, 258, 5, 20, "Print"],
Cell[9263, 252, 258, 5, 20, "Print"],
Cell[9524, 259, 258, 5, 20, "Print"],
Cell[9785, 266, 258, 5, 20, "Print"],
Cell[10046, 273, 257, 5, 20, "Print"],
Cell[10306, 280, 258, 5, 20, "Print"],
Cell[10567, 287, 258, 5, 20, "Print"],
Cell[10828, 294, 258, 5, 20, "Print"],
Cell[11089, 301, 258, 5, 20, "Print"],
Cell[11350, 308, 258, 5, 20, "Print"],
Cell[11611, 315, 257, 5, 20, "Print"],
Cell[11871, 322, 257, 5, 20, "Print"],
Cell[12131, 329, 258, 5, 20, "Print"],
Cell[12392, 336, 258, 5, 20, "Print"],
Cell[12653, 343, 258, 5, 20, "Print"],
Cell[12914, 350, 258, 5, 20, "Print"],
Cell[13175, 357, 257, 5, 20, "Print"],
Cell[13435, 364, 258, 5, 20, "Print"],
Cell[13696, 371, 258, 5, 20, "Print"],
Cell[13957, 378, 258, 5, 20, "Print"],
Cell[14218, 385, 258, 5, 20, "Print"],
Cell[14479, 392, 258, 5, 20, "Print"],
Cell[14740, 399, 258, 5, 20, "Print"],
Cell[15001, 406, 258, 5, 20, "Print"],
Cell[15262, 413, 258, 5, 20, "Print"],
Cell[15523, 420, 258, 5, 20, "Print"],
Cell[15784, 427, 257, 5, 20, "Print"],
Cell[16044, 434, 258, 5, 20, "Print"],
Cell[16305, 441, 258, 5, 20, "Print"],
Cell[16566, 448, 257, 5, 20, "Print"],
Cell[16826, 455, 258, 5, 20, "Print"],
Cell[17087, 462, 258, 5, 20, "Print"],
Cell[17348, 469, 258, 5, 20, "Print"],
Cell[17609, 476, 258, 5, 20, "Print"],
Cell[17870, 483, 258, 5, 20, "Print"],
Cell[18131, 490, 258, 5, 20, "Print"],
Cell[18392, 497, 258, 5, 20, "Print"],
Cell[18653, 504, 258, 5, 20, "Print"],
Cell[18914, 511, 258, 5, 20, "Print"],
Cell[19175, 518, 258, 5, 20, "Print"],
Cell[19436, 525, 258, 5, 20, "Print"],
Cell[19697, 532, 258, 5, 20, "Print"],
Cell[19958, 539, 257, 5, 20, "Print"],
Cell[20218, 546, 257, 5, 20, "Print"],
Cell[20478, 553, 258, 5, 20, "Print"],
Cell[20739, 560, 95, 2, 20, "Output"]
}, Closed]],
Cell[20849, 565, 602, 12, 58, "Text"],
Cell[21454, 579, 85, 2, 26, "Input"],

Cell[CellGroupData[{
Cell[21564, 585, 387, 7, 79, "Input"],
Cell[21954, 594, 24942, 601, 184, 4767, 347, "GraphicsData", "PostScript", \
"Graphics"],
Cell[46899, 1197, 135, 3, 20, "Output"]
}, Open  ]],
Cell[47049, 1203, 51, 0, 22, "Text"],

Cell[CellGroupData[{
Cell[47125, 1207, 157, 3, 42, "Input"],
Cell[47285, 1212, 20945, 631, 372, 6589, 448, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

