(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      7242,        194]*)
(*NotebookOutlinePosition[      8125,        222]*)
(*  CellTagsIndexPosition[      8081,        218]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Deriving recursions for the moment generating function", \
"SubsubsectionIcon"],

Cell[TextData[{
  "\tUnder the infinite-sites model, there is a simple recursion for the \
moment generating function of the number of mutations along each branch of a \
rooted genealogy.  This can be used to find the m.g.f. for a fairly large \
tree.  The moments of functions of the numbers of mutations can then be found \
quite easily.  The recursion gives the unconditional probability, and so the \
probability of the tree topology, summing over all possible mutational \
configurations, is also readily found.  The expression can also be regarded \
as a generating function for the distribution of coalescence times.  The \
difficulty, however, is in recovering the probability of some particular \
mutational configuration.  With J mutations, this involves J derivatives, and \
leads to a sum over all possible orderings of events: that may be just as \
hard to calculate as the ",
  ButtonBox["Griffiths & Tavare",
    ButtonData:>{"Griffiths-Tavare algorithm", None},
    ButtonStyle->"AddOnsLink"],
  " recursion."
}], "Text"],

Cell[TextData[{
  "Let the probability of finding ",
  Cell[BoxData[
      \(TraditionalForm\`j\_i\)]],
  "mutations in the branch leading down to node ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " be ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(P\)\([\)\(j\+_\)\)\)]],
  "]; the moment generating function for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(P\)\([\)\(j\+_\)\)\)]],
  "] is defined as ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(P\&~[\[Omega]\+_]\),
            "TraditionalForm"], 
          "=", \(\[Sum]\+\(j = 0\)\%\[Infinity]\[Product]\+k\( \[Omega]\_k\%j\
\_k\) P[j\+_]\)}], TraditionalForm]]],
  ".  Tracing back from the current ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " leaves, the time to the first coalescence is exponentially distributed \
with rate ",
  Cell[BoxData[
      RowBox[{"(", GridBox[{
            {"n"},
            {"2"}
            }], ")"}]]],
  " (time being scaled to 2N generations).  The coalescence is equally likely \
to occur between any of the ",
  Cell[BoxData[
      RowBox[{"(", GridBox[{
            {"n"},
            {"2"}
            }], ")"}]]],
  "pairs of lineages.  For each of the pairs of leaves which might actually \
coalesce first, we therefore have a probability ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"Exp", "[", 
          RowBox[{
            RowBox[{"-", 
              RowBox[{"(", GridBox[{
                    {"n"},
                    {"2"}
                    }], ")"}]}], "t"}], "]"}], \(\[DifferentialD]t\)}]]],
  ".  The number of mutations along each of the ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "  lineages during time ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " is Poisson distributed with expectation ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Theta]\[VeryThinSpace]t\)\/2\)]],
  ".  Integrating over ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  "  gives a recursion for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(P\)\([\)\(j\+_\)\)\)]],
  "].  For example, coalescence of lineages 1 and 2 gives a contribution:"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{\(P\_n[j\_1, j\_2, j\_3, \[Ellipsis]]\), "=", 
          RowBox[{\(\(1\/\[Lambda]\_n\) \(\[Sum]\+\(i\_m + k\_m = j\_m\ \n
                  \tfor\ m \[GreaterEqual] 3\)\(\(\((j\_1 + j\_2 + 
                            i\_3 + \[Ellipsis])\)!\)\/\((\(j\_1!\) \(j\_2!\) \
\(i\_3!\) \[Ellipsis])\)\) \(\[Phi]\_n\%\((j\_1 + j\_2 + 
                          i\_3 + \[Ellipsis])\)\) 
                  P\_\(n - 1\)[j\_12, 
                    k\_3, \[Ellipsis]]\ \ where\ \[Lambda]\_n\)\), "=", 
            RowBox[{\(\(n\[VeryThinSpace]\[Theta]\)\/2\), "+", 
              RowBox[{"(", GridBox[{
                    {"n"},
                    {"2"}
                    }], ")"}]}]}]}], ",", 
        " ", \(\[Phi]\_n = \(\[Theta]\/\(2  \[Lambda]\_n\) = \[Theta]\/\(n \
\((\[Theta] + n - 1)\)\)\)\)}], TextForm]], "NumberedEquation"],

Cell[TextData[{
  "Here, the probability involves ",
  Cell[BoxData[
      \(TextForm\`\(\(P\_\(n - 1\)[j\_12, j\_3, \[Ellipsis]]\)\(\ \)\)\)]],
  ", which is the probability of a genealogy with ",
  Cell[BoxData[
      \(TraditionalForm\`n - 1\)]],
  " leaves (leaves 1 & 2 being replaced by node {1,2}). This recursion is \
cumbersome, because it involves a sum over all the possible numbers of \
mutations which occurred in time ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ", rather than at some earlier time (i.e. over all ",
  Cell[BoxData[
      \(TraditionalForm\`i\_m + k\_m = j\_m\)]],
  ").  However, transforming to generating functions separates the recursion \
into a product:"
}], "Text"],

Cell[BoxData[
    \(TextForm\`P\&~\_n[\[Omega]\_1, \[Omega]\_2, \[Omega]\_3, \[Ellipsis]] = 
      P\&~\_\(n - 1\)[\[Omega]\_12, \[Omega]\_3, \
\[Ellipsis]]\/\(\(\[Lambda]\_n\) \((1 - \(\[Phi]\_n\) \((\[Omega]\_1 + \
\[Omega]\_2 + \(\[Omega]\_3\) \[Ellipsis])\))\)\)\)], "NumberedEquation"],

Cell[TextData[{
  "This gives the contribution from the first coalescence being between 1 & \
2; there may be additional terms if other coalescences are possible.  The sum \
of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_\(\(m\)\(\ \ \)\)\)]],
  "in the denominator is only over the \[Omega] corresponding to the leaves."
}], "Text"]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
WindowSize->{935, 671},
WindowMargins->{{72, Automatic}, {Automatic, 12}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oQon@3:`8g0dL5N`?P0080001804P000000]P2:001
0000I00000400`<30?l00BL?00400@0000000000000006P801T1T00000000000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 85, 1, 24, "SubsubsectionIcon"],
Cell[1827, 54, 1037, 17, 79, "Text"],
Cell[2867, 73, 2118, 65, 105, "Text"],
Cell[4988, 140, 885, 17, 64, "NumberedEquation"],
Cell[5876, 159, 711, 17, 50, "Text"],
Cell[6590, 178, 290, 4, 50, "NumberedEquation"],
Cell[6883, 184, 343, 7, 36, "Text"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

