(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      8412,        241]*)
(*NotebookOutlinePosition[      9294,        269]*)
(*  CellTagsIndexPosition[      9250,        265]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Deriving the probability", "SubsectionIcon"],

Cell[TextData[{
  "\tThe moment generating function can be calculated easily.  However, \
recovering the probability of a particular configuration of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(k\)\(\ \)\)\)]],
  "mutations is difficult, because it involves differentiating ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " times.  A simple recursion for the probability itself can be given, as a \
sum over multinomial partitions of the mutations.  This is still intractable, \
but lends itself to Monte Carlo estimation."
}], "Text"],

Cell["\<\
\tThe method is similar to Griffiths and Tavare's.  However, \
Griffiths and Tavare us a recursion back to the previous event, which may be \
a coalescence or a mutation.  I use a recursion back to the previous \
coalescence.  This should be more efficient with large numbers of mutations, \
though the gain may be slight in practice.\
\>", "Text"],

Cell[TextData[{
  "\tFor a given order of coalescence events, each branch is present during a \
certain time interval, defined by the number of extant lineages. This \
ordering can be described by a matrix ",
  Cell[BoxData[
      \(TraditionalForm\`S\_\(b, i\)\)]],
  " whose elements show whether a branch ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  " is present while there are ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " lineages present.  For example:"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {" ", "1", "2", "3", "4"},
            {"a", "0", "0", "0", "1"},
            {"b", "0", "0", "0", "1"},
            {"c", "0", "0", "1", "1"},
            {"d", "0", "0", "1", "1"},
            {"ab", "0", "1", "1", "0"},
            {"cd", "0", "1", "0", "0"},
            {"abcd", "1", "0", "0", "0"}
            }], ")"}], TextForm]], "Text"],

Cell[TextData[{
  "Here, the last row shows that the root node ",
  StyleBox["abcd",
    FontSlant->"Italic"],
  " is present only when there is a single lineage; the four leaves are \
present while there are 4 lineages. The intermediate columns show that ",
  Cell[BoxData[
      \(TraditionalForm\`{a, b}\)]],
  " coalesce before ",
  Cell[BoxData[
      \(TraditionalForm\`{c, d}\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\tFor a given number of mutations on each branch, ",
  Cell[BoxData[
      \(TraditionalForm\`\(J\_b, \ there\ are\ \)\)]],
  "many possible partitions ",
  Cell[BoxData[
      \(TraditionalForm\`j\_\(b, i\)\)]],
  "of mutations along each of the time intervals ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  ".  Interval ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " lasts for a time which is exponentially distributed with rate ",
  Cell[BoxData[
      RowBox[{"(", GridBox[{
            {"i"},
            {"2"}
            }], ")"}]]],
  " ; during this time, the total number of mutations is Poisson distributed \
with rate ",
  Cell[BoxData[
      \(TraditionalForm\`i\[VeryThinSpace]\[Theta]/2\)]],
  ".  Integrating over the length of the interval, one can write the \
probability as a sum over partitions ",
  Cell[BoxData[
      \(TraditionalForm\`j\_\(b, i\)\)]],
  ":"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
        \(\(1\/\(\[Product]\+\(i = 2\)\%n \[Lambda]\_i\)\) 
            \(\[Sum]\+\(j\_\(b, i\)\)\[Product]\+\(i = 2\)\%n
                  \(\( \[Phi]\_i\%J\&^\_i\) 
                      \(\(\(J\_i\)\&^\) ! \)\)\/\(\[Product]\+b\( j\_\(b, i\)!
                        \)\)\ \ \ \ \ where\ \[Lambda]\_i\)\), "=", 
          RowBox[{\(\(i\[VeryThinSpace]\[Theta]\)\/2\), "+", 
            RowBox[{"(", GridBox[{
                  {"i"},
                  {"2"}
                  }], ")"}]}]}], ",", " ", 
        \(\[Phi]\_i = \[Theta]\/\(i \((\[Theta] + i - 1)\)\)\), ",", " ", 
        \(\(J\_i\)\&^ = \[Sum]\+b j\_\(b, i\)\), ",", " ", 
        \(J\_b = \[Sum]\+\(i = 2\)\%n j\_\(b, i\)\)}], TextForm]], 
  "NumberedEquation"],

Cell[TextData[{
  "This sum is intractable for large nmbers of mutations, because there are \
so many partitions.  However, it can be estimated by taking multinomial \
samples of possible partitions.  These have probability ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", GridBox[{
              {\(J\_b\)},
              {\(j\_\(b, i\)\)}
              }], ")"}], \(\((\[Phi]\_i\/\[Phi]\_b)\)\^j\_\(b, i\)\)}]]],
  "where ",
  Cell[BoxData[
      \(TraditionalForm
      \`\[Phi]\_b = \[Sum]\+\(i = 2\)\%n\( S\_\(b, i\)\) \[Phi]\_i\)]],
  ".  Hence, an estimate of the probability can be found from the expectation \
of:"
}], "Text"],

Cell[BoxData[
    \(TextForm
    \`\(1\/\(\[Product]\+\(i = 2\)\%n \[Lambda]\_i\)\) 
      \(\[Product]\+b\( \[Phi]\_b\%J\_b\/\(J\_b!\)\) 
          \(\[Product]\+\(i = 2\)\%n\(\( J\_i\)\&^!\)\)\)\)], 
  "NumberedEquation"],

Cell["\<\
Note that only the last term, involving a product of factorials of \
the number of mutations extant in each interval, needs to be calculated for \
each replicate.  The other factors are constant.\
\>", "Text"],

Cell[TextData[{
  "\tThe partitions can be sampled using an arbitrary probability, ",
  Cell[BoxData[
      \(\(\[Phi]\_i\%*\)\)]],
  ", which need have no relation with \[Theta]. If this is done, then each \
partition can return a ",
  StyleBox["symbolic",
    FontSlant->"Italic"],
  " function of \[Theta], speeding computations.  We now take the expectation \
of:"
}], "Text"],

Cell[BoxData[
    \(TextForm
    \`\(1\/\(\[Product]\+\(i = 2\)\%n \[Lambda]\_i\)\) 
      \(\[Product]\+b\(\( \[Phi]\_b\%*\)\^J\_b\/\(J\_b!\)\) 
          \(\[Product]\+\(i = 2\)\%n
              \(\((\[Phi]\_i\/\(\[Phi]\_i\%*\))\)\^J\&^\_i\) 
              \(\(\(J\_i\)\&^\) ! \)\)\)\)], "NumberedEquation"],

Cell[TextData[{
  "The expectation equals the true probability for arbitrary ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\_i\%*\)\)]],
  ".  However, an appropriate choice of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\_i\%*\)\)]],
  " will minimise the  avriance of the estimate."
}], "Text"],

Cell["\<\
\tThis formula can be recovered from the moment generating function \
by successive differentiation.  Below, I do a quick check between the exact \
probability, calculated from the m.g.f., and the stochastic estimate.  \
However, a more thorough check is needed.\
\>", "Text"],

Cell["\<\
\tTo solve the problem in full, the estimate must be summed over \
orderings.  This should be done by choosing orderings at random, in \
proportion to their probability. (It is inefficient to choose them with \
equial weight - see example below).\
\>", "Text"]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{520, 653},
WindowMargins->{{Automatic, 0}, {Automatic, -1}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00`0001804P000000_02@?o/onh3109BI085:0?l0@00005X0FP000003[0;@001
0000I00100000@0000000BL?0040000000000000000000000000000000000?nL
ojH?50^J00P100000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 50, 0, 36, "SubsectionIcon"],
Cell[1792, 53, 544, 11, 64, "Text"],
Cell[2339, 66, 358, 6, 64, "Text"],
Cell[2700, 74, 489, 13, 50, "Text"],
Cell[3192, 89, 414, 11, 133, "Text"],
Cell[3609, 102, 405, 12, 52, "Text"],
Cell[4017, 116, 926, 28, 77, "Text"],
Cell[4946, 146, 788, 17, 104, "NumberedEquation"],
Cell[5737, 165, 641, 16, 102, "Text"],
Cell[6381, 183, 223, 5, 60, "NumberedEquation"],
Cell[6607, 190, 219, 4, 36, "Text"],
Cell[6829, 196, 380, 10, 52, "Text"],
Cell[7212, 208, 309, 6, 61, "NumberedEquation"],
Cell[7524, 216, 310, 8, 36, "Text"],
Cell[7837, 226, 286, 5, 50, "Text"],
Cell[8126, 233, 270, 5, 50, "Text"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

