(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      8091,        198]*)
(*NotebookOutlinePosition[      8975,        226]*)
(*  CellTagsIndexPosition[      8931,        222]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Introduction", "SubsectionIcon"],

Cell[TextData[{
  "\tThis package includes functions for finding genotype frequencies in \
models of admixture; representing multilocus genotype frequencies in terms of \
a tractable number of linkage disequilibria; and estimating these \
disequilibria by maximum likelihood.   Methods for estimating and \
interpreting pairwise associations are well worked-out, both for \
nuclear-nuclear and nuclear-cytoplasmic associations (Hill",
  Cell[BoxData[
      FormBox[
        ButtonBox[\(\(\ \)\(1974  a\)\),
          ButtonData:>{"References", "Hill 1974a"},
          ButtonStyle->"AddOnsLink"], TraditionalForm]]],
  "; Asmussen et al.",
  Cell[BoxData[
      FormBox[
        ButtonBox[\(\(\ \)\(1987\)\),
          ButtonData:>{"References", "Asmussen et al 1987"},
          ButtonStyle->"AddOnsLink"], TraditionalForm]]],
  ").  However, data are usually available from several marker loci: here, I \
set out methods for combining data across loci, paying particular attention \
to the case where there are associations both between genes from the same \
gamete, and inherited from different parents.  The method is explained in \
full in Barton (",
  ButtonBox["2000",
    ButtonData:>{"References", "Barton 2000"},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"2000"],
  ")."
}], "Text"],

Cell["\<\
\tThere are three key difficulties.  First, estimates of \
associations between different pairs of loci are not independent of \
eachother, especially when associations are strong. Second, we do not usually \
wish to estimate individual associations; in any case, there are far too many \
such associations with even a few loci.  Rather, we wish to find some \
composite measure which gives information about the process responsible for \
generating linkage disequilibrium.  (For example, random drift and \
recombination will generate a distribution whose parameters might be \
estimated from the variance in pairwise disequilibrium).  Third, unless \
samples are of zygotes freshly generated by random mating, there will be \
associations between genes from different parents; with diploids, these \
cannot be distinguished from associations between genes derived from the same \
gamete.\
\>", "Text"],

Cell[TextData[{
  "\tMost of the literature on estimating linkage disequilibrium has been \
concerned with the third problem, of resolving genotypes that are confounded \
in diploid data (for example, using the EM algorithm; Hill,",
  Cell[BoxData[
      FormBox[
        ButtonBox[\(\(\ \)\(1974  a\)\),
          ButtonData:>{"References", "Hill 1974a"},
          ButtonStyle->"AddOnsLink"], TraditionalForm]]],
  ", Dempster et al.",
  Cell[BoxData[
      FormBox[
        ButtonBox[\(\(\ \)\(1977\)\),
          ButtonData:>{"References", "Dempster et al 1977"},
          ButtonStyle->"AddOnsLink"], TraditionalForm]]],
  "; Long et al.",
  Cell[BoxData[
      FormBox[
        ButtonBox[\(\(\ \)\(1995\)\),
          ButtonData:>{"References", "Long et al 1995"},
          ButtonStyle->"AddOnsLink"], TraditionalForm]]],
  "; Slatkin and Excoffier",
  Cell[BoxData[
      FormBox[
        ButtonBox[\(\(\ \)\(1996\)\),
          ButtonData:>{"References", "Slatkin & Excoffier 1996"},
          ButtonStyle->"AddOnsLink"], TraditionalForm]]],
  ").  There is also a good understanding of the distribution of associations \
generated by random drift within a single population (Hill",
  Cell[BoxData[
      FormBox[
        ButtonBox[\(\(\ \)\(1974  b\)\),
          ButtonData:>{"References", "Hill 1974b"},
          ButtonStyle->"AddOnsLink"], TraditionalForm]]],
  ",",
  Cell[BoxData[
      FormBox[
        ButtonBox["c",
          ButtonData:>{"References", "Hill 1974c"},
          ButtonStyle->"AddOnsLink",
          ButtonNote->"c"], TraditionalForm]]],
  "). Here, we are concerned with associations generated by the mixing of \
populations.  This raises particular difficulties, since there are often \
strong associations, both within and between genomes; it is also particularly \
simple, in that admixture models make straightforward predictions as to the \
structure of associations in a population.  "
}], "Text"],

Cell["\<\
\tThe crucial requirement is for some model which specifies the \
frequencies of genotypes in terms of a reasonably small number of parameters. \
 Given such a model, the parameters can be estimated by maximum likelihood.   \
Here, I show that many kinds of admixture lead to a model with a simple \
structure, and show how the parameters of this model can be estimated by \
maximum likelihood.  \
\>", "Text"],

Cell["\<\
Two alleles vs. multiple alleles: relation with \
Multilocus`DataManipulation`\
\>", "SubsubsectionIcon"],

Cell["\<\
Multilocus`EstimatingD` assumes two alleles per locus, and \
represents haploid genotypes in the form {0,0,1,\[Ellipsis]}.  This \
assumption is made because the method assumes admixture between two source \
populations, and because it is computationally more efficient.  It would not \
be difficult to allow for more alleles, provided each could be assigned to \
one of two sources.  However, a more general scheme, allowing for multiple \
sources, would become cumbersome: a representation in terms of a small number \
of moments would not be possible.\
\>", "Text"],

Cell[TextData[{
  "The package ",
  Cell[BoxData[
      FormBox[
        ButtonBox["Multilocus`DataManipulation`",
          ButtonData:>{"Notation for genetic data", None},
          ButtonStyle->"AddOnsLink",
          ButtonNote->"Multilocus`DataManipulation`"], TraditionalForm]]],
  " does allow for multiple alleles and missing data; the function ",
  ButtonBox["ConvertData[]",
    ButtonData:>{"Converting a dataset", "ConvertData"},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"ConvertData[]"],
  " converts from the special biallelic form {0,0,1,\[Ellipsis]} to the \
general form.  Some functions in the two packages are similar: for example, \
",
  ButtonBox["PossibleGenotypes[]",
    ButtonData:>{"Diploid genotypes", "PossibleGenotypes"},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"PossibleGenotypes[]"],
  " and ",
  ButtonBox["PossibleDiploidGenotypes[]",
    ButtonData:>{"Full diploid genotypes", "PossibleDiploidGenotypes"},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"PossibleDiploidGenotypes[]"],
  ".  "
}], "Text"]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
WindowSize->{520, 626},
WindowMargins->{{245, Automatic}, {Automatic, 46}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00h0001804P000000b02<?oaonl3>@91H`85N0?N0@00005X0FP000003j0:l001
0@00I00100000@0200000BL?00400000000000000000010000000000000@0?ne
oj/@7@]500P1000000000000000001T1\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 38, 0, 36, "SubsectionIcon"],
Cell[1758, 51, 1297, 28, 121, "Text"],
Cell[3058, 81, 913, 14, 134, "Text"],
Cell[3974, 97, 1938, 46, 120, "Text"],
Cell[5915, 145, 420, 7, 78, "Text"],
Cell[6338, 154, 115, 3, 24, "SubsubsectionIcon"],
Cell[6456, 159, 578, 9, 92, "Text"],
Cell[7037, 170, 1050, 26, 67, "Text"]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

