(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    163382,       3733]*)
(*NotebookOutlinePosition[    235045,       6317]*)
(*  CellTagsIndexPosition[    234944,       6310]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Natural and sexual selection on haploids", "SubsectionIcon",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  "This example was suggested by Maria Servedio; it illustrates how selection \
at different stages can be combined, and how complicated algebraic \
expressions can be handled more or less safely.  Epistatic viability \
selection acts on two loci ",
  Cell[BoxData[
      \(TraditionalForm\`\((n, \ m\)\)]],
  "), favouring combinations ",
  Cell[BoxData[
      \(TraditionalForm\`X\_n, \ X\_m = 0, \ 0\ or\ 1, \ 1. \)]],
  "  Female preference for the fit combinations at these two loci depends on \
a third ",
  Cell[BoxData[
      \(TraditionalForm\`locus, 
      p : \ females\ with\ X\_p = 1\ prefer\ X\_n, \ X\_m = 1, \ 1\)]],
  " whereas females with ",
  Cell[BoxData[
      \(TraditionalForm\`X\_p = 0\)]],
  " prefer ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(X\_n\)\(,\)\(\ \)\(X\_m = 
        0\)\(,\)\(\ \)\(0.\)\(\ \ \)\)\)]],
  "The model is relevant to reinforcement of mate preferences in a hybrid \
population."
}], "Text",
  CellTags->"Servedio"],

Cell["\<\
Selection acts at two stages, so that though each stage is \
represented by a fairly simple expression, there are a very large number of \
terms if the expressions are combined.  However, most of these terms are \
insignificant when selection and preference are weak.  \
\>", "Text"],

Cell[TextData[{
  "Note:",
  StyleBox["  At the beginning of each generation, associations are \
independent of the sex of the gamete.  ",
    FontWeight->"Plain"]
}], "Text",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  FontWeight->"Bold"],

Cell["This reads in the package:", "MathCaption",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(<< Multilocus`Multilocus`;\)\)], "Input",
  CellLabel->"In[1]:=",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell["Stages in the life cycle", "SubsubsectionIcon",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell["\<\
Viability selection on haploids is kept separate from sexual \
selection, to simplify the algebra.\
\>", "Text"],

Cell[BoxData[{
    \(\(DefineContext[\[GothicCapitalG], {Sex}];\)\), "\[IndentingNewLine]", 
    \(\(DefineContext[\[GothicCapitalG]1, {Sex}];\)\), "\[IndentingNewLine]", \

    \(\(DefineContext[\[GothicCapitalG]2, {Sex}];\)\), "\[IndentingNewLine]", \

    \(\(DefineContext[\[GothicCapitalZ], {Sex, SexOfOrigin}];\)\), "\n", 
    \(\(DefineContext[\[GothicCapitalA], {Sex, SexOfOrigin}];\)\), "\n", 
    \(\(DefineContext[\(\[GothicCapitalG]\^*\), {\ Sex}];\)\)}], "Input",
  CellLabel->"In[2]:=",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["Viability selection acts between haploid stages \[GothicCapitalG] \
and \[GothicCapitalG]1. Nonrandom union of haploids occurs between haploid \
stage \[GothicCapitalG]2 and the diploid adult stage \[GothicCapitalA].  As \
in ",
    FontWeight->"Plain"],
  "Barton and Turelli, ",
  ButtonBox["1991",
    ButtonData:>{"Multilocus references", "Barton and Turelli 1991"},
    ButtonStyle->"AddOnsLink"],
  StyleBox[", this is acheived by supposing ",
    FontWeight->"Plain"],
  StyleBox["random",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[" union to produce a pool of potential mating pairs, denoted \
\[GothicCapitalZ]",
    FontWeight->"Plain"],
  StyleBox[", which then make different contributions to the adult diploid \
stage, \[GothicCapitalA].  Thus, sexual selection among haploids is \
equivalent to viability selection on diploids.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[TextData[{
  StyleBox["\[GothicCapitalD] here are defined such that before viability \
selection, and before sexual selection, the reference points equal the \
current allele frequencies: ",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`ReferencePointZero[{\[GothicCapitalG], \
\[GothicCapitalG]2, \(\[GothicCapitalG]\^*\)}]\)]],
  ". ",
  StyleBox[" However, in the packages selection ",
    FontWeight->"Plain"],
  "must",
  StyleBox[" act between stages with the ",
    FontWeight->"Plain"],
  "same",
  StyleBox[" refrence point.  Thus, there is a shift in reference point \
between stages \[GothicCapitalG]1 and \[GothicCapitalG]2, and between \
\[GothicCapitalA] and ",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`\(\[GothicCapitalG]\^*\)\)]],
  "."
}], "Text",
  FontWeight->"Bold"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Special notation", "SubsubsectionIcon",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  "Because selection acts at two stages in the life cycle, we need to define \
a new set of haploid selection coefficients and a new set of loci that \
influence haploid fitness: HaploidSelectionCoefficient[sex,\
\[DoubleStruckCapitalU]] and HaploidFitnessSet[sex], say. It is convenient \
(but not essential) to represent these using compact subscripted notation, \
via the ",
  ButtonBox["notation package",
    ButtonData:>{"Notation package", "Defining new notation"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "Text",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  "This must be done using the ",
  ButtonBox["notation palette",
    ButtonData:>{
      FrontEnd`FileName[ {
        ParentDirectory[ 
          ParentDirectory[ 
            ParentDirectory[ 
              ParentDirectory[ ]]]], "ExtraPackages", "Utilities"}, 
        "NotationPalette.nb", CharacterEncoding -> "MacintoshRoman"], None},
    ButtonStyle->"Hyperlink"],
  ".  Clicking on the top row, and filling in the external and internal \
representations:"
}], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"Notation", "[", 
        RowBox[{
          TagBox[\(\[GothicB]\_\(sex_, \[DoubleStruckCapitalU]_\)\),
            NotationBoxTag,
            Editable->True], " ", "\[DoubleLongLeftRightArrow]", " ", 
          
          TagBox[\(HaploidSelectionCoefficient[
              sex_, \[DoubleStruckCapitalU]_]\),
            NotationBoxTag,
            Editable->True]}], "]"}], ";"}], "\n", 
    RowBox[{
      RowBox[{"Notation", "[", 
        RowBox[{
          TagBox[\(\[DoubleStruckCapitalV]\_sex_\),
            NotationBoxTag,
            Editable->True], " ", "\[DoubleLongLeftRightArrow]", " ", 
          TagBox[\(HaploidFitnessSet[sex_]\),
            NotationBoxTag,
            Editable->True]}], "]"}], ";"}], "\n", 
    RowBox[{
      RowBox[{"Notation", "[", 
        RowBox[{
          TagBox[\(V\_sex_\),
            NotationBoxTag,
            Editable->True], " ", "\[DoubleLongLeftRightArrow]", " ", 
          TagBox[\(HaploidFitness[sex_]\),
            NotationBoxTag,
            Editable->True]}], "]"}], ";"}], "\n", 
    RowBox[{
      RowBox[{"Notation", "[", 
        RowBox[{
          TagBox[\(W\_sex_\),
            NotationBoxTag,
            Editable->True], " ", "\[DoubleLongLeftRightArrow]", " ", 
          TagBox[\(DiploidFitness[sex_]\),
            NotationBoxTag,
            Editable->True]}], "]"}], ";"}], "\n", 
    RowBox[{
      RowBox[{"Notation", "[", 
        RowBox[{
          TagBox[\(Wraw\_sex_\),
            NotationBoxTag,
            Editable->True], " ", "\[DoubleLongLeftRightArrow]", " ", 
          TagBox[\(RawDiploidFitness[sex_]\),
            NotationBoxTag,
            Editable->True]}], "]"}], ";"}]}], "Input",
  CellLabel->"In[8]:=",
  InitializationCell->True],

Cell["\<\
It will be useful to compress the subscripts to something more \
manageable:\
\>", "Text"],

Cell[BoxData[
    \(\(collapse[
          s_?ContextStageQ] := {m\_{s, __} \[RuleDelayed] \[DoubleStruckM], 
          n\_{s, __} \[RuleDelayed] \[DoubleStruckN], 
          p\_{s, __} \[RuleDelayed] \[DoubleStruckP]};\)\)], "Input",
  CellLabel->"In[13]:=",
  InitializationCell->True],

Cell["\<\
Sometimes, we will rewrite means more compactly in terms of \
\[GothicP]'s and \[GothicQ]'s:\
\>", "Text"],

Cell[BoxData[
    \(\(pqrl = {1 - \[GothicM]\_\[DoubleStruckI]_ \[RuleDelayed] \[GothicQ]\_\
\[DoubleStruckI], \(-1\) + \[GothicM]\_\[DoubleStruckI]_ \[RuleDelayed] \(-\
\[GothicQ]\_\[DoubleStruckI]\), \(-1\) + 
              2  \[GothicM]\_\[DoubleStruckI]_ \[RuleDelayed] \[GothicP]\_\
\[DoubleStruckI] - \[GothicQ]\_\[DoubleStruckI], \
\[GothicM]\_\[DoubleStruckI]_ \[RuleDelayed] \[GothicP]\_\[DoubleStruckI]};\)\
\)], "Input",
  CellLabel->"In[14]:=",
  InitializationCell->True],

Cell["Equivalent associations may need to be reduced:", "Text"],

Cell[BoxData[
    \(\(sort\[GothicCapitalD] = \
{\[GothicCapitalD]\_\(\[DoubleStruckCapitalU]_?\((Not[OrderedQ[#]] &)\)\) \
\[RuleDelayed] \[GothicCapitalD]\_\(Sort[\[DoubleStruckCapitalU]]\)};\)\)], \
"Input",
  CellLabel->"In[15]:=",
  InitializationCell->True],

Cell["\<\
The test is included so that the rule is applied only when \
needed.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Viability selection", "SubsubsectionIcon",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[StyleBox["Two genes influence the fitness of each sex:", \
"MathCaption"]], "MathCaption",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(\[DoubleStruckCapitalV]\_sex_ := {n\_{\[GothicCapitalG], sex}, 
          m\_{\[GothicCapitalG], sex}};\)\)], "Input",
  CellLabel->"In[12]:=",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell["\<\
This describes the effect of selection on the mean at locus i in  a \
general way:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(xx = \[GothicCapitalD]\_{i\_{\[GothicCapitalG]1, \[GothicCapitalM]}} /. 
        Selection[{\[GothicCapitalG], \[GothicCapitalG]1}, 
          HaploidSelectionCoefficient, HaploidFitnessSet, {Sex}]\)], "Input",
  CellLabel->"In[30]:="],

Cell[BoxData[
    \(\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}} + \((\(-\
\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}}\)\ \
\[GothicCapitalD]\_{m\_{\[GothicCapitalG], \[GothicCapitalM]}} + \
\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, m\_{\
\[GothicCapitalG], \[GothicCapitalM]}})\)\ \[GothicB]\_\(\[GothicCapitalM], \
{m\_{\[GothicCapitalG], \[GothicCapitalM]}}\) + \
\((\(-\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}}\)\ \
\[GothicCapitalD]\_{n\_{\[GothicCapitalG], \[GothicCapitalM]}} + \
\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, n\_{\
\[GothicCapitalG], \[GothicCapitalM]}})\)\ \[GothicB]\_\(\[GothicCapitalM], \
{n\_{\[GothicCapitalG], \[GothicCapitalM]}}\) + \
\((\(-\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}}\)\ \
\[GothicCapitalD]\_{m\_{\[GothicCapitalG], \[GothicCapitalM]}, n\_{\
\[GothicCapitalG], \[GothicCapitalM]}} + \[GothicCapitalD]\_{i\_{\
\[GothicCapitalG], \[GothicCapitalM]}, m\_{\[GothicCapitalG], \
\[GothicCapitalM]}, n\_{\[GothicCapitalG], \[GothicCapitalM]}})\)\ \[GothicB]\
\_\(\[GothicCapitalM], {m\_{\[GothicCapitalG], \[GothicCapitalM]}, n\_{\
\[GothicCapitalG], \[GothicCapitalM]}}\)\)], "Output",
  CellLabel->"Out[30]="]
}, Open  ]],

Cell["\<\
Note that the rule Selection[] specifies the stages involved ({\
\[GothicCapitalG],\[GothicCapitalG]1}), the selection coefficients to be used \
(HaploidSelectionCoefficient), and the relevant set of loci \
(HaploidFitnessSet).  These are called as HaploidSelectionCoefficient[sex,\
\[DoubleStruckCapitalU]] and HaploidFitnessSet[sex], but represented more \
compactly using the special notation definitions.  Each is sex-specific, \
because (rather obviously) male fitness depends on genes in the male, and \
vice versa.\
\>", "Text"],

Cell["\<\
To go further, we need to replace the selection coefficients by \
specific values, which depend on the model.\
\>", "Text",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell["\<\
Male and female viability involves an epistatic interaction between \
loci n,m:\
\>", "MathCaption",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(V\_sex_ := 
        1 + s \((\(X\_\(n\_{\[GothicCapitalG], sex}\)\) 
                  X\_\(m\_{\[GothicCapitalG], sex}\) + \((1 - 
                      X\_\(n\_{\[GothicCapitalG], sex}\))\) \((1 - 
                      X\_\(m\_{\[GothicCapitalG], sex}\))\))\);\)\)], "Input",\

  CellLabel->"In[17]:=",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(xx /. {\[GothicB]\_\(sex_, \[DoubleStruckCapitalU]_\) :> 
          MakeSelectionCoefficient[\[DoubleStruckCapitalU], V\_sex]/
            vb}\)], "Input",
  CellLabel->"In[31]:=",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}} + \(2\ s\
\ \((\(-\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}}\)\ \
\[GothicCapitalD]\_{m\_{\[GothicCapitalG], \[GothicCapitalM]}, n\_{\
\[GothicCapitalG], \[GothicCapitalM]}} + \[GothicCapitalD]\_{i\_{\
\[GothicCapitalG], \[GothicCapitalM]}, m\_{\[GothicCapitalG], \
\[GothicCapitalM]}, n\_{\[GothicCapitalG], \[GothicCapitalM]}})\)\)\/vb + \
\(\((\(-\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}}\)\ \
\[GothicCapitalD]\_{n\_{\[GothicCapitalG], \[GothicCapitalM]}} + \
\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, n\_{\
\[GothicCapitalG], \[GothicCapitalM]}})\)\ \((\(-s\) + 2\ s\ \
\[WeierstrassP]\_\(m\_{\[GothicCapitalG], \[GothicCapitalM]}\))\)\)\/vb + \
\(\((\(-\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}}\)\ \
\[GothicCapitalD]\_{m\_{\[GothicCapitalG], \[GothicCapitalM]}} + \
\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, m\_{\
\[GothicCapitalG], \[GothicCapitalM]}})\)\ \((\(-s\) + 2\ s\ \
\[WeierstrassP]\_\(n\_{\[GothicCapitalG], \[GothicCapitalM]}\))\)\)\/vb\)], \
"Output",
  CellLabel->"Out[31]="]
}, Open  ]],

Cell["Two loci affect fitness in each sex:", "MathCaption"],

Cell[BoxData[
    \(\(\[DoubleStruckCapitalV]\_sex_ := \(\[DoubleStruckCapitalV]\_sex = 
          MakeFitnessSet[V\_sex]\);\)\)], "Input",
  CellLabel->"In[32]:=",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[DoubleStruckCapitalV]\_\[GothicCapitalM]\)], "Input",
  CellLabel->"In[33]:="],

Cell[BoxData[
    \({m\_{\[GothicCapitalG], \[GothicCapitalM]}, 
      n\_{\[GothicCapitalG], \[GothicCapitalM]}}\)], "Output",
  CellLabel->"Out[33]="]
}, Open  ]],

Cell[TextData[{
  "It is best to start with an expression involving \[GothicB]'s, and then \
replace them, since it provides more control.  UsingSelection[{\
\[GothicCapitalG],\[GothicCapitalG]1},MakeSelectionCoefficient[\
\[DoubleStruckCapitalU]",
  Cell[BoxData[
      \(TraditionalForm\`\(\(,\)\(V\_sex\)\)\)]],
  "]/vb,HaploidFitnessSet,{Sex}] might generate too much algebra."
}], "Text"],

Cell["There are only three selection coefficients:", "MathCaption",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(DeleteCases[\(\(({#, 
                Simplify /@ 
                  Collect[
                    MakeSelectionCoefficient[#, 
                      V\_\[GothicCapitalM]], {vb}]})\) &\) /@ 
          Subsets[\[DoubleStruckCapitalV]\_\[GothicCapitalM], 1, 2], {_, 0}] // 
      TableForm\)], "Input",
  CellLabel->"In[34]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {GridBox[{
                {\(m\_{\[GothicCapitalG], \[GothicCapitalM]}\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], \(\(-s\) + 
              2\ s\ \[WeierstrassP]\_\(n\_{\[GothicCapitalG], \
\[GothicCapitalM]}\)\)},
          {GridBox[{
                {\(n\_{\[GothicCapitalG], \[GothicCapitalM]}\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], \(\(-s\) + 
              2\ s\ \[WeierstrassP]\_\(m\_{\[GothicCapitalG], \
\[GothicCapitalM]}\)\)},
          {GridBox[{
                {\(m\_{\[GothicCapitalG], \[GothicCapitalM]}\)},
                {\(n\_{\[GothicCapitalG], \[GothicCapitalM]}\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], \(2\ s\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {{{
        Subscript[ m, {\[GothicCapitalG], \[GothicCapitalM]}]}, 
        Plus[ 
          Times[ -1, s], 
          Times[ 2, s, 
            ReferencePoint[ 
              Subscript[ n, {\[GothicCapitalG], \[GothicCapitalM]}]]]]}, {{
        Subscript[ n, {\[GothicCapitalG], \[GothicCapitalM]}]}, 
        Plus[ 
          Times[ -1, s], 
          Times[ 2, s, 
            ReferencePoint[ 
              Subscript[ m, {\[GothicCapitalG], \[GothicCapitalM]}]]]]}, {{
        Subscript[ m, {\[GothicCapitalG], \[GothicCapitalM]}], 
        Subscript[ n, {\[GothicCapitalG], \[GothicCapitalM]}]}, 
        Times[ 2, s]}}]]], "Output",
  CellLabel->"Out[34]//TableForm="]
}, Open  ]],

Cell[TextData[{
  "Note that selection coefficients are defined wrt reference points,",
  Cell[BoxData[
      \(\(\(\ \)\(\[WeierstrassP]\_\(n\_{\[GothicCapitalG], \
\[GothicCapitalM]}\)\)\)\)]]
}], "Text"],

Cell["\<\
The mean viability vb is a complicated expression, which can be \
substituted later:\
\>", "MathCaption",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[LeftAngleBracket]V\_\[GothicCapitalM]\[RightAngleBracket]\)], "Input",\

  CellLabel->"In[35]:=",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(1 + s - 
      s\ \[GothicCapitalD]\_{m\_{\[GothicCapitalG], \[GothicCapitalM]}} - 
      s\ \[GothicCapitalD]\_{n\_{\[GothicCapitalG], \[GothicCapitalM]}} + 
      2\ s\ \[GothicCapitalD]\_{m\_{\[GothicCapitalG], \[GothicCapitalM]}, \
n\_{\[GothicCapitalG], \[GothicCapitalM]}} - 
      s\ \[WeierstrassP]\_\(m\_{\[GothicCapitalG], \[GothicCapitalM]}\) + 
      2\ s\ \[GothicCapitalD]\_{n\_{\[GothicCapitalG], \[GothicCapitalM]}}\ \
\[WeierstrassP]\_\(m\_{\[GothicCapitalG], \[GothicCapitalM]}\) - 
      s\ \[WeierstrassP]\_\(n\_{\[GothicCapitalG], \[GothicCapitalM]}\) + 
      2\ s\ \[GothicCapitalD]\_{m\_{\[GothicCapitalG], \[GothicCapitalM]}}\ \
\[WeierstrassP]\_\(n\_{\[GothicCapitalG], \[GothicCapitalM]}\) + 
      2\ s\ \[WeierstrassP]\_\(m\_{\[GothicCapitalG], \[GothicCapitalM]}\)\ \
\[WeierstrassP]\_\(n\_{\[GothicCapitalG], \[GothicCapitalM]}\)\)], "Output",
  CellLabel->"Out[35]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Change of reference points", "SubsubsectionIcon"],

Cell[TextData[{
  StyleBox["It is assumed that the reference points are the same in \
\[GothicCapitalG] and \[GothicCapitalG]1 - Selection[] does ",
    FontWeight->"Plain"],
  "not",
  StyleBox[" include shifts in reference point.  Now, later expressions \
assume that reference points in stage \[GothicCapitalG]2 are set to the \
current allele frequencies at that stage.  So, we now need to change the \
reference point to that given by the new allele frequencies in stages \
\[GothicCapitalG]1, \[GothicCapitalG]2.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[TextData[{
  "This is accomplished by applying a special ",
  StyleBox["transmission rule",
    FontSlant->"Italic"],
  " (",
  ButtonBox["Eq. 15",
    ButtonData:>{"Multilocus MS", "ChangeInReferenceValueEquation"},
    ButtonStyle->"AddOnsLink"],
  " of Multilocus MS):"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicCapitalD]\_{m\_{\[GothicCapitalG]2, \[GothicCapitalM]}, n\_{\
\[GothicCapitalG]2, \[GothicCapitalM]}}\[CirclePlus]{{\[GothicCapitalG]2, 
            sex_} \[LeftArrow] {\[GothicCapitalG]1, sex}}\)], "Input",
  CellLabel->"In[36]:="],

Cell[BoxData[
    \(\[GothicCapitalD]\_{m\_{\[GothicCapitalG]1, \[GothicCapitalM]}, n\_{\
\[GothicCapitalG]1, \[GothicCapitalM]}} + \[GothicCapitalD]\_{n\_{\
\[GothicCapitalG]1, \[GothicCapitalM]}}\ \((\[WeierstrassP]\_\(m\_{\
\[GothicCapitalG]1, \[GothicCapitalM]}\) - \[WeierstrassP]\_\(m\_{\
\[GothicCapitalG]2, \[GothicCapitalM]}\))\) + \[GothicCapitalD]\_{m\_{\
\[GothicCapitalG]1, \[GothicCapitalM]}}\ \((\[WeierstrassP]\_\(n\_{\
\[GothicCapitalG]1, \[GothicCapitalM]}\) - \[WeierstrassP]\_\(n\_{\
\[GothicCapitalG]2, \[GothicCapitalM]}\))\) + \((\[WeierstrassP]\_\(m\_{\
\[GothicCapitalG]1, \[GothicCapitalM]}\) - \[WeierstrassP]\_\(m\_{\
\[GothicCapitalG]2, \[GothicCapitalM]}\))\)\ \((\[WeierstrassP]\_\(n\_{\
\[GothicCapitalG]1, \[GothicCapitalM]}\) - \[WeierstrassP]\_\(n\_{\
\[GothicCapitalG]2, \[GothicCapitalM]}\))\)\)], "Output",
  CellLabel->"Out[36]="]
}, Open  ]],

Cell["We now define reference points appropriately:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\[GothicCapitalD]\_{m\_{\[GothicCapitalG]2, \[GothicCapitalM]}, \
n\_{\[GothicCapitalG]2, \[GothicCapitalM]}}\[CirclePlus]{{\[GothicCapitalG]2, 
                  sex_} \[LeftArrow] {\[GothicCapitalG]1, sex}} /. 
          ReferencePointSame[\[GothicCapitalG], \[GothicCapitalG]1]\) /. 
        ReferencePointZero[{\[GothicCapitalG], \[GothicCapitalG]2}]\) /. {\
\[GothicM]\_\(i_\_{\[GothicCapitalG], \[GothicCapitalM]}\) - \[GothicM]\_\(i_\
\_{\[GothicCapitalG]2, \[GothicCapitalM]}\) :> \
\(-\[CapitalDelta]v\[GothicM]\_i\), \
\[GothicCapitalD]\_{i_\_{\[GothicCapitalG]1, \[GothicCapitalM]}} \
\[RuleDelayed] \[CapitalDelta]v\[GothicM]\_i}\)], "Input",
  CellLabel->"In[37]:="],

Cell[BoxData[
    \(\[GothicCapitalD]\_{m\_{\[GothicCapitalG]1, \[GothicCapitalM]}, n\_{\
\[GothicCapitalG]1, \[GothicCapitalM]}} - \[CapitalDelta]v\[GothicM]\_m\ \
\[CapitalDelta]v\[GothicM]\_n\)], "Output",
  CellLabel->"Out[37]="]
}, Open  ]],

Cell[TextData[{
  "An association is generated by the shift in reference point at the two \
loci, ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]v\[GothicM]\_i\)]]
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Union of gametes", "SubsubsectionIcon",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell["\<\
Associations at the zygote stage are related in a trivial way to \
those at the stage before:\
\>", "MathCaption",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}} /. 
      UnionOfGametes[{\[GothicCapitalG]2, \[GothicCapitalZ]}]\)], "Input",
  CellLabel->"In[39]:=",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\[GothicCapitalD]\_{i\_{\[GothicCapitalG]2, \[GothicCapitalM]}, j\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}} + \[GothicCapitalD]\_{j\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}}\ \((\[WeierstrassP]\_\(i\_{\
\[GothicCapitalG]2, \[GothicCapitalM]}\) - \[WeierstrassP]\_\(i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}\))\) + \
\[GothicCapitalD]\_{i\_{\[GothicCapitalG]2, \[GothicCapitalM]}}\ \((\
\[WeierstrassP]\_\(j\_{\[GothicCapitalG]2, \[GothicCapitalF]}\) - \
\[WeierstrassP]\_\(j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}\))\) + \((\[WeierstrassP]\_\(i\_{\[GothicCapitalG]2, \
\[GothicCapitalM]}\) - \[WeierstrassP]\_\(i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}\))\)\ \((\[WeierstrassP]\_\(j\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}\) - \[WeierstrassP]\_\(j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}\))\)\)], "Output",
  CellLabel->"Out[39]="]
}, Open  ]],

Cell[TextData[{
  "We suppose that the pool of zygotes is formed by random union of gametes: \
sexual selection is imposed at the ",
  StyleBox["next",
    FontSlant->"Italic"],
  " stage, through selection on the hypothetical zygote pool.  Thus:"
}], "MathCaption",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}} //. 
      UnionOfGametes[{\[GothicCapitalG]2, \
\[GothicCapitalZ]}]\[Vee]RandomUnion[\[GothicCapitalG]2]\)], "Input",
  CellLabel->"In[32]:=",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\[GothicCapitalD]\_{i\_{\[GothicCapitalG]2, \[GothicCapitalM]}}\ \
\[GothicCapitalD]\_{j\_{\[GothicCapitalG]2, \[GothicCapitalF]}} + \
\[GothicCapitalD]\_{j\_{\[GothicCapitalG]2, \[GothicCapitalF]}}\ \((\
\[WeierstrassP]\_\(i\_{\[GothicCapitalG]2, \[GothicCapitalM]}\) - \
\[WeierstrassP]\_\(i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}\))\) + \[GothicCapitalD]\_{i\_{\[GothicCapitalG]2, \
\[GothicCapitalM]}}\ \((\[WeierstrassP]\_\(j\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}\) - \[WeierstrassP]\_\(j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}\))\) + \((\[WeierstrassP]\_\(i\_{\
\[GothicCapitalG]2, \[GothicCapitalM]}\) - \[WeierstrassP]\_\(i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}\))\)\ \((\
\[WeierstrassP]\_\(j\_{\[GothicCapitalG]2, \[GothicCapitalF]}\) - \
\[WeierstrassP]\_\(j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}\))\)\)], "Output",
  CellLabel->"Out[32]="]
}, Open  ]],

Cell["\<\
There are extra terms due to the change in reference points, which \
can be eliminated by making some specific assumptions.\
\>", "Text",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell["\<\
The expression simplifies greatly if reference points in gametes \
are set to the current allele frequencies, and the reference points in the \
following stages are the same:\
\>", "MathCaption",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}} //. 
        UnionOfGametes[{\[GothicCapitalG]2, \
\[GothicCapitalZ]}]\[Vee]RandomUnion[\[GothicCapitalG]2]\) /. 
      ReferencePointSame[\[GothicCapitalG], {\[GothicCapitalG]2, \
\[GothicCapitalZ]}]\)], "Input",
  CellLabel->"In[33]:=",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\[GothicCapitalD]\_{i\_{\[GothicCapitalG]2, \[GothicCapitalM]}}\ \
\[GothicCapitalD]\_{j\_{\[GothicCapitalG]2, \[GothicCapitalF]}}\)], "Output",
  CellLabel->"Out[33]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Sexual selection", "SubsubsectionIcon",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  "Females with allele ",
  Cell[BoxData[
      \(TraditionalForm\`X\_\(p\_{\[GothicCapitalG]2, \[GothicCapitalF]}\) = 
        0\)]],
  " have preference ",
  Cell[BoxData[
      \(TraditionalForm\`1 + \[Beta]\_1\)]],
  " for males ",
  Cell[BoxData[
      \(TraditionalForm\`X\_\(n\_{\[GothicCapitalG], \[GothicCapitalM]}\) = 
        0, \ X\_\(m\_{\[GothicCapitalG], \[GothicCapitalM]}\) = 0\)]],
  "; similarly, females with allele ",
  Cell[BoxData[
      \(TraditionalForm\`X\_\(p\_{\[GothicCapitalG], \[GothicCapitalF]}\) = 
        1\)]],
  " have preference ",
  Cell[BoxData[
      \(TraditionalForm\`1 + \[Beta]\_2\)]],
  " for males ",
  Cell[BoxData[
      \(TraditionalForm\`X\_\(n\_{\[GothicCapitalG], \[GothicCapitalM]}\) = 
        1, \ X\_\(m\_{\[GothicCapitalG], \[GothicCapitalM]}\) = 1\)]],
  ":"
}], "MathCaption",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(Wraw\_sex_ := 
        1 + \(\[Beta]\_1\) \((1 - 
                X\_\(p\_{\[GothicCapitalZ], sex, \[GothicCapitalF]}\))\) \((1 \
- X\_\(n\_{\[GothicCapitalZ], sex, \[GothicCapitalM]}\))\) \((1 - 
                X\_\(m\_{\[GothicCapitalZ], sex, \[GothicCapitalM]}\))\) + \(\
\[Beta]\_2\) \(X\_\(p\_{\[GothicCapitalZ], 
                      sex, \[GothicCapitalF]}\)\) \
\(X\_\(n\_{\[GothicCapitalZ], sex, \[GothicCapitalM]}\)\) 
            X\_\(m\_{\[GothicCapitalZ], sex, \[GothicCapitalM]}\);\)\)], \
"Input",
  CellLabel->"In[15]:=",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell["\<\
The fitness function must be normalised so that the mean fitness of \
each female genotype is 1:\
\>", "MathCaption"],

Cell[BoxData[
    \(\(W\_sex_ := \[IndentingNewLine]\(\((1 + \(\[Beta]\_1\) \((1 - \
X\_\(n\_{\[GothicCapitalZ], sex, \[GothicCapitalM]}\))\) \((1 - X\_\(m\_{\
\[GothicCapitalZ], sex, \[GothicCapitalM]}\))\))\) \((1 - X\_\(p\_{\
\[GothicCapitalZ], sex, \[GothicCapitalF]}\))\)\)\/wbF0\_sex + \(\((1 + \(\
\[Beta]\_2\) \(X\_\(n\_{\[GothicCapitalZ], sex, \[GothicCapitalM]}\)\) X\_\(m\
\_{\[GothicCapitalZ], sex, \[GothicCapitalM]}\))\) \
X\_\(p\_{\[GothicCapitalZ], sex, \[GothicCapitalF]}\)\)\/wbF1\_sex;\)\)], \
"Input",
  CellLabel->"In[16]:=",
  InitializationCell->True],

Cell["The normalisation constants can be substituted in later:", "MathCaption"],

Cell[BoxData[
    \(wbF[0, 
        sex_] := \(wbF[0, 
          sex] = \[LeftAngleBracket]\((Wraw\_sex /. \
X\_\(p\_{\[GothicCapitalZ], sex, \[GothicCapitalF]}\) \[Rule] 0)\) \((1 - X\_\
\(p\_{\[GothicCapitalZ], sex, \[GothicCapitalF]}\))\)\[RightAngleBracket]\/\
\[LeftAngleBracket]1 - X\_\(p\_{\[GothicCapitalZ], sex, \[GothicCapitalF]}\)\
\[RightAngleBracket]\); 
    wbF[1, sex_] := \(wbF[1, 
          sex] = \[LeftAngleBracket]\((Wraw\_sex /. \
X\_\(p\_{\[GothicCapitalZ], sex, \[GothicCapitalF]}\) \[Rule] 1)\) X\_\(p\_{\
\[GothicCapitalZ], sex, \[GothicCapitalF]}\)\[RightAngleBracket]\/\
\[LeftAngleBracket]X\_\(p\_{\[GothicCapitalZ], sex, \[GothicCapitalF]}\)\
\[RightAngleBracket]\);\)], "Input",
  CellLabel->"In[20]:=",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell["\<\
This simplifies the normalisation coefficients, in terms of stage \
\[GothicCapitalG]2:\
\>", "MathCaption"],

Cell[BoxData[
    \(\(wbFS[
          j_] := \(wbFS[
            j] = \(\(\(\(wbF[
                        j, \[GothicCapitalM]] \
/. \[InvisibleSpace]UnionOfGametes[{\[GothicCapitalG]2, \[GothicCapitalZ]}]\) \
/. \[InvisibleSpace]RandomUnion[\[GothicCapitalG]2]\) /. 
                  ReferencePointSame[\[GothicCapitalG]2, \[GothicCapitalZ]]\) \
/. ReferencePointZero[\[GothicCapitalG]2]\) /. SymmetricSexes[] // 
            Simplify\);\)\)], "Input",
  CellLabel->"In[43]:=",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \({wbFS[0], wbFS[1]}\)], "Input",
  CellLabel->"In[46]:="],

Cell[BoxData[
    \({1 + \((\[GothicCapitalD]\_{m\_{\[GothicCapitalG]2, \[GothicCapitalF]}, \
n\_{\[GothicCapitalG]2, \[GothicCapitalF]}} + \((\(-1\) + \[GothicM]\_\(m\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}\))\)\ \((\(-1\) + \[GothicM]\_\(n\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}\))\))\)\ \[Beta]\_1, 
      1 + \[GothicCapitalD]\_{m\_{\[GothicCapitalG]2, \[GothicCapitalF]}, \
n\_{\[GothicCapitalG]2, \[GothicCapitalF]}}\ \[Beta]\_2 + \[GothicM]\_\(m\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}\)\ \
\[GothicM]\_\(n\_{\[GothicCapitalG]2, \[GothicCapitalF]}\)\ \[Beta]\_2}\)], \
"Output",
  CellLabel->"Out[46]="]
}, Open  ]],

Cell[TextData[{
  " It will be useful later to express the coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta]\_i\)]],
  " in terms of the correpsonding normalising constants:"
}], "MathCaption"],

Cell[BoxData[
    \(\(sub\[Beta][
          i_] := \(sub\[Beta][
            i] = \[Beta]\_\(i + 1\) /. \(Solve[
                wbFS[i] \[Equal] \[Delta]w[i] + 
                    1, \[Beta]\_\(i + 1\)]\)\[LeftDoubleBracket]1\
\[RightDoubleBracket]\);\)\)], "Input",
  CellLabel->"In[76]:=",
  InitializationCell->True],

Cell["Three loci affect zygote fitness:", "MathCaption"],

Cell[BoxData[
    \(\(\[DoubleStruckCapitalW]\_sex_ := \(\[DoubleStruckCapitalW]\_sex = 
          MakeFitnessSet[W\_sex]\);\)\)], "Input",
  CellLabel->"In[47]:=",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[DoubleStruckCapitalW]\_\[GothicCapitalM]\)], "Input",
  CellLabel->"In[48]:="],

Cell[BoxData[
    \({m\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, 
      n\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, 
      p\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}}\)], \
"Output",
  CellLabel->"Out[48]="]
}, Open  ]],

Cell[TextData[{
  "Recall that the fitness of the ",
  StyleBox["zygote",
    FontSlant->"Italic"],
  " is irrelevant: only the sexes of the ",
  StyleBox["haploids",
    FontSlant->"Italic"],
  " matters."
}], "Text"],

Cell["Mean fitness is necessarily 1:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\[LeftAngleBracket]W\_\[GothicCapitalM]\[RightAngleBracket] /. \
{wbF0\_\[GothicCapitalM] \[Rule] wbF[0, \[GothicCapitalM]], 
            wbF1\_\[GothicCapitalM] \[Rule] wbF[1, \[GothicCapitalM]]}\) /. 
        ReferencePointZero[\[GothicCapitalZ]] // Simplify\)], "Input",
  CellLabel->"In[49]:="],

Cell[BoxData[
    \(1\)], "Output",
  CellLabel->"Out[49]="]
}, Open  ]],

Cell["\<\
Here, the algebra has been simplified by taking reference points \
equal to allele frequencies in the zygote population.\
\>", "Text"],

Cell["\<\
This tabulates the 8 selection coefficients, with some \
simplification of the notation:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\(({#, 
                  Simplify /@ 
                    Collect[
                      MakeSelectionCoefficient[#, W\_\[GothicCapitalM]] /. 
                        ReferencePointZero[\[GothicCapitalZ]], {wbF0\_\
\[GothicCapitalM]\ , wbF1\_\[GothicCapitalM]}]})\) &\) /@ 
            Subsets[\[DoubleStruckCapitalW]\_\[GothicCapitalM], 1, 5] /. 
          collapse[\[GothicCapitalZ]]\) /. pqrl // TableForm\)], "Input",
  CellLabel->"In[53]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {GridBox[{
                {"\[DoubleStruckM]"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              
              ColumnAlignments->{
                Left}], \(\(-\(\(\[GothicQ]\_\[DoubleStruckN]\ \[GothicQ]\_\
\[DoubleStruckP]\ \[Beta]\_1\)\/wbF0\_\[GothicCapitalM]\)\) + \(\[GothicP]\_\
\[DoubleStruckN]\ \[GothicP]\_\[DoubleStruckP]\ \[Beta]\_2\)\/wbF1\_\
\[GothicCapitalM]\)},
          {GridBox[{
                {"\[DoubleStruckN]"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              
              ColumnAlignments->{
                Left}], \(\(-\(\(\[GothicQ]\_\[DoubleStruckM]\ \[GothicQ]\_\
\[DoubleStruckP]\ \[Beta]\_1\)\/wbF0\_\[GothicCapitalM]\)\) + \(\[GothicP]\_\
\[DoubleStruckM]\ \[GothicP]\_\[DoubleStruckP]\ \[Beta]\_2\)\/wbF1\_\
\[GothicCapitalM]\)},
          {GridBox[{
                {"\[DoubleStruckP]"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              
              ColumnAlignments->{
                Left}], \(\(-\(\(1 + \[GothicQ]\_\[DoubleStruckM]\ \[GothicQ]\
\_\[DoubleStruckN]\ \[Beta]\_1\)\/wbF0\_\[GothicCapitalM]\)\) + \(1 + \
\[GothicP]\_\[DoubleStruckM]\ \[GothicP]\_\[DoubleStruckN]\ \
\[Beta]\_2\)\/wbF1\_\[GothicCapitalM]\)},
          {GridBox[{
                {"\[DoubleStruckM]"},
                {"\[DoubleStruckN]"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              
              ColumnAlignments->{
                Left}], \(\(\[GothicQ]\_\[DoubleStruckP]\ \
\[Beta]\_1\)\/wbF0\_\[GothicCapitalM] + \(\[GothicP]\_\[DoubleStruckP]\ \
\[Beta]\_2\)\/wbF1\_\[GothicCapitalM]\)},
          {GridBox[{
                {"\[DoubleStruckM]"},
                {"\[DoubleStruckP]"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              
              ColumnAlignments->{
                Left}], \(\(\[GothicQ]\_\[DoubleStruckN]\ \
\[Beta]\_1\)\/wbF0\_\[GothicCapitalM] + \(\[GothicP]\_\[DoubleStruckN]\ \
\[Beta]\_2\)\/wbF1\_\[GothicCapitalM]\)},
          {GridBox[{
                {"\[DoubleStruckN]"},
                {"\[DoubleStruckP]"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              
              ColumnAlignments->{
                Left}], \(\(\[GothicQ]\_\[DoubleStruckM]\ \
\[Beta]\_1\)\/wbF0\_\[GothicCapitalM] + \(\[GothicP]\_\[DoubleStruckM]\ \
\[Beta]\_2\)\/wbF1\_\[GothicCapitalM]\)},
          {GridBox[{
                {"\[DoubleStruckM]"},
                {"\[DoubleStruckN]"},
                {"\[DoubleStruckP]"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              
              ColumnAlignments->{
                Left}], \(\(-\(\[Beta]\_1\/wbF0\_\[GothicCapitalM]\)\) + \
\[Beta]\_2\/wbF1\_\[GothicCapitalM]\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {{{\[DoubleStruckM]}, 
        Plus[ 
          Times[ -1, 
            AlleleFrequencyQ[ \[DoubleStruckN]], 
            AlleleFrequencyQ[ \[DoubleStruckP]], 
            Power[ 
              Subscript[ wbF0, \[GothicCapitalM]], -1], 
            Subscript[ \[Beta], 1]], 
          Times[ 
            AlleleFrequencyP[ \[DoubleStruckN]], 
            AlleleFrequencyP[ \[DoubleStruckP]], 
            Power[ 
              Subscript[ wbF1, \[GothicCapitalM]], -1], 
            Subscript[ \[Beta], 2]]]}, {{\[DoubleStruckN]}, 
        Plus[ 
          Times[ -1, 
            AlleleFrequencyQ[ \[DoubleStruckM]], 
            AlleleFrequencyQ[ \[DoubleStruckP]], 
            Power[ 
              Subscript[ wbF0, \[GothicCapitalM]], -1], 
            Subscript[ \[Beta], 1]], 
          Times[ 
            AlleleFrequencyP[ \[DoubleStruckM]], 
            AlleleFrequencyP[ \[DoubleStruckP]], 
            Power[ 
              Subscript[ wbF1, \[GothicCapitalM]], -1], 
            Subscript[ \[Beta], 2]]]}, {{\[DoubleStruckP]}, 
        Plus[ 
          Times[ -1, 
            Power[ 
              Subscript[ wbF0, \[GothicCapitalM]], -1], 
            Plus[ 1, 
              Times[ 
                AlleleFrequencyQ[ \[DoubleStruckM]], 
                AlleleFrequencyQ[ \[DoubleStruckN]], 
                Subscript[ \[Beta], 1]]]], 
          Times[ 
            Power[ 
              Subscript[ wbF1, \[GothicCapitalM]], -1], 
            Plus[ 1, 
              Times[ 
                AlleleFrequencyP[ \[DoubleStruckM]], 
                AlleleFrequencyP[ \[DoubleStruckN]], 
                
                Subscript[ \[Beta], 
                  2]]]]]}, {{\[DoubleStruckM], \[DoubleStruckN]}, 
        Plus[ 
          Times[ 
            AlleleFrequencyQ[ \[DoubleStruckP]], 
            Power[ 
              Subscript[ wbF0, \[GothicCapitalM]], -1], 
            Subscript[ \[Beta], 1]], 
          Times[ 
            AlleleFrequencyP[ \[DoubleStruckP]], 
            Power[ 
              Subscript[ wbF1, \[GothicCapitalM]], -1], 
            Subscript[ \[Beta], 2]]]}, {{\[DoubleStruckM], \[DoubleStruckP]}, 
        
        Plus[ 
          Times[ 
            AlleleFrequencyQ[ \[DoubleStruckN]], 
            Power[ 
              Subscript[ wbF0, \[GothicCapitalM]], -1], 
            Subscript[ \[Beta], 1]], 
          Times[ 
            AlleleFrequencyP[ \[DoubleStruckN]], 
            Power[ 
              Subscript[ wbF1, \[GothicCapitalM]], -1], 
            Subscript[ \[Beta], 2]]]}, {{\[DoubleStruckN], \[DoubleStruckP]}, 
        
        Plus[ 
          Times[ 
            AlleleFrequencyQ[ \[DoubleStruckM]], 
            Power[ 
              Subscript[ wbF0, \[GothicCapitalM]], -1], 
            Subscript[ \[Beta], 1]], 
          Times[ 
            AlleleFrequencyP[ \[DoubleStruckM]], 
            Power[ 
              Subscript[ wbF1, \[GothicCapitalM]], -1], 
            
            Subscript[ \[Beta], 
              2]]]}, {{\[DoubleStruckM], \[DoubleStruckN], \[DoubleStruckP]}, 
        
        Plus[ 
          Times[ -1, 
            Power[ 
              Subscript[ wbF0, \[GothicCapitalM]], -1], 
            Subscript[ \[Beta], 1]], 
          Times[ 
            Power[ 
              Subscript[ wbF1, \[GothicCapitalM]], -1], 
            Subscript[ \[Beta], 2]]]}}]]], "Output",
  CellLabel->"Out[53]//TableForm="]
}, Open  ]],

Cell["\<\
Note that when the selection coefficient and fitness set are \
specified in Selection[], their full names must be given - not the shorthand \
forms \[GothicA], \[DoubleStruckCapitalW].\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Meiosis", "SubsubsectionIcon",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell["The life cycle is completed by meiosis: ", "MathCaption",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicCapitalD]\_{n\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}, m\
\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}} //. 
      Recombination[]\[Vee]SymmetricRecombination[]\)], "Input",
  CellLabel->"In[178]:=",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\[GothicR]\_\({}, {m, n}\)\ \
\((\[GothicCapitalD]\_{n\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}, m\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}} + \[GothicCapitalD]\_{n\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(m\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(m\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}\))\) - \((\
\[GothicCapitalD]\_{m\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}} - \[WeierstrassP]\_\(m\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}\) + \[WeierstrassP]\_\(m\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}\))\)\ \((\[WeierstrassP]\_\(n\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\) - \[WeierstrassP]\_\(n\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}\))\))\) + \[GothicR]\
\_\({m}, {n}\)\ \((\[GothicCapitalD]\_{n\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}, m\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\_{n\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}}\ \((\(-\
\[WeierstrassP]\_\(m\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(m\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}\))\) - \((\[GothicCapitalD]\_{m\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}} - \[WeierstrassP]\_\(m\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\) + \[WeierstrassP]\_\(m\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalM]}\))\)\ \((\
\[WeierstrassP]\_\(n\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\) - \
\[WeierstrassP]\_\(n\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}\))\))\) + \[GothicR]\_\({m}, {n}\)\ \
\((\[GothicCapitalD]\_{n\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}, m\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}} + \[GothicCapitalD]\_{n\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(m\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(m\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}\))\) - \((\
\[GothicCapitalD]\_{m\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}} - \[WeierstrassP]\_\(m\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}\) + \[WeierstrassP]\_\(m\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}\))\)\ \((\[WeierstrassP]\_\(n\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\) - \[WeierstrassP]\_\(n\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalM]}\))\))\) + \[GothicR]\
\_\({}, {n, m}\)\ \((\[GothicCapitalD]\_{n\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}, m\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\_{n\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalM]}}\ \((\(-\
\[WeierstrassP]\_\(m\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(m\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}\))\) - \((\[GothicCapitalD]\_{m\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}} - \[WeierstrassP]\_\(m\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\) + \[WeierstrassP]\_\(m\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalM]}\))\)\ \((\
\[WeierstrassP]\_\(n\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\) - \
\[WeierstrassP]\_\(n\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}\))\))\)\)], "Output",
  CellLabel->"Out[178]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Combining stages in the life cycle: rules for viability selection, \
sexual selection and meiosis\
\>", "SubsubsectionIcon",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell["\<\
It is safest to work up in stages from the beginning, to try and \
keep the algebra simple: if one tries to calculate all at once, using a long \
list of rules, the intermediate algebra can get out of hand.  This procedure \
simplifies expressions for gametic associations after viability \
selection:\
\>", "Text",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell["\<\
These are the rules for viability selection, assuming two alleles \
per locus:\
\>", "MathCaption"],

Cell[BoxData[
    \(\(vsr = {x : \((\[GothicCapitalD]\__ | \[GothicM]\__)\) \[RuleDelayed] 
            Simplify[\(\(\(\(\(\(x /. 
                            Selection[{\[GothicCapitalG], \
\[GothicCapitalG]1}, HaploidSelectionCoefficient, 
                              HaploidFitnessSet, {Sex}]\) /. \
{\[GothicB]\_\(sex_, \[DoubleStruckCapitalU]_\) \[RuleDelayed] 
                              Simplify[
                                MakeSelectionCoefficient[\
\[DoubleStruckCapitalU], V\_sex /. {s \[Rule] ss*vb}]/vb]}\) //. 
                        Biallelic[MeanContribution]\) /. 
                      ReferencePointSame[\[GothicCapitalG], \
\[GothicCapitalG]1]\) /. 
                    ReferencePointZero[\[GothicCapitalG]]\) /. {\
\[GothicCapitalD]\_\(\[DoubleStruckCapitalU]_?\((Not[OrderedQ[#]] &)\)\) \
\[RuleDelayed] \[GothicCapitalD]\_\(Sort[\[DoubleStruckCapitalU]]\)}\) /. 
                SymmetricSexes[]]};\)\)], "Input",
  CellLabel->"In[56]:=",
  InitializationCell->True],

Cell["\<\
The effect of this sequence of rules can be examined by invoking \
each rule in turn.  Briefly:\
\>", "Text"],

Cell[BoxData[GridBox[{
        {\(Selection[{\[GothicCapitalG], \[GothicCapitalG]1}, 
            HaploidSelectionCoefficient, 
            HaploidFitnessSet, {Sex}]\), \(expresses\ \
\(\[GothicCapitalD]\_{\(i\_{\[GothicCapitalG]1, \[Ellipsis]}\) \[Ellipsis]}\) 
            in\ terms\ of\ \[GothicCapitalD]\_{i\_{\[GothicCapitalG], \
\[Ellipsis]}, \[Ellipsis]}\ and\ \[GothicB]' s\)},
        {\({\[GothicB]\_\(sex_, \[DoubleStruckCapitalU]_\) \[RuleDelayed] 
              Simplify[
                MakeSelectionCoefficient[\[DoubleStruckCapitalU], 
                    V\_sex /. {s \[Rule] ss*vb}]/
                  vb]}\), \(substitutes\ for\ selection\ coefficients, \ \
\[GothicB], \ derived\ from\ viability\ V\_sex, \ 
          with\ ss \[Congruent] s\/vb\)},
        {\(Biallelic[MeanContribution]\), \(makes\ two - 
            allele\ simplifications\ \ replacing\ \[GothicCapitalD]\_{\
\[DoubleStruckI], \[DoubleStruckI]}\ by\ \(\[GothicP]\_\[DoubleStruckI]\) \
\((1 - \[GothicP]\_\[DoubleStruckI])\)\ etc; \ 
          writes\ allele\ frequency\ as\ \[GothicM]\_\[DoubleStruckI]\)},
        {\(ReferencePointSame[\[GothicCapitalG], \[GothicCapitalG]1]\), \
\(specifies\ that\ refrence\ points\ are\ the\ same\ at\ these\ two\ stages\ \
\((as\ is\ required\ by\ Selection[])\)\)},
        {\(ReferencePointZero[\[GothicCapitalG]]\), \(replaces\ \(\
\[GothicCapitalD]\_{\[DoubleStruckI]}\) by\ zero, \ 
          and\ writes\ allele\ frequency\ as\ \[GothicM]\_\[DoubleStruckI], \ 
          for\ stage\ \[GothicCapitalG]\)},
        {\({\[GothicCapitalD]\_\(\[DoubleStruckCapitalU]_?\((\(! \
OrderedQ[#]\) &)\)\) :> \[GothicCapitalD]\_\(Sort[\[DoubleStruckCapitalU]]\)}\
\), \(replaces\ equivalent\ sets\ such\ as\ \[GothicCapitalD]\_{\
\[DoubleStruckI], \[DoubleStruckJ]}, \ \[GothicCapitalD]\_{\[DoubleStruckJ], \
\[DoubleStruckI]} . \ \ The\ test\ \((\(! OrderedQ[#]\) &)\)\ is\ good\ \
practice, \ \(\(to\)\(\ \)\(ensure\)\(\ \)\(that\)\(\ \)\(the\)\(\ \)\(rule\)\
\(\ \)\(is\)\(\ \)\(only\)\(\ \)\(applied\)\(\ \)\(when\)\(\ \)\(needed\)\(\ \
\)\)\)},
        {\(SymmetricSexes[]\), \(uses\ the\ assumption\ that\ male\ and\ \
female\ gametes\ start\ out\ with\ the\ same\ frequencies\ at\ stage\ \
\[GothicCapitalG] . \ \ This\ must\ be\ applied\ last, \ 
          so\ that\ later\ stages\ are\ not\ \(\(affected\)\(.\)\)\)}
        }]], "DefinitionBox"],

Cell[TextData[{
  "Here, rules are applied in sequence, using /.r1/.r2...  This gives more \
control than the practice elsewhere in the examples, of using //.r1\[Vee]r2\
\[Vee]\[Ellipsis]  The latter may fail to completely reduce an expression if \
one rule ",
  ButtonBox["blocks",
    ButtonData:>{"Bugs", "Applying rules"},
    ButtonStyle->"AddOnsLink"],
  " application of later rules."
}], "Text"],

Cell["\<\
Here is a simple expression for the change in pairwise association \
due to viability selection:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\[GothicCapitalD]\_{m\_{\[GothicCapitalG]1, \[GothicCapitalM]}, \
n\_{\[GothicCapitalG]1, \[GothicCapitalM]}} - \[GothicCapitalD]\_{m\_{\
\[GothicCapitalG], \[GothicCapitalM]}, n\_{\[GothicCapitalG], \
\[GothicCapitalM]}} /. vsr\) /. collapse[\[GothicCapitalG]]\) /. 
      pqrl\)], "Input",
  CellLabel->"In[58]:="],

Cell[BoxData[
    \(2\ ss\ \[GothicP]\_\[DoubleStruckM]\ \[GothicP]\_\[DoubleStruckN]\ \
\[GothicQ]\_\[DoubleStruckM]\ \[GothicQ]\_\[DoubleStruckN] - 
      2\ ss\ \[GothicCapitalD]\_{\[DoubleStruckM], \[DoubleStruckN]}\%2\)], \
"Output",
  CellLabel->"Out[58]="]
}, Open  ]],

Cell["\<\
This is still at stage \[GothicCapitalG]1, and so is still defined \
relative to the old allele frequencies.  To change reference points, we move \
to stage \[GothicCapitalG]2.\
\>", "Text"],

Cell["\<\
This rule replaces \[GothicCapitalD] at stage \[GothicCapitalG]2 by \
\[GothicCapitalD] at stage \[GothicCapitalG]1, allowing for the shift in \
reference point:\
\>", "MathCaption"],

Cell[BoxData[
    \(\(vsr2 = {\[GothicCapitalD]\_\[DoubleStruckCapitalU]_ \[RuleDelayed] 
            Simplify[\(\[GothicCapitalD]\_\[DoubleStruckCapitalU]\[CirclePlus]\
{{\[GothicCapitalG]2, sex_} \[LeftArrow] {\[GothicCapitalG]1, 
                          sex}} //. \[InvisibleSpace]ReferencePointSame[\
\[GothicCapitalG], \[GothicCapitalG]1]\[Vee]ReferencePointZero[{\
\[GothicCapitalG], \[GothicCapitalG]2}]\) \
/. \[InvisibleSpace]{\[GothicM]\_\(i_\_{\[GothicCapitalG], _}\) - \
\[GothicM]\_\(i_\_{\[GothicCapitalG]2, _}\) \[RuleDelayed] \
\(-\[CapitalDelta]v\[GothicM]\_i\), \
\[GothicCapitalD]\_{i_\_{\[GothicCapitalG]1, \[GothicCapitalM]}} \
\[RuleDelayed] \[CapitalDelta]v\[GothicM]\_i}]};\)\)], "Input",
  CellLabel->"In[60]:=",
  InitializationCell->True],

Cell["\<\
A pairwise association is generated by the change in reference \
point:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicCapitalD]\_{m\_{\[GothicCapitalG]2, \[GothicCapitalM]}, n\_{\
\[GothicCapitalG]2, \[GothicCapitalM]}} /. vsr2\)], "Input",
  CellLabel->"In[61]:="],

Cell[BoxData[
    \(\[GothicCapitalD]\_{m\_{\[GothicCapitalG]1, \[GothicCapitalM]}, n\_{\
\[GothicCapitalG]1, \[GothicCapitalM]}} - \[CapitalDelta]v\[GothicM]\_m\ \
\[CapitalDelta]v\[GothicM]\_n\)], "Output",
  CellLabel->"Out[61]="]
}, Open  ]],

Cell[TextData[{
  "The ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]v\[GothicM]\_i\)]],
  " can be substituted later.  This is the change in mean, in compact \
notation:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((\(\[GothicM]\_\(m\_{\[GothicCapitalG]1, \[GothicCapitalM]}\) - \
\[GothicM]\_\(m\_{\[GothicCapitalG], \[GothicCapitalM]}\) //. vsr\) /. 
            collapse[\[GothicCapitalG]] // Simplify)\) /. pqrl\)], "Input",
  CellLabel->"In[70]:="],

Cell[BoxData[
    \(\(-ss\)\ \((\(-\[GothicP]\_\[DoubleStruckM]\)\ \[GothicQ]\_\
\[DoubleStruckM]\ \((\[GothicP]\_\[DoubleStruckN] - \[GothicQ]\_\
\[DoubleStruckN])\) + \((\[GothicP]\_\[DoubleStruckM] - \[GothicQ]\_\
\[DoubleStruckM])\)\ \[GothicCapitalD]\_{\[DoubleStruckM], \[DoubleStruckN]})\
\)\)], "Output",
  CellLabel->"Out[70]="]
}, Open  ]],

Cell["\<\
Rules are applied in a similar way to represent sexual selection:\
\
\>", "Text"],

Cell[BoxData[
    \(\(ssr = {x : \((\[GothicCapitalD]\__ | \[GothicM]\__)\) \[RuleDelayed] 
            Simplify[\(\(\(\(\(\(\(\(x /. 
                                Selection[{\[GothicCapitalZ], \
\[GothicCapitalA]}, SelectionCoefficient, FitnessSet, {Sex}]\) /. 
                              UnionOfGametes[{\[GothicCapitalG]2, \
\[GothicCapitalZ]}]\) /. 
                            RandomUnion[\[GothicCapitalG]2]\) /. \
{\[GothicA]\_\(sex_, \[DoubleStruckCapitalU]_\) \[RuleDelayed] 
                              Simplify[
                                MakeSelectionCoefficient[\
\[DoubleStruckCapitalU], W\_sex]]}\) /. Biallelic[MeanContribution]\) /. 
                      ReferencePointSame[\[GothicCapitalG]2, \
\[GothicCapitalZ]]\) /. ReferencePointZero[\[GothicCapitalG]2]\) /. 
                  SymmetricSexes[]\) /. {\[GothicCapitalD]\_\(\
\[DoubleStruckCapitalU]_?\((\(! OrderedQ[#]\) &)\)\) :> \
\[GothicCapitalD]\_\(Sort[\[DoubleStruckCapitalU]]\)}]};\)\)], "Input",
  CellLabel->"In[71]:=",
  InitializationCell->True],

Cell["\<\
This gives the pairwise association among genes from females in \
terms of the \[GothicCapitalD] at stage \[GothicCapitalG]2, after viability \
selection\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\[GothicCapitalD]\_{m\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}, n\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}} /. ssr\) /. collapse[\[GothicCapitalG]2]\) /. 
      pqrl\)], "Input",
  CellLabel->"In[73]:="],

Cell[BoxData[
    \(\[GothicCapitalD]\_{\[DoubleStruckM], \[DoubleStruckN]} + \
\[GothicCapitalD]\_{\[DoubleStruckM], \[DoubleStruckN]}\ \[GothicCapitalD]\_{\
\[DoubleStruckM], \[DoubleStruckN], \[DoubleStruckP]}\ \
\((\(-\(\[Beta]\_1\/wbF0\_\[GothicCapitalM]\)\) + \[Beta]\_2\/wbF1\_\
\[GothicCapitalM])\) + \(\[GothicCapitalD]\_{\[DoubleStruckM], \
\[DoubleStruckN], \[DoubleStruckP]}\ \((\(-wbF1\_\[GothicCapitalM]\)\ \((1 + \
\[GothicQ]\_\[DoubleStruckM]\ \[GothicQ]\_\[DoubleStruckN]\ \[Beta]\_1)\) + \
wbF0\_\[GothicCapitalM]\ \((1 + \[GothicP]\_\[DoubleStruckM]\ \[GothicP]\_\
\[DoubleStruckN]\ \[Beta]\_2)\))\)\)\/\(wbF0\_\[GothicCapitalM]\ wbF1\_\
\[GothicCapitalM]\)\)], "Output",
  CellLabel->"Out[73]="]
}, Open  ]],

Cell["\<\
The normalising constants have been left in at this stage.  To \
simplify,we do the following:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\(\[GothicCapitalD]\_{m\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}, n\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}} /. ssr\) /. {\[Beta]\_i_ :> sub\[Beta][i - 1], 
              wbF1\_\[GothicCapitalM] \[Rule] 1 + \[Delta]w[1], 
              wbF0\_\[GothicCapitalM] \[Rule] 1 + \[Delta]w[0]}\) /. 
          collapse[\[GothicCapitalG]2]\) /. pqrl // Simplify\)], "Input",
  CellLabel->"In[78]:="],

Cell[BoxData[
    \(\[GothicCapitalD]\_{\[DoubleStruckM], \[DoubleStruckN]}\)], "Output",
  CellLabel->"Out[78]="]
}, Open  ]],

Cell["\<\
Sexual selection does not alter associations between genes derived \
from females.  The expressions here are simple because they are expressed \
relative to reference points at stage \[GothicCapitalG]2.  \
\>", "Text"],

Cell["\<\
This gives the pairwise association `among genes from opposite \
sexes in terms of the \[GothicCapitalD] at stage \[GothicCapitalG]2, after \
viability selection\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\(\[GothicCapitalD]\_{m\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}, n\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}} /. ssr\) /. {\[Beta]\_i_ :> sub\[Beta][i - 1], 
              wbF1\_\[GothicCapitalM] \[Rule] 1 + \[Delta]w[1], 
              wbF0\_\[GothicCapitalM] \[Rule] 1 + \[Delta]w[0]}\) /. 
          collapse[\[GothicCapitalG]2]\) /. pqrl // Simplify\)], "Input",
  CellLabel->"In[80]:="],

Cell[BoxData[
    \(\(-\(\((\[GothicCapitalD]\_{\[DoubleStruckM], \[DoubleStruckP]}\ \((\(-\
\((\[GothicQ]\_\[DoubleStruckM]\ \[GothicQ]\_\[DoubleStruckN] + \
\[GothicCapitalD]\_{\[DoubleStruckM], \[DoubleStruckN]})\)\)\ \((1 + \
\[Delta]w[0])\)\ \[Delta]w[
                    1] + \[GothicP]\_\[DoubleStruckN]\%2\ \[GothicQ]\_\
\[DoubleStruckM]\ \[Delta]w[
                    0]\ \((1 + \[Delta]w[
                        1])\) + \[GothicP]\_\[DoubleStruckN]\ \((\
\[GothicCapitalD]\_{\[DoubleStruckM], \[DoubleStruckN]}\ \((\(-\[Delta]w[
                                0]\) + \[Delta]w[
                              1])\) + \[GothicQ]\_\[DoubleStruckM]\ \((\
\[GothicQ]\_\[DoubleStruckN]\ \((1 + \[Delta]w[0])\)\ \[Delta]w[
                                1] - \[Delta]w[
                                0]\ \((1 + \[Delta]w[
                                    1])\))\))\))\))\)/\((\((\[GothicQ]\_\
\[DoubleStruckM]\ \[GothicQ]\_\[DoubleStruckN] + \[GothicCapitalD]\_{\
\[DoubleStruckM], \[DoubleStruckN]})\)\ \((1 + \[Delta]w[
                  0])\)\ \((1 + \[Delta]w[1])\))\)\)\)\)], "Output",
  CellLabel->"Out[80]="]
}, Open  ]],

Cell["\<\
Note that I have used the fact that viability selection is \
sex-independent to reduce the expression to one in terms of frequencies in \
females at stage \[GothicCapitalG]2\
\>", "Text"],

Cell["\<\
Finally, set up rules for meiosis, which relate stages \
\[GothicCapitalG]2 to stage \[GothicCapitalA]:\
\>", "MathCaption"],

Cell[BoxData[
    \(\(rro = {\[GothicR]\_\(\[DoubleStruckCapitalA]_?\((\(! OrderedQ[#]\) &)\
\), \[DoubleStruckCapitalB]_\) \[RuleDelayed] \[GothicR]\_\(Sort[\
\[DoubleStruckCapitalA]], \[DoubleStruckCapitalB]\), \[GothicR]\_\(\
\[DoubleStruckCapitalA]_, \[DoubleStruckCapitalB]_?\((\(! OrderedQ[#]\) \
&)\)\) \[RuleDelayed] \[GothicR]\_\(\[DoubleStruckCapitalA], Sort[\
\[DoubleStruckCapitalB]]\)};\)\)], "Input",
  CellLabel->"In[24]:=",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(rcr = {\[GothicR]\_\({}, {m, n}\) \[Rule] \(1 - c\_\(m, n\)\)\/2, \
\[GothicR]\_\({m}, {n}\) \[Rule] 
            c\_\(m, n\)\/2, \[GothicR]\_\({}, {m, p}\) \[Rule] \(1 - c\_\(m, \
p\)\)\/2, \[GothicR]\_\({m}, {p}\) \[Rule] 
            c\_\(m, p\)\/2, \[GothicR]\_\({}, {n, p}\) \[Rule] \(\((1 - \
c\_\(m, n\))\) \((1 - c\_\(m, p\))\) + \(c\_\(m, n\)\) c\_\(m, p\)\)\/2, \
\[GothicR]\_\({n}, {p}\) \[Rule] \(\(c\_\(m, n\)\) \((1 - c\_\(m, p\))\) + \
\((1 - c\_\(m, n\))\) c\_\(m, p\)\)\/2, \[GothicR]\_\({}, {m, n, p}\) \[Rule] \
\(\((1 - c\_\(m, n\))\) \((1 - c\_\(m, p\))\)\)\/2, \[GothicR]\_\({m}, {n, p}\
\) \[Rule] \(\(c\_\(m, n\)\) c\_\(m, p\)\)\/2, \[GothicR]\_\({n}, {m, p}\) \
\[Rule] \(\(c\_\(m, n\)\) \((1 - c\_\(m, p\))\)\)\/2, \[GothicR]\_\({p}, {m, \
n}\) \[Rule] \(\((1 - c\_\(m, n\))\) c\_\(m, p\)\)\/2};\)\)], "Input",
  CellLabel->"In[25]:=",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  "Note that the factors of 2 arise because of the way the \[GothicR] are \
defined: ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicR]\_\(A, B\) + \[GothicR]\_\(B, A\)\)]],
  " is the total frequency of recombination events that bring A and B \
together.  This allows for the possibility of non-Mendelian inheritance."
}], "Text"],

Cell[BoxData[
    \(\(rec = {x : \((\[GothicCapitalD]\__ | \[GothicM]\__)\) \[RuleDelayed] 
              Simplify /@ 
                Collect[\(\(\(\(x /. Recombination[]\) /. 
                          SymmetricRecombination[]\) /. rro\) /. rcr\) /. 
                    ReferencePointSame[\[GothicCapitalG]2, \
\[GothicCapitalA]], 
                  c\___] /. \
{\[GothicCapitalD]\_\(\[DoubleStruckCapitalU]_?\((\(! OrderedQ[#]\) &)\)\) :> \
\[GothicCapitalD]\_\(Sort[\[DoubleStruckCapitalU]]\)}};\)\)], "Input",
  CellLabel->"In[26]:=",
  InitializationCell->True],

Cell["\<\
The pairwise association is a complicated expression which involves \
the various changes in reference point: \
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicCapitalD]\_{n\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}, m\
\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}} //. rec\)], "Input",
  CellLabel->"In[240]:="],

Cell[BoxData[
    \(1\/2\ \((\[GothicCapitalD]\_{n\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}, m\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}} + \[GothicCapitalD]\_{n\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}}\ \((\[WeierstrassP]\_\(m\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}\) - \[WeierstrassP]\_\(m\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\))\) + \((\[GothicCapitalD]\_{m\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}} + \[WeierstrassP]\_\
\(m\_{\[GothicCapitalG]2, \[GothicCapitalF]}\) - \[WeierstrassP]\_\(m\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\))\)\ \((\[WeierstrassP]\_\(n\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}\) - \[WeierstrassP]\_\(n\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\))\))\) + 
      1\/2\ \((\[GothicCapitalD]\_{n\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}, m\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}} + \[GothicCapitalD]\_{n\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}}\ \((\[WeierstrassP]\_\(m\_{\
\[GothicCapitalG]2, \[GothicCapitalM]}\) - \[WeierstrassP]\_\(m\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\))\) + \((\[GothicCapitalD]\_{m\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalM]}} + \[WeierstrassP]\_\
\(m\_{\[GothicCapitalG]2, \[GothicCapitalM]}\) - \[WeierstrassP]\_\(m\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\))\)\ \((\[WeierstrassP]\_\(n\_{\
\[GothicCapitalG]2, \[GothicCapitalM]}\) - \[WeierstrassP]\_\(n\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\))\))\) - 
      1\/2\ \((\[GothicCapitalD]\_{n\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}, m\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}} - \[GothicCapitalD]\_{n\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}, m\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\_{n\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalM]}, m\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\
\_{n\_{\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalM]}, m\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\
\_{n\_{\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}}\ \
\[WeierstrassP]\_\(m\_{\[GothicCapitalG]2, \[GothicCapitalF]}\) - \
\[GothicCapitalD]\_{n\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}}\ \[WeierstrassP]\_\(m\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}\) - \[GothicCapitalD]\_{n\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}}\ \[WeierstrassP]\_\(m\_{\
\[GothicCapitalG]2, \[GothicCapitalM]}\) + \[GothicCapitalD]\_{n\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalM]}}\ \
\[WeierstrassP]\_\(m\_{\[GothicCapitalG]2, \[GothicCapitalM]}\) + \
\[GothicCapitalD]\_{m\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}}\ \[WeierstrassP]\_\(n\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}\) - \[GothicCapitalD]\_{m\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}}\ \[WeierstrassP]\_\(n\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}\) + \[WeierstrassP]\_\(m\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}\)\ \[WeierstrassP]\_\(n\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}\) - \[WeierstrassP]\_\(m\_{\
\[GothicCapitalG]2, \[GothicCapitalM]}\)\ \[WeierstrassP]\_\(n\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}\) - \[GothicCapitalD]\_{m\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}}\ \
\[WeierstrassP]\_\(n\_{\[GothicCapitalG]2, \[GothicCapitalM]}\) + \
\[GothicCapitalD]\_{m\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}}\ \[WeierstrassP]\_\(n\_{\[GothicCapitalG]2, \
\[GothicCapitalM]}\) - \[WeierstrassP]\_\(m\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}\)\ \[WeierstrassP]\_\(n\_{\[GothicCapitalG]2, \
\[GothicCapitalM]}\) + \[WeierstrassP]\_\(m\_{\[GothicCapitalG]2, \
\[GothicCapitalM]}\)\ \[WeierstrassP]\_\(n\_{\[GothicCapitalG]2, \
\[GothicCapitalM]}\))\)\ c\_\(m, n\)\)], "Output",
  CellLabel->"Out[240]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Intermediate quantities: normalising constants vb, wb etc.", \
"SubsubsectionIcon",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  "As a reminder, the intermediate quantities are given as follows.  Mean \
viability, ",
  StyleBox["vb",
    FontWeight->"Bold"],
  ":"
}], "Text",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\[LeftAngleBracket]V\_\[GothicCapitalM]\[RightAngleBracket] /. vsr\) /. 
      ReferencePointZero[\[GothicCapitalG]]\)], "Input",
  CellLabel->"In[81]:="],

Cell[BoxData[
    \(1 + s + 
      2\ s\ \[GothicCapitalD]\_{m\_{\[GothicCapitalG], \[GothicCapitalF]}, \
n\_{\[GothicCapitalG], \[GothicCapitalF]}} - 
      s\ \[GothicM]\_\(m\_{\[GothicCapitalG], \[GothicCapitalM]}\) - 
      s\ \[GothicM]\_\(n\_{\[GothicCapitalG], \[GothicCapitalM]}\) + 
      2\ s\ \[GothicM]\_\(m\_{\[GothicCapitalG], \[GothicCapitalM]}\)\ \
\[GothicM]\_\(n\_{\[GothicCapitalG], \[GothicCapitalM]}\)\)], "Output",
  CellLabel->"Out[81]="]
}, Open  ]],

Cell[TextData[{
  "Mean output of females of genotype ",
  Cell[BoxData[
      \(TraditionalForm\`X\_P = 0, \ wbF0\_sex\)]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(wbFS[0]\)], "Input",
  CellLabel->"In[267]:="],

Cell[BoxData[
    \(1 + \((\[GothicCapitalD]\_{m\_{\[GothicCapitalG]2, \[GothicCapitalF]}, \
n\_{\[GothicCapitalG]2, \[GothicCapitalF]}} + \((\(-1\) + \[GothicM]\_\(m\_{\
\[GothicCapitalG]2, \[GothicCapitalM]}\))\)\ \((\(-1\) + \[GothicM]\_\(n\_{\
\[GothicCapitalG]2, \[GothicCapitalM]}\))\))\)\ \[Beta]\_1\)], "Output",
  CellLabel->"Out[267]="]
}, Open  ]],

Cell[TextData[{
  "Mean output of females of genotype ",
  Cell[BoxData[
      \(TraditionalForm\`X\_P = 1, \ wbF1\_sex\)]],
  ":"
}], "Text",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(wbFS[1]\)], "Input",
  CellLabel->"In[268]:="],

Cell[BoxData[
    \(1 + \[GothicCapitalD]\_{m\_{\[GothicCapitalG]2, \[GothicCapitalF]}, \
n\_{\[GothicCapitalG]2, \[GothicCapitalF]}}\ \[Beta]\_2 + \[GothicM]\_\(m\_{\
\[GothicCapitalG]2, \[GothicCapitalM]}\)\ \
\[GothicM]\_\(n\_{\[GothicCapitalG]2, \[GothicCapitalM]}\)\ \[Beta]\_2\)], \
"Output",
  CellLabel->"Out[268]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "The complete set of rules: ",
  Cell[BoxData[
      \(\[CapitalDelta]\[GothicM]\_\(n\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}\)\)]]
}], "SubsubsectionIcon"],

Cell[TextData[{
  "Now, try applying the complete set of rules:",
  Cell[BoxData[
      \(\(\(\ \)\(\[GothicM]\_\(n\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}\)\)\)\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(qqm = \(\(\[GothicM]\_\(n\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}\) //. rec\) /. ssr\) /. {\[Beta]\_i_ :> sub\[Beta][i - 1], 
            wbF1\_\[GothicCapitalM] \[Rule] 1 + \[Delta]w[1], 
            wbF0\_\[GothicCapitalM] \[Rule] 1 + \[Delta]w[0]} // 
        Simplify\)], "Input",
  CellLabel->"In[503]:="],

Cell[BoxData[
    \(\(\[GothicM]\_\(p\_{\[GothicCapitalG]2, \[GothicCapitalF]}\)\ \((1 + \
\[Delta]w[0])\)\ \[Delta]w[1] + \[GothicM]\_\(n\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}\)\ \((\[GothicM]\_\(p\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}\)\ \((\[Delta]w[0] - \[Delta]w[1])\) + \((2 + \
\[Delta]w[0])\)\ \((1 + \[Delta]w[1])\))\)\)\/\(2\ \((1 + \[Delta]w[0])\)\ \
\((1 + \[Delta]w[1])\)\)\)], "Output",
  CellLabel->"Out[503]="]
}, Open  ]],

Cell["\<\
Having checked that the expression has been fully reduced to \
frequencies in stage \[GothicCapitalG]2, we can collapse subscripts:\
\>", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify /@ Apart[qqm /. csr2]\)], "Input",
  CellLabel->"In[558]:="],

Cell[BoxData[
    \(\(\[GothicM]\_\[DoubleStruckP]\ \((1 + \[Delta]w[0])\) + \[GothicM]\_\
\[DoubleStruckN]\ \((2 - \[GothicM]\_\[DoubleStruckP] + \
\[Delta]w[0])\)\)\/\(2\ \((1 + \[Delta]w[0])\)\) + \(\((\(-1\) + \[GothicM]\_\
\[DoubleStruckN])\)\ \[GothicM]\_\[DoubleStruckP]\)\/\(2\ \((1 + \
\[Delta]w[1])\)\)\)], "Output",
  CellLabel->"Out[524]="]
}, Open  ]],

Cell[TextData[{
  "Recall that \[Delta]w[0], \[Delta]w[1] are expressions proportional to the \
",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta]\_1, \ \[Beta]\_2\)]],
  ".  To substitute, use:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(qqm /. {\[Delta]w[i : \((1 | 0)\)] \[RuleDelayed] wbFS[i]}\)], "Input",
  CellLabel->"In[561]:="],

Cell[BoxData[
    \(\((\[GothicM]\_\(p\_{\[GothicCapitalG]2, \[GothicCapitalF]}\)\ \((2 + \
\((\[GothicCapitalD]\_{m\_{\[GothicCapitalG]2, \[GothicCapitalF]}, n\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}} + \((\(-1\) + \[GothicM]\_\(m\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}\))\)\ \((\(-1\) + \[GothicM]\_\(n\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}\))\))\)\ \[Beta]\_1)\)\ \((1 + \
\[GothicCapitalD]\_{m\_{\[GothicCapitalG]2, \[GothicCapitalF]}, n\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}}\ \[Beta]\_2 + \[GothicM]\_\(m\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}\)\ \
\[GothicM]\_\(n\_{\[GothicCapitalG]2, \[GothicCapitalF]}\)\ \[Beta]\_2)\) + \
\[GothicM]\_\(n\_{\[GothicCapitalG]2, \[GothicCapitalF]}\)\ \
\((\[GothicM]\_\(p\_{\[GothicCapitalG]2, \[GothicCapitalF]}\)\ \((\((\
\[GothicCapitalD]\_{m\_{\[GothicCapitalG]2, \[GothicCapitalF]}, n\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}} + \((\(-1\) + \[GothicM]\_\(m\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}\))\)\ \((\(-1\) + \[GothicM]\_\(n\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}\))\))\)\ \[Beta]\_1 - \
\[GothicCapitalD]\_{m\_{\[GothicCapitalG]2, \[GothicCapitalF]}, n\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}}\ \[Beta]\_2 - \[GothicM]\_\(m\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}\)\ \
\[GothicM]\_\(n\_{\[GothicCapitalG]2, \[GothicCapitalF]}\)\ \[Beta]\_2)\) + \
\((3 + \((\[GothicCapitalD]\_{m\_{\[GothicCapitalG]2, \[GothicCapitalF]}, \
n\_{\[GothicCapitalG]2, \[GothicCapitalF]}} + \((\(-1\) + \[GothicM]\_\(m\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}\))\)\ \((\(-1\) + \[GothicM]\_\(n\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}\))\))\)\ \[Beta]\_1)\)\ \((2 + \
\[GothicCapitalD]\_{m\_{\[GothicCapitalG]2, \[GothicCapitalF]}, n\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}}\ \[Beta]\_2 + \[GothicM]\_\(m\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}\)\ \
\[GothicM]\_\(n\_{\[GothicCapitalG]2, \[GothicCapitalF]}\)\ \[Beta]\_2)\))\))\
\)/\((2\ \((2 + \((\[GothicCapitalD]\_{m\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}, n\_{\[GothicCapitalG]2, \[GothicCapitalF]}} + \((\(-1\) + \
\[GothicM]\_\(m\_{\[GothicCapitalG]2, \[GothicCapitalF]}\))\)\ \((\(-1\) + \
\[GothicM]\_\(n\_{\[GothicCapitalG]2, \[GothicCapitalF]}\))\))\)\ \[Beta]\_1)\
\)\ \((2 + \[GothicCapitalD]\_{m\_{\[GothicCapitalG]2, \[GothicCapitalF]}, \
n\_{\[GothicCapitalG]2, \[GothicCapitalF]}}\ \[Beta]\_2 + \[GothicM]\_\(m\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}\)\ \
\[GothicM]\_\(n\_{\[GothicCapitalG]2, \[GothicCapitalF]}\)\ \
\[Beta]\_2)\))\)\)], "Output",
  CellLabel->"Out[561]="]
}, Closed]],

Cell["Now, make a rule which does this and stores the result:", "MathCaption"],

Cell[BoxData[{
    \(\(Clear[new\[GothicM]];\)\), "\[IndentingNewLine]", 
    \(\(new\[GothicM][\[DoubleStruckI]_] := \(new\[GothicM][\[DoubleStruckI]] \
= Simplify /@ 
            Apart[\((\(\(\[GothicM]\_\[DoubleStruckI] //. rec\) /. 
                    ssr\) /. {\[Beta]\_i_ :> sub\[Beta][i - 1], 
                    wbF1\__ \[Rule] 1 + \[Delta]w[1], 
                    wbF0\__ \[Rule] 1 + \[Delta]w[0]})\)]\);\)\)}], "Input",
  CellLabel->"In[27]:=",
  InitializationCell->True],

Cell["This gives quite a simple result:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(new\[GothicM][n\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}] /. 
        csr2\) //. {\(-1\) + \[GothicM]\_\[DoubleStruckI]_ \[RuleDelayed] \(-\
\[GothicQ]\_\[DoubleStruckI]\), 
        1 - \[GothicM]\_\[DoubleStruckI]_ \[RuleDelayed] \[GothicQ]\_\
\[DoubleStruckI], \(-1\) + 
            2  \[GothicM]\_\[DoubleStruckI]_ \[RuleDelayed] \[GothicP]\_\
\[DoubleStruckI] - \[GothicQ]\_\[DoubleStruckI], \
\[GothicM]\_\[DoubleStruckI]_ \[RuleDelayed] \
\[GothicP]\_\[DoubleStruckI]}\)], "Input",
  CellLabel->"In[549]:="],

Cell[BoxData[
    \(\(\[GothicP]\_\[DoubleStruckP]\ \((1 + \[Delta]w[0])\) + \[GothicP]\_\
\[DoubleStruckN]\ \((2 - \[GothicP]\_\[DoubleStruckP] + \
\[Delta]w[0])\)\)\/\(2\ \((1 + \[Delta]w[0])\)\) - \(\[GothicP]\_\
\[DoubleStruckP]\ \[GothicQ]\_\[DoubleStruckN]\)\/\(2\ \((1 + \[Delta]w[1])\)\
\)\)], "Output",
  CellLabel->"Out[549]="]
}, Open  ]],

Cell["Some simplification  by hand gives:", "Text"],

Cell[BoxData[
    \(\((\[GothicP]\_\[DoubleStruckN] + \[GothicP]\_\[DoubleStruckP])\)\/2 + \
\(\[GothicP]\_\[DoubleStruckN]\ \[GothicQ]\_\[DoubleStruckP]\)\/\(2\ \((1 + \
\[Delta]w[0])\)\) - \(\[GothicP]\_\[DoubleStruckP]\ \[GothicQ]\_\
\[DoubleStruckN]\)\/\(2\ \((1 + \[Delta]w[1])\)\)\)], "Output",
  CellLabel->"Out[548]="],

Cell["This is the same as above.", "Text"],

Cell["\<\
To get the full recursion, one would use the rules for viability \
selection, vsr:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicM]\_\(n\_{\[GothicCapitalG]2, \[GothicCapitalM]}\) /. 
      vsr\)], "Input",
  CellLabel->"In[551]:="],

Cell[BoxData[
    \(\[GothicCapitalD]\_{m\_{\[GothicCapitalG], \[GothicCapitalF]}, n\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ \((ss - 
            2\ ss\ \[GothicM]\_\(n\_{\[GothicCapitalG], \[GothicCapitalF]}\))\
\) + \[GothicM]\_\(n\_{\[GothicCapitalG], \[GothicCapitalF]}\)\ \((1 - ss - 
            2\ ss\ \[GothicM]\_\(m\_{\[GothicCapitalG], \[GothicCapitalF]}\)\ \
\((\(-1\) + \[GothicM]\_\(n\_{\[GothicCapitalG], \[GothicCapitalF]}\))\) + 
            ss\ \[GothicM]\_\(n\_{\[GothicCapitalG], \
\[GothicCapitalF]}\))\)\)], "Output",
  CellLabel->"Out[551]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "The complete set of rules: ",
  Cell[BoxData[
      \(\[GothicCapitalD]\_{n\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}, \
m\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}}\)]]
}], "SubsubsectionIcon",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  "Now, try applying the complete set of rules:",
  Cell[BoxData[
      \(\(\(\ \)\(\[GothicCapitalD]\_{n\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}, m\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}}\)\)\)]]
}], "Text",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(qqm = 
      Simplify /@ 
        Apart[\(\(\(\(\[GothicCapitalD]\_{n\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}, m\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}} //. 
                    rec\) /. ssr\) /. 
                ReferencePointZero[{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalG]2, \[GothicCapitalG]}]\) /. 
              SymmetricSexes[]\) /. {\[Beta]\_i_ :> sub\[Beta][i - 1], 
              wbF1\_\[GothicCapitalM] \[Rule] 1 + \[Delta]w[1], 
              wbF0\_\[GothicCapitalM] \[Rule] 1 + \[Delta]w[0]}]\)], "Input",
  CellLabel->"In[566]:="],

Cell[BoxData[
    \(\(\(1\/\(2\ \((1 + \[Delta]w[
                  0])\)\)\)\((\(-2\)\ \
\[GothicM]\_\(m\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\ \
\[GothicM]\_\(n\_{\[GothicCapitalG]2, \[GothicCapitalF]}\) + 
          2\ \[GothicM]\_\(m\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\
\ \[GothicM]\_\(n\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\) + \
\[GothicM]\_\(p\_{\[GothicCapitalG]2, \[GothicCapitalF]}\) - \
\[GothicM]\_\(m\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\ \
\[GothicM]\_\(p\_{\[GothicCapitalG]2, \[GothicCapitalF]}\) + \
\[GothicM]\_\(m\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\ \
\[GothicM]\_\(n\_{\[GothicCapitalG]2, \[GothicCapitalF]}\)\ \
\[GothicM]\_\(p\_{\[GothicCapitalG]2, \[GothicCapitalF]}\) - \
\[GothicM]\_\(n\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\ \
\[GothicM]\_\(p\_{\[GothicCapitalG]2, \[GothicCapitalF]}\) + \
\[GothicCapitalD]\_{m\_{\[GothicCapitalG]2, \[GothicCapitalF]}, p\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}}\ c\_\(m, n\) + \
\[GothicCapitalD]\_{n\_{\[GothicCapitalG]2, \[GothicCapitalF]}, p\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}}\ c\_\(m, n\) - \
\[GothicCapitalD]\_{m\_{\[GothicCapitalG]2, \[GothicCapitalF]}, p\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}}\ \
\[GothicM]\_\(n\_{\[GothicCapitalG]2, \[GothicCapitalF]}\)\ c\_\(m, n\) - \
\[GothicM]\_\(p\_{\[GothicCapitalG]2, \[GothicCapitalF]}\)\ c\_\(m, n\) + \
\[GothicM]\_\(n\_{\[GothicCapitalG]2, \[GothicCapitalF]}\)\ \
\[GothicM]\_\(p\_{\[GothicCapitalG]2, \[GothicCapitalF]}\)\ c\_\(m, n\) + \
\[GothicCapitalD]\_{m\_{\[GothicCapitalG]2, \[GothicCapitalF]}, n\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}}\ \((\(-1\) + 
                c\_\(m, n\))\)\ \((\(-2\) + \[GothicM]\_\(p\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}\) - \[Delta]w[
                  0])\) - \[GothicM]\_\(m\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalF]}\)\ \[GothicM]\_\(n\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}\)\ \[Delta]w[0] + 
          2\ \[GothicM]\_\(m\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\
\ \[GothicM]\_\(n\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\ \[Delta]w[
              0] + \[GothicM]\_\(p\_{\[GothicCapitalG]2, \[GothicCapitalF]}\)\
\ \[Delta]w[
              0] - \[GothicM]\_\(m\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalF]}\)\ \[GothicM]\_\(p\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}\)\ \[Delta]w[
              0] - \[GothicM]\_\(n\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalF]}\)\ \[GothicM]\_\(p\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}\)\ \[Delta]w[
              0] + \[GothicCapitalD]\_{m\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}, p\_{\[GothicCapitalG]2, \[GothicCapitalF]}}\ c\_\(m, n\)\ \
\[Delta]w[
              0] + \[GothicCapitalD]\_{n\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}, p\_{\[GothicCapitalG]2, \[GothicCapitalF]}}\ c\_\(m, n\)\ \
\[Delta]w[
              0] - \[GothicM]\_\(p\_{\[GothicCapitalG]2, \[GothicCapitalF]}\)\
\ c\_\(m, n\)\ \[Delta]w[
              0] + \[GothicM]\_\(n\_{\[GothicCapitalG]2, \[GothicCapitalF]}\)\
\ \[GothicM]\_\(p\_{\[GothicCapitalG]2, \[GothicCapitalF]}\)\ c\_\(m, n\)\ \
\[Delta]w[
              0] - \[GothicM]\_\(m\_{\[GothicCapitalG]2, \[GothicCapitalF]}\)\
\ \((\[GothicM]\_\(n\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\ \((2 - \
\[GothicM]\_\(p\_{\[GothicCapitalG]2, \[GothicCapitalF]}\) + \[Delta]w[
                        0])\) + \[GothicM]\_\(n\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}\)\ \((\(-2\) + \[GothicM]\_\(p\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}\)\ \((1 + c\_\(m, n\))\) - \[Delta]w[0] + 
                      c\_\(m, n\)\ \[Delta]w[0])\) + 
                c\_\(m, n\)\ \((\[GothicCapitalD]\_{n\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}, p\_{\[GothicCapitalG]2, \[GothicCapitalF]}} - \
\[GothicM]\_\(p\_{\[GothicCapitalG]2, \[GothicCapitalF]}\)\ \((1 + \[Delta]w[
                              0])\))\))\))\)\) + \(\(1\/\(2\ \((1 + \[Delta]w[
                  1])\)\)\)\((\((\[GothicCapitalD]\_{n\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}, p\_{\[GothicCapitalG]2, \[GothicCapitalF]}}\ \((\(-1\) + \
\[GothicM]\_\(m\_{\[GothicCapitalG]2, \[GothicCapitalF]}\))\) + \
\[GothicCapitalD]\_{m\_{\[GothicCapitalG]2, \[GothicCapitalF]}, p\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}}\ \((\(-1\) + \[GothicM]\_\(n\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}\))\))\)\ c\_\(m, n\) + \[GothicM]\_\(p\
\_{\[GothicCapitalG]2, \[GothicCapitalF]}\)\ \((\(-1\) - \[GothicM]\_\(m\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\ \((\(-1\) + \[GothicM]\_\(n\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}\))\) + \[GothicM]\_\(m\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}\)\ \
\[GothicM]\_\(n\_{\[GothicCapitalG]2, \[GothicCapitalF]}\) + \
\[GothicM]\_\(n\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\) - \[GothicM]\
\_\(m\_{\[GothicCapitalG]2, \[GothicCapitalF]}\)\ \[GothicM]\_\(n\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\) - \[GothicCapitalD]\_{m\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}, n\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}}\ \((\(-1\) + c\_\(m, n\))\) + 
                c\_\(m, n\) - \[GothicM]\_\(m\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}\)\ c\_\(m, n\) - \[GothicM]\_\(n\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}\)\ c\_\(m, n\) + \[GothicM]\_\(m\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}\)\ \[GothicM]\_\(n\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}\)\ c\_\(m, n\))\))\)\)\)], "Output",
  CellLabel->"Out[566]="]
}, Closed]],

Cell["\<\
The expression involves the new mean, because that is the reference \
point for the new \[GothicCapitalD]:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Cases[qqm, \[GothicM]\__, {1, \[Infinity]}] // Union\)], "Input",
  CellLabel->"In[568]:="],

Cell[BoxData[
    \({\[GothicM]\_\(m\_{\[GothicCapitalG]2, \[GothicCapitalF]}\), \[GothicM]\
\_\(m\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\), \[GothicM]\_\(n\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}\), \[GothicM]\_\(n\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\), \[GothicM]\_\(p\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}\)}\)], "Output",
  CellLabel->"Out[568]="]
}, Open  ]],

Cell["Substitute for the new mean:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ff = \(qqm /. 
            csr2\) /. {\[GothicM]\_\(i_\_{\(\[GothicCapitalG]\^*\), sex_}\) \
\[RuleDelayed] \((new\[GothicM][i\_{\(\[GothicCapitalG]\^*\), sex}] /. 
                  csr2)\)} // Simplify\)], "Input",
  CellLabel->"In[577]:="],

Cell[BoxData[
    \(\((\(-2\)\ \[GothicCapitalD]\_{\[DoubleStruckM], \[DoubleStruckN]}\ \((\
\(-1\) + c\_\(m, n\))\)\ \((1 + \[Delta]w[0])\)\ \((1 + \[Delta]w[
                  1])\)\ \((\[GothicM]\_\[DoubleStruckP]\ \((\[Delta]w[
                        0] - \[Delta]w[1])\) + \((2 + \[Delta]w[
                        0])\)\ \((1 + \[Delta]w[1])\))\) + \((1 + \[Delta]w[
                  0])\)\ \((2\ \[GothicCapitalD]\_{\[DoubleStruckM], \
\[DoubleStruckP]}\ c\_\(m, n\)\ \((1 + \[Delta]w[
                        1])\)\ \((\[GothicM]\_\[DoubleStruckN]\ \((\[Delta]w[
                              0] - \[Delta]w[1])\) + \((1 + \[Delta]w[
                              0])\)\ \[Delta]w[1])\) + \[Delta]w[
                    1]\ \((2\ \[GothicCapitalD]\_{\[DoubleStruckN], \
\[DoubleStruckP]}\ c\_\(m, n\)\ \((1 + \[Delta]w[0])\)\ \((1 + \[Delta]w[
                              1])\) + \[GothicM]\_\[DoubleStruckP]\ \((\(-2\)\
\ \((\(-1\) + c\_\(m, n\))\)\ \((1 + \[Delta]w[
                                    0])\) + \[GothicM]\_\[DoubleStruckN]\ \((\
\(-2\) - \[Delta]w[0] + 2\ c\_\(m, n\)\ \((1 + \[Delta]w[
                                        0])\))\))\)\ \((1 + \[Delta]w[
                              1])\) - \[GothicM]\_\[DoubleStruckP]\%2\ \((\
\[GothicM]\_\[DoubleStruckN]\ \((\[Delta]w[0] - \[Delta]w[
                                    1])\) + \((1 + \[Delta]w[0])\)\ \[Delta]w[
                                1])\))\))\) - \[GothicM]\_\[DoubleStruckM]\ \
\((\[GothicM]\_\[DoubleStruckN]\ \((\[GothicM]\_\[DoubleStruckP]\ \
\((\[Delta]w[0] - \[Delta]w[1])\) - \[Delta]w[
                          0]\ \((1 + \[Delta]w[
                              1])\))\)\ \((\[GothicM]\_\[DoubleStruckP]\ \((\
\[Delta]w[0] - \[Delta]w[1])\) - 
                      2\ c\_\(m, n\)\ \((1 + \[Delta]w[
                              0])\)\ \((1 + \[Delta]w[
                              1])\) + \((2 + \[Delta]w[
                              0])\)\ \((1 + \[Delta]w[
                              1])\))\) - \((1 + \[Delta]w[
                        0])\)\ \((2\ \[GothicCapitalD]\_{\[DoubleStruckN], \
\[DoubleStruckP]}\ c\_\(m, n\)\ \((\[Delta]w[0] - \[Delta]w[
                              1])\)\ \((1 + \[Delta]w[
                              1])\) + \[GothicM]\_\[DoubleStruckP]\ \[Delta]w[
                          1]\ \((2\ c\_\(m, n\)\ \((1 + \[Delta]w[
                                    0])\)\ \((1 + \[Delta]w[
                                    1])\) - \((2 + \[Delta]w[
                                    0])\)\ \((1 + \[Delta]w[
                                    1])\) + \[GothicM]\_\[DoubleStruckP]\ \((\
\(-\[Delta]w[0]\) + \[Delta]w[
                                    1])\))\))\))\))\)/\((4\ \((1 + \
\[Delta]w[0])\)\^2\ \((1 + \[Delta]w[1])\)\^2)\)\)], "Output",
  CellLabel->"Out[577]="]
}, Open  ]],

Cell["I dare say this SHOULD simplify...", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["A numerical check", "SubsubsectionIcon"],

Cell[TextData[{
  "MS gets ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\[GothicM]\_\[DoubleStruckP] = 
        0.002827706462196148`\)]],
  " by both methods; for ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\[GothicCapitalD]\_{\[DoubleStruckP], \
\[DoubleStruckM]}\)]],
  " -0.00207824 from recursions, and ",
  "-0.00170887 from BT91 calculations."
}], "Text"],

Cell["\<\
I need touse the OLD version of the rules for sexual selection, \
which differ only in that stage \[GothicCapitalG]2 has reference point the \
genotype frequencies in \[GothicCapitalG], not \[GothicCapitalG]2.\
\>", \
"Text"],

Cell[BoxData[
    \(\(ssr2 = {x : \((\[GothicCapitalD]\__ | \[GothicM]\__)\) \[RuleDelayed] 
            Simplify[\(\(\(\(\(\(\(\(\(x /. 
                                  Selection[{\[GothicCapitalZ], \
\[GothicCapitalA]}, SelectionCoefficient, 
                                    FitnessSet, {Sex}]\) /. \
{\[GothicA]\_\(sex_, \[DoubleStruckCapitalU]_\) \[RuleDelayed] 
                                    Simplify[
                                      MakeSelectionCoefficient[\
\[DoubleStruckCapitalU], W\_sex]]}\) /. 
                              UnionOfGametes[{\[GothicCapitalG]2, \
\[GothicCapitalZ]}]\) /. RandomUnion[\[GothicCapitalG]2]\) /. 
                          ReferencePointSame[\[GothicCapitalG]2, \
\[GothicCapitalZ]]\) //. Biallelic[MeanContribution]\) /. 
                      ReferencePointSame[\[GothicCapitalG], \
\[GothicCapitalG]2]\) /. ReferencePointZero[\(\[GothicCapitalG]\^*\)]\) /. 
                  SymmetricSexes[]\) /. {\[GothicCapitalD]\_\(\
\[DoubleStruckCapitalU]_?\((\(! OrderedQ[#]\) &)\)\) :> \
\[GothicCapitalD]\_\(Sort[\[DoubleStruckCapitalU]]\)}]};\)\)], "Input",
  CellLabel->"In[744]:="],

Cell["Parameter substitutions are:", "Text"],

Cell[BoxData[
    \(\(pars1 = {\[GothicM]\_\[DoubleStruckP] \[Rule] 
            0.51, \[GothicM]\_\[DoubleStruckN] \[Rule] 
            0.47, \[GothicM]\_\[DoubleStruckM] \[Rule] 
            0.61, \[GothicCapitalD]\_{\[DoubleStruckM], \[DoubleStruckP]} \
\[Rule] 0.021, \[GothicCapitalD]\_{\[DoubleStruckN], \[DoubleStruckP]} \
\[Rule] 0.017, \[GothicCapitalD]\_{\[DoubleStruckM], \[DoubleStruckN]} \
\[Rule] 0.071, \[GothicCapitalD]\_{\[DoubleStruckM], \[DoubleStruckN], \
\[DoubleStruckP]} \[Rule] 0.0023, \[Beta]\_1 \[Rule] 0.39, \[Beta]\_2 \[Rule] 
            0.38};\)\)], "Input",
  CellLabel->"In[174]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(pars2 = \((ss \[Rule] \((\(s\/\(\(\[LeftAngleBracket]V\_\
\[GothicCapitalM]\[RightAngleBracket] /. \
ReferencePointZero[\[GothicCapitalG]]\) /. csr\) /. pars1\) /. 
              s \[Rule] 0.41)\))\)\)], "Input",
  CellLabel->"In[152]:="],

Cell[BoxData[
    \(ss \[Rule] 0.3252641382800985`\)], "Output",
  CellLabel->"Out[152]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(qq3 = \(\[GothicM]\_\(p\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}\) //. rec\) /. ssr2\)], "Input",
  CellLabel->"In[721]:="],

Cell[BoxData[
    \(1\/2\ \((\[GothicCapitalD]\_{p\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}} + \[WeierstrassP]\_\(p\_{\[GothicCapitalG], \
\[GothicCapitalM]}\) + \(\(1\/\(wbF0\_\[GothicCapitalM]\ wbF1\_\
\[GothicCapitalM]\)\)\((\((\(-\[GothicCapitalD]\_{n\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}}\)\ \[GothicCapitalD]\_{p\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}} + \[GothicCapitalD]\_{n\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}, p\_{\[GothicCapitalG]2, \[GothicCapitalF]}})\)\ \((\(-\((\
\(-1\) + \[WeierstrassP]\_\(m\_{\[GothicCapitalG], \[GothicCapitalM]}\))\)\)\ \
\((\(-1\) + \[WeierstrassP]\_\(p\_{\[GothicCapitalG], \[GothicCapitalF]}\))\)\
\ wbF1\_\[GothicCapitalM]\ \[Beta]\_1 + \[WeierstrassP]\_\(m\_{\
\[GothicCapitalG], \[GothicCapitalM]}\)\ \[WeierstrassP]\_\(p\_{\
\[GothicCapitalG], \[GothicCapitalF]}\)\ wbF0\_\[GothicCapitalM]\ \[Beta]\_2)\
\))\)\) + \(\(1\/\(wbF0\_\[GothicCapitalM]\ wbF1\_\[GothicCapitalM]\)\)\((\((\
\(-\[GothicCapitalD]\_{m\_{\[GothicCapitalG]2, \[GothicCapitalF]}}\)\ \
\[GothicCapitalD]\_{p\_{\[GothicCapitalG]2, \[GothicCapitalF]}} + \
\[GothicCapitalD]\_{m\_{\[GothicCapitalG]2, \[GothicCapitalF]}, p\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}})\)\ \((\(-\((\(-1\) + \[WeierstrassP]\
\_\(n\_{\[GothicCapitalG], \[GothicCapitalM]}\))\)\)\ \((\(-1\) + \
\[WeierstrassP]\_\(p\_{\[GothicCapitalG], \[GothicCapitalF]}\))\)\ wbF1\_\
\[GothicCapitalM]\ \[Beta]\_1 + \[WeierstrassP]\_\(n\_{\[GothicCapitalG], \
\[GothicCapitalM]}\)\ \[WeierstrassP]\_\(p\_{\[GothicCapitalG], \
\[GothicCapitalF]}\)\ wbF0\_\[GothicCapitalM]\ \[Beta]\_2)\))\)\) + \
\[GothicCapitalD]\_{p\_{\[GothicCapitalG]2, \[GothicCapitalF]}}\ \((\(-\
\[GothicCapitalD]\_{p\_{\[GothicCapitalG]2, \[GothicCapitalF]}}\)\ \
\[GothicCapitalD]\_{m\_{\[GothicCapitalG]2, \[GothicCapitalF]}, n\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}} + \[GothicCapitalD]\_{m\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}, n\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}, p\_{\[GothicCapitalG]2, \[GothicCapitalF]}})\)\ \((\(-\(\
\[Beta]\_1\/wbF0\_\[GothicCapitalM]\)\) + \
\[Beta]\_2\/wbF1\_\[GothicCapitalM])\) + \[GothicCapitalD]\_{p\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}}\ \((\(-\[GothicCapitalD]\_{n\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}}\)\ \[GothicCapitalD]\_{p\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}} + \[GothicCapitalD]\_{n\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}, p\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}})\)\ \((\(-\(\(\((\(-1\) + \[WeierstrassP]\_\(m\_{\
\[GothicCapitalG], \[GothicCapitalM]}\))\)\ \[Beta]\_1\)\/wbF0\_\
\[GothicCapitalM]\)\) + \(\[WeierstrassP]\_\(m\_{\[GothicCapitalG], \
\[GothicCapitalM]}\)\ \[Beta]\_2\)\/wbF1\_\[GothicCapitalM])\) + \
\[GothicCapitalD]\_{p\_{\[GothicCapitalG]2, \[GothicCapitalF]}}\ \((\(-\
\[GothicCapitalD]\_{m\_{\[GothicCapitalG]2, \[GothicCapitalF]}}\)\ \
\[GothicCapitalD]\_{p\_{\[GothicCapitalG]2, \[GothicCapitalF]}} + \
\[GothicCapitalD]\_{m\_{\[GothicCapitalG]2, \[GothicCapitalF]}, p\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}})\)\ \((\(-\(\(\((\(-1\) + \
\[WeierstrassP]\_\(n\_{\[GothicCapitalG], \[GothicCapitalM]}\))\)\ \[Beta]\_1\
\)\/wbF0\_\[GothicCapitalM]\)\) + \(\[WeierstrassP]\_\(n\_{\[GothicCapitalG], \
\[GothicCapitalM]}\)\ \[Beta]\_2\)\/wbF1\_\[GothicCapitalM])\) + \((\(-\
\[GothicCapitalD]\_{p\_{\[GothicCapitalG]2, \[GothicCapitalF]}}\)\ \
\[GothicCapitalD]\_{m\_{\[GothicCapitalG]2, \[GothicCapitalF]}, n\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}} + \[GothicCapitalD]\_{m\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}, n\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}, p\_{\[GothicCapitalG]2, \[GothicCapitalF]}})\)\ \
\((\(-\(\(\((\(-1\) + \[WeierstrassP]\_\(p\_{\[GothicCapitalG], \
\[GothicCapitalF]}\))\)\ \[Beta]\_1\)\/wbF0\_\[GothicCapitalM]\)\) + \(\
\[WeierstrassP]\_\(p\_{\[GothicCapitalG], \[GothicCapitalF]}\)\ \
\[Beta]\_2\)\/wbF1\_\[GothicCapitalM])\))\) + 
      1\/2\ \((\[GothicCapitalD]\_{p\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}} + \[WeierstrassP]\_\(p\_{\[GothicCapitalG], \
\[GothicCapitalF]}\) + \(\(1\/\(wbF0\_\[GothicCapitalM]\ wbF1\_\
\[GothicCapitalM]\)\)\((\[GothicCapitalD]\_{m\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}, n\_{\[GothicCapitalG]2, \[GothicCapitalF]}}\ \((\
\[GothicCapitalD]\_{p\_{\[GothicCapitalG]2, \[GothicCapitalF]}}\%2 + \
\((\(-1\) + \[GothicM]\_\(p\_{\[GothicCapitalG]2, \[GothicCapitalF]}\))\)\ \
\[GothicM]\_\(p\_{\[GothicCapitalG]2, \[GothicCapitalF]}\) + \
\[GothicCapitalD]\_{p\_{\[GothicCapitalG]2, \[GothicCapitalF]}}\ \((\(-1\) + 
                          2\ \[GothicM]\_\(p\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}\))\))\)\ \((wbF1\_\[GothicCapitalM]\ \[Beta]\_1 - 
                    wbF0\_\[GothicCapitalM]\ \[Beta]\_2)\))\)\) + \
\(\(1\/\(wbF0\_\[GothicCapitalM]\ wbF1\_\[GothicCapitalM]\)\)\((\
\[GothicCapitalD]\_{n\_{\[GothicCapitalG]2, \[GothicCapitalF]}}\ \((\
\[GothicCapitalD]\_{p\_{\[GothicCapitalG]2, \[GothicCapitalF]}}\%2 + \
\((\(-1\) + \[GothicM]\_\(p\_{\[GothicCapitalG]2, \[GothicCapitalF]}\))\)\ \
\[GothicM]\_\(p\_{\[GothicCapitalG]2, \[GothicCapitalF]}\) + \
\[GothicCapitalD]\_{p\_{\[GothicCapitalG]2, \[GothicCapitalF]}}\ \((\(-1\) + 
                          2\ \[GothicM]\_\(p\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}\))\))\)\ \((\((\(-1\) + \[WeierstrassP]\_\(m\_{\
\[GothicCapitalG], \[GothicCapitalM]}\))\)\ wbF1\_\[GothicCapitalM]\ \
\[Beta]\_1 - \[WeierstrassP]\_\(m\_{\[GothicCapitalG], \[GothicCapitalM]}\)\ \
wbF0\_\[GothicCapitalM]\ \[Beta]\_2)\))\)\) + \
\(\(1\/\(wbF0\_\[GothicCapitalM]\ wbF1\_\[GothicCapitalM]\)\)\((\
\[GothicCapitalD]\_{m\_{\[GothicCapitalG]2, \[GothicCapitalF]}}\ \((\
\[GothicCapitalD]\_{p\_{\[GothicCapitalG]2, \[GothicCapitalF]}}\%2 + \
\((\(-1\) + \[GothicM]\_\(p\_{\[GothicCapitalG]2, \[GothicCapitalF]}\))\)\ \
\[GothicM]\_\(p\_{\[GothicCapitalG]2, \[GothicCapitalF]}\) + \
\[GothicCapitalD]\_{p\_{\[GothicCapitalG]2, \[GothicCapitalF]}}\ \((\(-1\) + 
                          
                          2\ \[GothicM]\_\(p\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}\))\))\)\ \((\((\(-1\) + \[WeierstrassP]\_\(n\_{\
\[GothicCapitalG], \[GothicCapitalM]}\))\)\ wbF1\_\[GothicCapitalM]\ \
\[Beta]\_1 - \[WeierstrassP]\_\(n\_{\[GothicCapitalG], \[GothicCapitalM]}\)\ \
wbF0\_\[GothicCapitalM]\ \[Beta]\_2)\))\)\) - \
\(\(1\/\(wbF0\_\[GothicCapitalM]\ wbF1\_\[GothicCapitalM]\)\)\((\((\
\[GothicCapitalD]\_{p\_{\[GothicCapitalG]2, \[GothicCapitalF]}}\%2 + \
\((\(-1\) + \[GothicM]\_\(p\_{\[GothicCapitalG]2, \[GothicCapitalF]}\))\)\ \
\[GothicM]\_\(p\_{\[GothicCapitalG]2, \[GothicCapitalF]}\) + \
\[GothicCapitalD]\_{p\_{\[GothicCapitalG]2, \[GothicCapitalF]}}\ \((\(-1\) + 
                          2\ \[GothicM]\_\(p\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}\))\))\)\ \((\(-wbF1\_\[GothicCapitalM]\)\ \((1 + \((\(-1\) \
+ \[WeierstrassP]\_\(m\_{\[GothicCapitalG], \[GothicCapitalM]}\))\)\ \
\((\(-1\) + \[WeierstrassP]\_\(n\_{\[GothicCapitalG], \[GothicCapitalM]}\))\)\
\ \[Beta]\_1)\) + 
                    wbF0\_\[GothicCapitalM]\ \((1 + \[WeierstrassP]\_\(m\_{\
\[GothicCapitalG], \[GothicCapitalM]}\)\ \[WeierstrassP]\_\(n\_{\
\[GothicCapitalG], \[GothicCapitalM]}\)\ \[Beta]\_2)\))\))\)\))\)\)], "Output",\

  CellLabel->"Out[721]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \({Union[Cases[qq3, \[GothicCapitalD]\__, {1, \[Infinity]}]], 
      Union[Cases[qq3, \[GothicM]\__, {1, \[Infinity]}]]}\)], "Input",
  CellLabel->"In[710]:="],

Cell[BoxData[
    \({{\[GothicCapitalD]\_{m\_{\[GothicCapitalG]2, \[GothicCapitalF]}, n\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}}, \[GothicCapitalD]\_{m\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}, p\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}}, \[GothicCapitalD]\_{n\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}, p\_{\[GothicCapitalG]2, \[GothicCapitalF]}}, \
\[GothicCapitalD]\_{m\_{\[GothicCapitalG]2, \[GothicCapitalF]}, n\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}, p\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}}}, {\[GothicM]\_\(m\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}\), \[GothicM]\_\(n\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}\), \[GothicM]\_\(p\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}\)}}\)], "Output",
  CellLabel->"Out[710]="]
}, Open  ]],

Cell[BoxData[{
    \(\(ww0 = \(\(\(wbFS[0] /. vsr\) /. csr\) /. pars1\) /. 
          pars2;\)\), "\[IndentingNewLine]", 
    \(\(ww1 = \(\(\(wbFS[1] /. vsr\) /. csr\) /. pars1\) /. 
          pars2;\)\)}], "Input",
  CellLabel->"In[723]:="],

Cell[BoxData[
    \(\(ff = \(\(\(\(qq3 /. {\[Beta]\[Beta]\_1 \[Rule] \[Beta]\_1\/ww0, \
\[Beta]\[Beta]\_2 \[Rule] \[Beta]\_2\/ww1}\) /. {wbF0\_\[GothicCapitalM] \
\[Rule] ww0, wbF1\_\[GothicCapitalM] \[Rule] ww1}\) /. vsr\) /. 
            ReferencePointZero[\[GothicCapitalG]]\) /. csr;\)\)], "Input",
  CellLabel->"In[728]:="],

Cell["It's (almost) a miracle!!", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\((ff - \[GothicM]\_\[DoubleStruckP])\) /. pars1\) /. pars2 // 
      Simplify\)], "Input",
  CellLabel->"In[729]:="],

Cell[BoxData[
    \(0.002827313444252688`\)], "Output",
  CellLabel->"Out[729]="]
}, Open  ]],

Cell[TextData[{
  "Now for ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalD]\_{\[DoubleStruckM], \
\[DoubleStruckP]}\)]],
  ":"
}], "MathCaption"],

Cell[BoxData[
    \(\(qq4 = \(\(\(\(\(\(\[GothicCapitalD]\_{m\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}, p\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}} //. 
                      rec\) /. ssr2\) /. 
                  ReferencePointZero[\(\[GothicCapitalG]\^*\)]\) //. rec\) /. 
              ssr2\) /. {\[Beta]\[Beta]\_1 \[Rule] \[Beta]\_1\/ww0, \[Beta]\
\[Beta]\_2 \[Rule] \[Beta]\_2\/ww1}\) /. {wbF0\_\[GothicCapitalM] \[Rule] 
              ww0, wbF1\_\[GothicCapitalM] \[Rule] ww1};\)\)], "Input",
  CellLabel->"In[757]:="],

Cell["\<\
Two passes are needed (//.rec/.ssr2//.rec/.ssr2), as the first pass \
generates something which contains the change in allele frequency, which must \
then be reduced in the same way.\
\>", "Text"],

Cell["This is just to check it's all been reduced properly:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \({Union[Cases[qq4, \[GothicCapitalD]\__, {1, \[Infinity]}]], 
      Union[Cases[qq4, \[GothicM]\__, {1, \[Infinity]}]], 
      Union[Cases[qq4, \[WeierstrassP]\__, {1, \[Infinity]}]]}\)], "Input",
  CellLabel->"In[759]:="],

Cell[BoxData[
    \({{\[GothicCapitalD]\_{m\_{\[GothicCapitalG]2, \[GothicCapitalF]}}, \
\[GothicCapitalD]\_{n\_{\[GothicCapitalG]2, \[GothicCapitalF]}}, \
\[GothicCapitalD]\_{p\_{\[GothicCapitalG]2, \[GothicCapitalF]}}, \
\[GothicCapitalD]\_{m\_{\[GothicCapitalG]2, \[GothicCapitalF]}, n\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}}, \[GothicCapitalD]\_{m\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}, p\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}}, \[GothicCapitalD]\_{n\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}, p\_{\[GothicCapitalG]2, \[GothicCapitalF]}}, \
\[GothicCapitalD]\_{m\_{\[GothicCapitalG]2, \[GothicCapitalF]}, n\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}, p\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}}}, {\[GothicM]\_\(m\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}\), \[GothicM]\_\(p\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}\)}, {\[WeierstrassP]\_\(m\_{\[GothicCapitalG], \
\[GothicCapitalF]}\), \[WeierstrassP]\_\(m\_{\[GothicCapitalG], \
\[GothicCapitalM]}\), \[WeierstrassP]\_\(m\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}\), \[WeierstrassP]\_\(m\_{\[GothicCapitalG]2, \
\[GothicCapitalM]}\), \[WeierstrassP]\_\(n\_{\[GothicCapitalG], \
\[GothicCapitalM]}\), \[WeierstrassP]\_\(p\_{\[GothicCapitalG], \
\[GothicCapitalF]}\), \[WeierstrassP]\_\(p\_{\[GothicCapitalG], \
\[GothicCapitalM]}\), \[WeierstrassP]\_\(p\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}\), \[WeierstrassP]\_\(p\_{\[GothicCapitalG]2, \
\[GothicCapitalM]}\)}}\)], "Output",
  CellLabel->"Out[759]="]
}, Open  ]],

Cell[BoxData[
    \(\(ff = \(\(qq4 /. SymmetricSexes[]\) /. vsr\) //. 
          ReferencePointZero[\[GothicCapitalG]];\)\)], "Input",
  CellLabel->"In[763]:="],

Cell["\<\
ff is a vast expression as I have made no attempts at \
simplification\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({Union[Cases[ff, \[GothicCapitalD]\__, {1, \[Infinity]}]], 
      Union[Cases[ff, \[GothicM]\__, {1, \[Infinity]}]], 
      Union[Cases[\((ff //. 
              ReferencePointZero[\[GothicCapitalG]])\), \[WeierstrassP]\__, \
{1, \[Infinity]}]]}\)], "Input",
  CellLabel->"In[770]:="],

Cell[BoxData[
    \({{\[GothicCapitalD]\_{m\_{\[GothicCapitalG], \[GothicCapitalF]}, n\_{\
\[GothicCapitalG], \[GothicCapitalF]}}, \[GothicCapitalD]\_{m\_{\
\[GothicCapitalG], \[GothicCapitalF]}, p\_{\[GothicCapitalG], \
\[GothicCapitalF]}}, \[GothicCapitalD]\_{n\_{\[GothicCapitalG], \
\[GothicCapitalF]}, p\_{\[GothicCapitalG], \[GothicCapitalF]}}, \
\[GothicCapitalD]\_{m\_{\[GothicCapitalG], \[GothicCapitalF]}, n\_{\
\[GothicCapitalG], \[GothicCapitalF]}, p\_{\[GothicCapitalG], \
\[GothicCapitalF]}}}, {\[GothicM]\_\(m\_{\[GothicCapitalG], \
\[GothicCapitalF]}\), \[GothicM]\_\(m\_{\[GothicCapitalG], \[GothicCapitalM]}\
\), \[GothicM]\_\(n\_{\[GothicCapitalG], \[GothicCapitalF]}\), \
\[GothicM]\_\(n\_{\[GothicCapitalG], \[GothicCapitalM]}\), \[GothicM]\_\(p\_{\
\[GothicCapitalG], \[GothicCapitalF]}\), \[GothicM]\_\(p\_{\[GothicCapitalG], \
\[GothicCapitalM]}\)}, {\[WeierstrassP]\_\(m\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}\), \[WeierstrassP]\_\(m\_{\[GothicCapitalG]2, \
\[GothicCapitalM]}\), \[WeierstrassP]\_\(p\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}\), \[WeierstrassP]\_\(p\_{\[GothicCapitalG]2, \
\[GothicCapitalM]}\)}}\)], "Output",
  CellLabel->"Out[770]="]
}, Open  ]],

Cell["Beats me why the reference points are so hard to reduce...", "Text"],

Cell["It's almost another miracle:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\(\(\(\((ff - \[GothicCapitalD]\_{\[DoubleStruckM], \
\[DoubleStruckP]})\) /. 
                ReferencePointSame[\[GothicCapitalG], \[GothicCapitalG]2]\) /. 
              vsr\) /. ReferencePointZero[\[GothicCapitalG]]\) /. csr\) /. 
        pars1\) /. pars2\)], "Input",
  CellLabel->"In[773]:="],

Cell[BoxData[
    \(\(\(0.0019972877650820623`\)\(\[InvisibleSpace]\)\) - 
      0.008070225479647792`\ c\_\(m, p\)\)], "Output",
  CellLabel->"Out[773]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. c\_\(m, p\) \[Rule] 1/2\)], "Input",
  CellLabel->"In[774]:="],

Cell[BoxData[
    \(\(-0.002037824974741834`\)\)], "Output",
  CellLabel->"Out[774]="]
}, Open  ]],

Cell["MS got:", "Text"],

Cell[BoxData[
    \(\(-0.0020782416428651446`\)\)], "Output"],

Cell[BoxData[
    \(\ \)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Weak selection and preference", "SubsubsectionIcon",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  "Suppose that s, \[Beta] are small.  If we write s as \[GothicS] (the \
default symbol for a weak selection coefficient) and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta]\_i\)]],
  " as ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicS]\[VeryThinSpace]\[Beta]\_i\)]],
  "then:"
}], "Text",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(vbS = 
      SlowChange[\(\(\[LeftAngleBracket]V\_\[GothicCapitalM]\
\[RightAngleBracket] /. vsr\) /. ReferencePointZero[\[GothicCapitalG]]\) /. 
            s \[Rule] \[GothicS]] // Simplify\)], "Input",
  CellLabel->"In[219]:="],

Cell[BoxData[
    \(1 + \[GothicS] + 
      2\ \[GothicS]\ \[GothicCapitalD]\_{m\_{\[GothicCapitalG], \
\[GothicCapitalF]}, n\_{\[GothicCapitalG], \[GothicCapitalF]}} - \[GothicS]\ \
\[GothicM]\_\(n\_{\[GothicCapitalG], \[GothicCapitalM]}\) + \[GothicS]\ \
\[GothicM]\_\(m\_{\[GothicCapitalG], \[GothicCapitalM]}\)\ \((\(-1\) + 
            2\ \[GothicM]\_\(n\_{\[GothicCapitalG], \
\[GothicCapitalM]}\))\)\)], "Output",
  CellLabel->"Out[219]="]
}, Open  ]],

Cell[TextData[{
  "Here, we do not need to let ",
  Cell[BoxData[
      \(TraditionalForm\`ss \[Rule] \[GothicS]\/vbS\)]],
  " because vbS is 1+O(\[GothicS]):"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(wbF0S = 
      SlowChange[\(\(\(\(wbF[0, \[GothicCapitalM]] /. ssr\) /. vsr\) /. 
                ReferencePointSame[\[GothicCapitalG], \[GothicCapitalZ]]\) /. 
              ReferencePointZero[\[GothicCapitalG]]\) /. {ss \[Rule] \
\[GothicS], \[Beta]\_i_ \[RuleDelayed] \[GothicS]\[VeryThinSpace]\[Beta]\_i}] \
// Simplify\)], "Input",
  CellLabel->"In[221]:="],

Cell[BoxData[
    \(1 + \[GothicS]\ \((\[GothicCapitalD]\_{m\_{\[GothicCapitalG], \
\[GothicCapitalF]}, n\_{\[GothicCapitalG], \[GothicCapitalF]}} + \((\(-1\) + \
\[GothicM]\_\(m\_{\[GothicCapitalG], \[GothicCapitalM]}\))\)\ \((\(-1\) + \
\[GothicM]\_\(n\_{\[GothicCapitalG], \[GothicCapitalM]}\))\))\)\ \
\[Beta]\_1\)], "Output",
  CellLabel->"Out[221]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(wbF1S = 
      SlowChange[\(\(\(\(wbF[1, \[GothicCapitalM]] /. ssr\) /. vsr\) /. 
                ReferencePointSame[\[GothicCapitalG], \[GothicCapitalZ]]\) /. 
              ReferencePointZero[\[GothicCapitalG]]\) /. {ss \[Rule] \
\[GothicS], \[Beta]\_i_ \[RuleDelayed] \[GothicS]\[VeryThinSpace]\[Beta]\_i}] \
// Simplify\)], "Input",
  CellLabel->"In[222]:="],

Cell[BoxData[
    \(1 + \[GothicS]\ \[GothicCapitalD]\_{m\_{\[GothicCapitalG], \
\[GothicCapitalF]}, n\_{\[GothicCapitalG], \[GothicCapitalF]}}\ \[Beta]\_2 + \
\[GothicS]\ \[GothicM]\_\(m\_{\[GothicCapitalG], \[GothicCapitalM]}\)\ \
\[GothicM]\_\(n\_{\[GothicCapitalG], \[GothicCapitalM]}\)\ \[Beta]\_2\)], \
"Output",
  CellLabel->"Out[222]="]
}, Open  ]],

Cell[TextData[{
  "Overall, the new association ",
  Cell[BoxData[
      \(\[GothicCapitalD]\_{n\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}, \
m\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}}\)]],
  " is, to O(\[GothicS]):"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sc = 
      SlowChange[\(\(qq2 /. {ss \[Rule] \[GothicS], \[Beta]\[Beta]\_1 \
\[RuleDelayed] \[GothicS]\[VeryThinSpace]\ \[Beta]\_1, \[Beta]\[Beta]\_2 \
\[RuleDelayed] \[GothicS]\[VeryThinSpace]\ \[Beta]\_2, 
                  wbF0\_\[GothicCapitalM] \[Rule] wbF0S, 
                  wbF1\_\[GothicCapitalM] -> 
                    wbF1S}\) /. \[GothicCapitalD]\_\[DoubleStruckCapitalU]_ :> \
\[GothicCapitalD]\_\(Sort[\[DoubleStruckCapitalU]]\)\) /. SymmetricSexes[]] // 
        Simplify\)], "Input",
  CellLabel->"In[226]:="],

Cell[BoxData[
    \(\[GothicCapitalD]\_{m\_{\[GothicCapitalG], \[GothicCapitalF]}, n\_{\
\[GothicCapitalG], \[GothicCapitalF]}} - \[GothicCapitalD]\_{m\_{\
\[GothicCapitalG], \[GothicCapitalF]}, n\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ c\_\(m, n\) + 
      1\/2\ \[GothicS]\ \((\(-4\)\ \[GothicCapitalD]\_{m\_{\[GothicCapitalG], \
\[GothicCapitalF]}, n\_{\[GothicCapitalG], \[GothicCapitalF]}}\%2 + 
            4\ \((\(-1\) + \[GothicM]\_\(m\_{\[GothicCapitalG], \
\[GothicCapitalF]}\))\)\ \[GothicM]\_\(m\_{\[GothicCapitalG], \
\[GothicCapitalF]}\)\ \((\(-1\) + \[GothicM]\_\(n\_{\[GothicCapitalG], \
\[GothicCapitalF]}\))\)\ \[GothicM]\_\(n\_{\[GothicCapitalG], \
\[GothicCapitalF]}\) + \((\[GothicCapitalD]\_{m\_{\[GothicCapitalG], \
\[GothicCapitalF]}, n\_{\[GothicCapitalG], \[GothicCapitalF]}}\%2 - \((\(-1\) \
+ \[GothicM]\_\(m\_{\[GothicCapitalG], \[GothicCapitalF]}\))\)\ \
\[GothicM]\_\(m\_{\[GothicCapitalG], \[GothicCapitalF]}\)\ \((\(-1\) + \
\[GothicM]\_\(n\_{\[GothicCapitalG], \[GothicCapitalF]}\))\)\ \[GothicM]\_\(n\
\_{\[GothicCapitalG], \[GothicCapitalF]}\) - \[GothicCapitalD]\_{m\_{\
\[GothicCapitalG], \[GothicCapitalF]}, n\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \((\(-1\) + \[GothicM]\_\(m\_{\[GothicCapitalG], \
\[GothicCapitalF]}\) + \[GothicM]\_\(n\_{\[GothicCapitalG], \
\[GothicCapitalF]}\))\))\)\ \((\(-1\) + \[GothicM]\_\(p\_{\[GothicCapitalG], \
\[GothicCapitalF]}\))\)\ \[Beta]\_1 - \((\[GothicCapitalD]\_{m\_{\
\[GothicCapitalG], \[GothicCapitalF]}, n\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\%2 - \((\(-1\) + \[GothicM]\_\(m\_{\[GothicCapitalG], \
\[GothicCapitalF]}\))\)\ \[GothicM]\_\(m\_{\[GothicCapitalG], \
\[GothicCapitalF]}\)\ \((\(-1\) + \[GothicM]\_\(n\_{\[GothicCapitalG], \
\[GothicCapitalF]}\))\)\ \[GothicM]\_\(n\_{\[GothicCapitalG], \
\[GothicCapitalF]}\) + \[GothicCapitalD]\_{m\_{\[GothicCapitalG], \
\[GothicCapitalF]}, n\_{\[GothicCapitalG], \[GothicCapitalF]}}\ \((\(-1\) + \
\[GothicM]\_\(m\_{\[GothicCapitalG], \[GothicCapitalF]}\) + \
\[GothicM]\_\(n\_{\[GothicCapitalG], \[GothicCapitalF]}\))\))\)\ \[GothicM]\_\
\(p\_{\[GothicCapitalG], \[GothicCapitalF]}\)\ \[Beta]\_2 + \((4\ \
\[GothicCapitalD]\_{m\_{\[GothicCapitalG], \[GothicCapitalF]}, n\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\%2 - 
                  4\ \((\(-1\) + \[GothicM]\_\(m\_{\[GothicCapitalG], \
\[GothicCapitalF]}\))\)\ \[GothicM]\_\(m\_{\[GothicCapitalG], \
\[GothicCapitalF]}\)\ \((\(-1\) + \[GothicM]\_\(n\_{\[GothicCapitalG], \
\[GothicCapitalF]}\))\)\ \[GothicM]\_\(n\_{\[GothicCapitalG], \
\[GothicCapitalF]}\) + \[GothicCapitalD]\_{n\_{\[GothicCapitalG], \
\[GothicCapitalF]}, p\_{\[GothicCapitalG], \[GothicCapitalF]}}\ \
\[GothicM]\_\(m\_{\[GothicCapitalG], \[GothicCapitalF]}\)\ \((\
\[GothicCapitalD]\_{m\_{\[GothicCapitalG], \[GothicCapitalF]}, n\_{\
\[GothicCapitalG], \[GothicCapitalF]}} + \((\(-1\) + \[GothicM]\_\(m\_{\
\[GothicCapitalG], \[GothicCapitalF]}\))\)\ \((\(-1\) + \[GothicM]\_\(n\_{\
\[GothicCapitalG], \[GothicCapitalF]}\))\))\)\ \[Beta]\_1 + \[GothicCapitalD]\
\_{m\_{\[GothicCapitalG], \[GothicCapitalF]}, p\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \((\[GothicCapitalD]\_{m\_{\[GothicCapitalG], \
\[GothicCapitalF]}, n\_{\[GothicCapitalG], \[GothicCapitalF]}} + \((\(-1\) + \
\[GothicM]\_\(m\_{\[GothicCapitalG], \[GothicCapitalF]}\))\)\ \((\(-1\) + \
\[GothicM]\_\(n\_{\[GothicCapitalG], \[GothicCapitalF]}\))\))\)\ \[GothicM]\_\
\(n\_{\[GothicCapitalG], \[GothicCapitalF]}\)\ \[Beta]\_1 - \((\
\[GothicCapitalD]\_{m\_{\[GothicCapitalG], \[GothicCapitalF]}, n\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\%2 - \((\(-1\) + \[GothicM]\_\(m\_{\
\[GothicCapitalG], \[GothicCapitalF]}\))\)\ \[GothicM]\_\(m\_{\
\[GothicCapitalG], \[GothicCapitalF]}\)\ \((\(-1\) + \[GothicM]\_\(n\_{\
\[GothicCapitalG], \[GothicCapitalF]}\))\)\ \[GothicM]\_\(n\_{\
\[GothicCapitalG], \[GothicCapitalF]}\) - \[GothicCapitalD]\_{m\_{\
\[GothicCapitalG], \[GothicCapitalF]}, n\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \((\(-1\) + \[GothicM]\_\(m\_{\[GothicCapitalG], \
\[GothicCapitalF]}\) + \[GothicM]\_\(n\_{\[GothicCapitalG], \
\[GothicCapitalF]}\))\))\)\ \((\(-1\) + \[GothicM]\_\(p\_{\[GothicCapitalG], \
\[GothicCapitalF]}\))\)\ \[Beta]\_1 - \[GothicCapitalD]\_{n\_{\
\[GothicCapitalG], \[GothicCapitalF]}, p\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \((\(-1\) + \[GothicM]\_\(m\_{\[GothicCapitalG], \
\[GothicCapitalF]}\))\)\ \((\[GothicCapitalD]\_{m\_{\[GothicCapitalG], \
\[GothicCapitalF]}, n\_{\[GothicCapitalG], \[GothicCapitalF]}} + \[GothicM]\_\
\(m\_{\[GothicCapitalG], \[GothicCapitalF]}\)\ \[GothicM]\_\(n\_{\
\[GothicCapitalG], \[GothicCapitalF]}\))\)\ \[Beta]\_2 - \
\[GothicCapitalD]\_{m\_{\[GothicCapitalG], \[GothicCapitalF]}, p\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ \((\(-1\) + \[GothicM]\_\(n\_{\
\[GothicCapitalG], \[GothicCapitalF]}\))\)\ \((\[GothicCapitalD]\_{m\_{\
\[GothicCapitalG], \[GothicCapitalF]}, n\_{\[GothicCapitalG], \
\[GothicCapitalF]}} + \[GothicM]\_\(m\_{\[GothicCapitalG], \[GothicCapitalF]}\
\)\ \[GothicM]\_\(n\_{\[GothicCapitalG], \[GothicCapitalF]}\))\)\ \[Beta]\_2 \
+ \((\[GothicCapitalD]\_{m\_{\[GothicCapitalG], \[GothicCapitalF]}, n\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\%2 - \((\(-1\) + \[GothicM]\_\(m\_{\
\[GothicCapitalG], \[GothicCapitalF]}\))\)\ \[GothicM]\_\(m\_{\
\[GothicCapitalG], \[GothicCapitalF]}\)\ \((\(-1\) + \[GothicM]\_\(n\_{\
\[GothicCapitalG], \[GothicCapitalF]}\))\)\ \[GothicM]\_\(n\_{\
\[GothicCapitalG], \[GothicCapitalF]}\) + \[GothicCapitalD]\_{m\_{\
\[GothicCapitalG], \[GothicCapitalF]}, n\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \((\(-1\) + \[GothicM]\_\(m\_{\[GothicCapitalG], \
\[GothicCapitalF]}\) + \[GothicM]\_\(n\_{\[GothicCapitalG], \
\[GothicCapitalF]}\))\))\)\ \[GothicM]\_\(p\_{\[GothicCapitalG], \
\[GothicCapitalF]}\)\ \[Beta]\_2)\)\ c\_\(m, n\))\)\)], "Output",
  CellLabel->"Out[226]="]
}, Open  ]],

Cell[TextData[{
  "Equivalent associations have been merged using ",
  Cell[BoxData[
      \(\[GothicCapitalD]\_\[DoubleStruckCapitalU]_ :> \
\[GothicCapitalD]\_\(Sort[\[DoubleStruckCapitalU]]\)\)]],
  ". The expression could be calculated much faster by throwing out higher \
order terms at intermediate stages in the calculation: qq is an exact but \
extremely complicated expression."
}], "Text"],

Cell[TextData[{
  "This rewrites the expression in terms of \
\[GothicQ]\[Congruent]1-\[GothicP], and also equates equivalent disequilibria \
such as ",
  Cell[BoxData[
      \(\[GothicCapitalD]\_{m\_{\[GothicCapitalG], \[GothicCapitalF]}, n\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\)]],
  ",",
  Cell[BoxData[
      \(\[GothicCapitalD]\_{n\_{\[GothicCapitalG], \[GothicCapitalF]}, m\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\)]],
  ":"
}], "Text",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(pqrl = {\(-1\) + \[GothicP]\_\[DoubleStruckI]_ :> \(-\[GothicQ]\_\
\[DoubleStruckI]\), \(-1\) + 
              2  \[GothicP]\_\[DoubleStruckI]_ :> \
\[GothicP]\_\[DoubleStruckI] - \[GothicQ]\_\[DoubleStruckI]};\)\), "\
\[IndentingNewLine]", 
    \(\((Simplify /@ \((Collect[
                scb /. \[GothicM]\_\[DoubleStruckI]_ \[RuleDelayed] \
\[GothicP]\_\[DoubleStruckI], {\[GothicS], \[GothicCapitalD]\__}] //. 
              pqrl)\))\) //. pqrl\)}], "Input",
  CellLabel->"In[231]:="],

Cell[BoxData[
    \(\[GothicCapitalD]\_{m\_{\[GothicCapitalG], \[GothicCapitalF]}, n\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ \((1 - c\_\(m, n\))\) + 
      1\/2\ \[GothicS]\ \((\((\[GothicP]\_\(m\_{\[GothicCapitalG], \
\[GothicCapitalF]}\)\ \[GothicP]\_\(n\_{\[GothicCapitalG], \[GothicCapitalF]}\
\)\ \[GothicQ]\_\(m\_{\[GothicCapitalG], \[GothicCapitalF]}\)\ \
\[GothicQ]\_\(n\_{\[GothicCapitalG], \[GothicCapitalF]}\) - \[GothicCapitalD]\
\_{m\_{\[GothicCapitalG], \[GothicCapitalF]}, n\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\%2)\)\ \((4 + \[GothicQ]\_\(p\_{\[GothicCapitalG], \
\[GothicCapitalF]}\)\ \[Beta]\_1 + \[GothicP]\_\(p\_{\[GothicCapitalG], \
\[GothicCapitalF]}\)\ \[Beta]\_2)\)\ \((1 - 
                  c\_\(m, n\))\) + \[GothicP]\_\(n\_{\[GothicCapitalG], \
\[GothicCapitalF]}\)\ \[GothicQ]\_\(n\_{\[GothicCapitalG], \[GothicCapitalF]}\
\)\ \[GothicCapitalD]\_{m\_{\[GothicCapitalG], \[GothicCapitalF]}, p\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ \
\((\[GothicQ]\_\(m\_{\[GothicCapitalG], \[GothicCapitalF]}\)\ \[Beta]\_1 + \
\[GothicP]\_\(m\_{\[GothicCapitalG], \[GothicCapitalF]}\)\ \[Beta]\_2)\)\ c\_\
\(m, n\) + \[GothicP]\_\(m\_{\[GothicCapitalG], \[GothicCapitalF]}\)\ \
\[GothicQ]\_\(m\_{\[GothicCapitalG], \[GothicCapitalF]}\)\ \
\[GothicCapitalD]\_{n\_{\[GothicCapitalG], \[GothicCapitalF]}, p\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ \
\((\[GothicQ]\_\(n\_{\[GothicCapitalG], \[GothicCapitalF]}\)\ \[Beta]\_1 + \
\[GothicP]\_\(n\_{\[GothicCapitalG], \[GothicCapitalF]}\)\ \[Beta]\_2)\)\ c\_\
\(m, n\) + \[GothicCapitalD]\_{n\_{\[GothicCapitalG], \[GothicCapitalF]}, \
p\_{\[GothicCapitalG], \[GothicCapitalF]}}\ \(\[GothicCapitalD]\_{m\_{\
\[GothicCapitalG], \[GothicCapitalF]}, 
                    n\_{\[GothicCapitalG], \[GothicCapitalF]}}\) \
\((\[GothicP]\_\(m\_{\[GothicCapitalG], \[GothicCapitalF]}\)\ \[Beta]\_1 + \(\
\[GothicQ]\_\(m\_{\[GothicCapitalG], \[GothicCapitalF]}\)\) \[Beta]\_2)\)\ \
c\_\(m, n\) + \[GothicCapitalD]\_{m\_{\[GothicCapitalG], \[GothicCapitalF]}, \
p\_{\[GothicCapitalG], \[GothicCapitalF]}}\ \(\[GothicCapitalD]\_{m\_{\
\[GothicCapitalG], \[GothicCapitalF]}, 
                    n\_{\[GothicCapitalG], \[GothicCapitalF]}}\) \
\((\[GothicP]\_\(n\_{\[GothicCapitalG], \[GothicCapitalF]}\)\ \[Beta]\_1 + \(\
\[GothicQ]\_\(n\_{\[GothicCapitalG], \[GothicCapitalF]}\)\) \[Beta]\_2)\)\ \
c\_\(m, n\) + \[GothicCapitalD]\_{m\_{\[GothicCapitalG], \[GothicCapitalF]}, \
n\_{\[GothicCapitalG], \[GothicCapitalF]}}\ \((\((\[GothicQ]\_\(m\_{\
\[GothicCapitalG], \[GothicCapitalF]}\)\ \[GothicQ]\_\(p\_{\[GothicCapitalG], \
\[GothicCapitalF]}\)\ \[Beta]\_1 - \(\[GothicP]\_\(n\_{\[GothicCapitalG], \
\[GothicCapitalF]}\)\) \[GothicQ]\_\(p\_{\[GothicCapitalG], \
\[GothicCapitalF]}\)\ \[Beta]\_1 + \(\[GothicP]\_\(n\_{\[GothicCapitalG], \
\[GothicCapitalF]}\)\) \[GothicP]\_\(p\_{\[GothicCapitalG], \
\[GothicCapitalF]}\)\ \[Beta]\_2 - \[GothicP]\_\(p\_{\[GothicCapitalG], \
\[GothicCapitalF]}\)\ \[GothicQ]\_\(m\_{\[GothicCapitalG], \[GothicCapitalF]}\
\)\ \[Beta]\_2)\)\ \((\(-1\) + c\_\(m, n\))\))\))\)\)], "Output",
  CellLabel->"Out[146]="]
}, Open  ]],

Cell["I have simplified the above somewhat by hand.", "Text",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell["\<\
All this could be speeded up by storing results within each of the \
three stages: at present, if the same association is encountered several \
times, it is recalculated each time.\
\>", "Text",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Quasi-linkage equilibrium", "SubsubsectionIcon",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"QLE"],

Cell[TextData[{
  "The QLE expression is obtained by assuming that the linkage disequilibria \
are of O(\[GothicS]), and setting the leading-order expression for ",
  Cell[BoxData[
      \(\[GothicCapitalD]\[GothicCapitalD]\_{n\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalF]}, m\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}}\)]],
  "to equal ",
  Cell[BoxData[
      \(\[GothicCapitalD]\[GothicCapitalD]\_{n\_{\[GothicCapitalG], \
\[GothicCapitalF]}, m\_{\[GothicCapitalG], \[GothicCapitalF]}}\)]],
  ".  "
}], "Text",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicCapitalD]qle = \((SlowChange[\[GothicCapitalD]\[GothicCapitalD]\
\_{m\_{\[GothicCapitalG], \[GothicCapitalF]}, n\_{\[GothicCapitalG], \
\[GothicCapitalF]}} /. \(Solve[\[GothicS]\ \[GothicCapitalD]\[GothicCapitalD]\
\_{m\_{\[GothicCapitalG], \[GothicCapitalF]}, n\_{\[GothicCapitalG], \
\[GothicCapitalF]}} == 
                      SlowChange[\(scb /. \[GothicM]\_\[DoubleStruckI]_ \
\[RuleDelayed] \[GothicP]\_\[DoubleStruckI]\) /. \[GothicCapitalD]\_\
\[DoubleStruckCapitalU]_ :> \[GothicS]\ \[GothicCapitalD]\[GothicCapitalD]\_\
\[DoubleStruckCapitalU]], \[GothicCapitalD]\[GothicCapitalD]\_{m\_{\
\[GothicCapitalG], \[GothicCapitalF]}, n\_{\[GothicCapitalG], \
\[GothicCapitalF]}}]\)\[LeftDoubleBracket]1\[RightDoubleBracket]] // 
            Simplify)\) //. pqrl\)], "Input",
  CellLabel->"In[233]:="],

Cell[BoxData[
    \(\[GothicP]\_\(m\_{\[GothicCapitalG], \[GothicCapitalF]}\)\ \[GothicP]\_\
\(n\_{\[GothicCapitalG], \[GothicCapitalF]}\)\ \[GothicQ]\_\(m\_{\
\[GothicCapitalG], \[GothicCapitalF]}\)\ \[GothicQ]\_\(n\_{\[GothicCapitalG], \
\[GothicCapitalF]}\)\ \((2 + \(\[GothicQ]\_\(p\_{\[GothicCapitalG], \
\[GothicCapitalF]}\)\ \[Beta]\_1 + \[GothicP]\_\(p\_{\[GothicCapitalG], \
\[GothicCapitalF]}\)\ \[Beta]\_2\)\/2)\)\ \((1 - c\_\(m, n\))\)\/\(\(\ \
\)\(c\_\(m, n\)\)\)\)], "Output",
  CellLabel->"Out[46]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Combining the two kinds of selection: a bad idea", "SubsubsectionIcon"],

Cell["\<\
One could choose to represent viability and sexual selection in a \
single diploid fitness function.  This approach is not recommended, because \
it is hard to check intermediate steps, and because more careis needed to \
define the fitness function correctly. \
\>", "Text"],

Cell["This is the complete set of loci that influence fitness:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[DoubleStruckCapitalW]tot = \[DoubleStruckCapitalW]\_\[GothicCapitalM] \
\[Union] \((\[DoubleStruckCapitalV]\_\[GothicCapitalM] /. {\[GothicCapitalG], 
                x_} \[RuleDelayed] {\[GothicCapitalZ], \[GothicCapitalM], 
                x})\)\)], "Input",
  CellLabel->"In[153]:=",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \({m\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, 
      m\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, 
      n\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, 
      n\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, 
      p\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}}\)], \
"Output",
  CellLabel->"Out[153]="]
}, Open  ]],

Cell[TextData[{
  "This is the complete fitness function (barring normalisation by ",
  Cell[BoxData[
      \(TraditionalForm\`vb\^2\)]],
  "):"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Wtot = \(W\_\[GothicCapitalM]\) \(V\_\[GothicCapitalM]\) 
          V\_\[GothicCapitalF] /. {\[GothicCapitalG], 
            x_} \[RuleDelayed] {\[GothicCapitalZ], \[GothicCapitalM], 
            x}\)], "Input",
  CellLabel->"In[154]:=",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\((1 + 
          s\ \((\((1 - 
                      X\_\(m\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}\))\)\ \((1 - 
                      X\_\(n\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}\))\) + 
                X\_\(m\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}\)\ X\_\(n\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}\))\))\)\ \((1 + 
          s\ \((\((1 - 
                      X\_\(m\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}\))\)\ \((1 - 
                      X\_\(n\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}\))\) + 
                X\_\(m\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}\)\ X\_\(n\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}\))\))\)\ \((\(\((1 - X\_\(p\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}\))\)\ \((1 + \((1 - X\_\(m\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}\))\)\ \((1 - \
X\_\(n\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}\))\)\ \
\[Beta]\_1)\)\)\/wbF0\_\[GothicCapitalM] + \(X\_\(p\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}\)\ \((1 + X\_\(m\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}\)\ X\_\(n\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}\)\ \[Beta]\_2)\)\)\/wbF1\_\
\[GothicCapitalM])\)\)], "Output",
  CellLabel->"Out[154]="]
}, Open  ]],

Cell[TextData[{
  "Using Wtot as it stands would lead to ",
  ButtonBox["trouble",
    ButtonData:>{"Fitness", "Two alleles"},
    ButtonStyle->"AddOnsLink"],
  ", because it includes products of the ",
  Cell[BoxData[
      \(TraditionalForm\`X\_\[DoubleStruckI]\)]],
  ".  With just two alleles per locus, these are unnecessary, and indeed, \
will lead to errors.  This problem can be checked using MakeFitnessSet[], \
which gives the list of loci appropriate for a given function.  Here, there \
are repeated loci which we do not want with only two allweles per locus:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MakeFitnessSet[Wtot]\)], "Input",
  CellLabel->"In[161]:="],

Cell[BoxData[
    \({m\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, 
      m\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, 
      m\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, 
      n\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, 
      n\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, 
      n\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, 
      p\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}}\)], \
"Output",
  CellLabel->"Out[161]="]
}, Open  ]],

Cell["\<\
This expression now gives the correct set of loci, with no repeats:\
\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(WtotGood = \((\((Wtot // Expand)\) //. Biallelic[])\) // 
        Simplify\)], "Input",
  CellLabel->"In[209]:="],

Cell[BoxData[
    \(\(1\/\(wbF0\_\[GothicCapitalM]\ wbF1\_\[GothicCapitalM]\)\) \((\((1 + 
              s - s\ X\_\(n\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}\) + 
              s\ X\_\(m\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}\)\ \((\(-1\) + 
                    2\ X\_\(n\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}\))\))\)\ \((wbF1\_\[GothicCapitalM]\ \((\((1 + 
                          s)\)\ \((1 + \[Beta]\_1)\) - 
                    X\_\(n\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}\)\ \((s + \((1 + s)\)\ \[Beta]\_1)\) + 
                    X\_\(m\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}\)\ \((\(-s\) - \[Beta]\_1 - s\ \[Beta]\_1 + 
                          X\_\(n\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}\)\ \((2\ s + \((1 + s)\)\ \[Beta]\_1)\))\))\) + 
              X\_\(p\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}\)\ \((\(-wbF1\_\[GothicCapitalM]\)\ \((\((1 + 
                                s)\)\ \((1 + \[Beta]\_1)\) - 
                          X\_\(n\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}\)\ \((s + \((1 + s)\)\ \[Beta]\_1)\) + 
                          X\_\(m\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}\)\ \((\(-s\) - \[Beta]\_1 - s\ \[Beta]\_1 + 
                                X\_\(n\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}\)\ \((2\ s + \((1 + 
                                        s)\)\ \[Beta]\_1)\))\))\) + 
                    wbF0\_\[GothicCapitalM]\ \((1 + s - 
                          s\ X\_\(n\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}\) + 
                          X\_\(m\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}\)\ \((\(-s\) + 
                                X\_\(n\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}\)\ \((2\ s + \((1 + 
                                        s)\)\ \
\[Beta]\_2)\))\))\))\))\))\)\)], "Output",
  CellLabel->"Out[209]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(MakeFitnessSet[WtotGood]\)], "Input",
  CellLabel->"In[210]:="],

Cell[BoxData[
    \({m\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, 
      m\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, 
      n\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, 
      n\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, 
      p\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}}\)], \
"Output",
  CellLabel->"Out[210]="]
}, Open  ]],

Cell["\<\
This is the selection coefficient for locus m derived from female \
haploids:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify /@ 
      Collect[MakeSelectionCoefficient[{m\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}}, WtotGood] /. 
          ReferencePointZero[\[GothicCapitalZ]], {wbF0\_\[GothicCapitalM], 
          wbF1\_\[GothicCapitalM]}]\)], "Input",
  CellLabel->"In[214]:="],

Cell[BoxData[
    \(\(-\(\(1\/wbF0\_\[GothicCapitalM]\)\((s\ \((\(-1\) + 
                2\ \[GothicM]\_\(n\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}\))\)\ \((\(-1\) + \[GothicM]\_\(p\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}\))\)\ \((\((1 + 
                      s)\)\ \((1 + \[Beta]\_1)\) - \[GothicM]\_\(n\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}\)\ \((s + \((1 + 
                            s)\)\ \[Beta]\_1)\) + \[GothicM]\_\(m\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}\)\ \((\(-s\) - \
\[Beta]\_1 - 
                      s\ \[Beta]\_1 + \[GothicM]\_\(n\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}\)\ \((2\ s + \((1 + 
                                  s)\)\ \[Beta]\_1)\))\))\))\)\)\) + \
\(\(1\/wbF1\_\[GothicCapitalM]\)\((s\ \((\(-1\) + 
              2\ \[GothicM]\_\(n\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}\))\)\ \[GothicM]\_\(p\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}\)\ \((1 + s - 
              s\ \[GothicM]\_\(n\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}\) + \[GothicM]\_\(m\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}\)\ \((\(-s\) + \[GothicM]\_\(n\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}\)\ \((2\ s + \((1 + 
                                s)\)\ \[Beta]\_2)\))\))\))\)\)\)], "Output",
  CellLabel->"Out[214]="]
}, Open  ]],

Cell["\<\
This will not simplify when the normalising constants are \
substituted in.  Those involve disequilibria, whereas the selection \
coefficients do not.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify /@ 
      Collect[wbF[1, \[GothicCapitalM]] //. 
          ReferencePointZero[\[GothicCapitalZ]], \[Beta]\_2]\)], "Input",
  CellLabel->"In[107]:=",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(1 + \(1\/\[GothicM]\_\(p\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}\)\) \((\((\[GothicCapitalD]\_{m\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, n\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, p\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\_{n\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, p\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}}\ \[GothicM]\_\(m\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}\) + \
\[GothicCapitalD]\_{m\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, p\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}}\ \[GothicM]\_\(n\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}\) + \[GothicCapitalD]\_{m\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, n\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}}\ \[GothicM]\_\(p\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}\) + \
\[GothicM]\_\(m\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}\)\ \
\[GothicM]\_\(n\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}\)\ \
\[GothicM]\_\(p\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}\))\
\)\ \[Beta]\_2)\)\)], "Output",
  CellLabel->"Out[107]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Sexual selection: a forbidden alternative", "SubsubsectionIcon",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell["\<\
The most natural way to implement sexual selection among haploids \
might be to calculate associations between male and female haploid \
individuals.  However, this is not allowed:\
\>", "MathCaption",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(yy = \[GothicCapitalD]\_{i\_{\[GothicCapitalG]2, \[GothicCapitalM]}, \
i\_{\[GothicCapitalG]2, \[GothicCapitalF]}} /. 
        Selection[{\[GothicCapitalG], \[GothicCapitalG]2}, 
          SelectionCoefficient, FitnessSet, {Sex}]\)], "Input",
  CellLabel->"In[120]:=",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(Selection::mix \(\(:\)\(\ \)\) 
      "Mixed contexts in \
\!\(\[GothicCapitalD]\_\!\({i\_\({\[GothicCapitalG]2, \[GothicCapitalM]}\), i\
\_\({\[GothicCapitalG]2, \[GothicCapitalF]}\)}\)\)/.Selection[\!\({\
\[GothicCapitalG], \
\[GothicCapitalG]2}\),\!\(SelectionCoefficient\),\!\(FitnessSet\),\!\({Sex}\)]\
: the relevant components \!\({Sex}\) must be the same for all genes."\)], \
"Message",
  CellLabel->"From In[120]:="],

Cell[BoxData[
    \(\[GothicCapitalD]\_{i\_{\[GothicCapitalG]2, \[GothicCapitalM]}, i\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}}\)], "Output",
  CellLabel->"Out[120]="]
}, Open  ]],

Cell[TextData[{
  "Instead, the method of Barton and Turelli (",
  Cell[BoxData[
      FormBox[
        ButtonBox["1991",
          ButtonData:>{"Multilocus references", "Barton and Turelli 1991"},
          ButtonStyle->"AddOnsLink"], TraditionalForm]]],
  ") should be used, in which the contribution of mating pairs, expressed as \
diploids, is calculated."
}], "Text",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Another approach: in terms of \[GothicA]'a and \[GothicB]'s\
\>", \
"SubsubsectionIcon"],

Cell["\<\
It might be clearer to work in a more general way, keeping the \
selection coefficients as \[GothicA]'s and \[GothicB]'s.  \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(nonZeroA[] = 
      Select[Subsets[\[DoubleStruckCapitalW]\_\[GothicCapitalM], 1, 
          5], \((If[MakeSelectionCoefficient[#, W\_\[GothicCapitalM]] === 0, 
              False, True])\) &]\)], "Input",
  CellLabel->"In[628]:="],

Cell[BoxData[
    \({{n\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}}, {m\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}}, {p\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}}, {m\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, 
        n\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}}, {m\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, 
        p\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}}, {n\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, 
        p\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}}, {m\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, 
        n\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, 
        p\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}}}\)], \
"Output",
  CellLabel->"Out[628]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\(\(\(\(\(\[GothicCapitalD]\_{m\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}, n\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}} /. 
                    Selection[{\[GothicCapitalZ], \[GothicCapitalA]}, 
                      SelectionCoefficient, 
                      FitnessSet, {Sex}]\) /. \
\[GothicA]\_\(\[GothicCapitalM], \
\[DoubleStruckCapitalU]_?\((Not[MemberQ[nonZeroA[], #]] &)\)\) \[RuleDelayed] 
                    0\) /. UnionOfGametes[{\[GothicCapitalG]2, \
\[GothicCapitalZ]}]\) /. RandomUnion[\[GothicCapitalG]2]\) /. 
            ReferencePointSame[\[GothicCapitalG]2, \[GothicCapitalZ]]\) //. 
          Biallelic[MeanContribution]\) /. 
        ReferencePointZero[\[GothicCapitalG]2]\) /. 
      SymmetricSexes[]\)], "Input",
  CellLabel->"In[655]:="],

Cell[BoxData[
    \(\[GothicCapitalD]\_{m\_{\[GothicCapitalG]2, \[GothicCapitalF]}, n\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}} + \[GothicCapitalD]\_{m\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}, n\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}}\ \((1 - 
            2\ \[GothicM]\_\(m\_{\[GothicCapitalG]2, \[GothicCapitalF]}\))\)\ \
\[GothicA]\_\(\[GothicCapitalM], {m\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}\) + \[GothicCapitalD]\_{n\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}, m\_{\[GothicCapitalG]2, \[GothicCapitalF]}}\ \((1 - 
            2\ \[GothicM]\_\(n\_{\[GothicCapitalG]2, \[GothicCapitalF]}\))\)\ \
\[GothicA]\_\(\[GothicCapitalM], {n\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}\) + \((\(-\[GothicCapitalD]\_{m\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}, n\_{\[GothicCapitalG]2, \[GothicCapitalF]}}\%2\) + \
\[GothicCapitalD]\_{n\_{\[GothicCapitalG]2, \[GothicCapitalF]}, m\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}}\ \((1 - 
                  2\ \[GothicM]\_\(m\_{\[GothicCapitalG]2, \[GothicCapitalF]}\
\))\)\ \((1 - 
                  2\ \[GothicM]\_\(n\_{\[GothicCapitalG]2, \[GothicCapitalF]}\
\))\) + \((1 - \[GothicM]\_\(m\_{\[GothicCapitalG]2, \[GothicCapitalF]}\))\)\ \
\[GothicM]\_\(m\_{\[GothicCapitalG]2, \[GothicCapitalF]}\)\ \((1 - \[GothicM]\
\_\(n\_{\[GothicCapitalG]2, \[GothicCapitalF]}\))\)\ \[GothicM]\_\(n\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}\))\)\ \[GothicA]\_\(\[GothicCapitalM], \
{m\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, n\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}}\)\)], "Output",
  CellLabel->"Out[655]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\[GothicCapitalD]\_{m\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}, \
n\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}} //. rec\) /. 
      ReferencePointZero[{\(\[GothicCapitalG]\^*\), \[GothicCapitalG]2}]\)], \
"Input",
  CellLabel->"In[660]:="],

Cell[BoxData[
    \(1\/2\ \((\[GothicCapitalD]\_{m\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}, n\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}} + \[GothicCapitalD]\_{n\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}}\ \
\((\[GothicM]\_\(m\_{\[GothicCapitalG]2, \[GothicCapitalF]}\) - \
\[GothicM]\_\(m\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\))\) + \((\
\[GothicCapitalD]\_{m\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}} + \[GothicM]\_\(m\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}\) - \[GothicM]\_\(m\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}\))\)\ \((\[GothicM]\_\(n\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}\) - \[GothicM]\_\(n\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}\))\))\) + 
      1\/2\ \((\[GothicCapitalD]\_{m\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}, n\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}} + \[GothicCapitalD]\_{n\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}}\ \
\((\[GothicM]\_\(m\_{\[GothicCapitalG]2, \[GothicCapitalM]}\) - \
\[GothicM]\_\(m\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\))\) + \((\
\[GothicCapitalD]\_{m\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}} + \[GothicM]\_\(m\_{\[GothicCapitalG]2, \
\[GothicCapitalM]}\) - \[GothicM]\_\(m\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}\))\)\ \((\[GothicM]\_\(n\_{\[GothicCapitalG]2, \
\[GothicCapitalM]}\) - \[GothicM]\_\(n\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}\))\))\) - 
      1\/2\ \((\[GothicCapitalD]\_{m\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}, n\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}} - \[GothicCapitalD]\_{m\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}, n\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\_{m\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalM]}, n\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\
\_{m\_{\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalM]}, n\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\
\_{n\_{\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}}\ \
\[GothicM]\_\(m\_{\[GothicCapitalG]2, \[GothicCapitalF]}\) - \
\[GothicCapitalD]\_{n\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}}\ \[GothicM]\_\(m\_{\[GothicCapitalG]2, \[GothicCapitalF]}\
\) - \[GothicCapitalD]\_{n\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}}\ \[GothicM]\_\(m\_{\[GothicCapitalG]2, \[GothicCapitalM]}\
\) + \[GothicCapitalD]\_{n\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}}\ \[GothicM]\_\(m\_{\[GothicCapitalG]2, \[GothicCapitalM]}\
\) + \[GothicCapitalD]\_{m\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}}\ \[GothicM]\_\(n\_{\[GothicCapitalG]2, \[GothicCapitalF]}\
\) - \[GothicCapitalD]\_{m\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}}\ \[GothicM]\_\(n\_{\[GothicCapitalG]2, \[GothicCapitalF]}\
\) + \[GothicM]\_\(m\_{\[GothicCapitalG]2, \[GothicCapitalF]}\)\ \[GothicM]\_\
\(n\_{\[GothicCapitalG]2, \[GothicCapitalF]}\) - \[GothicM]\_\(m\_{\
\[GothicCapitalG]2, \[GothicCapitalM]}\)\ \
\[GothicM]\_\(n\_{\[GothicCapitalG]2, \[GothicCapitalF]}\) - \
\[GothicCapitalD]\_{m\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}}\ \[GothicM]\_\(n\_{\[GothicCapitalG]2, \[GothicCapitalM]}\
\) + \[GothicCapitalD]\_{m\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}}\ \[GothicM]\_\(n\_{\[GothicCapitalG]2, \[GothicCapitalM]}\
\) - \[GothicM]\_\(m\_{\[GothicCapitalG]2, \[GothicCapitalF]}\)\ \[GothicM]\_\
\(n\_{\[GothicCapitalG]2, \[GothicCapitalM]}\) + \[GothicM]\_\(m\_{\
\[GothicCapitalG]2, \[GothicCapitalM]}\)\ \
\[GothicM]\_\(n\_{\[GothicCapitalG]2, \[GothicCapitalM]}\))\)\ c\_\(m, \
n\)\)], "Output",
  CellLabel->"Out[660]="]
}, Closed]],

Cell[BoxData[
    \(\(\(ssr2 = \((x : \((\[GothicCapitalD]\__ | \[GothicM]\__)\) \
\[RuleDelayed] 
              Simplify[\(\(\(\(\(\(\(x /. 
                                Selection[{\[GothicCapitalZ], \
\[GothicCapitalA]}, SelectionCoefficient, 
                                  FitnessSet, {Sex}]\) /. \[GothicA]\_\(\
\[GothicCapitalM], \[DoubleStruckCapitalU]_?\((Not[MemberQ[nonZeroA[], #]] &)\
\)\) \[RuleDelayed] 0\) /. 
                            UnionOfGametes[{\[GothicCapitalG]2, \
\[GothicCapitalZ]}]\) /. RandomUnion[\[GothicCapitalG]2]\) /. 
                        ReferencePointSame[\[GothicCapitalG]2, \
\[GothicCapitalZ]]\) //. Biallelic[MeanContribution]\) /. 
                    ReferencePointZero[\[GothicCapitalG]2]\) /. 
                  SymmetricSexes[]])\);\);\)\)], "Input",
  CellLabel->"In[662]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(ff = \(\(\[GothicCapitalD]\_{m\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}, n\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}} //. 
            rec\) /. 
          ReferencePointZero[{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalG]2}]\) /. ssr2\)], "Input",
  CellLabel->"In[665]:="],

Cell[BoxData[
    \(1\/2\ \((\[GothicCapitalD]\_{m\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}, n\_{\[GothicCapitalG]2, \[GothicCapitalF]}} + \
\[GothicCapitalD]\_{m\_{\[GothicCapitalG]2, \[GothicCapitalF]}, n\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}}\ \((1 - 
                  2\ \[GothicM]\_\(m\_{\[GothicCapitalG]2, \[GothicCapitalF]}\
\))\)\ \[GothicA]\_\(\[GothicCapitalM], {m\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}}\) + \[GothicCapitalD]\_{n\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}, m\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}}\ \((1 - 
                  2\ \[GothicM]\_\(n\_{\[GothicCapitalG]2, \[GothicCapitalF]}\
\))\)\ \[GothicA]\_\(\[GothicCapitalM], {n\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}}\) + \((\(-\[GothicCapitalD]\_{m\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}, n\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}}\%2\) + \((\(-1\) + \[GothicM]\_\(m\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}\))\)\ \[GothicM]\_\(m\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}\)\ \((\(-1\) + \[GothicM]\_\(n\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}\))\)\ \[GothicM]\_\(n\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}\) + \[GothicCapitalD]\_{n\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}, m\_{\[GothicCapitalG]2, \[GothicCapitalF]}}\ \((\(-1\) + 
                        2\ \[GothicM]\_\(m\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}\))\)\ \((\(-1\) + 
                        2\ \[GothicM]\_\(n\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}\))\))\)\ \[GothicA]\_\(\[GothicCapitalM], {m\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, n\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}}\) + \((\[GothicM]\_\
\(n\_{\[GothicCapitalG]2, \[GothicCapitalF]}\) - \[GothicM]\_\(n\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\))\)\ \((\[GothicM]\_\(m\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}\) - \[GothicM]\_\(m\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\) - \((\(-1\) + \[GothicM]\_\(m\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}\))\)\ \[GothicM]\_\(m\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}\)\ \[GothicA]\_\(\[GothicCapitalM], {m\
\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}}\) + \
\[GothicCapitalD]\_{m\_{\[GothicCapitalG]2, \[GothicCapitalF]}, n\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}}\ \[GothicA]\_\(\[GothicCapitalM], \
{n\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}}\) + \
\[GothicCapitalD]\_{m\_{\[GothicCapitalG]2, \[GothicCapitalF]}, n\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}}\ \((1 - 
                        2\ \[GothicM]\_\(m\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}\))\)\ \[GothicA]\_\(\[GothicCapitalM], {m\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, n\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}}\))\) + \
\((\[GothicM]\_\(m\_{\[GothicCapitalG]2, \[GothicCapitalF]}\) - \
\[GothicM]\_\(m\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\))\)\ \
\((\(-\((\(-1\) + \[GothicM]\_\(n\_{\[GothicCapitalG]2, \[GothicCapitalF]}\))\
\)\)\ \[GothicM]\_\(n\_{\[GothicCapitalG]2, \[GothicCapitalF]}\)\ \
\[GothicA]\_\(\[GothicCapitalM], {n\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}\) + \[GothicCapitalD]\_{n\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}, m\_{\[GothicCapitalG]2, \[GothicCapitalF]}}\ \
\((\[GothicA]\_\(\[GothicCapitalM], {m\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}}\) + \((1 - 
                              2\ \[GothicM]\_\(n\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}\))\)\ \[GothicA]\_\(\[GothicCapitalM], {m\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, n\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}}\))\))\))\) + 
      1\/2\ \((\[GothicCapitalD]\_{m\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}, n\_{\[GothicCapitalG]2, \[GothicCapitalF]}, p\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}}\ \[GothicA]\_\(\[GothicCapitalM], \
{p\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}}\) + \
\[GothicCapitalD]\_{n\_{\[GothicCapitalG]2, \[GothicCapitalF]}, p\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}}\ \((\[GothicM]\_\(m\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}\) - \[GothicM]\_\(m\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\))\)\ \((\[GothicA]\_\(\
\[GothicCapitalM], {p\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}}\) + \[GothicCapitalD]\_{m\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}, n\_{\[GothicCapitalG]2, \[GothicCapitalF]}}\ \[GothicA]\_\
\(\[GothicCapitalM], {m\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, n\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, p\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}}\))\) + \[GothicCapitalD]\_{m\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}, n\_{\[GothicCapitalG]2, \[GothicCapitalF]}}\ \((1 + \
\[GothicCapitalD]\_{m\_{\[GothicCapitalG]2, \[GothicCapitalF]}, n\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}, p\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}}\ \[GothicA]\_\(\[GothicCapitalM], {m\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, n\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, p\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}}\))\) + \((\[GothicM]\_\(n\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}\) - \[GothicM]\_\(n\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\))\)\ \((\[GothicM]\_\(m\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}\) - \[GothicM]\_\(m\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\) + \[GothicCapitalD]\_{m\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}, p\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}}\ \((\[GothicA]\_\(\[GothicCapitalM], {p\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}}\) + \
\[GothicCapitalD]\_{m\_{\[GothicCapitalG]2, \[GothicCapitalF]}, n\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}}\ \[GothicA]\_\(\[GothicCapitalM], \
{m\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, n\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, p\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}}\))\))\))\) - 
      1\/2\ \((\[GothicCapitalD]\_{m\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}, n\_{\[GothicCapitalG]2, \[GothicCapitalF]}} + \
\[GothicCapitalD]\_{m\_{\[GothicCapitalG]2, \[GothicCapitalF]}, n\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}}\ \((1 - 
                  2\ \[GothicM]\_\(m\_{\[GothicCapitalG]2, \[GothicCapitalF]}\
\))\)\ \[GothicA]\_\(\[GothicCapitalM], {m\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}}\) + \[GothicCapitalD]\_{n\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}, m\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}}\ \((1 - 
                  2\ \[GothicM]\_\(n\_{\[GothicCapitalG]2, \[GothicCapitalF]}\
\))\)\ \[GothicA]\_\(\[GothicCapitalM], {n\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}}\) + \[GothicCapitalD]\_{m\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}, n\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}, p\_{\[GothicCapitalG]2, \[GothicCapitalF]}}\ \[GothicA]\_\
\(\[GothicCapitalM], {p\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}}\) + \((\(-\[GothicCapitalD]\_{m\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}, n\_{\[GothicCapitalG]2, \[GothicCapitalF]}}\%2\) + \
\((\(-1\) + \[GothicM]\_\(m\_{\[GothicCapitalG]2, \[GothicCapitalF]}\))\)\ \
\[GothicM]\_\(m\_{\[GothicCapitalG]2, \[GothicCapitalF]}\)\ \((\(-1\) + \
\[GothicM]\_\(n\_{\[GothicCapitalG]2, \[GothicCapitalF]}\))\)\ \
\[GothicM]\_\(n\_{\[GothicCapitalG]2, \[GothicCapitalF]}\) + \
\[GothicCapitalD]\_{n\_{\[GothicCapitalG]2, \[GothicCapitalF]}, m\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}}\ \((\(-1\) + 
                        2\ \[GothicM]\_\(m\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}\))\)\ \((\(-1\) + 
                        2\ \[GothicM]\_\(n\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}\))\))\)\ \[GothicA]\_\(\[GothicCapitalM], {m\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, n\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}}\) + \
\[GothicCapitalD]\_{m\_{\[GothicCapitalG]2, \[GothicCapitalF]}, n\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}}\ \((1 + \[GothicCapitalD]\_{m\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}, n\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}, p\_{\[GothicCapitalG]2, \[GothicCapitalF]}}\ \[GothicA]\_\
\(\[GothicCapitalM], {m\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, n\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, p\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}}\))\) - \[GothicCapitalD]\_{n\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}, p\_{\[GothicCapitalG]2, \[GothicCapitalF]}}\ \
\((\(-\((\(-1\) + \[GothicM]\_\(m\_{\[GothicCapitalG]2, \[GothicCapitalF]}\))\
\)\)\ \[GothicM]\_\(m\_{\[GothicCapitalG]2, \[GothicCapitalF]}\)\ \
\[GothicA]\_\(\[GothicCapitalM], {m\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, p\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}}\) + \[GothicCapitalD]\_{m\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}, n\_{\[GothicCapitalG]2, \[GothicCapitalF]}}\ \[GothicA]\_\
\(\[GothicCapitalM], {n\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, p\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}}\) + \[GothicCapitalD]\_{m\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}, n\_{\[GothicCapitalG]2, \[GothicCapitalF]}}\ \((1 - 
                        2\ \[GothicM]\_\(m\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}\))\)\ \[GothicA]\_\(\[GothicCapitalM], {m\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, n\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, p\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}}\))\) - \
\[GothicCapitalD]\_{m\_{\[GothicCapitalG]2, \[GothicCapitalF]}, p\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}}\ \((\(-\((\(-1\) + \[GothicM]\_\(n\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}\))\)\)\ \[GothicM]\_\(n\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}\)\ \[GothicA]\_\(\[GothicCapitalM], {n\
\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, p\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}}\) + \
\[GothicCapitalD]\_{n\_{\[GothicCapitalG]2, \[GothicCapitalF]}, m\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}}\ \((\[GothicA]\_\(\[GothicCapitalM], \
{m\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, p\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}}\) + \((1 - 
                              2\ \[GothicM]\_\(n\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}\))\)\ \[GothicA]\_\(\[GothicCapitalM], {m\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, n\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, p\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}}\))\))\))\)\ c\_\(m, \
n\)\)], "Output",
  CellLabel->"Out[665]="]
}, Closed]],

Cell["\<\
All this gives a reasonably simple expressionfor the effects of \
sexual selection on pairwise associations, in terms of the change in allele \
frequency and the selection coefficients. \
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify /@ \((\(Collect[
                ff /. \[GothicM]\_\(i_\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalF]}\) \[RuleDelayed] \[CapitalDelta]\[GothicM]\_i + \[GothicM]\
\_\(i\_{\[GothicCapitalG]2, \[GothicCapitalF]}\), \[GothicA]\_\(\
\[GothicCapitalM], _\)] /. {\[GothicCapitalZ], \[GothicCapitalM], 
                  x_} :> {\[GothicCapitalG]2, x}\) /. 
            csr2)\) /. {\(-1\) + \[GothicM]\_\[DoubleStruckI]_ \[RuleDelayed] \
\(-\[GothicQ]\_\[DoubleStruckI]\), 
        1 - \[GothicM]\_\[DoubleStruckI]_ \[RuleDelayed] \[GothicQ]\_\
\[DoubleStruckI], \(-1\) + 
            2  \[GothicM]\_\[DoubleStruckI]_ \[RuleDelayed] \[GothicP]\_\
\[DoubleStruckI] - \[GothicQ]\_\[DoubleStruckI], 
        1 - 2  \[GothicM]\_\[DoubleStruckI]_ \[RuleDelayed] \(-\[GothicP]\_\
\[DoubleStruckI]\) + \[GothicQ]\_\[DoubleStruckI], \[GothicM]\_\
\[DoubleStruckI]_ \[RuleDelayed] \[GothicP]\_\[DoubleStruckI]}\)], "Input",
  CellLabel->"In[682]:="],

Cell[BoxData[
    \(\[GothicCapitalD]\_{\[DoubleStruckM], \[DoubleStruckN]} + \
\[CapitalDelta]\[GothicM]\_m\ \[CapitalDelta]\[GothicM]\_n + 
      1\/2\ \[GothicA]\_\(\[GothicCapitalM], {\[DoubleStruckM]}\)\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckN], \[DoubleStruckM]}\)\ \[CapitalDelta]\
\[GothicM]\_m - \[GothicP]\_\[DoubleStruckM]\ \[GothicQ]\_\[DoubleStruckM]\ \
\[CapitalDelta]\[GothicM]\_n + \((\[GothicP]\_\[DoubleStruckM] - \[GothicQ]\_\
\[DoubleStruckM])\)\ \[GothicCapitalD]\_{\[DoubleStruckM], \[DoubleStruckN]}\ \
\((\(-1\) + c\_\(m, n\))\))\) + 
      1\/2\ \[GothicA]\_\(\[GothicCapitalM], {\[DoubleStruckN]}\)\ \((\(-\
\[GothicP]\_\[DoubleStruckN]\)\ \[CapitalDelta]\[GothicM]\_m + \[GothicP]\_\
\[DoubleStruckN]\%2\ \[CapitalDelta]\[GothicM]\_m - \[GothicCapitalD]\_{\
\[DoubleStruckM], \[DoubleStruckN]}\ \[CapitalDelta]\[GothicM]\_n + \((\
\[GothicP]\_\[DoubleStruckN] - \[GothicQ]\_\[DoubleStruckN])\)\ \
\[GothicCapitalD]\_{\[DoubleStruckN], \[DoubleStruckM]}\ \((\(-1\) + 
                  c\_\(m, n\))\))\) - 
      1\/2\ \[GothicA]\_\(\[GothicCapitalM], {\[DoubleStruckP]}\)\ \((\
\[GothicCapitalD]\_{\[DoubleStruckN], \[DoubleStruckP]}\ \[CapitalDelta]\
\[GothicM]\_m + \[GothicCapitalD]\_{\[DoubleStruckM], \[DoubleStruckP]}\ \
\[CapitalDelta]\[GothicM]\_n + \[GothicCapitalD]\_{\[DoubleStruckM], \
\[DoubleStruckN], \[DoubleStruckP]}\ \((\(-1\) + 
                  c\_\(m, n\))\))\) - \[GothicCapitalD]\_{\[DoubleStruckM], \
\[DoubleStruckN]}\ c\_\(m, n\) + 
      1\/2\ \((\[GothicCapitalD]\_{\[DoubleStruckM], \[DoubleStruckP]}\ \
\[GothicCapitalD]\_{\[DoubleStruckN], \[DoubleStruckM]} + \[GothicP]\_\
\[DoubleStruckM]\ \[GothicQ]\_\[DoubleStruckM]\ \[GothicCapitalD]\_{\
\[DoubleStruckN], \[DoubleStruckP]})\)\ \[GothicA]\_\(\[GothicCapitalM], {\
\[DoubleStruckM], \[DoubleStruckP]}\)\ c\_\(m, n\) + 
      1\/2\ \((\[GothicP]\_\[DoubleStruckN]\ \[GothicQ]\_\[DoubleStruckN]\ \
\[GothicCapitalD]\_{\[DoubleStruckM], \[DoubleStruckP]} + \
\[GothicCapitalD]\_{\[DoubleStruckM], \[DoubleStruckN]}\ \[GothicCapitalD]\_{\
\[DoubleStruckN], \[DoubleStruckP]})\)\ \[GothicA]\_\(\[GothicCapitalM], {\
\[DoubleStruckN], \[DoubleStruckP]}\)\ c\_\(m, n\) + 
      1\/2\ \[GothicA]\_\(\[GothicCapitalM], {\[DoubleStruckM], \
\[DoubleStruckN]}\)\ \((\((\[GothicP]\_\[DoubleStruckM] - \[GothicQ]\_\
\[DoubleStruckM])\)\ \[GothicCapitalD]\_{\[DoubleStruckM], \[DoubleStruckN]}\ \
\[CapitalDelta]\[GothicM]\_n - \[GothicP]\_\[DoubleStruckM]\ \[GothicP]\_\
\[DoubleStruckN]\ \[GothicQ]\_\[DoubleStruckM]\ \[GothicQ]\_\[DoubleStruckN]\ \
\((\(-1\) + 
                  c\_\(m, n\))\) + \[GothicCapitalD]\_{\[DoubleStruckM], \
\[DoubleStruckN]}\%2\ \((\(-1\) + 
                  c\_\(m, n\))\) + \((\[GothicP]\_\[DoubleStruckN] - \
\[GothicQ]\_\[DoubleStruckN])\)\ \[GothicCapitalD]\_{\[DoubleStruckN], \
\[DoubleStruckM]}\ \((\(-1\) + \[CapitalDelta]\[GothicM]\_m - 
                  2\ \[GothicP]\_\[DoubleStruckM]\ \((\(-1\) + 
                        c\_\(m, n\))\) + c\_\(m, n\))\))\) + 
      1\/2\ \[GothicA]\_\(\[GothicCapitalM], {\[DoubleStruckM], \
\[DoubleStruckN], \[DoubleStruckP]}\)\ \
\((\((\(-\[GothicP]\_\[DoubleStruckN]\) + \[GothicQ]\_\[DoubleStruckN])\)\ \
\[GothicCapitalD]\_{\[DoubleStruckM], \[DoubleStruckP]}\ \[GothicCapitalD]\_{\
\[DoubleStruckN], \[DoubleStruckM]}\ c\_\(m, n\) - \[GothicCapitalD]\_{\
\[DoubleStruckM], \[DoubleStruckN]}\ \((\[GothicCapitalD]\_{\[DoubleStruckM], \
\[DoubleStruckP]}\ \[CapitalDelta]\[GothicM]\_n + \[GothicCapitalD]\_{\
\[DoubleStruckM], \[DoubleStruckN], \[DoubleStruckP]}\ \((\(-1\) + 
                        c\_\(m, n\))\) + \
\[GothicCapitalD]\_{\[DoubleStruckN], \[DoubleStruckP]}\ \((\[CapitalDelta]\
\[GothicM]\_m + \((\[GothicP]\_\[DoubleStruckM] - \
\[GothicQ]\_\[DoubleStruckM])\)\ c\_\(m, n\))\))\))\)\)], "Output",
  CellLabel->"Out[682]="]
}, Open  ]],

Cell["\<\
 The changes in allele frequency are themselves expressed in terms \
of the selection coefficients:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(hh = \(\(\[GothicM]\_\(n\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\
\) - \[GothicM]\_\(n\_{\[GothicCapitalG]2, \[GothicCapitalM]}\) //. rec\) /. 
          ReferencePointZero[{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalG]2}]\) /. ssr2\)], "Input",
  CellLabel->"In[683]:="],

Cell[BoxData[
    \(\(-\[GothicM]\_\(n\_{\[GothicCapitalG]2, \[GothicCapitalF]}\)\) + 
      1\/2\ \((\[GothicM]\_\(n\_{\[GothicCapitalG]2, \[GothicCapitalF]}\) + \
\[GothicCapitalD]\_{n\_{\[GothicCapitalG]2, \[GothicCapitalF]}, m\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}}\ \[GothicA]\_\(\[GothicCapitalM], \
{m\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}}\) - \((\(-1\) \
+ \[GothicM]\_\(n\_{\[GothicCapitalG]2, \[GothicCapitalF]}\))\)\ \[GothicM]\_\
\(n\_{\[GothicCapitalG]2, \[GothicCapitalF]}\)\ \[GothicA]\_\(\
\[GothicCapitalM], {n\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}\) + \[GothicCapitalD]\_{n\_{\[GothicCapitalG]2, \
\[GothicCapitalF]}, m\_{\[GothicCapitalG]2, \[GothicCapitalF]}}\ \((1 - 
                  2\ \[GothicM]\_\(n\_{\[GothicCapitalG]2, \[GothicCapitalF]}\
\))\)\ \[GothicA]\_\(\[GothicCapitalM], {m\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, n\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}}\))\) + 
      1\/2\ \((\[GothicM]\_\(n\_{\[GothicCapitalG]2, \[GothicCapitalF]}\) + \
\[GothicCapitalD]\_{n\_{\[GothicCapitalG]2, \[GothicCapitalF]}, p\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}}\ \((\[GothicA]\_\(\[GothicCapitalM], \
{p\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}}\) + \
\[GothicCapitalD]\_{m\_{\[GothicCapitalG]2, \[GothicCapitalF]}, n\_{\
\[GothicCapitalG]2, \[GothicCapitalF]}}\ \[GothicA]\_\(\[GothicCapitalM], \
{m\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, n\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, p\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}}\))\))\)\)], "Output",\

  CellLabel->"Out[683]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify /@ \((\(Collect[
                hh, \[GothicA]\_\(\[GothicCapitalM], _\)] /. {\
\[GothicCapitalZ], \[GothicCapitalM], x_} :> {\[GothicCapitalG]2, x}\) /. 
            csr2)\) /. {\(-1\) + \[GothicM]\_\[DoubleStruckI]_ \[RuleDelayed] \
\(-\[GothicQ]\_\[DoubleStruckI]\), 
        1 - \[GothicM]\_\[DoubleStruckI]_ \[RuleDelayed] \[GothicQ]\_\
\[DoubleStruckI], \(-1\) + 
            2  \[GothicM]\_\[DoubleStruckI]_ \[RuleDelayed] \[GothicP]\_\
\[DoubleStruckI] - \[GothicQ]\_\[DoubleStruckI], 
        1 - 2  \[GothicM]\_\[DoubleStruckI]_ \[RuleDelayed] \(-\[GothicP]\_\
\[DoubleStruckI]\) + \[GothicQ]\_\[DoubleStruckI], \[GothicM]\_\
\[DoubleStruckI]_ \[RuleDelayed] \[GothicP]\_\[DoubleStruckI]}\)], "Input",
  CellLabel->"In[684]:="],

Cell[BoxData[
    \(1\/2\ \[GothicCapitalD]\_{\[DoubleStruckN], \[DoubleStruckM]}\ \
\[GothicA]\_\(\[GothicCapitalM], {\[DoubleStruckM]}\) + 
      1\/2\ \[GothicP]\_\[DoubleStruckN]\ \[GothicQ]\_\[DoubleStruckN]\ \
\[GothicA]\_\(\[GothicCapitalM], {\[DoubleStruckN]}\) + 
      1\/2\ \[GothicCapitalD]\_{\[DoubleStruckN], \[DoubleStruckP]}\ \
\[GothicA]\_\(\[GothicCapitalM], {\[DoubleStruckP]}\) + 
      1\/2\ \((\(-\[GothicP]\_\[DoubleStruckN]\) + \[GothicQ]\_\
\[DoubleStruckN])\)\ \[GothicCapitalD]\_{\[DoubleStruckN], \[DoubleStruckM]}\ \
\[GothicA]\_\(\[GothicCapitalM], {\[DoubleStruckM], \[DoubleStruckN]}\) + 
      1\/2\ \[GothicCapitalD]\_{\[DoubleStruckM], \[DoubleStruckN]}\ \
\[GothicCapitalD]\_{\[DoubleStruckN], \[DoubleStruckP]}\ \[GothicA]\_\(\
\[GothicCapitalM], {\[DoubleStruckM], \[DoubleStruckN], \
\[DoubleStruckP]}\)\)], "Output",
  CellLabel->"Out[684]="]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
AutoGeneratedPackage->None,
WindowSize->{1061, 693},
WindowMargins->{{Automatic, 16}, {Automatic, 1}},
Visible->True,
InputAliases->{"notation"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnotation"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {"\[Placeholder]", "\[Rule]", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "pattwraper"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswraper"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
Magnification->1.5,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions for On-line Help", "Subtitle"],
  
  Cell["\<\
These styles are carefully tuned for all aspects of the online \
help. It's recommended that they remain unchanged.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Subsubsection"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ShowCellBracket->False,
    ShowAutoStyles->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Brackets"],
    PageWidth->WindowWidth,
    ShowAutoStyles->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ShowAutoStyles->False,
    ScriptMinSize->5,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Subsubsection"],
  
  Cell["\<\
  The options defined for the style below will be used at the \
Notebook level.  \
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"]}, {Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageFooters->{{None, Cell[ 
            
            TextData[ {
              "\[Copyright]1999 Wolfram Research, Inc. All rights \
reserved."}], "PageFooter"], None}, {None, Cell[ 
            
            TextData[ {
              "\[Copyright]1999 Wolfram Research, Inc. All rights \
reserved."}], "PageFooter"], None}},
    PageHeaderLines->{True, True},
    PageFooterLines->{True, True},
    PrintingOptions->{"FacingPages"->True},
    CellLabelAutoDelete->False,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Headings", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Chapter"],
    CellMargins->{{10, 4}, {4, 24}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"+3\" FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Chapter", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->22]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellMargins->{{10, 4}, {12, 18}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"+2\" FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->20,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{24, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT SIZE=\"+1\" FACE=\"Helvetica, \
Arial\"><P><B>", "</B></P></FONT>\n"}},
    CellFrameLabelMargins->6,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{16, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellMargins->{{10, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {"<FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionColor"],
    CellMargins->{{10, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {
      "<FONT FACE=\"Helvetica, Arial\" COLOR=\"660099\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold",
    FontColor->RGBColor[0.297993, 0, 0.454994]],
  
  Cell[StyleData["SubsubsectionColor", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionIcon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->8},
    CellGroupingRules->{"SectionGrouping", 50},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Section",
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsectionIcon", "Printout"],
    CellDingbat->"\[FilledSquare]",
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{16, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionIcon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {0, 8}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    CellGroupingRules->{"SectionGrouping", 60},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubection", 0}},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsubsectionIcon", "Printout"],
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Text", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<P>", "</P>"}},
    CellHorizontalScrolling->True,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", 
                BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    Hyphenation->True,
    ParagraphSpacing->{0, 8}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CompactText"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<FONT SIZE=\"-1\">", "</FONT>\n"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 0},
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["CompactText", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Compact12Text"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<P>", "</P>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 0},
    StyleMenuListing->None],
  
  Cell[StyleData["Compact12Text", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TextSans"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"-1\" FACE=\"Helvetica, Arial\">", "</FONT>\n"}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["TextSans", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedText"],
    CellMargins->{{20, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    ParagraphIndent->-15,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedText", "Printout"],
    CellMargins->{{12, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedTextNote"],
    CellMargins->{{35, 4}, {0, 4}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedTextNote", "Printout"],
    CellMargins->{{27, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndentedText"],
    CellMargins->{{20, 4}, {0, 6}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["IndentedText", "Printout"],
    CellMargins->{{12, 0}, {0, 6}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MathCaption"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{19, 62}, {0, 14}},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><P><FONT COLOR=\"000066\">", "</FONT></P></LI>"}},
    PageBreakBelow->False,
    CellFrameLabelMargins->4,
    Hyphenation->True,
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8},
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["MathCaption", "Printout"],
    CellMargins->{{9, 0}, {0, 14}},
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<FONT SIZE=\"1\"><P>", "</P></FONT>"}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0.7, 0},
    CounterIncrements->"SmallText",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    TextJustification->1,
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Input/Output", "Subsubsection"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.    \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    ShowCellBracket->True,
    CellMargins->{{46, 4}, {3, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->StandardForm],
  
  Cell[StyleData["Output", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatType->InputForm,
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Printout"],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatType->InputForm,
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"GraphicsGrouping",
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->Utilities`Notation`Private`DefaultFormatTypeForOutput,
    FormatType->InputForm,
    StyleMenuListing->None,
    FontWeight->"Plain"],
  
  Cell[StyleData["Graphics", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->7,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Name"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Name", "Printout"],
    FontSize->7,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlinks", "Subsubsection"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks. The others point to the various sections of the help \
browser. These styles will modify individual words or letters in a cell \
exclusive of the cell tag.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLinkMR"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLinkMR", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLinkMR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLinkMR", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Subsubsection"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->Automatic,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Subsubsection"],
  
  Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell tag.\
\>", "Text"],
  
  Cell[StyleData["JT"],
    StyleMenuListing->None,
    FontFamily->"JFontText"],
  
  Cell[StyleData["JS"],
    StyleMenuListing->None,
    FontFamily->"JFontSans"],
  
  Cell[StyleData["JSB"],
    StyleMenuListing->None,
    FontFamily->"JFontSansBold"],
  
  Cell[StyleData["RM"],
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["BF"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["IT"],
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["TR"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["TI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["TB"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["TBI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["MO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["MB"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["MBO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["SR"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["SO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SB"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["SBO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["M4"],
    ShowCellBracket->True,
    StyleMenuListing->None,
    FontFamily->"Math4",
    CharacterEncoding->"Math4"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SO10"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "Printout"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["C1"],
    StyleMenuListing->None,
    FontColor->RGBColor[0.4, 0, 1]],
  
  Cell[StyleData["C1", "Printout"],
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["C1MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->RGBColor[0.4, 0, 1]],
  
  Cell[StyleData["C1MR", "Printout"],
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Emphasis Boxes and Pictures", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Box"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["Box", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DoubleBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->2,
    RowAlignments->Top}],
  
  Cell[StyleData["DoubleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["1ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["1ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.31, 0.62}}],
  
  Cell[StyleData["2ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.46}],
  
  Cell[StyleData["2ColumnEvenBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnSmallBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.35,
    ColumnAlignments->{Right, Left}}],
  
  Cell[StyleData["2ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.31}],
  
  Cell[StyleData["3ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnSmallBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.24,
    ColumnAlignments->{Right, Center, Left}}],
  
  Cell[StyleData["3ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["4ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.13, 0.33, 0.13, 0.33}}],
  
  Cell[StyleData["4ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["5ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.194}],
  
  Cell[StyleData["5ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["6ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.12, 0.22, 0.12, 0.12, 0.22, 0.12}}],
  
  Cell[StyleData["6ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedNoteBox"],
    CellFrame->0.5,
    CellMargins->{{37, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["ItemizedNoteBox", "Printout"],
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.4, 0.6},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox3Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.35, 0.2, 0.45},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox3Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox4Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.15, 0.35, 0.15, 0.35},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox4Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox5Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->0.2,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox5Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox6Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.13, 0.24, 0.13, 0.13, 0.24, 0.13},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox6Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{11, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{11, 4}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 0}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BottomBox"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{11, 4}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["BottomBox", "Printout"],
    CellMargins->{{2, 4}, {0, 0}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{11, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopSpanBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{11, 4}, {0, 0}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleSpanBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Picture"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Picture", "Printout"],
    CellMargins->{{2, 0}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedPicture"],
    CellMargins->{{35, 4}, {0, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedPicture", "Printout"],
    CellMargins->{{27, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureGroup"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureGroup", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Sound"],
    ShowCellBracket->True,
    CellMargins->{{10, Inherited}, {0, 8}},
    StyleMenuListing->None],
  
  Cell[StyleData["Sound", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{10, 4}, {0, 3}},
    PageBreakAbove->False,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Caption", "Printout"],
    CellMargins->{{2, 0}, {0, 3}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Tables", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.34, 0.64},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->0.49,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnEvenTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.28, 0.28, 0.43},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["3ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    ScriptLevel->1,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineOutput"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["InlineOutput", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, 10}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True},
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{34, Inherited}, {Inherited, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayMath"],
    CellMargins->{{42, 10}, {7, 7}},
    Evaluatable->False,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input"],
  
  Cell[StyleData["DisplayMath", "Printout"],
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{42, 10}, {7, 7}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{34, 55}, {0, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EquationNumber"],
    LineSpacing->{1.83, 0},
    LanguageCategory->"Formula"],
  
  Cell[StyleData["EquationNumber", "Printout"],
    LineSpacing->{1.7, 0},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{16, Inherited}, {Inherited, 10}},
    CellHorizontalScrolling->True,
    LanguageCategory->"Formula",
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{8, Inherited}, {Inherited, 10}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Help Browser Styles", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InspectorLevel1"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{12, 10}, {2, 7}},
    CellGroupingRules->{"SectionGrouping", 60},
    ParagraphIndent->-38,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel1", "Brackets"]],
  
  Cell[StyleData["InspectorLevel1", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InspectorLevel2"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel2", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{48, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel2", "Printout"],
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectName"],
    CellMargins->{{10, 4}, {1, 10}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    CellGroupingRules->{"SectionGrouping", 90},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubObjectNameClosed"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {1, 10}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->{"SectionGrouping", 90},
    FontFamily->"Courier",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectNameClosed", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectNameClosed", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubObjectName"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {1, 10}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectName", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{90, 4}, {1, 14}},
    FontFamily->"Courier",
    FontSize->12],
  
  Cell[StyleData["SubObjectName", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontFamily->"Courier",
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GroupObjectName"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectName", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{72, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectName", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GroupObjectNameClosed"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->{"SectionGrouping", 80},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectNameClosed", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{72, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectNameClosed", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectNameWarningMessages"],
    CellMargins->{{10, 4}, {1, 10}},
    CellGroupingRules->{"SectionGrouping", 65},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectNameWarningMessages", "Brackets"],
    CellMargins->{{10, 4}, {1, 10}},
    CellGroupingRules->{"SectionGrouping", 65},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectNameWarningMessages", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Command"],
    CellMargins->{{10, 4}, {0, 14}},
    CounterIncrements->"Section",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Command", "Printout"],
    CellMargins->{{2, 0}, {0, 14}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CharacterName"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 4}},
    CellFrameMargins->4,
    StyleMenuListing->None],
  
  Cell[StyleData["CharacterName", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    CellGroupingRules->{"SectionGrouping", 90},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["CharacterName", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Usage"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 4}},
    CellFrameMargins->5,
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None],
  
  Cell[StyleData["Usage", "Brackets"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{72, 4}, {0, 4}},
    CellFrameMargins->5,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None],
  
  Cell[StyleData["Usage", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    FontSize->10,
    FontWeight->"Plain"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ErrorMessage"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    ShowCellBracket->True,
    CellMargins->{{10, 4}, {0, 4}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    CellFrameMargins->5,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["ErrorMessage", "Brackets"],
    CellMargins->{{72, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ErrorMessage", "Printout"],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Notes"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["Notes", "Brackets"],
    CellMargins->{{72, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["Notes", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NotesList"],
    CellMargins->{{20, 4}, {2, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ScriptLevel->1,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["NotesList", "Brackets"],
    CellMargins->{{82, 4}, {2, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["NotesList", "Printout"],
    CellMargins->{{12, 0}, {2, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleSection"],
    CellFrame->{{0, 0}, {0, 0.5}},
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{11, 4}, {0, 10}},
    CellGroupingRules->{"SectionGrouping", 70},
    CellFrameMargins->12,
    StyleMenuListing->None,
    FontSize->13,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["ExampleSection", "Printout"],
    CellMargins->{{3, 0}, {0, 10}},
    PageBreakBelow->False,
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleText"],
    CellMargins->{{20, 40}, {0, 18}},
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["ExampleText", "Printout"],
    CellMargins->{{2, 80}, {0, 8}},
    PageBreakBelow->False,
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleSubsection"],
    ShowCellBracket->True,
    CellMargins->{{20, 4}, {0, 16}},
    CellGroupingRules->{"SectionGrouping", 80},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold"],
  
  Cell[StyleData["ExampleSubsection", "Printout"],
    CellMargins->{{12, 0}, {0, 16}},
    PageBreakBelow->False,
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["LineHead"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellMargins->{{10, 4}, {8, 18}},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["LineHead", "Printout"],
    CellMargins->{{2, 0}, {8, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FlushInput"],
    CellMargins->{{10, 4}, {1, 4}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["FlushInput", "Printout"],
    CellMargins->{{2, 0}, {1, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FlushOutput"],
    CellMargins->{{10, Inherited}, {Inherited, Inherited}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->StandardForm,
    StyleMenuListing->None],
  
  Cell[StyleData["FlushOutput", "Printout"],
    CellMargins->{{2, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DialogItem"],
    CellDingbat->"\[EmptyDiamond]",
    CellMargins->{{20, 4}, {0, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold"],
  
  Cell[StyleData["DialogItem", "Printout"],
    CellMargins->{{12, 0}, {0, 12}},
    PageBreakBelow->False,
    FontSize->8]
  }, Closed]],
  
  Cell[StyleData["GroupDivider"],
    CellMargins->{{10, Inherited}, {Inherited, Inherited}},
    CellEditDuplicate->True,
    CellGroupingRules->{"TitleGrouping", 0},
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Highlight"],
    CellMargins->{{10, 4}, {0, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["Highlight", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    LineSpacing->{1, 3}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UserNotes"],
    CellFrame->{{2, 0}, {0, 0.25}},
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["UserNotes", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MoreInfo"],
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.700008, 0.4, 0.100008]],
  
  Cell[StyleData["MoreInfo", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UserTips"],
    CellFrame->{{2, 0}, {0, 0.25}},
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.500008, 0.700008]],
  
  Cell[StyleData["UserTips", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8,
    Background->GrayLevel[0.700008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Theorem"],
    CellFrame->{{4, 0}, {0, 0}},
    CellMargins->{{12, 62}, {0, 14}},
    CellFrameMargins->4,
    CellFrameColor->RGBColor[0, 0, 0.8],
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8}],
  
  Cell[StyleData["Theorem", "Printout"],
    CellMargins->{{2, 0}, {0, 14}},
    CellFrameMargins->3,
    CellFrameColor->GrayLevel[0.8],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Commentary"],
    CellFrame->{{2, 0}, {0, 0}},
    CellMargins->{{36, 10}, {7, 7}},
    PageBreakBelow->False,
    CellFrameMargins->8,
    CellFrameColor->RGBColor[0, 0.2, 1],
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    FontSlant->"Italic"],
  
  Cell[StyleData["Commentary", "Printout"],
    CellMargins->{{32, 0}, {6, 6}},
    CellFrameColor->GrayLevel[0.8],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Level1Icon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["Level1Icon", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Level2Icon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["Level2Icon", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Contents and Index", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsTitle"],
    CellMargins->{{10, 4}, {0, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["ContentsTitle", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsSection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{20, 4}, {3, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["ContentsSection", "Printout"],
    CellMargins->{{12, 0}, {3, 18}},
    PageBreakBelow->False]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{20, 4}, {5, 20}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["IndexSection", "Printout"],
    CellMargins->{{12, 0}, {5, 20}},
    PageBreakBelow->False,
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Contents"],
    CellMargins->{{21, 4}, {0, 8}},
    StyleMenuListing->None],
  
  Cell[StyleData["Contents", "Printout"],
    CellMargins->{{13, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Index"],
    CellMargins->{{21, 4}, {0, 0}},
    ParagraphIndent->-48,
    StyleMenuListing->None],
  
  Cell[StyleData["Index", "Printout"],
    CellMargins->{{13, 0}, {0, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSubentry"],
    CellMargins->{{36, 4}, {0, 0}},
    ParagraphIndent->-48,
    StyleMenuListing->None],
  
  Cell[StyleData["IndexSubentry", "Printout"],
    CellMargins->{{24, 0}, {0, 0}},
    FontSize->9]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Horizontal Lines", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Line1"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellMargins->{{10, 4}, {-16, 9}},
    StyleMenuListing->None,
    FontSize->2],
  
  Cell[StyleData["Line1", "Printout"],
    CellMargins->{{2, 0}, {-16, 9}}]
  }, Closed]],
  
  Cell["\<\

The item above is horizontal 0.5 pt line\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProgramTop"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{10, 4}, {-18, 18}},
    LineSpacing->{1, -4},
    StyleMenuListing->None,
    FontSize->4],
  
  Cell[StyleData["ProgramTop", "Printout"],
    CellMargins->{{2, 0}, {-18, 18}}]
  }, Closed]],
  
  Cell["\<\

The item above is a ProgramTop line
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProgramBottom"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{10, 4}, {-10, -2}},
    LineSpacing->{1, -4},
    StyleMenuListing->None,
    FontSize->4],
  
  Cell[StyleData["ProgramBottom", "Printout"],
    CellMargins->{{2, 0}, {-10, -2}}]
  }, Closed]],
  
  Cell["\<\

The item above is a ProgramBottom line
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SessionLabel"],
    CellFrame->{{0.5, 0}, {0, 0.5}},
    CellMargins->{{10, 4}, {-4, 18}},
    LineSpacing->{1, -3},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SessionLabel", "Printout"],
    CellMargins->{{2, 0}, {-4, 18}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Page Headers and Footers", "Subsubsection"],
  
  Cell[StyleData["PageHeader"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontSize->8,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->8,
    FontWeight->"Bold"],
  
  Cell[StyleData["PageFooter"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->6]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Notation Package Styles", "Section",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell["\<\
The cells below define certain styles needed by the Notation \
package. These styles serve to make visible otherwise invisible \
tagboxes.\
\>", "Text",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationTemplateStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.850004],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationPatternWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.900008, 0.979995],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationMadeBoxesWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.889998, 1],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"]
  }, Closed]]
  }],
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oQon@3:`8g0dL5N`?P0080001804P000000]P2:001
0000I00000400`<30?l00BL?00400@0000000000000006P801T1T00000000000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Servedio"->{
    Cell[1858, 55, 986, 25, 116, "Text",
      CellTags->"Servedio"]},
  "QLE"->{
    Cell[119606, 2862, 123, 3, 27, "SubsubsectionIcon",
      CellTags->"QLE"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Servedio", 234756, 6300},
  {"QLE", 234838, 6303}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 116, 2, 58, "SubsectionIcon"],
Cell[1858, 55, 986, 25, 116, "Text",
  CellTags->"Servedio"],
Cell[2847, 82, 293, 5, 52, "Text"],
Cell[3143, 89, 247, 8, 35, "Text"],
Cell[3393, 99, 99, 2, 41, "MathCaption"],
Cell[3495, 103, 165, 5, 37, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[3685, 112, 103, 2, 35, "SubsubsectionIcon"],
Cell[3791, 116, 122, 3, 32, "Text"],
Cell[3916, 121, 528, 10, 152, "Input",
  InitializationCell->True],
Cell[4447, 133, 950, 23, 95, "Text"],
Cell[5400, 158, 838, 23, 80, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6275, 186, 95, 2, 35, "SubsubsectionIcon"],
Cell[6373, 190, 588, 13, 72, "Text"],
Cell[6964, 205, 491, 13, 32, "Text"],
Cell[7458, 220, 1775, 49, 144, "Input",
  InitializationCell->True],
Cell[9236, 271, 100, 3, 32, "Text"],
Cell[9339, 276, 286, 6, 40, "Input",
  InitializationCell->True],
Cell[9628, 284, 116, 3, 32, "Text"],
Cell[9747, 289, 484, 9, 40, "Input",
  InitializationCell->True],
Cell[10234, 300, 63, 0, 32, "Text"],
Cell[10300, 302, 263, 6, 40, "Input",
  InitializationCell->True],
Cell[10566, 310, 92, 3, 32, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10695, 318, 98, 2, 35, "SubsubsectionIcon"],
Cell[10796, 322, 154, 3, 41, "MathCaption"],
Cell[10953, 327, 243, 6, 40, "Input",
  InitializationCell->True],
Cell[11199, 335, 113, 3, 41, "MathCaption"],

Cell[CellGroupData[{
Cell[11337, 342, 255, 4, 66, "Input"],
Cell[11595, 348, 1268, 19, 105, "Output"]
}, Open  ]],
Cell[12878, 370, 545, 9, 92, "Text"],
Cell[13426, 381, 183, 5, 32, "Text"],
Cell[13612, 388, 160, 5, 41, "MathCaption"],
Cell[13775, 395, 405, 10, 44, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[14205, 409, 250, 6, 40, "Input"],
Cell[14458, 417, 1183, 18, 178, "Output"]
}, Open  ]],
Cell[15656, 438, 59, 0, 41, "MathCaption"],
Cell[15718, 440, 192, 4, 40, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[15935, 448, 100, 2, 37, "Input"],
Cell[16038, 452, 152, 3, 32, "Output"]
}, Open  ]],
Cell[16205, 458, 393, 8, 52, "Text"],
Cell[16601, 468, 117, 2, 41, "MathCaption"],

Cell[CellGroupData[{
Cell[16743, 474, 344, 8, 60, "Input"],
Cell[17090, 484, 1897, 49, 130, "Output"]
}, Open  ]],
Cell[19002, 536, 206, 5, 38, "Text"],
Cell[19211, 543, 165, 5, 41, "MathCaption"],

Cell[CellGroupData[{
Cell[19401, 552, 169, 5, 37, "Input"],
Cell[19573, 559, 919, 14, 67, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[20541, 579, 55, 0, 35, "SubsubsectionIcon"],
Cell[20599, 581, 579, 12, 75, "Text"],
Cell[21181, 595, 296, 9, 43, "MathCaption"],

Cell[CellGroupData[{
Cell[21502, 608, 260, 4, 43, "Input"],
Cell[21765, 614, 869, 13, 72, "Output"]
}, Open  ]],
Cell[22649, 630, 68, 0, 41, "MathCaption"],

Cell[CellGroupData[{
Cell[22742, 634, 703, 11, 77, "Input"],
Cell[23448, 647, 233, 4, 37, "Output"]
}, Open  ]],
Cell[23696, 654, 187, 5, 32, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[23920, 664, 95, 2, 27, "SubsubsectionIcon"],
Cell[24018, 668, 174, 5, 41, "MathCaption"],

Cell[CellGroupData[{
Cell[24217, 677, 321, 7, 43, "Input"],
Cell[24541, 686, 943, 14, 72, "Output"]
}, Open  ]],
Cell[25499, 703, 316, 8, 65, "MathCaption"],

Cell[CellGroupData[{
Cell[25840, 715, 361, 8, 43, "Input"],
Cell[26204, 725, 966, 15, 72, "Output"]
}, Open  ]],
Cell[27185, 743, 197, 5, 32, "Text"],
Cell[27385, 750, 255, 6, 61, "MathCaption"],

Cell[CellGroupData[{
Cell[27665, 760, 458, 10, 66, "Input"],
Cell[28126, 772, 189, 3, 37, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[28364, 781, 95, 2, 27, "SubsubsectionIcon"],
Cell[28462, 785, 902, 26, 71, "MathCaption"],
Cell[29367, 813, 639, 14, 70, "Input",
  InitializationCell->True],
Cell[30009, 829, 127, 3, 41, "MathCaption"],
Cell[30139, 834, 574, 10, 176, "Input",
  InitializationCell->True],
Cell[30716, 846, 79, 0, 41, "MathCaption"],
Cell[30798, 848, 811, 17, 163, "Input",
  InitializationCell->True],
Cell[31612, 867, 118, 3, 41, "MathCaption"],
Cell[31733, 872, 508, 11, 83, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[32266, 887, 76, 2, 37, "Input"],
Cell[32345, 891, 620, 10, 72, "Output"]
}, Open  ]],
Cell[32980, 904, 208, 5, 41, "MathCaption"],
Cell[33191, 911, 321, 8, 37, "Input",
  InitializationCell->True],
Cell[33515, 921, 56, 0, 41, "MathCaption"],
Cell[33574, 923, 192, 4, 40, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[33791, 931, 100, 2, 37, "Input"],
Cell[33894, 935, 261, 5, 32, "Output"]
}, Open  ]],
Cell[34170, 943, 218, 8, 34, "Text"],
Cell[34391, 953, 53, 0, 41, "MathCaption"],

Cell[CellGroupData[{
Cell[34469, 957, 320, 5, 37, "Input"],
Cell[34792, 964, 60, 2, 30, "Output"]
}, Open  ]],
Cell[34867, 969, 144, 3, 32, "Text"],
Cell[35014, 974, 119, 3, 41, "MathCaption"],

Cell[CellGroupData[{
Cell[35158, 981, 471, 9, 60, "Input"],
Cell[35632, 992, 6784, 184, 334, "Output"]
}, Open  ]],
Cell[42431, 1179, 208, 4, 52, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[42676, 1188, 86, 2, 27, "SubsubsectionIcon"],
Cell[42765, 1192, 113, 2, 41, "MathCaption"],

Cell[CellGroupData[{
Cell[42903, 1198, 287, 6, 48, "Input"],
Cell[43193, 1206, 3501, 52, 285, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[46743, 1264, 184, 5, 27, "SubsubsectionIcon"],
Cell[46930, 1271, 375, 8, 52, "Text"],
Cell[47308, 1281, 109, 3, 41, "MathCaption"],
Cell[47420, 1286, 999, 18, 136, "Input",
  InitializationCell->True],
Cell[48422, 1306, 119, 3, 32, "Text"],
Cell[48544, 1311, 2375, 38, 549, "DefinitionBox"],
Cell[50922, 1351, 403, 9, 52, "Text"],
Cell[51328, 1362, 127, 3, 41, "MathCaption"],

Cell[CellGroupData[{
Cell[51480, 1369, 340, 6, 43, "Input"],
Cell[51823, 1377, 263, 5, 37, "Output"]
}, Open  ]],
Cell[52101, 1385, 200, 4, 32, "Text"],
Cell[52304, 1391, 192, 4, 41, "MathCaption"],
Cell[52499, 1397, 767, 13, 75, "Input",
  InitializationCell->True],
Cell[53269, 1412, 102, 3, 41, "MathCaption"],

Cell[CellGroupData[{
Cell[53396, 1419, 175, 3, 43, "Input"],
Cell[53574, 1424, 233, 4, 37, "Output"]
}, Open  ]],
Cell[53822, 1431, 203, 6, 41, "MathCaption"],

Cell[CellGroupData[{
Cell[54050, 1441, 260, 4, 44, "Input"],
Cell[54313, 1447, 337, 6, 32, "Output"]
}, Open  ]],
Cell[54665, 1456, 91, 3, 32, "Text"],
Cell[54759, 1461, 1042, 18, 159, "Input",
  InitializationCell->True],
Cell[55804, 1481, 184, 4, 41, "MathCaption"],

Cell[CellGroupData[{
Cell[56013, 1489, 267, 5, 43, "Input"],
Cell[56283, 1496, 715, 11, 54, "Output"]
}, Open  ]],
Cell[57013, 1510, 125, 3, 41, "MathCaption"],

Cell[CellGroupData[{
Cell[57163, 1517, 455, 7, 66, "Input"],
Cell[57621, 1526, 114, 2, 32, "Output"]
}, Open  ]],
Cell[57750, 1531, 228, 4, 52, "Text"],
Cell[57981, 1537, 192, 4, 41, "MathCaption"],

Cell[CellGroupData[{
Cell[58198, 1545, 455, 7, 66, "Input"],
Cell[58656, 1554, 1128, 19, 85, "Output"]
}, Open  ]],
Cell[59799, 1576, 197, 4, 52, "Text"],
Cell[59999, 1582, 134, 3, 41, "MathCaption"],
Cell[60136, 1587, 517, 10, 40, "Input",
  InitializationCell->True],
Cell[60656, 1599, 961, 16, 234, "Input",
  InitializationCell->True],
Cell[61620, 1617, 351, 7, 52, "Text"],
Cell[61974, 1626, 568, 11, 89, "Input",
  InitializationCell->True],
Cell[62545, 1639, 141, 3, 41, "MathCaption"],

Cell[CellGroupData[{
Cell[62711, 1646, 188, 3, 48, "Input"],
Cell[62902, 1651, 4018, 59, 306, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[66969, 1716, 139, 3, 27, "SubsubsectionIcon"],
Cell[67111, 1721, 215, 8, 35, "Text"],

Cell[CellGroupData[{
Cell[67351, 1733, 176, 3, 37, "Input"],
Cell[67530, 1738, 461, 8, 37, "Output"]
}, Open  ]],
Cell[68006, 1749, 142, 5, 32, "Text"],

Cell[CellGroupData[{
Cell[68173, 1758, 66, 2, 37, "Input"],
Cell[68242, 1762, 346, 5, 39, "Output"]
}, Open  ]],
Cell[68603, 1770, 192, 7, 32, "Text"],

Cell[CellGroupData[{
Cell[68820, 1781, 66, 2, 37, "Input"],
Cell[68889, 1785, 324, 6, 37, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[69262, 1797, 183, 5, 35, "SubsubsectionIcon"],
Cell[69448, 1804, 186, 5, 39, "Text"],

Cell[CellGroupData[{
Cell[69659, 1813, 339, 6, 72, "Input"],
Cell[70001, 1821, 436, 7, 63, "Output"]
}, Open  ]],
Cell[70452, 1831, 164, 4, 41, "MathCaption"],

Cell[CellGroupData[{
Cell[70641, 1839, 89, 2, 37, "Input"],
Cell[70733, 1843, 352, 6, 52, "Output"]
}, Open  ]],
Cell[71100, 1852, 215, 6, 41, "MathCaption"],

Cell[CellGroupData[{
Cell[71340, 1862, 117, 2, 37, "Input"],
Cell[71460, 1866, 2525, 37, 237, "Output"]
}, Closed]],
Cell[74000, 1906, 78, 0, 24, "MathCaption"],
Cell[74081, 1908, 486, 9, 86, "Input",
  InitializationCell->True],
Cell[74570, 1919, 56, 0, 41, "MathCaption"],

Cell[CellGroupData[{
Cell[74651, 1923, 541, 10, 42, "Input"],
Cell[75195, 1935, 337, 6, 52, "Output"]
}, Open  ]],
Cell[75547, 1944, 51, 0, 32, "Text"],
Cell[75601, 1946, 326, 5, 52, "Output"],
Cell[75930, 1953, 42, 0, 32, "Text"],
Cell[75975, 1955, 106, 3, 32, "Text"],

Cell[CellGroupData[{
Cell[76106, 1962, 131, 3, 43, "Input"],
Cell[76240, 1967, 568, 9, 39, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[76857, 1982, 273, 7, 37, "SubsubsectionIcon"],
Cell[77133, 1991, 291, 7, 43, "Text"],

Cell[CellGroupData[{
Cell[77449, 2002, 584, 11, 77, "Input"],
Cell[78036, 2015, 5391, 85, 431, "Output"]
}, Closed]],
Cell[83442, 2103, 137, 3, 24, "MathCaption"],

Cell[CellGroupData[{
Cell[83604, 2110, 111, 2, 40, "Input"],
Cell[83718, 2114, 380, 6, 40, "Output"]
}, Open  ]],
Cell[84113, 2123, 51, 0, 41, "MathCaption"],

Cell[CellGroupData[{
Cell[84189, 2127, 262, 5, 47, "Input"],
Cell[84454, 2134, 2827, 44, 281, "Output"]
}, Open  ]],
Cell[87296, 2181, 50, 0, 32, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[87383, 2186, 46, 0, 27, "SubsubsectionIcon"],
Cell[87432, 2188, 391, 11, 54, "Text"],
Cell[87826, 2201, 235, 5, 52, "Text"],
Cell[88064, 2208, 1139, 19, 182, "Input"],
Cell[89206, 2229, 44, 0, 32, "Text"],
Cell[89253, 2231, 614, 10, 66, "Input"],

Cell[CellGroupData[{
Cell[89892, 2245, 258, 5, 67, "Input"],
Cell[90153, 2252, 90, 2, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[90280, 2259, 151, 3, 46, "Input"],
Cell[90434, 2264, 7151, 105, 889, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[97622, 2374, 177, 3, 32, "Input"],
Cell[97802, 2379, 744, 12, 72, "Output"]
}, Open  ]],
Cell[98561, 2394, 241, 5, 60, "Input"],
Cell[98805, 2401, 328, 5, 87, "Input"],
Cell[99136, 2408, 48, 0, 41, "MathCaption"],

Cell[CellGroupData[{
Cell[99209, 2412, 139, 3, 39, "Input"],
Cell[99351, 2417, 81, 2, 30, "Output"]
}, Open  ]],
Cell[99447, 2422, 158, 6, 43, "MathCaption"],
Cell[99608, 2430, 537, 8, 99, "Input"],
Cell[100148, 2440, 206, 4, 52, "Text"],
Cell[100357, 2446, 76, 0, 41, "MathCaption"],

Cell[CellGroupData[{
Cell[100458, 2450, 241, 4, 66, "Input"],
Cell[100702, 2456, 1483, 23, 105, "Output"]
}, Open  ]],
Cell[102200, 2482, 160, 3, 37, "Input"],
Cell[102363, 2487, 94, 3, 32, "Text"],

Cell[CellGroupData[{
Cell[102482, 2494, 303, 6, 66, "Input"],
Cell[102788, 2502, 1183, 18, 105, "Output"]
}, Open  ]],
Cell[103986, 2523, 74, 0, 32, "Text"],
Cell[104063, 2525, 51, 0, 41, "MathCaption"],

Cell[CellGroupData[{
Cell[104139, 2529, 322, 6, 62, "Input"],
Cell[104464, 2537, 155, 3, 32, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[104656, 2545, 87, 2, 40, "Input"],
Cell[104746, 2549, 86, 2, 30, "Output"]
}, Open  ]],
Cell[104847, 2554, 23, 0, 32, "Text"],
Cell[104873, 2556, 61, 1, 30, "Output"],
Cell[104937, 2559, 35, 1, 37, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[105009, 2565, 108, 2, 27, "SubsubsectionIcon"],
Cell[105120, 2569, 367, 11, 32, "Text"],

Cell[CellGroupData[{
Cell[105512, 2584, 250, 5, 37, "Input"],
Cell[105765, 2591, 446, 8, 39, "Output"]
}, Open  ]],
Cell[106226, 2602, 178, 5, 48, "MathCaption"],

Cell[CellGroupData[{
Cell[106429, 2611, 382, 7, 63, "Input"],
Cell[106814, 2620, 356, 6, 39, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[107207, 2631, 382, 7, 63, "Input"],
Cell[107592, 2640, 344, 6, 37, "Output"]
}, Open  ]],
Cell[107951, 2649, 240, 6, 43, "Text"],

Cell[CellGroupData[{
Cell[108216, 2659, 549, 10, 63, "Input"],
Cell[108768, 2671, 5853, 85, 521, "Output"]
}, Open  ]],
Cell[114636, 2759, 399, 8, 70, "Text"],
Cell[115038, 2769, 501, 14, 70, "Text"],

Cell[CellGroupData[{
Cell[115564, 2787, 512, 10, 70, "Input"],
Cell[116079, 2799, 3107, 45, 70, "Output"]
}, Open  ]],
Cell[119201, 2847, 111, 2, 70, "Text"],
Cell[119315, 2851, 254, 6, 70, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[119606, 2862, 123, 3, 27, "SubsubsectionIcon",
  CellTags->"QLE"],
Cell[119732, 2867, 571, 13, 74, "Text"],

Cell[CellGroupData[{
Cell[120328, 2884, 834, 13, 106, "Input"],
Cell[121165, 2899, 515, 8, 63, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[121729, 2913, 77, 0, 27, "SubsubsectionIcon"],
Cell[121809, 2915, 285, 5, 70, "Text"],
Cell[122097, 2922, 79, 0, 70, "MathCaption"],

Cell[CellGroupData[{
Cell[122201, 2926, 358, 7, 70, "Input"],
Cell[122562, 2935, 400, 7, 70, "Output"]
}, Open  ]],
Cell[122977, 2945, 163, 5, 70, "MathCaption"],

Cell[CellGroupData[{
Cell[123165, 2954, 307, 7, 70, "Input"],
Cell[123475, 2963, 1423, 26, 70, "Output"]
}, Open  ]],
Cell[124913, 2992, 584, 12, 70, "Text"],

Cell[CellGroupData[{
Cell[125522, 3008, 79, 2, 70, "Input"],
Cell[125604, 3012, 538, 9, 70, "Output"]
}, Open  ]],
Cell[126157, 3024, 100, 3, 70, "MathCaption"],

Cell[CellGroupData[{
Cell[126282, 3031, 133, 3, 70, "Input"],
Cell[126418, 3036, 2045, 34, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[128500, 3075, 83, 2, 70, "Input"],
Cell[128586, 3079, 400, 7, 70, "Output"]
}, Open  ]],
Cell[129001, 3089, 108, 3, 70, "MathCaption"],

Cell[CellGroupData[{
Cell[129134, 3096, 302, 6, 70, "Input"],
Cell[129439, 3104, 1426, 22, 70, "Output"]
}, Open  ]],
Cell[130880, 3129, 181, 4, 70, "MathCaption"],

Cell[CellGroupData[{
Cell[131086, 3137, 227, 6, 70, "Input"],
Cell[131316, 3145, 1320, 20, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[132685, 3171, 120, 2, 27, "SubsubsectionIcon"],
Cell[132808, 3175, 261, 6, 70, "MathCaption"],

Cell[CellGroupData[{
Cell[133094, 3185, 338, 7, 70, "Input"],
Cell[133435, 3194, 446, 9, 70, "Message"],
Cell[133884, 3205, 169, 3, 70, "Output"]
}, Open  ]],
Cell[134068, 3211, 422, 11, 70, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[134527, 3227, 98, 3, 27, "SubsubsectionIcon"],
Cell[134628, 3232, 147, 3, 32, "Text"],

Cell[CellGroupData[{
Cell[134800, 3239, 252, 5, 60, "Input"],
Cell[135055, 3246, 877, 14, 57, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[135969, 3265, 827, 15, 138, "Input"],
Cell[136799, 3282, 1633, 24, 140, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[138469, 3311, 271, 5, 48, "Input"],
Cell[138743, 3318, 3878, 59, 306, "Output"]
}, Closed]],
Cell[142636, 3380, 831, 15, 125, "Input"],

Cell[CellGroupData[{
Cell[143492, 3399, 305, 6, 48, "Input"],
Cell[143800, 3407, 10647, 158, 842, "Output"]
}, Closed]],
Cell[154462, 3568, 217, 4, 44, "MathCaption"],

Cell[CellGroupData[{
Cell[154704, 3576, 964, 16, 98, "Input"],
Cell[155671, 3594, 3833, 58, 376, "Output"]
}, Open  ]],
Cell[159519, 3655, 130, 3, 41, "MathCaption"],

Cell[CellGroupData[{
Cell[159674, 3662, 298, 5, 46, "Input"],
Cell[159975, 3669, 1678, 25, 160, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[161690, 3699, 767, 13, 66, "Input"],
Cell[162460, 3714, 882, 14, 94, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

