(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      9134,        291]*)
(*NotebookOutlinePosition[     10827,        341]*)
(*  CellTagsIndexPosition[     10608,        331]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Stages in the life cycle", "SubsectionIcon"],

Cell["\<\
Contexts can be defined in a very general way.  The number of \
components depends on how many components need to be tracked: for example, \
with sex-symmetric selection it may not be necessary to specify whether genes \
are in males or females.  As a gene moves through the life cycle, it moves \
between contexts that have a different structure.  For example, at the gamete \
stage a gene may only be in either male or female gametes, whilst at the \
zygote stage, both the sex and the sex-of-origin may need to be specified.  \
With selection on families, which gene a family is in needs to be specified. \
\
\>", "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{"DefineContext", "[", 
              RowBox[{
                StyleBox["stage",
                  FontSlant->"Italic"], 
                StyleBox[",",
                  FontSlant->"Italic"], 
                StyleBox[" ",
                  FontSlant->"Italic"], 
                RowBox[{
                  StyleBox["{",
                    FontSlant->"Italic"], 
                  RowBox[{
                    SubscriptBox[
                      StyleBox["component",
                        FontSlant->"Italic"], "1"], ",", "\[Ellipsis]"}], 
                  "}"}]}], 
              "]"}], \(defines\ a\ context\ with\ components\ in\ the\ given\ \
\(\(order\)\(.\)\)\)},
          {
            RowBox[{"ContextStructure", "[", 
              StyleBox["stage",
                FontSlant->"Italic"], "]"}], 
            RowBox[{"lists", " ", "the", " ", "components", " ", "of", " ", 
              RowBox[{
                StyleBox["stage",
                  FontSlant->"Italic"], "."}]}]}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->{"DefineContext", "ContextStructure"}],

Cell[TextData[{
  "Components could be identified either by their position within the context \
vector, or by a qualitative 'tag'.  This ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " package uses both methods.  Each kind of context is named, and that name \
must appear as the first component of the context. This first component is \
referred to as a ",
  StyleBox["stage",
    FontSlant->"Italic"],
  " in the life cycle.  Each component is given a unique name, and the \
structure of each named stage is defined as a list of components."
}], "Text"],

Cell["This reads in the package:", "MathCaption"],

Cell[BoxData[
    \(\(<< Multilocus`Multilocus`;\)\)], "Input",
  CellLabel->"In[17]:="],

Cell["\<\
This defines the gamete stage of the life cycle as \
\[GothicCapitalG].  Gamete contexts are structured by Time and Sex:\
\>", \
"MathCaption"],

Cell[BoxData[
    \(\(DefineContext[\[GothicCapitalG], {Time, \ Sex}];\)\)], "Input",
  CellLabel->"In[20]:="],

Cell["\<\
For example, a gene at locus i in a male gamete at time t would be \
written as:\
\>", "MathCaption"],

Cell[BoxData[
    \(\[DoubleStruckI] = 
      i\_{\[GothicCapitalG], t, \[GothicCapitalM]}\)], "Input"],

Cell["\<\
This lists the components of \[GothicCapitalG]:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ContextStructure[\[GothicCapitalG]]\)], "Input",
  CellLabel->"In[21]:="],

Cell[BoxData[
    \({Time, Sex}\)], "Output",
  CellLabel->"Out[21]="]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{"ContextPosition", "[", 
              RowBox[{
                StyleBox["stage",
                  FontSlant->"Italic"], ",", " ", 
                StyleBox["component",
                  FontSlant->"Italic"]}], 
              StyleBox["]",
                FontSlant->"Italic"]}], 
            RowBox[{"gives", " ", "the", " ", "position", " ", "of", " ", 
              StyleBox["component",
                FontSlant->"Italic"], " ", "in", " ", "the", " ", "context", 
              " ", "whose", " ", "structure", " ", "is", " ", "defined", " ", 
              "by", " ", 
              RowBox[{
                StyleBox["stage",
                  FontSlant->"Italic"], "."}]}]}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"ContextPosition"],

Cell["\<\
This finds the position of Sex in \[GothicCapitalG]:\
\>", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ContextPosition[\[GothicCapitalG], \ Sex]\)], "Input",
  CellLabel->"In[28]:="],

Cell[BoxData[
    \(3\)], "Output",
  CellLabel->"Out[28]="]
}, Open  ]],

Cell["\<\
Note that this is the position in the context vector, not the list \
of components used to define the context.  The stage is always the first \
component.  \
\>", "Text"],

Cell["ContextPosition[] returns zero for inappropriate components:", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \({ContextPosition[\[GothicCapitalG], \ \[GothicCapitalG]], 
      ContextPosition[\[GothicCapitalG], \ SexOfOrigin]}\)], "Input",
  CellLabel->"In[7]:="],

Cell[BoxData[
    \(ContextPosition::"nocom" \(\(:\)\(\ \)\) 
      "Components not defined for \
ContextPosition[\!\(\[GothicCapitalG]\),\!\(SexOfOrigin\)]"\)], "Message",
  CellLabel->"From In[7]:="],

Cell[BoxData[
    \({1, 0}\)], "Output",
  CellLabel->"Out[7]="]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{"ContextComponentQ", "[", 
              StyleBox[\(stage, \ symbol\),
                FontSlant->"Italic"], "]"}], 
            RowBox[{"finds", " ", "whether", " ", 
              StyleBox["symbol",
                FontSlant->"Italic"], " ", "is", " ", "a", " ", "component", 
              " ", "of", " ", 
              RowBox[{
                StyleBox["stage",
                  FontSlant->"Italic"], "."}]}]},
          {
            RowBox[{"ContextStageQ", "[", 
              StyleBox["symbol",
                FontSlant->"Italic"], 
              StyleBox["]",
                FontSlant->"Italic"]}], 
            RowBox[{"finds", " ", "whether", " ", 
              StyleBox["symbol",
                FontSlant->"Italic"], 
              StyleBox[" ",
                FontSlant->"Plain"], 
              StyleBox["is",
                FontSlant->"Plain"], 
              StyleBox[" ",
                FontSlant->"Plain"], 
              StyleBox["a",
                FontSlant->"Plain"], 
              StyleBox[" ",
                FontSlant->"Plain"], 
              StyleBox["defined",
                FontSlant->"Plain"], 
              StyleBox[" ",
                FontSlant->"Plain"], 
              StyleBox[\(\(stage\)\(.\)\),
                FontSlant->"Plain"]}]}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->{"ContextComponentQ", "ContextStageQ"}],

Cell["\<\
This shows that Time is a component of Gamete, but SexOfOrigin is \
not:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \({ContextComponentQ[\[GothicCapitalG], Time], 
      ContextComponentQ[\[GothicCapitalG], SexOfOrigin]}\)], "Input",
  CellLabel->"In[8]:="],

Cell[BoxData[
    \({True, False}\)], "Output",
  CellLabel->"Out[8]="]
}, Open  ]],

Cell["\<\
This shows that \[GothicCapitalG] has been defined as a \
stage:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ContextStageQ[\[GothicCapitalG]]\)], "Input",
  CellLabel->"In[9]:="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[9]="]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{749, 614},
WindowMargins->{{Automatic, 56}, {Automatic, 20}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000]P2:?oQon82n@960dL5:0?l0080001804P000000]P2:001
0000I00000400`<300000BL?00400@0000000000000006P801T1T00000000000
00000000000000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "DefineContext"->{
    Cell[2429, 65, 1177, 30, 58, "DefinitionBox",
      CellTags->{"DefineContext", "ContextStructure"}]},
  "ContextStructure"->{
    Cell[2429, 65, 1177, 30, 58, "DefinitionBox",
      CellTags->{"DefineContext", "ContextStructure"}]},
  "ContextPosition"->{
    Cell[5093, 151, 847, 20, 37, "DefinitionBox",
      CellTags->"ContextPosition"]},
  "ContextComponentQ"->{
    Cell[6981, 216, 1472, 39, 56, "DefinitionBox",
      CellTags->{"ContextComponentQ", "ContextStageQ"}]},
  "ContextStageQ"->{
    Cell[6981, 216, 1472, 39, 56, "DefinitionBox",
      CellTags->{"ContextComponentQ", "ContextStageQ"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"DefineContext", 9971, 312},
  {"ContextStructure", 10102, 315},
  {"ContextPosition", 10232, 318},
  {"ContextComponentQ", 10344, 321},
  {"ContextStageQ", 10474, 324}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 50, 0, 36, "SubsectionIcon"],
Cell[1792, 53, 634, 10, 64, "Text"],
Cell[2429, 65, 1177, 30, 58, "DefinitionBox",
  CellTags->{"DefineContext", "ContextStructure"}],
Cell[3609, 97, 565, 12, 54, "Text"],
Cell[4177, 111, 49, 0, 28, "MathCaption"],
Cell[4229, 113, 88, 2, 27, "Input"],
Cell[4320, 117, 153, 4, 28, "MathCaption"],
Cell[4476, 123, 110, 2, 27, "Input"],
Cell[4589, 127, 111, 3, 28, "MathCaption"],
Cell[4703, 132, 103, 2, 28, "Input"],
Cell[4809, 136, 78, 2, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[4912, 142, 93, 2, 27, "Input"],
Cell[5008, 146, 70, 2, 20, "Output"]
}, Open  ]],
Cell[5093, 151, 847, 20, 37, "DefinitionBox",
  CellTags->"ContextPosition"],
Cell[5943, 173, 85, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[6053, 180, 99, 2, 27, "Input"],
Cell[6155, 184, 60, 2, 20, "Output"]
}, Open  ]],
Cell[6230, 189, 180, 4, 22, "Text"],
Cell[6413, 195, 85, 1, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[6523, 200, 172, 3, 27, "Input"],
Cell[6698, 205, 201, 4, 20, "Message"],
Cell[6902, 211, 64, 2, 20, "Output"]
}, Open  ]],
Cell[6981, 216, 1472, 39, 56, "DefinitionBox",
  CellTags->{"ContextComponentQ", "ContextStageQ"}],
Cell[8456, 257, 103, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[8584, 264, 159, 3, 27, "Input"],
Cell[8746, 269, 71, 2, 20, "Output"]
}, Open  ]],
Cell[8832, 274, 95, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[8952, 281, 89, 2, 27, "Input"],
Cell[9044, 285, 62, 2, 20, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

