(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     16532,        409]*)
(*NotebookOutlinePosition[     23707,        566]*)
(*  CellTagsIndexPosition[     22921,        543]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Overview of numerical models", "SubsectionIcon"],

Cell[TextData[{
  "This section includes a variety of ways of following the evolution of \
populations that segregate for multiple loci.  Although symbolic solutions \
can be found, the package is designed for numerical recursion.  Compiled code \
can be used for faster solutions; however, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is inherently slower than (say) C.  The aim is to give a set of simple \
functions which can be used to explore fairly general models of multilocus \
evolution.  "
}], "Text"],

Cell["\<\
The package will follow any number of loci, each with two alleles.  \
There can be a single population, or a set of demes in a linear stepping  \
stone model, with nearest-neighbour migration.  Deme size can vary as a \
function of genotype.\
\>", "Text"],

Cell["\<\
The key restrictions are that there are only two alleles per locus, \
and that the population is described in terms of haploid genotypes: thus, \
random union of gametes must be assumed.  However, selection and migration \
may cause deviations from Hardy-Weinberg proportions at intermediate stages \
of the life cycle, and so diploid frequencies are followed at intermediate \
stages.\
\>", "Text"],

Cell["\<\
Single populations, or linear clines, can be iterated using \
IterateExact[\[Psi],W,m], where W is an arbitrary fitness function and m the \
migration rate.  Several orders for events in the life cycle are provided as \
options to IterateExact.  Other models can be constructed using simple \
functions which implement random union, migration, selection, meiosis and \
random drift.\
\>", "Text"],

Cell["\<\
Simulations should be checked either against theoretical \
expectations, or against eachother.  For example, random drift can be \
simulated either by following a finite population of individuals, or by \
multinomial sampling from a list of genotype frequencies.  These two methods \
should give the same distribution of results.  \
\>", "Text"],

Cell["\<\
Multilocus`Multilocus` gives a much more general representation, \
designed for algebraic work.  Populations are represented by associations \
among sets of genes-in-context:\
\>", "Text"],

Cell[BoxData[GridBox[{
        {
          ButtonBox[\(Multilocus\ notation\),
            ButtonData:>{"Introduction to multilocus algebra", None},
            
            ButtonStyle->
              "AddOnsLink"], \(\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, 
                j\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}}\
\), \(gives\ associations\ between\ sets\ of\ genes - in - context; \ here, \ 
          loci\ i\ and\ j\ in\ the\ maternal\ genome\ of\ a\ male\ \(\(zygote\
\)\(.\)\(\ \ \)\)\)}
        }]], "DefinitionBox3Col"],

Cell[CellGroupData[{

Cell["Representing the population", "SubsubsectionIcon",
  CellTags->"Representing the population"],

Cell[TextData[{
  "A single population is represented in a form such as HaploidFrequencies[",
  Cell[BoxData[
      \(TraditionalForm\`{\[Psi]\_000, \[Psi]\_001, \
\[Ellipsis]\[Psi]\_111}\)]],
  "]. Optionally, deme size can be added to the representation: for example, \
HaploidFrequencies[",
  Cell[BoxData[
      \(TraditionalForm\`{\[Psi]\_000, \[Psi]\_001, \[Ellipsis]\[Psi]\_111}, 
      n\)]],
  "]. "
}], "Text"],

Cell[TextData[{
  "A cline is represented by a list of populations, such as \
{HaploidFrequencies[",
  Cell[BoxData[
      \(TraditionalForm\`{\[Psi]\_000, \[Psi]\_001, \
\[Ellipsis]\[Psi]\_111}\)]],
  "],HaploidFrequencies[",
  Cell[BoxData[
      \(TraditionalForm\`{\[Psi]\_000, \[Psi]\_001, \
\[Ellipsis]\[Psi]\_111}\)]],
  "],\[Ellipsis]}.  Most functions can handle either a single population or a \
cline."
}], "Text"],

Cell["\<\
There are several ways of representing the evolution of multiple \
genes:\
\>", "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      FormBox[GridBox[{
            {
              RowBox[{
                ButtonBox["HaploidFrequencies",
                  ButtonData:>{"Recursions: representation", None},
                  ButtonStyle->"AddOnsLink"], 
                "[", \({\[Psi]\_000, \[Psi]\_001, \[Ellipsis]\[Psi]\_111}\), 
                "]"}], \(lists\ haploid\ genotype\ \(\(frequencies\)\(.\)\(\ \
\ \)\)\)},
            {
              RowBox[{
                ButtonBox["DiploidFrequencies",
                  ButtonData:>{"Recursions: representation", None},
                  ButtonStyle->"AddOnsLink"], 
                "[", \({{\[Psi]\_\(000, 000\), \[Psi]\_\(000, 001\), \
\[Ellipsis]}, \[Ellipsis]}\), 
                "]"}], \(lists\ diploid\ genotype\ frequencies\ as\ a\ \
\(\(matrix\)\(.\)\(\ \ \)\)\)},
            {
              RowBox[{
                ButtonBox["AlleleFrequencies",
                  ButtonData:>{"Allele frequencies: representation", None},
                  ButtonStyle->"AddOnsLink"], 
                "[", \({p\_1, p\_2, \[Ellipsis]p\_n}\), 
                "]"}], \(lists\ allele\ frequencies; \ 
              assumes\ linkage\ \(\(equilibrium\)\(.\)\(\ \)\)\)},
            {
              RowBox[{
                ButtonBox["SymmetricHaploidFrequencies",
                  ButtonData:>{"Genotype frequencies", None},
                  ButtonStyle->"AddOnsLink"], 
                "[", \({\[Psi]\_0, \[Psi]\_1, \[Ellipsis], \[Psi]\_n}\), 
                "]"}], \(lists\ the\ frequencies\ of\ haploid\ genotypes\ \
carrying\ 0, \ 1  \[Ellipsis]alleles\ of\ type\ ' 1'; \ 
              assumes\ that\ all\ genotypes\ in\ a\ given\ class\ are\ \
equally\ frequent . \ \ Includes\ checks\ on\ whether\ such\ symmetric\ \
solutions\ are\ \(\(stable\)\(.\)\)\)},
            {
              RowBox[{
                ButtonBox["SymmetricDiploidFrequencies",
                  ButtonData:>{"Genotype frequencies", None},
                  ButtonStyle->"AddOnsLink"], 
                "[", \({{\[Psi]\_\(0, 0\), \[Psi]\_\(0, 1\), \[Ellipsis]}, \
\[Ellipsis], {\[Ellipsis], \[Psi]\_\(n, n\)}}\), 
                "]"}], \(lists\ the\ frequencies\ of\ diploid\ genotypes\ \
carrying\ 0, \ 1  \[Ellipsis]alleles\ of\ type\ ' 1', \ 
              as\ a\ \(\(matrix\)\(.\)\)\)},
            {
              RowBox[{
                ButtonBox["SymmetricNeutralHaploidFrequencies",
                  ButtonData:>{"Adding a neutral gene", None},
                  ButtonStyle->"AddOnsLink"], 
                "[", \({{\[Psi]\_0, \[Psi]\_1, \[Ellipsis]\[Psi]\_n}, {u\_0, \
\[Ellipsis]u\_n}}\), "]"}], \(includes\ a\ neutral\ marker, \ 
              at\ frequency\ u\_i\ within\ background\ i\)},
            {
              RowBox[{
                ButtonBox["SymmetricNeutralDiploidFrequencies",
                  ButtonData:>{"Adding a neutral gene", None},
                  ButtonStyle->"AddOnsLink"], 
                "[", \({{{\[Psi]\_\(0, 0\), \[Ellipsis]}, \[Ellipsis]}, {{u\_\
\(0, 0\), \[Ellipsis]}, \[Ellipsis]}}\), "]"}], \(as\ above, \ 
              but\ for\ diploids; \ 
              represented\ as\ a\ pair\ of\ \(\(matrices\)\(.\)\)\)},
            {
              RowBox[{
                ButtonBox["HaploidIndividuals",
                  
                  ButtonData:>{"Simulating individuals: representation", 
                    None},
                  ButtonStyle->"AddOnsLink"], 
                "[", \({{0, 0, 1, \[Ellipsis]}, \[Ellipsis]}\), 
                "]"}], \(lists\ a\ set\ of\ haploid\ individuals; \ 
              necessarily, \ includes\ random\ \(\(drift\)\(.\)\)\)},
            {
              RowBox[{
                ButtonBox["DiploidIndividuals",
                  
                  ButtonData:>{"Simulating individuals: representation", 
                    None},
                  ButtonStyle->"AddOnsLink"], 
                "[", \({{{0, 0, 1, \[Ellipsis]}, {1, 0, 
                      1, \[Ellipsis]}}, \[Ellipsis]}\), 
                "]"}], \(lists\ a\ set\ of\ diploid\ \(\(individuals\)\(.\)\)\
\)}
            }], TraditionalForm]]]
}], "DefinitionBox",
  CellTags->{
  "HaploidFrequencies", "DiploidFrequencies", "AlleleFrequencies", 
    "SymmetricNeutralDiploidFrequencies", "", "DiploidIndividuals", 
    "SymmetricHaploidFrequencies", "SymmetricNeutralHaploidFrequencies", 
    "SymmetricDiploidFrequencies", "HaploidIndividuals"}],

Cell["\<\
For the most part, the same functions are used for all these \
representations.  However, the different representations are documented \
separately.\
\>", "Text"],

Cell["\<\
For each representation, deme size is automatically added.  For \
deterministic representations, the default is a deme size of 1:\
\>", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(AlleleFrequencies[{0.1, 0.2, 0.4}]\)], "Input"],

Cell[BoxData[
    \(AlleleFrequencies[{0.1, 0.2, 0.4}, 1]\)], "Output"]
}, Open  ]],

Cell["\<\
For individual representations, the deme size is calculated \
automatically from the number of individuals:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(HaploidIndividuals[{{0, 0, 1}, {0, 0, 0}, {1, 1, 0}}]\)], "Input"],

Cell[BoxData[
    \(HaploidIndividuals[{{0, 0, 1}, {0, 0, 0}, {1, 1, 0}}, 3]\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Selection", "SubsubsectionIcon",
  CellTags->"Selection"],

Cell[TextData[{
  "Selection is modelled through a fitness function, W, which gives the ",
  StyleBox["relative",
    FontSlant->"Italic"],
  " fitness of each genotype.  A second function must be provided, which \
gives the change in deme size.  By definition, this is just the mean absolute \
fitness; in principle, therefore, it would be possible to just specify the \
absolute fitness of each genotype, and calculate both changes in genotype \
frequnecy and in population size from this one function.  However, this is \
usually inefficient.  Often, relative fitnesses are assumed to be independent \
of population size (i.e. density-independent selection), so that absolute \
fitness is a product of a function of population size, and a function of \
genotype.  If these were combined, every genotypic fitness would be given by \
a complicated function.  Thus, it is convenient to represent absolute fitness \
by a product of two functions - the genetic and ecological components.  There \
is, however, no loss of generality: each can be an arbitrary function, and so \
frequency-dependent selection, density-dependent selection, and \
genotype-dependent  population size, can all be modelled."
}], "Text"],

Cell["\<\
Where diploid genotypes are specified, we have genetic component \
W[X,Y].  If this depends on location, it is given as W[i][X,Y].  Other \
variables could be given in a similar way: for example, W[p][i][X,Y] gives \
the fitness as a function of allele frequencies, p.  This convention is, \
however, not as yet supported by IterateExact[].\
\>", "Text"],

Cell[TextData[{
  "Where allele frequencies are specified, a function W[p] gives the \
selection coefficients at each locus, together with the mean fitness: ",
  Cell[BoxData[
      \(TraditionalForm\`{W\&_, {s\_1, \[Ellipsis]}\)]],
  "}.  This is necessary for three reasons.  First, there are typically too \
many genotypes for it to be possible to calculate maginal fitnesses from \
genotypic fitnesses: calculations are only feasible if the marginal fitnesses \
can be written as a simple function of allele frequencies.  Second, the \
change in allele frequency typically appears as ",
  Cell[BoxData[
      \(TraditionalForm\`\(s\_i\[VeryThinSpace]p\_i\[VeryThinSpace]q\_i\)\/W\&\
_, \ and\ so\ it\ is\ convenient\ to\ provide\ the\ common\ denominator\ W\&_\
\)]],
  " separately, rather than within each of the coefficients, ",
  Cell[BoxData[
      \(TraditionalForm\`s\_i\)]],
  ".  Finally, the change in population size may involve the mean relative \
fitness, ",
  Cell[BoxData[
      \(TraditionalForm\`W\&_\)]],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Representations", "SubsubsectionIcon",
  CellTags->"Representations"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            "PopulationRepresentations", \(HaploidFrequencies | 
              DiploidFrequencies | AlleleFrequencies | 
              SymmetricHaploidFrequencies | SymmetricDiploidFrequencies | 
              SymmetricNeutralHaploidFrequencies | 
              SymmetricNeutralDiploidFrequencies | HaploidIndividuals | 
              DiploidIndividuals\)},
          {
            "FrequencyRepresentations", \(HaploidFrequencies | 
              DiploidFrequencies | AlleleFrequencies | 
              SymmetricHaploidFrequencies | SymmetricDiploidFrequencies | 
              SymmetricNeutralHaploidFrequencies | 
              SymmetricNeutralDiploidFrequencies\)},
          {
            "IndividualRepresentations", \(HaploidIndividuals | 
              DiploidIndividuals\)},
          {
            "HaploidRepresentations", \(HaploidFrequencies | 
              AlleleFrequencies | SymmetricHaploidFrequencies | 
              SymmetricNeutralHaploidFrequencies | HaploidIndividuals\)},
          {
            "DiploidRepresentations", \(DiploidFrequencies | 
              AlleleFrequencies | SymmetricDiploidFrequencies | 
              SymmetricNeutralDiploidFrequencies | DiploidIndividuals\)},
          {
            "NeutralRepresentations", \(SymmetricNeutralHaploidFrequencies | 
              SymmetricNeutralDiploidFrequencies\)},
          {
            "NonNeutralRepresentations", \(HaploidFrequencies | 
              DiploidFrequencies | AlleleFrequencies | 
              SymmetricHaploidFrequencies | SymmetricDiploidFrequencies | 
              HaploidIndividuals | DiploidIndividuals\)},
          {
            "SymmetricRepresentations", \(SymmetricHaploidFrequencies | 
              SymmetricDiploidFrequencies | 
              SymmetricNeutralHaploidFrequencies | 
              SymmetricNeutralDiploidFrequencies\)},
          {
            "NonSymmetricRepresentations", \(HaploidFrequencies | 
              DiploidFrequencies | HaploidIndividuals | DiploidIndividuals\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->{
  "PopulationRepresentations", "HaploidRepresentations", 
    "DiploidRepresentations", "IndividualRepresentations", 
    "FrequencyRepresentations"}],

Cell["\<\
The various representations can be classed as deterministic or \
individual, haploid or diploid.  (Note that AlleleFrequencies can represent \
either a haploid or a diploid population; and AlleleFrequencies is in neither \
SymmetricRepresentations nor NonSymmetricRepresentations).  These patterns \
can be used to determine the range of application of the various functions.\
\
\>", "Text"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
WindowSize->{963, 691},
WindowMargins->{{-3, Automatic}, {Automatic, 1}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
0@00D01804P000000]X2:?oQon82n@96D005:0?l0040D01804P000000]X2:000
0000I0000000000000000BL?00400@00000000000000000B0002I0000aP00000
8W800@0100<00P0000000000oW`10000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Representing the population"->{
    Cell[4592, 120, 99, 1, 24, "SubsubsectionIcon",
      CellTags->"Representing the population"]},
  "HaploidFrequencies"->{
    Cell[5645, 155, 4448, 94, 258, "DefinitionBox",
      CellTags->{
      "HaploidFrequencies", "DiploidFrequencies", "AlleleFrequencies", 
        "SymmetricNeutralDiploidFrequencies", "", "DiploidIndividuals", 
        "SymmetricHaploidFrequencies", "SymmetricNeutralHaploidFrequencies", 
        "SymmetricDiploidFrequencies", "HaploidIndividuals"}]},
  "DiploidFrequencies"->{
    Cell[5645, 155, 4448, 94, 258, "DefinitionBox",
      CellTags->{
      "HaploidFrequencies", "DiploidFrequencies", "AlleleFrequencies", 
        "SymmetricNeutralDiploidFrequencies", "", "DiploidIndividuals", 
        "SymmetricHaploidFrequencies", "SymmetricNeutralHaploidFrequencies", 
        "SymmetricDiploidFrequencies", "HaploidIndividuals"}]},
  "AlleleFrequencies"->{
    Cell[5645, 155, 4448, 94, 258, "DefinitionBox",
      CellTags->{
      "HaploidFrequencies", "DiploidFrequencies", "AlleleFrequencies", 
        "SymmetricNeutralDiploidFrequencies", "", "DiploidIndividuals", 
        "SymmetricHaploidFrequencies", "SymmetricNeutralHaploidFrequencies", 
        "SymmetricDiploidFrequencies", "HaploidIndividuals"}]},
  "SymmetricNeutralDiploidFrequencies"->{
    Cell[5645, 155, 4448, 94, 258, "DefinitionBox",
      CellTags->{
      "HaploidFrequencies", "DiploidFrequencies", "AlleleFrequencies", 
        "SymmetricNeutralDiploidFrequencies", "", "DiploidIndividuals", 
        "SymmetricHaploidFrequencies", "SymmetricNeutralHaploidFrequencies", 
        "SymmetricDiploidFrequencies", "HaploidIndividuals"}]},
  ""->{
    Cell[5645, 155, 4448, 94, 258, "DefinitionBox",
      CellTags->{
      "HaploidFrequencies", "DiploidFrequencies", "AlleleFrequencies", 
        "SymmetricNeutralDiploidFrequencies", "", "DiploidIndividuals", 
        "SymmetricHaploidFrequencies", "SymmetricNeutralHaploidFrequencies", 
        "SymmetricDiploidFrequencies", "HaploidIndividuals"}]},
  "DiploidIndividuals"->{
    Cell[5645, 155, 4448, 94, 258, "DefinitionBox",
      CellTags->{
      "HaploidFrequencies", "DiploidFrequencies", "AlleleFrequencies", 
        "SymmetricNeutralDiploidFrequencies", "", "DiploidIndividuals", 
        "SymmetricHaploidFrequencies", "SymmetricNeutralHaploidFrequencies", 
        "SymmetricDiploidFrequencies", "HaploidIndividuals"}]},
  "SymmetricHaploidFrequencies"->{
    Cell[5645, 155, 4448, 94, 258, "DefinitionBox",
      CellTags->{
      "HaploidFrequencies", "DiploidFrequencies", "AlleleFrequencies", 
        "SymmetricNeutralDiploidFrequencies", "", "DiploidIndividuals", 
        "SymmetricHaploidFrequencies", "SymmetricNeutralHaploidFrequencies", 
        "SymmetricDiploidFrequencies", "HaploidIndividuals"}]},
  "SymmetricNeutralHaploidFrequencies"->{
    Cell[5645, 155, 4448, 94, 258, "DefinitionBox",
      CellTags->{
      "HaploidFrequencies", "DiploidFrequencies", "AlleleFrequencies", 
        "SymmetricNeutralDiploidFrequencies", "", "DiploidIndividuals", 
        "SymmetricHaploidFrequencies", "SymmetricNeutralHaploidFrequencies", 
        "SymmetricDiploidFrequencies", "HaploidIndividuals"}]},
  "SymmetricDiploidFrequencies"->{
    Cell[5645, 155, 4448, 94, 258, "DefinitionBox",
      CellTags->{
      "HaploidFrequencies", "DiploidFrequencies", "AlleleFrequencies", 
        "SymmetricNeutralDiploidFrequencies", "", "DiploidIndividuals", 
        "SymmetricHaploidFrequencies", "SymmetricNeutralHaploidFrequencies", 
        "SymmetricDiploidFrequencies", "HaploidIndividuals"}]},
  "HaploidIndividuals"->{
    Cell[5645, 155, 4448, 94, 258, "DefinitionBox",
      CellTags->{
      "HaploidFrequencies", "DiploidFrequencies", "AlleleFrequencies", 
        "SymmetricNeutralDiploidFrequencies", "", "DiploidIndividuals", 
        "SymmetricHaploidFrequencies", "SymmetricNeutralHaploidFrequencies", 
        "SymmetricDiploidFrequencies", "HaploidIndividuals"}]},
  "Selection"->{
    Cell[11005, 289, 63, 1, 24, "SubsubsectionIcon",
      CellTags->"Selection"]},
  "Representations"->{
    Cell[13733, 347, 75, 1, 24, "SubsubsectionIcon",
      CellTags->"Representations"]},
  "PopulationRepresentations"->{
    Cell[13811, 350, 2289, 46, 304, "DefinitionBox",
      CellTags->{
      "PopulationRepresentations", "HaploidRepresentations", 
        "DiploidRepresentations", "IndividualRepresentations", 
        "FrequencyRepresentations"}]},
  "HaploidRepresentations"->{
    Cell[13811, 350, 2289, 46, 304, "DefinitionBox",
      CellTags->{
      "PopulationRepresentations", "HaploidRepresentations", 
        "DiploidRepresentations", "IndividualRepresentations", 
        "FrequencyRepresentations"}]},
  "DiploidRepresentations"->{
    Cell[13811, 350, 2289, 46, 304, "DefinitionBox",
      CellTags->{
      "PopulationRepresentations", "HaploidRepresentations", 
        "DiploidRepresentations", "IndividualRepresentations", 
        "FrequencyRepresentations"}]},
  "IndividualRepresentations"->{
    Cell[13811, 350, 2289, 46, 304, "DefinitionBox",
      CellTags->{
      "PopulationRepresentations", "HaploidRepresentations", 
        "DiploidRepresentations", "IndividualRepresentations", 
        "FrequencyRepresentations"}]},
  "FrequencyRepresentations"->{
    Cell[13811, 350, 2289, 46, 304, "DefinitionBox",
      CellTags->{
      "PopulationRepresentations", "HaploidRepresentations", 
        "DiploidRepresentations", "IndividualRepresentations", 
        "FrequencyRepresentations"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Representing the population", 17382, 430},
  {"HaploidFrequencies", 17509, 433},
  {"DiploidFrequencies", 17892, 440},
  {"AlleleFrequencies", 18274, 447},
  {"SymmetricNeutralDiploidFrequencies", 18673, 454},
  {"", 19038, 461},
  {"DiploidIndividuals", 19421, 468},
  {"SymmetricHaploidFrequencies", 19813, 475},
  {"SymmetricNeutralHaploidFrequencies", 20212, 482},
  {"SymmetricDiploidFrequencies", 20604, 489},
  {"HaploidIndividuals", 20987, 496},
  {"Selection", 21361, 503},
  {"Representations", 21468, 506},
  {"PopulationRepresentations", 21591, 509},
  {"HaploidRepresentations", 21857, 515},
  {"DiploidRepresentations", 22123, 521},
  {"IndividualRepresentations", 22392, 527},
  {"FrequencyRepresentations", 22660, 533}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 54, 0, 36, "SubsectionIcon"],
Cell[1796, 53, 525, 10, 52, "Text"],
Cell[2324, 65, 265, 5, 36, "Text"],
Cell[2592, 72, 409, 7, 36, "Text"],
Cell[3004, 81, 406, 7, 36, "Text"],
Cell[3413, 90, 355, 6, 36, "Text"],
Cell[3771, 98, 198, 4, 22, "Text"],
Cell[3972, 104, 595, 12, 70, "DefinitionBox3Col"],

Cell[CellGroupData[{
Cell[4592, 120, 99, 1, 24, "SubsubsectionIcon",
  CellTags->"Representing the population"],
Cell[4694, 123, 420, 11, 38, "Text"],
Cell[5117, 136, 425, 12, 37, "Text"],
Cell[5545, 150, 97, 3, 22, "Text"],
Cell[5645, 155, 4448, 94, 258, "DefinitionBox",
  CellTags->{
  "HaploidFrequencies", "DiploidFrequencies", "AlleleFrequencies", 
    "SymmetricNeutralDiploidFrequencies", "", "DiploidIndividuals", 
    "SymmetricHaploidFrequencies", "SymmetricNeutralHaploidFrequencies", 
    "SymmetricDiploidFrequencies", "HaploidIndividuals"}],
Cell[10096, 251, 172, 4, 22, "Text"],
Cell[10271, 257, 162, 4, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[10458, 265, 67, 1, 26, "Input"],
Cell[10528, 268, 71, 1, 20, "Output"]
}, Open  ]],
Cell[10614, 272, 138, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[10777, 279, 86, 1, 26, "Input"],
Cell[10866, 282, 90, 1, 20, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[11005, 289, 63, 1, 24, "SubsubsectionIcon",
  CellTags->"Selection"],
Cell[11071, 292, 1211, 18, 94, "Text"],
Cell[12285, 312, 364, 6, 36, "Text"],
Cell[12652, 320, 1044, 22, 74, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13733, 347, 75, 1, 24, "SubsubsectionIcon",
  CellTags->"Representations"],
Cell[13811, 350, 2289, 46, 304, "DefinitionBox",
  CellTags->{
  "PopulationRepresentations", "HaploidRepresentations", 
    "DiploidRepresentations", "IndividualRepresentations", 
    "FrequencyRepresentations"}],
Cell[16103, 398, 401, 7, 36, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

