(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     11289,        305]*)
(*NotebookOutlinePosition[     13983,        380]*)
(*  CellTagsIndexPosition[     13617,        367]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Describing genotype frequencies", "SubsectionIcon"],

Cell[TextData[{
  "\tSuppose that two alleles, labelled '0' or '1',  segregate at each of ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " unlinked loci.  Then, haploid genotypes can be divided into ",
  Cell[BoxData[
      \(TraditionalForm\`n + 1\)]],
  " ",
  StyleBox["classes",
    FontSlant->"Italic"],
  ", according to the number of '1' alleles they carry.  Provided that \
diploid fitness depends only on the number of '1' alleles inherited from \
either parent, and on the number of heterozygous loci, there may be a \
symmetrical solution in which all genotypes within a class are equally \
frequent.  This makes possible a deterministic model of many loci, since only \
the frequencies of the ",
  Cell[BoxData[
      \(TraditionalForm\`n + 1\)]],
  " classes in the gamete pool need be followed, instead of the ",
  Cell[BoxData[
      \(TraditionalForm\`2\^n\)]],
  "genotypes (Barton, ",
  ButtonBox["1992",
    ButtonData:>{"Symmetric model: references", "Barton 1992"},
    ButtonStyle->"AddOnsLink"],
  ";  Kondrashov, ",
  ButtonBox["1994",
    ButtonData:>{"Symmetric model: references", "Kondrashov 1994"},
    ButtonStyle->"AddOnsLink"],
  "; Doebeli, ",
  ButtonBox["1996",
    ButtonData:>{"Symmetric model: references", "Doebeli 1996"},
    ButtonStyle->"AddOnsLink"],
  "; Shpak & Kondrashov, ",
  ButtonBox["1999",
    ButtonData:>{"Symmetric model: references", "Shpak & Kondrashov 1999"},
    ButtonStyle->"AddOnsLink"],
  "; see Falush, ",
  ButtonBox["1999",
    ButtonData:>{"Symmetric model: references", "Falush 1999"},
    ButtonStyle->"AddOnsLink"],
  ", for an extension to allow for linkage).   However, the symmetrical model \
need not be stable: for example, stabilising selection can lead to multiple \
asymmetric equilibria, in which any one of the many genotypes which approach \
the optimum is fixed (Barton & Shpak, ",
  ButtonBox["2000",
    ButtonData:>{"Symmetric model: references", "Barton & Shpak 2000"},
    ButtonStyle->"AddOnsLink"],
  ")."
}], "Text"],

Cell["\<\
\tThis package implements this symmetric model, either for a single \
deme (possibly with immigration), or for a linear chain of demes with \
nearest-neighbour migration. An unlinked neutral locus can be added.  The \
recursions can be compiled, which greatly speeds numerical calculations.  \
There are also algorithms which calculate the stability of the symmetric \
solution, both for a single deme or for a linear chain.\
\>", "Text"],

Cell[TextData[{
  "\tThe package also includes similar algorithms for iterating populations \
that are represented in other ways - for example, in terms of ",
  ButtonBox["genotype frequencies",
    ButtonData:>{"Recursions: representation", None},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["allele frequencies",
    ButtonData:>{"Allele frequencies: representation", None},
    ButtonStyle->"AddOnsLink"],
  ", or ",
  ButtonBox["individuals",
    ButtonData:>{"Simulating individuals: representation", None},
    ButtonStyle->"AddOnsLink"],
  "."
}], "Text"],

Cell["This loads the package. ", "MathCaption",
  CellTags->{"S5.24.1", "1.4"}],

Cell[BoxData[
    \(\(<< NumericalModels`ExactModel`;\)\)], "Input",
  CellLabel->"In[1]:=  (7:02:15 on 4/23/01)"],

Cell[BoxData[{
    FormBox[GridBox[{
          {\(NumericalModel \[Rule] 
              SymmetricHaploidFrequencies\), \(specifies\ a\ symmetric\ model\
\ in\ which\ the\ frequencies\ of\ n + 1\ classes\ of\ genotype, \ 
            with\ 0, \[Ellipsis]n\ ' 
              1'\ alleles\ are\ \(\(listed\)\(.\)\(\ \)\)\)},
          {\(NumericalModel \[Rule] 
              SymmetricDiploidFrequencies\), \(specifies\ an\ \((n + 
                  1)\)\[Times]\((n + 
                  1)\)\ matrix\ of\ diploid\ class\ \
\(\(frequencies\)\(.\)\)\)}
          },
        GridFrame->False], TextForm], "\n", 
    FormBox[
      FormBox[GridBox[{
            {\(MakePopulation[n, p, 
                NumericalModel \[Rule] 
                  SymmetricHaploidFrequencies]\), \(gives\ a\ haploid\ \
population\ at\ linkage\ equilibrium, \ with\ n\ loci, \ 
              each\ at\ allele\ frequency\ \(\(p\)\(.\)\(\ \ \)\)\)},
            {\(MakePopulation[n, p, 
                NumericalModel \[Rule] 
                  SymmetricDiploidFrequencies]\), \(specifies\ a\ diploid\ \
population\)}
            },
          GridFrame->False],
        "TextForm"], TextForm]}], "DefinitionBox",
  CellTags->{
  "NumericalModel", "SymmetricHaploidFrequencies", 
    "SymmetricDiploidFrequencies", "MakePopulation"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(MakePopulation[5, 0.2, 
      NumericalModel \[Rule] SymmetricHaploidFrequencies]\)], "Input",
  CellLabel->"In[42]:="],

Cell[BoxData[
    \(SymmetricHaploidFrequencies[{0.3276800000000002`, 0.40960000000000024`, 
        0.2048000000000001`, 0.05120000000000002`, 0.006400000000000004`, 
        0.0003200000000000002`}, 1]\)], "Output",
  CellLabel->"Out[42]="]
}, Open  ]],

Cell[TextData[StyleBox["By default, deme size is 1.  It can be set to any \
value:", "MathCaption"]], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MakePopulation[5, 0.2, 100, 
      NumericalModel \[Rule] SymmetricHaploidFrequencies]\)], "Input",
  CellLabel->"In[43]:="],

Cell[BoxData[
    \(SymmetricHaploidFrequencies[{0.3276800000000002`, 0.40960000000000024`, 
        0.2048000000000001`, 0.05120000000000002`, 0.006400000000000004`, 
        0.0003200000000000002`}, 100]\)], "Output",
  CellLabel->"Out[43]="]
}, Open  ]],

Cell["\<\
This specifies the frequencies of diploid genotypes, assuming \
random union:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MakePopulation[5, 0.2, 
      NumericalModel \[Rule] SymmetricDiploidFrequencies]\)], "Input",
  CellLabel->"In[44]:="],

Cell[BoxData[
    \(SymmetricDiploidFrequencies[{{0.10737418240000013`, 
          0.13421772800000015`, 0.06710886400000007`, 0.01677721600000002`, 
          0.0020971520000000023`, 
          0.00010485760000000013`}, {0.13421772800000015`, 
          0.1677721600000002`, 0.08388608000000009`, 0.02097152000000002`, 
          0.002621440000000003`, 
          0.00013107200000000014`}, {0.06710886400000007`, 
          0.08388608000000009`, 0.041943040000000036`, 0.010485760000000009`, 
          0.0013107200000000013`, 
          0.00006553600000000007`}, {0.01677721600000002`, 
          0.02097152000000002`, 0.010485760000000009`, 
          0.0026214400000000022`, 0.00032768000000000033`, 
          0.000016384000000000018`}, {0.0020971520000000023`, 
          0.002621440000000003`, 0.0013107200000000013`, 
          0.00032768000000000033`, 0.00004096000000000005`, 
          2.0480000000000022`*^-6}, {0.00010485760000000013`, 
          0.00013107200000000014`, 0.00006553600000000007`, 
          0.000016384000000000018`, 2.0480000000000022`*^-6, 
          1.0240000000000012`*^-7}}, 1]\)], "Output",
  CellLabel->"Out[44]="]
}, Open  ]],

Cell[BoxData[
    FormBox[
      RowBox[{"\n", 
        FormBox[GridBox[{
              {\(MakePopulation[n, {p, u}, 
                  NumericalModel \[Rule] 
                    SymmetricNeutralHaploidFrequencies]\), \(gives\ a\ \
haploid\ population\ at\ linkage\ equilibrium, \ with\ n\ loci, \ 
                each\ at\ allele\ frequency\ p, \ 
                and\ a\ neutral\ marker\ at\ frequency\ u\)},
              {\(MakePopulation[n, {p, u}, 
                  NumericalModel \[Rule] 
                    SymmetricNeutralHaploidFrequencies]\), \(does\ the\ same\ \
for\ a\ diploid\ population\)}
              },
            GridFrame->False],
          "TextForm"]}], TextForm]], "DefinitionBox",
  CellTags->{
  "SymmetricNeutralHaploidFrequencies", "SymmetricNeutralDiploidFrequencies"}],

Cell["\<\
A single unlinked neutral marker locus can be added, by specifying \
its frequency within each of the selected classes.\
\>", "Text"],

Cell["\<\
As well as the frequencies of each class, the frequency of the \
neutral marker within each of the n+1 classes is listed:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MakePopulation[3, {0.1, 0.4}, 
      NumericalModel \[Rule] SymmetricNeutralHaploidFrequencies]\)], "Input",
  CellLabel->"In[46]:="],

Cell[BoxData[
    \(SymmetricNeutralHaploidFrequencies[{{0.7290000000000001`, 
          0.24300000000000005`, 0.02700000000000001`, 
          0.0010000000000000002`}, {0.4`, 0.4`, 0.4`, 0.4`}}, 1]\)], "Output",\

  CellLabel->"Out[46]="]
}, Open  ]],

Cell["This does the same for a diploid population:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MakePopulation[3, {0.1, 0.4}, 
      NumericalModel \[Rule] SymmetricNeutralDiploidFrequencies]\)], "Input",
  CellLabel->"In[47]:="],

Cell[BoxData[
    \(SymmetricNeutralDiploidFrequencies[{{{0.5314410000000002`, 
            0.17714700000000005`, 0.01968300000000001`, 
            0.0007290000000000003`}, {0.17714700000000005`, 
            0.059049000000000025`, 0.0065610000000000035`, 
            0.0002430000000000001`}, {0.01968300000000001`, 
            0.0065610000000000035`, 0.0007290000000000006`, 
            0.000027000000000000016`}, {0.0007290000000000003`, 
            0.0002430000000000001`, 0.000027000000000000016`, 
            1.0000000000000004`*^-6}}, {{0.4`, 0.4`, 0.4`, 0.4`}, {0.4`, 
            0.4`, 0.4`, 0.4`}, {0.4`, 0.4`, 0.4`, 0.4`}, {0.4`, 0.4`, 0.4`, 
            0.4`}}}, 1]\)], "Output",
  CellLabel->"Out[47]="]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
AutoGeneratedPackage->None,
WindowSize->{708, 709},
WindowMargins->{{-3, Automatic}, {Automatic, 0}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oRon@3:`8f0dL5N`?N0080001804P000000`d26P01
0000I00000400@410?l00BL?00400@00000000000000000201T1T0000000@000
00000000004000000000000000010000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "S5.24.1"->{
    Cell[4838, 130, 79, 1, 28, "MathCaption",
      CellTags->{"S5.24.1", "1.4"}]},
  "1.4"->{
    Cell[4838, 130, 79, 1, 28, "MathCaption",
      CellTags->{"S5.24.1", "1.4"}]},
  "NumericalModel"->{
    Cell[5037, 137, 1303, 30, 145, "DefinitionBox",
      CellTags->{
      "NumericalModel", "SymmetricHaploidFrequencies", 
        "SymmetricDiploidFrequencies", "MakePopulation"}]},
  "SymmetricHaploidFrequencies"->{
    Cell[5037, 137, 1303, 30, 145, "DefinitionBox",
      CellTags->{
      "NumericalModel", "SymmetricHaploidFrequencies", 
        "SymmetricDiploidFrequencies", "MakePopulation"}]},
  "SymmetricDiploidFrequencies"->{
    Cell[5037, 137, 1303, 30, 145, "DefinitionBox",
      CellTags->{
      "NumericalModel", "SymmetricHaploidFrequencies", 
        "SymmetricDiploidFrequencies", "MakePopulation"}]},
  "MakePopulation"->{
    Cell[5037, 137, 1303, 30, 145, "DefinitionBox",
      CellTags->{
      "NumericalModel", "SymmetricHaploidFrequencies", 
        "SymmetricDiploidFrequencies", "MakePopulation"}]},
  "SymmetricNeutralHaploidFrequencies"->{
    Cell[8752, 235, 804, 18, 99, "DefinitionBox",
      CellTags->{
      "SymmetricNeutralHaploidFrequencies", 
        "SymmetricNeutralDiploidFrequencies"}]},
  "SymmetricNeutralDiploidFrequencies"->{
    Cell[8752, 235, 804, 18, 99, "DefinitionBox",
      CellTags->{
      "SymmetricNeutralHaploidFrequencies", 
        "SymmetricNeutralDiploidFrequencies"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"S5.24.1", 12147, 327},
  {"1.4", 12242, 330},
  {"NumericalModel", 12348, 333},
  {"SymmetricHaploidFrequencies", 12569, 338},
  {"SymmetricDiploidFrequencies", 12790, 343},
  {"MakePopulation", 12998, 348},
  {"SymmetricNeutralHaploidFrequencies", 13226, 353},
  {"SymmetricNeutralDiploidFrequencies", 13430, 358}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 57, 0, 36, "SubsectionIcon"],
Cell[1799, 53, 2012, 49, 113, "Text"],
Cell[3814, 104, 448, 7, 50, "Text"],
Cell[4265, 113, 570, 15, 38, "Text"],
Cell[4838, 130, 79, 1, 28, "MathCaption",
  CellTags->{"S5.24.1", "1.4"}],
Cell[4920, 133, 114, 2, 39, "Input"],
Cell[5037, 137, 1303, 30, 145, "DefinitionBox",
  CellTags->{
  "NumericalModel", "SymmetricHaploidFrequencies", 
    "SymmetricDiploidFrequencies", "MakePopulation"}],

Cell[CellGroupData[{
Cell[6365, 171, 139, 3, 27, "Input"],
Cell[6507, 176, 242, 4, 20, "Output"]
}, Open  ]],
Cell[6764, 183, 116, 1, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[6905, 188, 144, 3, 27, "Input"],
Cell[7052, 193, 244, 4, 20, "Output"]
}, Open  ]],
Cell[7311, 200, 108, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[7444, 207, 139, 3, 27, "Input"],
Cell[7586, 212, 1151, 20, 89, "Output"]
}, Open  ]],
Cell[8752, 235, 804, 18, 99, "DefinitionBox",
  CellTags->{
  "SymmetricNeutralHaploidFrequencies", 
    "SymmetricNeutralDiploidFrequencies"}],
Cell[9559, 255, 143, 3, 22, "Text"],
Cell[9705, 260, 152, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[9882, 267, 153, 3, 27, "Input"],
Cell[10038, 272, 239, 5, 20, "Output"]
}, Open  ]],
Cell[10292, 280, 67, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[10384, 284, 153, 3, 27, "Input"],
Cell[10540, 289, 721, 12, 61, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

