(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     83615,       2276]*)
(*NotebookOutlinePosition[     84461,       2303]*)
(*  CellTagsIndexPosition[     84417,       2299]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Hierarchical analysis", "SubsectionIcon"],

Cell["This loads the package", "MathCaption"],

Cell[BoxData[
    \(<< Utilities`StructuredModels`; \)], "Input",
  CellLabel->"In[1]:="],

Cell[CellGroupData[{

Cell["\<\
A hierarchical analysis of likelihood: setting up the example\
\>", \
"SubsubsectionIcon"],

Cell[TextData[{
  "It is important to define the likelihood function so that it dos not \
return imaginary numbers or infinities; FindMinimum[] does not cope with \
these.  Instead, such values are set to some low value, ",
  Cell[BoxData[
      \(TraditionalForm\`\(-10\^8\)\)]],
  ".  If the second parameter, ",
  Cell[BoxData[
      \(TraditionalForm\`c = variance\/mean\)]],
  ", is below 1, the distribution needs to be normalised, which is ",
  ButtonBox["slow",
    ButtonData:>{"Negative binomial likelihoods", "Normalisation"},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"slow"],
  "."
}], "Text"],

Cell[BoxData[{
    \(<< Utilities`RandomNumbers`; \), "\n", 
    \(LogL2[n_, {z_, c_}] := \[IndentingNewLine]Chop[
        NegativeBinomialLogLikelihood[
          n, {\[ExponentialE]\^z, \[ExponentialE]\^c}, 
          Compiled \[Rule] True]]; \)}], "Input",
  CellLabel->"In[7]:="],

Cell[TextData[{
  "The function ",
  Cell[BoxData[
      \(TraditionalForm\`lik[model\_1, model\_2]\)]],
  " compares the likelihoods and degrees of freedom of the two models:"
}], "MathCaption"],

Cell[BoxData[{
    \(lik[model1_, model2_, opts___Rule] := 
      Module[{\[IndentingNewLine]dl = \(lik[model1, 
                  opts]\)\[LeftDoubleBracket]1\[RightDoubleBracket] - \(lik[
                  model2, 
                  opts]\)\[LeftDoubleBracket]1\[RightDoubleBracket], \
\[IndentingNewLine]df = 
            Plus @@ \((\[IndentingNewLine]DegreesOfFreedom[
                    dd, {line, rep, density}, model1] - 
                  DegreesOfFreedom[dd, {line, rep, density}, 
                    model2])\)}, \[IndentingNewLine]{{dl, \
\[IndentingNewLine]df, 
            1 - CDF[ChiSquareDistribution[df], 
                2  dl]}, \[IndentingNewLine]\(lik[model1, 
              opts]\)\[LeftDoubleBracket]2\[RightDoubleBracket]}]; \), "\n", 
    \(lik[model_, opts___Rule] := \(lik[model, opts] = 
        Module[{pp}, \[IndentingNewLine]pp = 
            StructuredMLE[dd, {line, rep, density}, 
              model, \[IndentingNewLine]StructuredInitialParameters[
                dd, {line, rep, density}, 
                model, {N[Log[Mean[#]]] &, 
                  Min[N[Log[Variance[#]\/Mean[#]]], 
                      1] &}], \[IndentingNewLine]LogL2, 
              opts]; \[IndentingNewLine]{StructuredLogLikelihood[
              dd, {line, rep, density}, model, pp, LogL2], 
            pp}]\); \)}], "Input",
  CellLabel->"In[14]:="],

Cell[TextData[{
  "The initial ",
  Cell[BoxData[
      \(TraditionalForm\`variance\/mean\)]],
  " ratio cannot be set too high, otherwise FindMinimum[] tends to crash."
}], "Text"],

Cell["\<\
There is a very large gain by fitting density effects on both mean \
and variance:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(lik[{{density}, {}}, {{}, {}}] // TableForm\)], "Input",
  CellLabel->"In[52]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {"344.3675950460065`", "3", "0.`"},
          {GridBox[{
                {"4.205930568888586`", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>"},
                {\(-0.9231174515249788`\), \(-0.27448785563077754`\), 
                  "0.06034470665664356`", "1.1372606004991128`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"1.3655370091072634`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "\<\"\"\>"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {{344.3675950460065, 3, 0.0}, {{
        4.2059305688885864, {-0.92311745152497882, -0.27448785563077754, 
        0.060344706656643557, 1.1372606004991128}}, {
        1.3655370091072634}}}]]], "Output",
  CellLabel->"Out[52]//TableForm="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(lik[{{density}, {density}}, {{}, {}}] // TableForm\)], "Input",
  CellLabel->"In[53]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {"505.6248367960718`", "6", "0.`"},
          {GridBox[{
                {"4.195389400597718`", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>"},
                {\(-0.9586738498934289`\), \(-0.28396656471135284`\), 
                  "0.059229960049162686`", "1.1834104545556188`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"0.7960107537399518`", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>"},
                {\(-1.4161997368577444`\), \(-0.7174605529999378`\), \
\(-0.2899439480411807`\), "2.423604237898863`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "\<\"\"\>"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {{505.6248367960718, 6, 0.0}, {{
        4.1953894005977181, {-0.95867384989342885, -0.28396656471135284, 
        0.059229960049162686, 1.1834104545556188}}, {
        0.79601075373995178, {-1.4161997368577444, -0.71746055299993783, \
-0.28994394804118068, 2.4236042378988629}}}}]]], "Output",
  CellLabel->"Out[53]//TableForm="]
}, Closed]],

Cell["\<\
The first row gives the gain in log likelihood, together with the \
associated d.f. and probability.  The second row gives the fixed baseline \
effects for each variable.  The last row gives the estimated density effects \
for each variable.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
A hierarchical analysis of likelihood: fitting the mean, assuming \
density effects on the variance\
\>", "SubsubsectionIcon"],

Cell[TextData[{
  "First, fit the mean assuming just density effects on the ",
  Cell[BoxData[
      \(TraditionalForm\`variance\/mean\)]],
  " ratio.  There are significant line effects:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(lik[{{density, line}, {density}}, {{density}, {density}}] // 
      TableForm\)], "Input",
  CellLabel->"In[54]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {"88.89975203365066`", "9", "0.`"},
          {GridBox[{
                {
                  "4.190210413282516`", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\
\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>"},
                {\(-0.9586884453729296`\), \(-0.2839817575199706`\), 
                  "0.05921469449016799`", 
                  "1.1834555084027323`", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", \
"\<\"\"\>", "\<\"\"\>", "\<\"\"\>"},
                {\(-0.03556754982407306`\), 
                  "0.0342145933744665`", \(-0.0555791997458933`\), \
\(-0.2463199222304208`\), \(-0.020297234504730845`\), \
\(-0.053195103725835045`\), "0.06555858911982403`", "0.11596705082161135`", 
                  "0.12528994639147942`", "0.0699288303235717`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"0.3654553784011737`", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>"},
                {\(-1.2122830842972223`\), \(-0.9846741184172401`\), \
\(-0.5171863964688483`\), "2.714143599183311`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "\<\"\"\>"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {{88.899752033650657, 9, 0.0}, {{
        4.1902104132825162, {-0.95868844537292963, -0.28398175751997062, 
        0.059214694490167988, 1.1834555084027323}, {-0.035567549824073057, 
        0.034214593374466501, -0.055579199745893301, -0.24631992223042079, \
-0.020297234504730845, -0.053195103725835045, 0.065558589119824026, 
        0.11596705082161135, 0.12528994639147942, 0.069928830323571695}}, {
        0.3654553784011737, {-1.2122830842972223, -0.98467411841724006, \
-0.51718639646884834, 2.7141435991833109}}}}]]], "Output",
  CellLabel->"Out[54]//TableForm="]
}, Closed]],

Cell["There is no significant line*rep interaction:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(lik[{{density, {line, rep}}, {density}}, {{density, line}, {density}}] // 
      TableForm\)], "Input",
  CellLabel->"In[55]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {"5.241889271736454`", "10", "0.3991222045402143`"},
          {GridBox[{
                {
                  "4.189967935434801`", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\
\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>"},
                {\(-0.9586888020715802`\), \(-0.283981963368828`\), 
                  "0.0592144214089593`", 
                  "1.1834563440314492`", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", \
"\<\"\"\>", "\<\"\"\>", "\<\"\"\>"},
                {GridBox[{
                      {"0.0029674762613124323`"},
                      {\(-0.07441452760748905`\)}
                      },
                    RowSpacings->0.25,
                    ColumnSpacings->1,
                    RowAlignments->Baseline,
                    ColumnAlignments->{Left}], GridBox[{
                      {"0.04193187335634811`"},
                      {"0.026961317894172474`"}
                      },
                    RowSpacings->0.25,
                    ColumnSpacings->1,
                    RowAlignments->Baseline,
                    ColumnAlignments->{Left}], GridBox[{
                      {\(-0.06328777210686656`\)},
                      {\(-0.04616433587087604`\)}
                      },
                    RowSpacings->0.25,
                    ColumnSpacings->1,
                    RowAlignments->Baseline,
                    ColumnAlignments->{Left}], GridBox[{
                      {\(-0.21633064520905165`\)},
                      {\(-0.2777044324260038`\)}
                      },
                    RowSpacings->0.25,
                    ColumnSpacings->1,
                    RowAlignments->Baseline,
                    ColumnAlignments->{Left}], GridBox[{
                      {\(-0.019695627529144853`\)},
                      {\(-0.02178106844516286`\)}
                      },
                    RowSpacings->0.25,
                    ColumnSpacings->1,
                    RowAlignments->Baseline,
                    ColumnAlignments->{Left}], GridBox[{
                      {\(-0.07003011001198899`\)},
                      {\(-0.036625277489968175`\)}
                      },
                    RowSpacings->0.25,
                    ColumnSpacings->1,
                    RowAlignments->Baseline,
                    ColumnAlignments->{Left}], GridBox[{
                      {"0.034334463459989806`"},
                      {"0.09646280527923874`"}
                      },
                    RowSpacings->0.25,
                    ColumnSpacings->1,
                    RowAlignments->Baseline,
                    ColumnAlignments->{Left}], GridBox[{
                      {"0.10248001521028036`"},
                      {"0.1288080641290432`"}
                      },
                    RowSpacings->0.25,
                    ColumnSpacings->1,
                    RowAlignments->Baseline,
                    ColumnAlignments->{Left}], GridBox[{
                      {"0.11201668311678116`"},
                      {"0.14045915843479145`"}
                      },
                    RowSpacings->0.25,
                    ColumnSpacings->1,
                    RowAlignments->Baseline,
                    ColumnAlignments->{Left}], GridBox[{
                      {"0.052328840899481116`"},
                      {"0.08728309865511302`"}
                      },
                    RowSpacings->0.25,
                    ColumnSpacings->1,
                    RowAlignments->Baseline,
                    ColumnAlignments->{Left}]}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"0.335612936073153`", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>"},
                {\(-1.1720330134148715`\), \(-1.0365472598526624`\), \
\(-0.4962773253883712`\), "2.704857598655905`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "\<\"\"\>"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {{5.2418892717364542, 10, 0.3991222045402143}, {{
        4.1899679354348009, {-0.95868880207158025, -0.28398196336882803, 
        0.0592144214089593, 1.1834563440314492}, {{
        0.0029674762613124323, -0.074414527607489053}, {0.041931873356348112, 
        0.026961317894172474}, {-0.063287772106866563, \
-0.046164335870876039}, {-0.21633064520905165, -0.27770443242600379}, \
{-0.019695627529144853, -0.021781068445162859}, {-0.070030110011988986, \
-0.036625277489968175}, {0.034334463459989806, 0.096462805279238742}, {
        0.10248001521028036, 0.12880806412904319}, {0.11201668311678116, 
        0.14045915843479145}, {0.052328840899481116, 
        0.087283098655113023}}}, {
        0.33561293607315301, {-1.1720330134148715, -1.0365472598526624, \
-0.49627732538837122, 2.7048575986559049}}}}]]], "Output",
  CellLabel->"Out[55]//TableForm="]
}, Closed]],

Cell["There is a significant density*line interaction:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(lik[{{{density, line}}, {density}}, {{density, line}, {density}}] // 
      TableForm\)], "Input",
  CellLabel->"In[56]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {"40.44044972888264`", "27", "2.775167294855052`*^-7"},
          {GridBox[{
                {"4.182621609844977`", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>"},
                {GridBox[{
                      {\(-0.8755787411716163`\)},
                      {\(-0.9025709708789306`\)},
                      {\(-1.0092734880585246`\)},
                      {\(-1.2082800632728383`\)},
                      {\(-0.9288046068638396`\)},
                      {\(-0.9998891497488271`\)},
                      {\(-0.8920560498668066`\)},
                      {\(-0.8704798513288761`\)},
                      {\(-0.8810010107303547`\)},
                      {\(-0.9366639151480073`\)}
                      },
                    RowSpacings->0.25,
                    ColumnSpacings->1,
                    RowAlignments->Baseline,
                    ColumnAlignments->{Left}], GridBox[{
                      {\(-0.27743506797954975`\)},
                      {\(-0.24419054286440167`\)},
                      {\(-0.30272378925090665`\)},
                      {\(-0.5740839302867181`\)},
                      {\(-0.31256276276947753`\)},
                      {\(-0.3159499634092856`\)},
                      {\(-0.21144416764028126`\)},
                      {\(-0.18455586760361317`\)},
                      {\(-0.13551735754556646`\)},
                      {\(-0.2147532146135978`\)}
                      },
                    RowSpacings->0.25,
                    ColumnSpacings->1,
                    RowAlignments->Baseline,
                    ColumnAlignments->{Left}], GridBox[{
                      {\(-0.1364407590210074`\)},
                      {"0.08592215789467779`"},
                      {\(-0.009320689204103044`\)},
                      {\(-0.11590304896100603`\)},
                      {"0.047782210131610235`"},
                      {"0.015439019455452741`"},
                      {"0.136406199221191`"},
                      {"0.21634687720182466`"},
                      {"0.21371745970651077`"},
                      {"0.19277540141478194`"}
                      },
                    RowSpacings->0.25,
                    ColumnSpacings->1,
                    RowAlignments->Baseline,
                    ColumnAlignments->{Left}], GridBox[{
                      {"1.4693879507467726`"},
                      {"1.3493112602018495`"},
                      {"1.0591894555967525`"},
                      {"1.0157420270351276`"},
                      {"0.8458909014652168`"},
                      {"0.7293643053457975`"},
                      {"1.264541514115091`"},
                      {"1.597559101261002`"},
                      {"1.2419177331902556`"},
                      {"1.058185434234223`"}
                      },
                    RowSpacings->0.25,
                    ColumnSpacings->1,
                    RowAlignments->Baseline,
                    ColumnAlignments->{Left}]}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {
                  "0.054099383611066254`", "\<\"\"\>", "\<\"\"\>", \
"\<\"\"\>"},
                {\(-1.0471744712216342`\), \(-0.7129833823764007`\), \
\(-0.5196836634106332`\), "2.2798415170086685`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "\<\"\"\>"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {{40.440449728882641, 27, 2.7751672948550521`17*^-7}, {{
        4.1826216098449773, {{-0.87557874117161627, -0.90257097087893057, \
-1.0092734880585246, -1.2082800632728383, -0.92880460686383959, \
-0.99988914974882714, -0.89205604986680664, -0.87047985132887606, \
-0.88100101073035475, -0.93666391514800729}, {-0.27743506797954975, \
-0.24419054286440167, -0.30272378925090665, -0.57408393028671811, \
-0.31256276276947753, -0.31594996340928561, -0.21144416764028126, \
-0.18455586760361317, -0.13551735754556646, -0.21475321461359781}, \
{-0.13644075902100741, 
        0.085922157894677789, -0.0093206892041030436, -0.11590304896100603, 
        0.047782210131610235, 0.015439019455452741, 0.13640619922119099, 
        0.21634687720182466, 0.21371745970651077, 0.19277540141478194}, {
        1.4693879507467726, 1.3493112602018495, 1.0591894555967525, 
        1.0157420270351276, 0.84589090146521684, 0.72936430534579755, 
        1.2645415141150911, 1.597559101261002, 1.2419177331902556, 
        1.058185434234223}}}, {
        0.054099383611066254, {-1.0471744712216342, -0.71298338237640069, \
-0.51968366341063321, 2.2798415170086685}}}}]]], "Output",
  CellLabel->"Out[56]//TableForm="]
}, Closed]],

Cell["\<\
As a check on the method, we can examine this interaction by \
looking at the raw means.  Values are similar:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(StructuredInitialParameters[
          dd, {line, rep, 
            density}, {{{density, line}}, {density}}, {N[Log[Mean[#]]] &, 
            N[Log[Variance[#]\/Mean[#]]] &}]\)\[LeftDoubleBracket]1\
\[RightDoubleBracket] // TableForm\)], "Input",
  CellLabel->"In[102]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {"4.225372824628505`", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>"},
          {GridBox[{
                {\(-0.9148298112344806`\)},
                {\(-0.9407092592223014`\)},
                {\(-1.0812205459562407`\)},
                {\(-1.2652677287176655`\)},
                {\(-0.967276286607023`\)},
                {\(-1.0473189942805594`\)},
                {\(-0.92583909674285`\)},
                {\(-0.9039404114352125`\)},
                {\(-0.9148298112344806`\)},
                {\(-0.978881832727331`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {\(-0.3213819908976232`\)},
                {\(-0.2857346521673856`\)},
                {\(-0.34380902668506774`\)},
                {\(-0.6280605640400592`\)},
                {\(-0.3562573202116357`\)},
                {\(-0.3562573202116357`\)},
                {\(-0.2550809110763832`\)},
                {\(-0.22350911520056993`\)},
                {\(-0.17707220090781117`\)},
                {\(-0.2569694857642517`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {\(-0.17707220090781117`\)},
                {"0.042925044717033956`"},
                {\(-0.05561162312165013`\)},
                {\(-0.15977073127205887`\)},
                {"0.004376374599798893`"},
                {\(-0.026668247082161756`\)},
                {"0.09344773414158425`"},
                {"0.17523019561831177`"},
                {"0.17154242253912688`"},
                {"0.15038419703178096`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"1.4271163556401456`"},
                {"1.2960880932337409`"},
                {"1.0123980420514975`"},
                {"1.0163741904311374`"},
                {"0.7869277487868116`"},
                {"0.672466975322406`"},
                {"1.203972804325936`"},
                {"1.5452891788672405`"},
                {"1.2299482907291965`"},
                {"1.0137251822595603`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        4.2253728246285052, {{-0.91482981123448059, -0.94070925922230142, \
-1.0812205459562407, -1.2652677287176655, -0.96727628660702303, \
-1.0473189942805594, -0.92583909674285003, -0.90394041143521253, \
-0.91482981123448059, -0.97888183272733098}, {-0.3213819908976232, \
-0.28573465216738558, -0.34380902668506774, -0.62806056404005917, \
-0.3562573202116357, -0.3562573202116357, -0.2550809110763832, \
-0.22350911520056993, -0.17707220090781117, -0.25696948576425171}, \
{-0.17707220090781117, 
        0.042925044717033956, -0.055611623121650133, -0.15977073127205887, 
        0.0043763745997988934, -0.026668247082161756, 0.093447734141584249, 
        0.17523019561831177, 0.17154242253912688, 0.15038419703178096}, {
        1.4271163556401456, 1.2960880932337409, 1.0123980420514975, 
        1.0163741904311374, 0.7869277487868116, 0.67246697532240596, 
        1.2039728043259359, 1.5452891788672405, 1.2299482907291965, 
        1.0137251822595603}}}]]], "Output",
  CellLabel->"Out[102]//TableForm="]
}, Closed]],

Cell["\<\
There is a significant density*line*rep interaction (P=0.0017), \
though this may not be significant when compared against residual \
variation.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(lik[{{{density, line, rep}}, {density}}, {{{density, 
              line}}, {density}}] // TableForm\)], "Input",
  CellLabel->"In[57]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {"35.647011049076355`", "40", "0.0016939466011086646`"},
          {GridBox[{
                {"4.178373631934154`", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>"},
                {GridBox[{
                      {\(-0.8832766743867361`\), \(-0.8582991996786606`\)},
                      {\(-0.9178951414422996`\), \(-0.8787679103158246`\)},
                      {\(-1.0196087199983064`\), \(-0.9770991060779597`\)},
                      {\(-1.2055575869765423`\), \(-1.193273493452721`\)},
                      {\(-0.8972803619151021`\), \(-0.9524918772528128`\)},
                      {\(-1.1065902835567825`\), \(-0.9111938055754388`\)},
                      {\(-0.9153169090194436`\), \(-0.8629191423885373`\)},
                      {\(-0.8852697779309768`\), \(-0.8488805119215542`\)},
                      {\(-0.8631669272535957`\), \(-0.8914252780358968`\)},
                      {\(-0.973564018739965`\), \(-0.8939656883758115`\)}
                      },
                    RowSpacings->0.25,
                    ColumnSpacings->1,
                    RowAlignments->Baseline,
                    ColumnAlignments->{Left}], GridBox[{
                      {\(-0.19352016970043098`\), \(-0.3679371649561928`\)},
                      {\(-0.22634512749019822`\), \(-0.252936540610644`\)},
                      {\(-0.32391428841494324`\), \(-0.2736363431128685`\)},
                      {\(-0.5189893416327586`\), \(-0.6179108601739378`\)},
                      {\(-0.271504649527887`\), \(-0.3460568929247727`\)},
                      {\(-0.305760460136322`\), \(-0.31747279989320715`\)},
                      {\(-0.22823103491982863`\), \(-0.18500040446771687`\)},
                      {\(-0.18987604670475502`\), \(-0.1717233151094677`\)},
                      {\(-0.15157189762187434`\), \(-0.1109708381057571`\)},
                      {\(-0.2213973050712517`\), \(-0.19889314433352007`\)}
                      },
                    RowSpacings->0.25,
                    ColumnSpacings->1,
                    RowAlignments->Baseline,
                    ColumnAlignments->{Left}], GridBox[{
                      {\(-0.12069059827549179`\), \(-0.14434243396110305`\)},
                      {"0.10674350587007377`", "0.0739058199998483`"},
                      {"0.016718858681272573`", \(-0.025214471419223356`\)},
                      {\(-0.09711285194308011`\), \(-0.12476570040517762`\)},
                      {\(-0.01960095402145796`\), "0.11660071587496679`"},
                      {"0.0335184253008904`", "0.005875415954645348`"},
                      {"0.09529329864838028`", "0.18334805422800343`"},
                      {"0.20870300031198927`", "0.23185818615025522`"},
                      {"0.20428870306734423`", "0.2315995676766434`"},
                      {"0.17252745638946787`", "0.22084951920612894`"}
                      },
                    RowSpacings->0.25,
                    ColumnSpacings->1,
                    RowAlignments->Baseline,
                    ColumnAlignments->{Left}], GridBox[{
                      {"1.651995243353712`", "1.2697905912999323`"},
                      {"1.4528623827637177`", "1.228820483145283`"},
                      {"0.9967491597242945`", "1.1030429578785552`"},
                      {"1.3764922844428138`", "0.617259755462659`"},
                      {"0.9152561357104388`", "0.7466243832405434`"},
                      {"0.6132796944983914`", "0.8117182952621914`"},
                      {"1.1998053088848102`", "1.3105233092768458`"},
                      {"1.51028168664804`", "1.6738052764145352`"},
                      {"1.0423536021445137`", "1.4310833418616213`"},
                      {"1.2608257064814405`", "0.8268179233745837`"}
                      },
                    RowSpacings->0.25,
                    ColumnSpacings->1,
                    RowAlignments->Baseline,
                    ColumnAlignments->{Left}]}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {\(-0.2712646534326512`\), "\<\"\"\>", "\<\"\"\>", \
"\<\"\"\>"},
                {\(-0.8388617290066682`\), \(-0.519045271249674`\), \
\(-0.29743501725584137`\), "1.6553420175121838`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "\<\"\"\>"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {{35.647011049076355, 40, 0.0016939466011086646}, {{
        4.1783736319341536, {{{-0.88327667438673607, -0.85829919967866064}, \
{-0.91789514144229956, -0.87876791031582457}, {-1.0196087199983064, \
-0.97709910607795969}, {-1.2055575869765423, -1.1932734934527209}, \
{-0.89728036191510208, -0.95249187725281281}, {-1.1065902835567825, \
-0.91119380557543883}, {-0.91531690901944363, -0.86291914238853729}, \
{-0.88526977793097683, -0.84888051192155423}, {-0.86316692725359567, \
-0.89142527803589677}, {-0.97356401873996501, -0.89396568837581147}}, \
{{-0.19352016970043098, -0.36793716495619277}, {-0.22634512749019822, \
-0.25293654061064402}, {-0.32391428841494324, -0.2736363431128685}, \
{-0.51898934163275856, -0.61791086017393781}, {-0.271504649527887, \
-0.34605689292477271}, {-0.30576046013632202, -0.31747279989320715}, \
{-0.22823103491982863, -0.18500040446771687}, {-0.18987604670475502, \
-0.1717233151094677}, {-0.15157189762187434, -0.1109708381057571}, \
{-0.22139730507125169, -0.19889314433352007}}, {{-0.12069059827549179, \
-0.14434243396110305}, {0.10674350587007377, 0.073905819999848299}, {
        0.016718858681272573, -0.025214471419223356}, {-0.097112851943080114, \
-0.12476570040517762}, {-0.019600954021457961, 0.11660071587496679}, {
        0.0335184253008904, 0.0058754159546453482}, {0.095293298648380279, 
        0.18334805422800343}, {0.20870300031198927, 0.23185818615025522}, {
        0.20428870306734423, 0.23159956767664339}, {0.17252745638946787, 
        0.22084951920612894}}, {{1.651995243353712, 1.2697905912999323}, {
        1.4528623827637177, 1.2288204831452829}, {0.99674915972429445, 
        1.1030429578785552}, {1.3764922844428138, 0.61725975546265899}, {
        0.91525613571043885, 0.74662438324054337}, {0.61327969449839137, 
        0.81171829526219141}, {1.1998053088848102, 1.3105233092768458}, {
        1.51028168664804, 1.6738052764145352}, {1.0423536021445137, 
        1.4310833418616213}, {1.2608257064814405, 
        0.82681792337458371}}}}, {-0.27126465343265121, \
{-0.83886172900666822, -0.51904527124967403, -0.29743501725584137, 
        1.6553420175121838}}}}]]], "Output",
  CellLabel->"Out[57]//TableForm="]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
A hierarchical analysis of likelihood: examining the variance, \
assuming density\[Times]line effects on the mean\
\>", "SubsubsectionIcon"],

Cell["\<\
Now, examine the model for the variance.  There is a significant \
line effect on the variance:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(lik[{{{density, line}}, {density, 
            line}}, {{{density, line}}, {density}}] // TableForm\)], "Input",
  CellLabel->"In[160]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {"25.14551313231641`", "9", "9.496569419731316`*^-8"},
          {GridBox[{
                {"4.183047390156265`", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>"},
                {GridBox[{
                      {\(-0.8722713167917964`\)},
                      {\(-0.9000179798451351`\)},
                      {\(-1.0334003935210099`\)},
                      {\(-1.222642310407767`\)},
                      {\(-0.9282419249380969`\)},
                      {\(-0.9937141095118308`\)},
                      {\(-0.8927410353697954`\)},
                      {\(-0.8630088990536644`\)},
                      {\(-0.8817350911939467`\)},
                      {\(-0.9334618604312693`\)}
                      },
                    RowSpacings->0.25,
                    ColumnSpacings->1,
                    RowAlignments->Baseline,
                    ColumnAlignments->{Left}], GridBox[{
                      {\(-0.2760194378042752`\)},
                      {\(-0.24366049853238483`\)},
                      {\(-0.30136367464408703`\)},
                      {\(-0.5861990498415834`\)},
                      {\(-0.3126897301476199`\)},
                      {\(-0.3163076778560084`\)},
                      {\(-0.20933237068933272`\)},
                      {\(-0.18409696477515922`\)},
                      {\(-0.135106080273151`\)},
                      {\(-0.2149121479781775`\)}
                      },
                    RowSpacings->0.25,
                    ColumnSpacings->1,
                    RowAlignments->Baseline,
                    ColumnAlignments->{Left}], GridBox[{
                      {\(-0.1371185216805537`\)},
                      {"0.08648351692705537`"},
                      {\(-0.013711761110796803`\)},
                      {\(-0.11593651491159823`\)},
                      {"0.04732342441024119`"},
                      {"0.015065409597013652`"},
                      {"0.13721103716611863`"},
                      {"0.21916745355222644`"},
                      {"0.21359998903629215`"},
                      {"0.19237585403734983`"}
                      },
                    RowSpacings->0.25,
                    ColumnSpacings->1,
                    RowAlignments->Baseline,
                    ColumnAlignments->{Left}], GridBox[{
                      {"1.4668317002164248`"},
                      {"1.345408058382765`"},
                      {"1.0853515767200361`"},
                      {"1.0451740954607078`"},
                      {"0.8452826961773172`"},
                      {"0.726947922130731`"},
                      {"1.2588886986010233`"},
                      {"1.5867197224459773`"},
                      {"1.2388451215997258`"},
                      {"1.057013074848031`"}
                      },
                    RowSpacings->0.25,
                    ColumnSpacings->1,
                    RowAlignments->Baseline,
                    ColumnAlignments->{Left}]}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {\(-0.07941588049886714`\), "\<\"\"\>", "\<\"\"\>", \
"\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\
\"\>"},
                {\(-1.1705009404986635`\), \(-0.7025161841943394`\), \
\(-0.4573172962603582`\), 
                  "2.330334420953361`", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\
\<\"\"\>", "\<\"\"\>", "\<\"\"\>"},
                {\(-0.06152597282668665`\), \(-0.11564603808414736`\), 
                  "0.7977080806554919`", "0.8914931262749904`", 
                  "0.07883916977933537`", 
                  "0.027207041172346996`", \(-0.19126844111353025`\), \
\(-1.348961343216775`\), \(-0.1308698050928654`\), "0.05302418245184003`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "\<\"\"\>"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {{25.14551313231641, 9, 9.4965694197313155`17*^-8}, {{
        4.1830473901562648, {{-0.87227131679179637, -0.9000179798451351, \
-1.0334003935210099, -1.2226423104077671, -0.92824192493809687, \
-0.99371410951183081, -0.89274103536979543, -0.8630088990536644, \
-0.88173509119394666, -0.93346186043126933}, {-0.27601943780427518, \
-0.24366049853238483, -0.30136367464408703, -0.58619904984158344, \
-0.31268973014761992, -0.31630767785600838, -0.20933237068933272, \
-0.18409696477515922, -0.13510608027315099, -0.21491214797817751}, \
{-0.13711852168055369, 
        0.086483516927055373, -0.013711761110796803, -0.11593651491159823, 
        0.047323424410241191, 0.015065409597013652, 0.13721103716611863, 
        0.21916745355222644, 0.21359998903629215, 0.19237585403734983}, {
        1.4668317002164248, 1.345408058382765, 1.0853515767200361, 
        1.0451740954607078, 0.84528269617731722, 0.72694792213073101, 
        1.2588886986010233, 1.5867197224459773, 1.2388451215997258, 
        1.0570130748480311}}}, {-0.079415880498867136, {-1.1705009404986635, \
-0.70251618419433937, -0.45731729626035822, 
        2.3303344209533612}, {-0.061525972826686648, -0.11564603808414736, 
        0.79770808065549192, 0.89149312627499044, 0.078839169779335375, 
        0.027207041172346996, -0.19126844111353025, -1.3489613432167751, \
-0.13086980509286539, 0.053024182451840027}}}}]]], "Output",
  CellLabel->"Out[160]//TableForm="]
}, Closed]],

Cell["\<\
There is only a marginally significant (P=4%) density*line \
interaction:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(lik[{{{density, line}}, {{density, line}}}, {{{density, 
              line}}, {density, line}}] // TableForm\)], "Input",
  CellLabel->"In[159]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {"20.45226403439301`", "27", "0.042064180993253264`"},
          {GridBox[{
                {"4.1823107753701185`", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>"},
                {GridBox[{
                      {\(-0.8717681796564614`\)},
                      {\(-0.897649055349919`\)},
                      {\(-1.038159909478824`\)},
                      {\(-1.2222062290052533`\)},
                      {\(-0.9242208160037058`\)},
                      {\(-1.0042562918678413`\)},
                      {\(-0.8829276320451386`\)},
                      {\(-0.8610457915764012`\)},
                      {\(-0.8718863093498546`\)},
                      {\(-0.9358203035956599`\)}
                      },
                    RowSpacings->0.25,
                    ColumnSpacings->1,
                    RowAlignments->Baseline,
                    ColumnAlignments->{Left}], GridBox[{
                      {\(-0.2783205071985525`\)},
                      {\(-0.24267320737078765`\)},
                      {\(-0.30074759937167167`\)},
                      {\(-0.5850000891783409`\)},
                      {\(-0.3131957064310621`\)},
                      {\(-0.3131956528946013`\)},
                      {\(-0.2120098140473317`\)},
                      {\(-0.18045100034639108`\)},
                      {\(-0.13401068127045837`\)},
                      {\(-0.21390785418315483`\)}
                      },
                    RowSpacings->0.25,
                    ColumnSpacings->1,
                    RowAlignments->Baseline,
                    ColumnAlignments->{Left}], GridBox[{
                      {\(-0.13398390701419913`\)},
                      {"0.08599957091827372`"},
                      {\(-0.012562741252730008`\)},
                      {\(-0.11670438325530026`\)},
                      {"0.04744278748834624`"},
                      {"0.01640501853544948`"},
                      {"0.13651721899302138`"},
                      {"0.2183227553499557`"},
                      {"0.21461577973957144`"},
                      {"0.19345612438673188`"}
                      },
                    RowSpacings->0.25,
                    ColumnSpacings->1,
                    RowAlignments->Baseline,
                    ColumnAlignments->{Left}], GridBox[{
                      {"1.470159844118941`"},
                      {"1.3391238906107228`"},
                      {"1.0554303261917473`"},
                      {"1.0589741952864697`"},
                      {"0.829939813280896`"},
                      {"0.7154544597407897`"},
                      {"1.2470322282002535`"},
                      {"1.5883353630173156`"},
                      {"1.2727545562729086`"},
                      {"1.0567397296122487`"}
                      },
                    RowSpacings->0.25,
                    ColumnSpacings->1,
                    RowAlignments->Baseline,
                    ColumnAlignments->{Left}]}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {\(-0.22724630784264432`\), "\<\"\"\>", "\<\"\"\>", \
"\<\"\"\>"},
                {GridBox[{
                      {\(-1.067261675682175`\)},
                      {\(-1.2572329773831699`\)},
                      {"0.3090905542470898`"},
                      {\(-0.08761861649527956`\)},
                      {\(-1.284109672164106`\)},
                      {\(-0.4900922733812661`\)},
                      {\(-2.433482694287546`\)},
                      {\(-2.4437110044333226`\)},
                      {\(-2.232808896744041`\)},
                      {\(-0.8009583975896926`\)}
                      },
                    RowSpacings->0.25,
                    ColumnSpacings->1,
                    RowAlignments->Baseline,
                    ColumnAlignments->{Left}], GridBox[{
                      {\(-0.2287245638203059`\)},
                      {\(-0.7130951117631593`\)},
                      {\(-0.8416038949362492`\)},
                      {"0.6028855019413414`"},
                      {\(-0.23603046882425782`\)},
                      {\(-1.0422234381748667`\)},
                      {\(-0.23387037366501387`\)},
                      {\(-2.3204826474254463`\)},
                      {\(-0.7530553140060714`\)},
                      {\(-0.5610720609024766`\)}
                      },
                    RowSpacings->0.25,
                    ColumnSpacings->1,
                    RowAlignments->Baseline,
                    ColumnAlignments->{Left}], GridBox[{
                      {\(-1.2982279411680895`\)},
                      {\(-0.16055308890988262`\)},
                      {"0.6711260457954041`"},
                      {"0.052550926705074226`"},
                      {\(-0.01968520529308932`\)},
                      {\(-0.5186472275980893`\)},
                      {\(-0.16345697658344926`\)},
                      {\(-1.4240186100537153`\)},
                      {\(-0.5386104251051971`\)},
                      {\(-0.4087661075477895`\)}
                      },
                    RowSpacings->0.25,
                    ColumnSpacings->1,
                    RowAlignments->Baseline,
                    ColumnAlignments->{Left}], GridBox[{
                      {"2.586684510009282`"},
                      {"1.717961559355591`"},
                      {"2.3760321019949626`"},
                      {"3.575641709181157`"},
                      {"1.808866528221834`"},
                      {"2.029432801467635`"},
                      {"0.37136680277296896`"},
                      {"1.4632341233727688`"},
                      {"3.509484957270065`"},
                      {"2.4850415416025675`"}
                      },
                    RowSpacings->0.25,
                    ColumnSpacings->1,
                    RowAlignments->Baseline,
                    ColumnAlignments->{Left}]}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "\<\"\"\>"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {{20.452264034393011, 27, 0.042064180993253264}, {{
        4.1823107753701185, {{-0.87176817965646136, -0.89764905534991901, \
-1.0381599094788241, -1.2222062290052533, -0.92422081600370576, \
-1.0042562918678413, -0.88292763204513858, -0.86104579157640115, \
-0.87188630934985456, -0.93582030359565993}, {-0.2783205071985525, \
-0.24267320737078765, -0.30074759937167167, -0.5850000891783409, \
-0.31319570643106209, -0.31319565289460127, -0.21200981404733171, \
-0.18045100034639108, -0.13401068127045837, -0.21390785418315483}, \
{-0.13398390701419913, 
        0.085999570918273718, -0.012562741252730008, -0.11670438325530026, 
        0.047442787488346239, 0.01640501853544948, 0.13651721899302138, 
        0.21832275534995571, 0.21461577973957144, 0.19345612438673188}, {
        1.470159844118941, 1.3391238906107228, 1.0554303261917473, 
        1.0589741952864697, 0.82993981328089605, 0.71545445974078969, 
        1.2470322282002535, 1.5883353630173156, 1.2727545562729086, 
        1.0567397296122487}}}, {-0.22724630784264432, {{-1.0672616756821749, \
-1.2572329773831699, 
        0.30909055424708981, -0.087618616495279564, -1.2841096721641061, \
-0.4900922733812661, -2.4334826942875458, -2.4437110044333226, \
-2.2328088967440411, -0.80095839758969256}, {-0.2287245638203059, \
-0.71309511176315932, -0.84160389493624921, 
        0.60288550194134138, -0.23603046882425782, -1.0422234381748667, \
-0.23387037366501387, -2.3204826474254463, -0.7530553140060714, \
-0.56107206090247663}, {-1.2982279411680895, -0.16055308890988262, 
        0.67112604579540414, 
        0.052550926705074226, -0.019685205293089321, -0.51864722759808934, \
-0.16345697658344926, -1.4240186100537153, -0.53861042510519708, \
-0.40876610754778953}, {2.5866845100092819, 1.717961559355591, 
        2.3760321019949626, 3.575641709181157, 1.8088665282218339, 
        2.0294328014676348, 0.37136680277296896, 1.4632341233727688, 
        3.509484957270065, 2.4850415416025675}}}}}]]], "Output",
  CellLabel->"Out[159]//TableForm="]
}, Closed]],

Cell["\<\
There is a marginal (P=2.5%) line*rep interaction for the variance:\
\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(lik[{{{density, line}}, {density, {line, rep}}}, {{{density, 
              line}}, {density, line}}] // TableForm\)], "Input",
  CellLabel->"In[161]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {"10.215674442282761`", "10", "0.025426936277454515`"},
          {GridBox[{
                {"4.192122451372951`", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>"},
                {GridBox[{
                      {\(-0.8881243162784637`\)},
                      {\(-0.9061261717431818`\)},
                      {\(-1.0407656787169985`\)},
                      {\(-1.2288703431170103`\)},
                      {\(-0.931323878429873`\)},
                      {\(-1.0665653807929827`\)},
                      {\(-0.8900067770643003`\)},
                      {\(-0.8767067728676782`\)},
                      {\(-0.8940432004298022`\)},
                      {\(-0.9591092026469685`\)}
                      },
                    RowSpacings->0.25,
                    ColumnSpacings->1,
                    RowAlignments->Baseline,
                    ColumnAlignments->{Left}], GridBox[{
                      {\(-0.2524950287794009`\)},
                      {\(-0.25356154431878186`\)},
                      {\(-0.30832022641511225`\)},
                      {\(-0.5767038314116321`\)},
                      {\(-0.3139832670189703`\)},
                      {\(-0.31835050672695575`\)},
                      {\(-0.21084700567121273`\)},
                      {\(-0.19419020960146036`\)},
                      {\(-0.12884843420531658`\)},
                      {\(-0.22809788897207905`\)}
                      },
                    RowSpacings->0.25,
                    ColumnSpacings->1,
                    RowAlignments->Baseline,
                    ColumnAlignments->{Left}], GridBox[{
                      {\(-0.14196408846951739`\)},
                      {"0.07537815015774782`"},
                      {\(-0.024053184134360146`\)},
                      {\(-0.11958310660404488`\)},
                      {"0.023847413898822313`"},
                      {"0.015448174973495845`"},
                      {"0.14848215353212407`"},
                      {"0.2054988635768773`"},
                      {"0.21615108838432154`"},
                      {"0.1741040593892424`"}
                      },
                    RowSpacings->0.25,
                    ColumnSpacings->1,
                    RowAlignments->Baseline,
                    ColumnAlignments->{Left}], GridBox[{
                      {"1.5242513994479228`"},
                      {"1.3253649194703165`"},
                      {"1.076894175453139`"},
                      {"1.1513197308905874`"},
                      {"0.8506827555731259`"},
                      {"0.6490979669194994`"},
                      {"1.2693019111896395`"},
                      {"1.5570338981799012`"},
                      {"1.3581002098936048`"},
                      {"1.1316831734857327`"}
                      },
                    RowSpacings->0.25,
                    ColumnSpacings->1,
                    RowAlignments->Baseline,
                    ColumnAlignments->{Left}]}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {\(-0.1509261911132453`\), "\<\"\"\>", "\<\"\"\>", \
"\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\
\"\>"},
                {\(-1.1932282160897705`\), \(-0.6408721850773232`\), \
\(-0.4327257631047098`\), 
                  "2.2668261642718033`", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", \
"\<\"\"\>", "\<\"\"\>", "\<\"\"\>"},
                {GridBox[{
                      {\(-0.42880644718282834`\)},
                      {"0.3749236496892226`"}
                      },
                    RowSpacings->0.25,
                    ColumnSpacings->1,
                    RowAlignments->Baseline,
                    ColumnAlignments->{Left}], GridBox[{
                      {"0.02049892585799786`"},
                      {\(-0.15485324803701778`\)}
                      },
                    RowSpacings->0.25,
                    ColumnSpacings->1,
                    RowAlignments->Baseline,
                    ColumnAlignments->{Left}], GridBox[{
                      {"0.9438503591074264`"},
                      {"0.8119489985520999`"}
                      },
                    RowSpacings->0.25,
                    ColumnSpacings->1,
                    RowAlignments->Baseline,
                    ColumnAlignments->{Left}], GridBox[{
                      {"0.5765585563156845`"},
                      {"1.2835276226072911`"}
                      },
                    RowSpacings->0.25,
                    ColumnSpacings->1,
                    RowAlignments->Baseline,
                    ColumnAlignments->{Left}], GridBox[{
                      {\(-0.08821223485795004`\)},
                      {"0.34614852813704017`"}
                      },
                    RowSpacings->0.25,
                    ColumnSpacings->1,
                    RowAlignments->Baseline,
                    ColumnAlignments->{Left}], GridBox[{
                      {\(-0.7277658600019784`\)},
                      {"0.6241543964664773`"}
                      },
                    RowSpacings->0.25,
                    ColumnSpacings->1,
                    RowAlignments->Baseline,
                    ColumnAlignments->{Left}], GridBox[{
                      {"0.25403580193583`"},
                      {\(-0.6321417451495709`\)}
                      },
                    RowSpacings->0.25,
                    ColumnSpacings->1,
                    RowAlignments->Baseline,
                    ColumnAlignments->{Left}], GridBox[{
                      {\(-1.5852108645461653`\)},
                      {\(-1.0674994164019842`\)}
                      },
                    RowSpacings->0.25,
                    ColumnSpacings->1,
                    RowAlignments->Baseline,
                    ColumnAlignments->{Left}], GridBox[{
                      {"0.5579474677604714`"},
                      {\(-1.159051506023517`\)}
                      },
                    RowSpacings->0.25,
                    ColumnSpacings->1,
                    RowAlignments->Baseline,
                    ColumnAlignments->{Left}], GridBox[{
                      {\(-0.4193738530234332`\)},
                      {"0.4693208687949041`"}
                      },
                    RowSpacings->0.25,
                    ColumnSpacings->1,
                    RowAlignments->Baseline,
                    ColumnAlignments->{Left}]}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "\<\"\"\>"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {{10.215674442282761, 10, 0.025426936277454515}, {{
        4.1921224513729509, {{-0.88812431627846367, -0.90612617174318177, \
-1.0407656787169985, -1.2288703431170103, -0.93132387842987296, \
-1.0665653807929827, -0.89000677706430031, -0.87670677286767817, \
-0.89404320042980223, -0.95910920264696853}, {-0.25249502877940089, \
-0.25356154431878186, -0.30832022641511225, -0.57670383141163206, \
-0.31398326701897028, -0.31835050672695575, -0.21084700567121273, \
-0.19419020960146036, -0.12884843420531658, -0.22809788897207905}, \
{-0.14196408846951739, 
        0.07537815015774782, -0.024053184134360146, -0.11958310660404488, 
        0.023847413898822313, 0.015448174973495845, 0.14848215353212407, 
        0.2054988635768773, 0.21615108838432154, 0.17410405938924239}, {
        1.5242513994479228, 1.3253649194703165, 1.0768941754531389, 
        1.1513197308905874, 0.85068275557312589, 0.64909796691949939, 
        1.2693019111896395, 1.5570338981799012, 1.3581002098936048, 
        1.1316831734857327}}}, {-0.15092619111324529, {-1.1932282160897705, \
-0.64087218507732324, -0.43272576310470978, 
        2.2668261642718033}, {{-0.42880644718282834, 0.37492364968922259}, {
        0.020498925857997861, -0.15485324803701778}, {0.94385035910742643, 
        0.8119489985520999}, {0.57655855631568453, 
        1.2835276226072911}, {-0.088212234857950045, 
        0.34614852813704017}, {-0.7277658600019784, 0.6241543964664773}, {
        0.25403580193582997, -0.63214174514957089}, {-1.5852108645461653, \
-1.0674994164019842}, {
        0.55794746776047144, -1.1590515060235169}, {-0.41937385302343322, 
        0.46932086879490409}}}}}]]], "Output",
  CellLabel->"Out[161]//TableForm="]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
A hierarchical analysis of likelihood: examining the mean, assuming \
density and line effects on the variance\
\>", "SubsubsectionIcon"],

Cell["\<\
Now, return to examine the mean, assuming density and line effects \
on the variance.  There is a significant density\[Times]line interaction on \
the mean:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(lik[{{{density, line}}, {density, line}}, {{density, line}, {density, 
            line}}] // TableForm\)], "Input",
  CellLabel->"In[68]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {"43.56376738793347`", "27", "3.007096149865163`*^-8"},
          {GridBox[{
                {"4.182985886646385`", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>"},
                {GridBox[{
                      {\(-0.8724302496941044`\)},
                      {\(-0.9001166111773344`\)},
                      {\(-1.0334547256169264`\)},
                      {\(-1.2226696398704393`\)},
                      {\(-0.9282649207467878`\)},
                      {\(-0.993813480991324`\)},
                      {\(-0.8927007788804852`\)},
                      {\(-0.8635350597089892`\)},
                      {\(-0.8816877755924113`\)},
                      {\(-0.9336689419891098`\)}
                      },
                    RowSpacings->0.25,
                    ColumnSpacings->1,
                    RowAlignments->Baseline,
                    ColumnAlignments->{Left}], GridBox[{
                      {\(-0.2759661010712479`\)},
                      {\(-0.24360641376153355`\)},
                      {\(-0.30135189858938`\)},
                      {\(-0.5861333200699924`\)},
                      {\(-0.31262870523079994`\)},
                      {\(-0.3162366618101506`\)},
                      {\(-0.2092866087289449`\)},
                      {\(-0.18421995093658022`\)},
                      {\(-0.13504590236159683`\)},
                      {\(-0.2148498314990682`\)}
                      },
                    RowSpacings->0.25,
                    ColumnSpacings->1,
                    RowAlignments->Baseline,
                    ColumnAlignments->{Left}], GridBox[{
                      {\(-0.1370536165954756`\)},
                      {"0.08652365831098821`"},
                      {\(-0.013651877265355562`\)},
                      {\(-0.11586769263692423`\)},
                      {"0.04737719893441521`"},
                      {"0.015135315009175497`"},
                      {"0.1372510629611922`"},
                      {"0.21891894440729617`"},
                      {"0.21365665439236817`"},
                      {"0.192435163627452`"}
                      },
                    RowSpacings->0.25,
                    ColumnSpacings->1,
                    RowAlignments->Baseline,
                    ColumnAlignments->{Left}], GridBox[{
                      {"1.4669039347952249`"},
                      {"1.3454985321299657`"},
                      {"1.0851552812893683`"},
                      {"1.0453176464752434`"},
                      {"0.8454067747912615`"},
                      {"0.7268189750283403`"},
                      {"1.258986965222581`"},
                      {"1.5868534940821395`"},
                      {"1.238898427874781`"},
                      {"1.0571027354931717`"}
                      },
                    RowSpacings->0.25,
                    ColumnSpacings->1,
                    RowAlignments->Baseline,
                    ColumnAlignments->{Left}]}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {\(-0.07230923939525088`\), "\<\"\"\>", "\<\"\"\>", \
"\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\
\"\>"},
                {\(-1.1617792907337843`\), \(-0.7067873688099551`\), \
\(-0.4591894061589035`\), 
                  "2.3277560657026433`", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", \
"\<\"\"\>", "\<\"\"\>", "\<\"\"\>"},
                {\(-0.06326143094847587`\), \(-0.11754827117540949`\), 
                  "0.7909777253200688`", "0.8875327592454544`", 
                  "0.07569041606094046`", 
                  "0.016311828417254808`", \(-0.19272251181238875`\), \
\(-1.3142375457156905`\), \(-0.1327671352239041`\), "0.05002416583215033`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "\<\"\"\>"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {{43.563767387933467, 27, 3.0070961498651627`17*^-8}, {{
        4.1829858866463852, {{-0.87243024969410443, -0.90011661117733444, \
-1.0334547256169264, -1.2226696398704393, -0.92826492074678779, \
-0.99381348099132405, -0.89270077888048516, -0.86353505970898925, \
-0.88168777559241129, -0.93366894198910977}, {-0.27596610107124792, \
-0.24360641376153355, -0.30135189858938, -0.58613332006999241, \
-0.31262870523079994, -0.31623666181015059, -0.20928660872894489, \
-0.18421995093658022, -0.13504590236159683, -0.21484983149906819}, \
{-0.1370536165954756, 
        0.086523658310988211, -0.013651877265355562, -0.11586769263692423, 
        0.047377198934415207, 0.015135315009175497, 0.13725106296119219, 
        0.21891894440729617, 0.21365665439236817, 0.192435163627452}, {
        1.4669039347952249, 1.3454985321299657, 1.0851552812893683, 
        1.0453176464752434, 0.84540677479126147, 0.72681897502834025, 
        1.2589869652225809, 1.5868534940821395, 1.238898427874781, 
        1.0571027354931717}}}, {-0.072309239395250885, {-1.1617792907337843, \
-0.70678736880995507, -0.45918940615890352, 
        2.3277560657026433}, {-0.063261430948475875, -0.11754827117540949, 
        0.79097772532006883, 0.88753275924545438, 0.075690416060940457, 
        0.016311828417254808, -0.19272251181238875, -1.3142375457156905, \
-0.1327671352239041, 0.05002416583215033}}}}]]], "Output",
  CellLabel->"Out[68]//TableForm="]
}, Closed]],

Cell["\<\
There is a significant density\[Times]line\[Times]rep interaction \
on the mean:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(lik[{{{density, line, rep}}, {density, 
            line}}, {{{density, line}}, {density, line}}] // 
      TableForm\)], "Input",
  CellLabel->"In[69]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {"40.04592254858903`", "40", "0.00017194712350543373`"},
          {GridBox[{
                {"4.178188322194256`", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>"},
                {GridBox[{
                      {\(-0.8804899971620632`\), \(-0.8326308148923445`\)},
                      {\(-0.9156187552962153`\), \(-0.8755503379615789`\)},
                      {\(-1.0391277694530479`\), \(-1.0199020020567495`\)},
                      {\(-1.2204727504812904`\), \(-1.2113612792260842`\)},
                      {\(-0.896587337280917`\), \(-0.94929666734637`\)},
                      {\(-1.105184666569894`\), \(-0.9041628680765238`\)},
                      {\(-0.9155282624057215`\), \(-0.863060152880484`\)},
                      {\(-0.8785874070243133`\), \(-0.8427878916335555`\)},
                      {\(-0.8631773984871484`\), \(-0.8913023413355989`\)},
                      {\(-0.9712782003494367`\), \(-0.8865255078878298`\)}
                      },
                    RowSpacings->0.25,
                    ColumnSpacings->1,
                    RowAlignments->Baseline,
                    ColumnAlignments->{Left}], GridBox[{
                      {\(-0.188811193927198`\), \(-0.3686926061671521`\)},
                      {\(-0.2261358656412735`\), \(-0.251143585036463`\)},
                      {\(-0.32338152565505834`\), \(-0.2696217427444478`\)},
                      {\(-0.5300078638350488`\), \(-0.6339335498281637`\)},
                      {\(-0.27098900736731446`\), \(-0.3450190542252621`\)},
                      {\(-0.30510000198634607`\), \(-0.31638615022626254`\)},
                      {\(-0.22199833096662785`\), \(-0.18462687697576774`\)},
                      {\(-0.18627733065357405`\), \(-0.1711013302826968`\)},
                      {\(-0.15182955933575273`\), \(-0.1106911760477974`\)},
                      {\(-0.22093414647576645`\), \(-0.19758916510468644`\)}
                      },
                    RowSpacings->0.25,
                    ColumnSpacings->1,
                    RowAlignments->Baseline,
                    ColumnAlignments->{Left}], GridBox[{
                      {\(-0.12096323278188358`\), \(-0.14303433190939802`\)},
                      {"0.10864171205972835`", "0.07397517197723104`"},
                      {"0.01071833780372697`", \(-0.028627275947026208`\)},
                      {\(-0.092305342041863`\), \(-0.13214839039250384`\)},
                      {\(-0.01920390094700164`\), "0.11686065308068821`"},
                      {"0.03371833369258761`", "0.007326183134707731`"},
                      {"0.0968106531330306`", "0.1846180910436199`"},
                      {"0.2083234349843761`", "0.23909615677794296`"},
                      {"0.20421344027028945`", "0.23187393507620477`"},
                      {"0.17292955748961208`", "0.22135457093072894`"}
                      },
                    RowSpacings->0.25,
                    ColumnSpacings->1,
                    RowAlignments->Baseline,
                    ColumnAlignments->{Left}], GridBox[{
                      {"1.6496558723442518`", "1.2664433683290515`"},
                      {"1.4521321967517828`", "1.2278612243064029`"},
                      {"1.0068844757360174`", "1.115425339793464`"},
                      {"1.3850968839087314`", "0.633119232132821`"},
                      {"0.9149326787504569`", "0.7457575837432212`"},
                      {"0.6104671464523533`", "0.8109298265959811`"},
                      {"1.1978023045376378`", "1.3085735670571794`"},
                      {"1.5090255894684026`", "1.6695867762472476`"},
                      {"1.0419299363155894`", "1.4316447345324093`"},
                      {"1.259995729338601`", "0.8254602465134251`"}
                      },
                    RowSpacings->0.25,
                    ColumnSpacings->1,
                    RowAlignments->Baseline,
                    ColumnAlignments->{Left}]}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {\(-0.4323078857397582`\), "\<\"\"\>", "\<\"\"\>", \
"\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\
\"\>"},
                {\(-0.9585636828089716`\), \(-0.4821891047874283`\), \
\(-0.2494090116899904`\), 
                  "1.6901617992863904`", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", \
"\<\"\"\>", "\<\"\"\>", "\<\"\"\>"},
                {\(-0.4430080098959481`\), \(-0.025195298940781576`\), 
                  "0.9812064402844998`", "0.8695560695861452`", 
                  "0.04719295771257138`", \(-0.09893053446962766`\), \
\(-0.17312958862943695`\), \(-1.3355307613403533`\), 
                  "0.18129556415974102`", \(-0.003456838466809677`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "\<\"\"\>"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {{40.045922548589033, 40, 0.00017194712350543373}, {{
        4.1781883221942557, {{{-0.88048999716206322, -0.83263081489234447}, \
{-0.91561875529621528, -0.87555033796157888}, {-1.0391277694530479, \
-1.0199020020567495}, {-1.2204727504812904, -1.2113612792260842}, \
{-0.896587337280917, -0.94929666734636997}, {-1.1051846665698939, \
-0.9041628680765238}, {-0.91552826240572149, -0.86306015288048399}, \
{-0.87858740702431326, -0.8427878916335555}, {-0.86317739848714836, \
-0.89130234133559894}, {-0.97127820034943668, -0.8865255078878298}}, \
{{-0.188811193927198, -0.3686926061671521}, {-0.2261358656412735, \
-0.251143585036463}, {-0.32338152565505834, -0.26962174274444778}, \
{-0.53000786383504883, -0.63393354982816374}, {-0.27098900736731446, \
-0.34501905422526208}, {-0.30510000198634607, -0.31638615022626254}, \
{-0.22199833096662785, -0.18462687697576774}, {-0.18627733065357405, \
-0.17110133028269681}, {-0.15182955933575273, -0.11069117604779739}, \
{-0.22093414647576645, -0.19758916510468644}}, {{-0.12096323278188358, \
-0.14303433190939802}, {0.10864171205972835, 0.073975171977231038}, {
        0.01071833780372697, -0.028627275947026208}, {-0.092305342041862998, \
-0.13214839039250384}, {-0.01920390094700164, 0.11686065308068821}, {
        0.033718333692587608, 0.0073261831347077311}, {0.096810653133030597, 
        0.1846180910436199}, {0.20832343498437611, 0.23909615677794296}, {
        0.20421344027028945, 0.23187393507620477}, {0.17292955748961208, 
        0.22135457093072894}}, {{1.6496558723442518, 1.2664433683290515}, {
        1.4521321967517828, 1.2278612243064029}, {1.0068844757360174, 
        1.1154253397934639}, {1.3850968839087314, 0.63311923213282095}, {
        0.91493267875045692, 0.74575758374322121}, {0.61046714645235334, 
        0.81092982659598112}, {1.1978023045376378, 1.3085735670571794}, {
        1.5090255894684026, 1.6695867762472476}, {1.0419299363155894, 
        1.4316447345324093}, {1.259995729338601, 
        0.82546024651342509}}}}, {-0.4323078857397582, {-0.95856368280897164, \
-0.48218910478742832, -0.24940901168999041, 
        1.6901617992863904}, {-0.44300800989594807, -0.025195298940781576, 
        0.98120644028449977, 0.86955606958614517, 
        0.047192957712571378, -0.098930534469627657, -0.17312958862943695, \
-1.3355307613403533, 
        0.18129556415974102, -0.0034568384668096771}}}}]]], "Output",
  CellLabel->"Out[69]//TableForm="]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
A hierarchical analysis of likelihood: the relation between mean \
and variance\
\>", "SubsubsectionIcon"],

Cell["\<\
An economical explanation for the line effects on the variance is \
that denser lines also have higher variance. Is there a systematic relation \
between mean and variance of numbers?\
\>", "Text"],

Cell[BoxData[
    \(<< Graphics`Colors`; \)], "Input",
  CellLabel->"In[50]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(sp = 
      StructuredInitialParameters[
        dd, {line, rep, 
          density}, {{density, {line, rep}}, {density, {line, rep}}}, {N[
              Log[Mean[#]]] &, N[Log[Variance[#]\/Mean[#]]] &}]; 
    sp // TableForm\)], "Input",
  CellLabel->"In[29]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {"4.225372824628505`", GridBox[{
                {\(-0.9886570816319735`\)},
                {\(-0.31394999927239153`\)},
                {"0.029246484128814032`"},
                {"1.1534871246347187`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"0.16616723708324965`", \(-0.04647087437834152`\)},
                {"0.11919624751047575`", "0.018911884884510677`"},
                {\(-0.11064910006975204`\), \(-0.07758042796299147`\)},
                {\(-0.05643021428110018`\), \(-0.37647757123491266`\)},
                {\(-0.12030168466776114`\), \(-0.15483891110012316`\)},
                {\(-0.2266326031188659`\), \(-0.15684896202814702`\)},
                {"0.014683548774988786`", "0.09914931556518525`"},
                {"0.18564134691862844`", "0.26919436973691013`"},
                {"0.04061557486837142`", "0.17414696749289327`"},
                {"0.057807975408743495`", \(-0.05279714943121849`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"4.0420266021919184`", GridBox[{
                {\(-4.572208444604204`\)},
                {\(-3.9613072604925708`\)},
                {\(-3.5407499510532627`\)},
                {\(-0.8658099558721903`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"0.7394291162554136`", "0.0843319079790339`"},
                {"0.3341804118260914`", \(-0.08946923854358069`\)},
                {\(-0.2883750672219283`\), \(-0.2187002389092183`\)},
                {"0.404256385885164`", \(-0.8767287003304971`\)},
                {\(-0.6039607145587826`\), \(-0.9717055304759228`\)},
                {\(-1.1762952063633976`\), \(-0.7568187196595293`\)},
                {\(-0.14988855795776912`\), \(-0.006327609104720189`\)},
                {"0.3938686908068396`", "0.6558641034439399`"},
                {\(-0.16487802963310827`\), "0.20364544907088433`"},
                {\(-0.04588703069916056`\), \(-0.907577514188866`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {{
        4.2253728246285052, {-0.98865708163197352, -0.31394999927239153, 
        0.029246484128814032, 1.1534871246347187}, {{
        0.16616723708324965, -0.04647087437834152}, {0.11919624751047575, 
        0.018911884884510677}, {-0.11064910006975204, -0.077580427962991472}, \
{-0.056430214281100177, -0.37647757123491266}, {-0.12030168466776114, \
-0.15483891110012316}, {-0.22663260311886591, -0.15684896202814702}, {
        0.014683548774988786, 0.099149315565185248}, {0.18564134691862844, 
        0.26919436973691013}, {0.040615574868371418, 0.17414696749289327}, {
        0.057807975408743495, -0.052797149431218493}}}, {
        4.0420266021919184, {-4.5722084446042039, -3.9613072604925708, \
-3.5407499510532627, -0.86580995587219034}, {{0.73942911625541363, 
        0.084331907979033893}, {
        0.33418041182609137, -0.089469238543580687}, {-0.28837506722192829, \
-0.2187002389092183}, {
        0.40425638588516399, -0.8767287003304971}, {-0.60396071455878264, \
-0.97170553047592279}, {-1.1762952063633976, -0.75681871965952929}, \
{-0.14988855795776912, -0.0063276091047201888}, {0.39386869080683962, 
        0.65586410344393986}, {-0.16487802963310827, 
        0.20364544907088433}, {-0.045887030699160558, \
-0.90757751418886601}}}}]]], "Output",
  CellLabel->"Out[29]//TableForm="]
}, Closed]],

Cell[BoxData[
    \(g[i_] := 
      StructuredParameter[
        i, {line, rep, 
          density}, {{density, {line, rep}}, {density, {line, rep}}}, 
        sp]\)], "Input",
  CellLabel->"In[33]:="],

Cell[BoxData[
    \(col[1] = Blue; col[2] = Red; col[3] = Purple; 
    col[4] = Brown; \)], "Input",
  CellLabel->"In[69]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[
      Graphics[Table[{Table[{col[d], Thickness[0.005], 
                Line[{g[{l, 1, d}], g[{l, 2, d}]}]}, {d, 4}], 
            Line[Table[\((g[{l, 1, d}] + g[{l, 2, d}])\)\/2, {d, 4}]]}, {l, 
            10}]], Plot[0, {x, 0, 5}], 
      PlotRange \[Rule] {{2.5, 6}, {\(-2\), 4.5}}, Axes \[Rule] True, 
      AxesOrigin \[Rule] {2.5, \(-2\)}]; \)], "Input",
  CellLabel->"In[205]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.714286 0.285714 0.190164 0.0950822 [
[.14286 -0.0125 -3 -9 ]
[.14286 -0.0125 3 0 ]
[.28571 -0.0125 -9 -9 ]
[.28571 -0.0125 9 0 ]
[.42857 -0.0125 -3 -9 ]
[.42857 -0.0125 3 0 ]
[.57143 -0.0125 -9 -9 ]
[.57143 -0.0125 9 0 ]
[.71429 -0.0125 -3 -9 ]
[.71429 -0.0125 3 0 ]
[.85714 -0.0125 -9 -9 ]
[.85714 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .09508 -12 -4.5 ]
[-0.0125 .09508 0 4.5 ]
[-0.0125 .19016 -6 -4.5 ]
[-0.0125 .19016 0 4.5 ]
[-0.0125 .28525 -6 -4.5 ]
[-0.0125 .28525 0 4.5 ]
[-0.0125 .38033 -6 -4.5 ]
[-0.0125 .38033 0 4.5 ]
[-0.0125 .47541 -6 -4.5 ]
[-0.0125 .47541 0 4.5 ]
[-0.0125 .57049 -6 -4.5 ]
[-0.0125 .57049 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.14286 0 m
.14286 .00625 L
s
[(3)] .14286 -0.0125 0 1 Mshowa
.28571 0 m
.28571 .00625 L
s
[(3.5)] .28571 -0.0125 0 1 Mshowa
.42857 0 m
.42857 .00625 L
s
[(4)] .42857 -0.0125 0 1 Mshowa
.57143 0 m
.57143 .00625 L
s
[(4.5)] .57143 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(5)] .71429 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(5.5)] .85714 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(6)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.02857 0 m
.02857 .00375 L
s
.05714 0 m
.05714 .00375 L
s
.08571 0 m
.08571 .00375 L
s
.11429 0 m
.11429 .00375 L
s
.17143 0 m
.17143 .00375 L
s
.2 0 m
.2 .00375 L
s
.22857 0 m
.22857 .00375 L
s
.25714 0 m
.25714 .00375 L
s
.31429 0 m
.31429 .00375 L
s
.34286 0 m
.34286 .00375 L
s
.37143 0 m
.37143 .00375 L
s
.4 0 m
.4 .00375 L
s
.45714 0 m
.45714 .00375 L
s
.48571 0 m
.48571 .00375 L
s
.51429 0 m
.51429 .00375 L
s
.54286 0 m
.54286 .00375 L
s
.6 0 m
.6 .00375 L
s
.62857 0 m
.62857 .00375 L
s
.65714 0 m
.65714 .00375 L
s
.68571 0 m
.68571 .00375 L
s
.74286 0 m
.74286 .00375 L
s
.77143 0 m
.77143 .00375 L
s
.8 0 m
.8 .00375 L
s
.82857 0 m
.82857 .00375 L
s
.88571 0 m
.88571 .00375 L
s
.91429 0 m
.91429 .00375 L
s
.94286 0 m
.94286 .00375 L
s
.97143 0 m
.97143 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .09508 m
.00625 .09508 L
s
[(-1)] -0.0125 .09508 1 0 Mshowa
0 .19016 m
.00625 .19016 L
s
[(0)] -0.0125 .19016 1 0 Mshowa
0 .28525 m
.00625 .28525 L
s
[(1)] -0.0125 .28525 1 0 Mshowa
0 .38033 m
.00625 .38033 L
s
[(2)] -0.0125 .38033 1 0 Mshowa
0 .47541 m
.00625 .47541 L
s
[(3)] -0.0125 .47541 1 0 Mshowa
0 .57049 m
.00625 .57049 L
s
[(4)] -0.0125 .57049 1 0 Mshowa
.125 Mabswid
0 .01902 m
.00375 .01902 L
s
0 .03803 m
.00375 .03803 L
s
0 .05705 m
.00375 .05705 L
s
0 .07607 m
.00375 .07607 L
s
0 .1141 m
.00375 .1141 L
s
0 .13312 m
.00375 .13312 L
s
0 .15213 m
.00375 .15213 L
s
0 .17115 m
.00375 .17115 L
s
0 .20918 m
.00375 .20918 L
s
0 .2282 m
.00375 .2282 L
s
0 .24721 m
.00375 .24721 L
s
0 .26623 m
.00375 .26623 L
s
0 .30426 m
.00375 .30426 L
s
0 .32328 m
.00375 .32328 L
s
0 .3423 m
.00375 .3423 L
s
0 .36131 m
.00375 .36131 L
s
0 .39935 m
.00375 .39935 L
s
0 .41836 m
.00375 .41836 L
s
0 .43738 m
.00375 .43738 L
s
0 .45639 m
.00375 .45639 L
s
0 .49443 m
.00375 .49443 L
s
0 .51344 m
.00375 .51344 L
s
0 .53246 m
.00375 .53246 L
s
0 .55148 m
.00375 .55148 L
s
0 .58951 m
.00375 .58951 L
s
0 .60853 m
.00375 .60853 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.005 w
.25797 .21006 m
.19721 .14777 L
s
1 0 0 r
.45074 .26815 m
.38999 .20586 L
s
.628 .126 .941 r
.5488 .30813 m
.48804 .24585 L
s
.5 .165 .165 r
.87001 .56247 m
.80925 .50018 L
s
0 g
.5 Mabswid
.22759 .17892 m
.42036 .237 L
.51842 .27699 L
.83963 .53133 L
s
0 0 1 r
.005 w
.24455 .17153 m
.21589 .13125 L
s
1 0 0 r
.43732 .22961 m
.40867 .18933 L
s
.628 .126 .941 r
.53538 .2696 m
.50672 .22932 L
s
.5 .165 .165 r
.85659 .52394 m
.82793 .48366 L
s
0 g
.5 Mabswid
.23022 .15139 m
.42299 .20947 L
.52105 .24946 L
.84226 .5038 L
s
0 0 1 r
.005 w
.17888 .11233 m
.18832 .11896 L
s
1 0 0 r
.37165 .17042 m
.3811 .17704 L
s
.628 .126 .941 r
.46971 .21041 m
.47915 .21703 L
s
.5 .165 .165 r
.79092 .46475 m
.80037 .47137 L
s
0 g
.5 Mabswid
.1836 .11565 m
.37637 .17373 L
.47443 .21372 L
.79564 .46806 L
s
0 0 1 r
.005 w
.19437 .17819 m
.10293 .05639 L
s
1 0 0 r
.38714 .23628 m
.2957 .11448 L
s
.628 .126 .941 r
.4852 .27626 m
.39375 .15447 L
s
.5 .165 .165 r
.80641 .5306 m
.71497 .4088 L
s
0 g
.5 Mabswid
.14865 .11729 m
.34142 .17538 L
.43948 .21536 L
.76069 .4697 L
s
0 0 1 r
.005 w
.17612 .08233 m
.16625 .04736 L
s
1 0 0 r
.36889 .14041 m
.35902 .10545 L
s
.628 .126 .941 r
.46695 .1804 m
.45708 .14543 L
s
.5 .165 .165 r
.78816 .43474 m
.77829 .39977 L
s
0 g
.5 Mabswid
.17118 .06484 m
.36396 .12293 L
.46201 .16292 L
.78323 .41726 L
s
0 0 1 r
.005 w
.14574 .02791 m
.16568 .06779 L
s
1 0 0 r
.33851 .08599 m
.35845 .12588 L
s
.628 .126 .941 r
.43657 .12598 m
.45651 .16587 L
s
.5 .165 .165 r
.75778 .38032 m
.77772 .42021 L
s
0 g
.5 Mabswid
.15571 .04785 m
.34848 .10594 L
.44654 .14592 L
.76775 .40026 L
s
0 0 1 r
.005 w
.21469 .1255 m
.23882 .13915 L
s
1 0 0 r
.40746 .18359 m
.43159 .19724 L
s
.628 .126 .941 r
.50552 .22358 m
.52965 .23723 L
s
.5 .165 .165 r
.82673 .47791 m
.85086 .49156 L
s
0 g
.5 Mabswid
.22675 .13233 m
.41953 .19041 L
.51758 .2304 L
.83879 .48474 L
s
0 0 1 r
.005 w
.26353 .1772 m
.2874 .20211 L
s
1 0 0 r
.4563 .23529 m
.48018 .2602 L
s
.628 .126 .941 r
.55436 .27528 m
.57823 .30019 L
s
.5 .165 .165 r
.87557 .52962 m
.89944 .55453 L
s
0 g
.5 Mabswid
.27547 .18966 m
.46824 .24774 L
.5663 .28773 L
.88751 .54207 L
s
0 0 1 r
.005 w
.22209 .12408 m
.26025 .15912 L
s
1 0 0 r
.41487 .18216 m
.45302 .2172 L
s
.628 .126 .941 r
.51292 .22215 m
.55108 .25719 L
s
.5 .165 .165 r
.83414 .47649 m
.87229 .51153 L
s
0 g
.5 Mabswid
.24117 .1416 m
.43394 .19968 L
.532 .23967 L
.85321 .49401 L
s
0 0 1 r
.005 w
.22701 .13539 m
.19541 .05346 L
s
1 0 0 r
.41978 .19348 m
.38818 .11154 L
s
.628 .126 .941 r
.51784 .23346 m
.48623 .15153 L
s
.5 .165 .165 r
.83905 .4878 m
.80745 .40587 L
s
0 g
.5 Mabswid
.21121 .09442 m
.40398 .15251 L
.50204 .1925 L
.82325 .44684 L
s
0 .19016 m
.05976 .19016 L
.11792 .19016 L
.17975 .19016 L
.23932 .19016 L
.29661 .19016 L
.35757 .19016 L
.41627 .19016 L
.47864 .19016 L
.53874 .19016 L
.59657 .19016 L
.65807 .19016 L
.71429 .19016 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[205]:=",
  ImageSize->{551.5, 340.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]
}, Closed]],

Cell[TextData[{
  "The plot shows the log(mean) and log(variance/mean) on the x and y axes.  \
The horizontal line shows a ",
  Cell[BoxData[
      \(TraditionalForm\`variance\/\(\(mean\)\(\[NonBreakingSpace]\)\)\)]],
  "ratio of 1.  For each line, 4 short thickcoloured lines connect the two \
replicates at each of the 4 densities; and a black line connects the average \
over replicates across the 4 densities. For clarity, only the fitted \
replicate effects, common to all densities, are shown; thus, the bars  are \
the same shape across all densities.Variation between replicates is small: at \
each density, lines have characteristic effects on mean and variance/mean \
ratio.  However, there seem to be separate effects on the mean and on the \
variance/mean: some lines have low variance, and some high, for similar \
means."
}], "Text"]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{520, 626},
WindowMargins->{{245, Automatic}, {Automatic, 46}},
MacintoshSystemPageSetup->"\<\
00h0001804P000000b02<?oaonl3>@91H`85N0?N0@00005X0FP000003j0:l001
0@00I00100000@0200000BL?00400000000000000000010000000000000@0?ne
oj/@7@]500P1000000000000000001T1\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 47, 0, 36, "SubsectionIcon"],
Cell[1789, 53, 45, 0, 28, "MathCaption"],
Cell[1837, 55, 89, 2, 27, "Input"],

Cell[CellGroupData[{
Cell[1951, 61, 100, 3, 24, "SubsubsectionIcon"],
Cell[2054, 66, 611, 15, 70, "Text"],
Cell[2668, 83, 283, 6, 70, "Input"],
Cell[2954, 91, 195, 5, 70, "MathCaption"],
Cell[3152, 98, 1367, 26, 70, "Input"],
Cell[4522, 126, 181, 5, 70, "Text"],
Cell[4706, 133, 113, 3, 70, "MathCaption"],

Cell[CellGroupData[{
Cell[4844, 140, 101, 2, 70, "Input"],
Cell[4948, 144, 1106, 27, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[6091, 176, 108, 2, 70, "Input"],
Cell[6202, 180, 1353, 30, 70, "Output"]
}, Closed]],
Cell[7570, 213, 265, 5, 70, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[7872, 223, 136, 3, 36, "SubsubsectionIcon"],
Cell[8011, 228, 207, 5, 70, "MathCaption"],

Cell[CellGroupData[{
Cell[8243, 237, 135, 3, 70, "Input"],
Cell[8381, 242, 2094, 42, 70, "Output"]
}, Closed]],
Cell[10490, 287, 68, 0, 70, "MathCaption"],

Cell[CellGroupData[{
Cell[10583, 291, 148, 3, 70, "Input"],
Cell[10734, 296, 5132, 113, 70, "Output"]
}, Closed]],
Cell[15881, 412, 71, 0, 70, "MathCaption"],

Cell[CellGroupData[{
Cell[15977, 416, 143, 3, 70, "Input"],
Cell[16123, 421, 4927, 104, 70, "Output"]
}, Closed]],
Cell[21065, 528, 140, 3, 70, "MathCaption"],

Cell[CellGroupData[{
Cell[21230, 535, 295, 6, 70, "Input"],
Cell[21528, 543, 3715, 85, 70, "Output"]
}, Closed]],
Cell[25258, 631, 175, 4, 70, "MathCaption"],

Cell[CellGroupData[{
Cell[25458, 639, 158, 3, 70, "Input"],
Cell[25619, 644, 6894, 116, 70, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[32562, 766, 150, 3, 36, "SubsubsectionIcon"],
Cell[32715, 771, 126, 3, 70, "MathCaption"],

Cell[CellGroupData[{
Cell[32866, 778, 158, 3, 70, "Input"],
Cell[33027, 783, 5637, 114, 70, "Output"]
}, Closed]],
Cell[38679, 900, 104, 3, 70, "MathCaption"],

Cell[CellGroupData[{
Cell[38808, 907, 168, 3, 70, "Input"],
Cell[38979, 912, 8404, 175, 70, "Output"]
}, Closed]],
Cell[47398, 1090, 100, 3, 70, "MathCaption"],

Cell[CellGroupData[{
Cell[47523, 1097, 173, 3, 70, "Input"],
Cell[47699, 1102, 8610, 185, 70, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[56358, 1293, 147, 3, 36, "SubsubsectionIcon"],
Cell[56508, 1298, 187, 4, 70, "MathCaption"],

Cell[CellGroupData[{
Cell[56720, 1306, 161, 3, 70, "Input"],
Cell[56884, 1311, 5632, 114, 70, "Output"]
}, Closed]],
Cell[62531, 1428, 111, 3, 70, "MathCaption"],

Cell[CellGroupData[{
Cell[62667, 1435, 175, 4, 70, "Input"],
Cell[62845, 1441, 7636, 128, 70, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[70530, 1575, 116, 3, 20, "SubsubsectionIcon"],
Cell[70649, 1580, 207, 4, 70, "Text"],
Cell[70859, 1586, 79, 2, 70, "Input"],

Cell[CellGroupData[{
Cell[70963, 1592, 283, 7, 70, "Input"],
Cell[71249, 1601, 4000, 78, 70, "Output"]
}, Closed]],
Cell[75264, 1682, 201, 6, 70, "Input"],
Cell[75468, 1690, 125, 3, 70, "Input"],

Cell[CellGroupData[{
Cell[75618, 1697, 413, 8, 70, "Input"],
Cell[76034, 1707, 6691, 548, 70, 6536, 543, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False]
}, Closed]],
Cell[82740, 2258, 847, 14, 70, "Text"]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

