(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     31557,        877]*)
(*NotebookOutlinePosition[     32782,        916]*)
(*  CellTagsIndexPosition[     32660,        909]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Likelihood", "SubsectionIcon"],

Cell["This loads the package:", "MathCaption"],

Cell[BoxData[
    \(\(<< Utilities`StructuredModels`;\)\)], "Input",
  CellLabel->"In[1]:="],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{"StructuredLogLikelihood", "[", 
              StyleBox[\(data, vars, model, pars, LogL\),
                FontSlant->"Italic"], "]"}], 
            RowBox[{
              RowBox[{
              "gives", " ", "the", " ", "log", " ", "likelihoodof", " ", 
                "the", " ", "parameters", " ", 
                StyleBox["pars",
                  FontSlant->"Italic"]}], ",", " ", 
              RowBox[{"given", " ", "the", " ", 
                RowBox[{
                  StyleBox["model",
                    FontSlant->"Italic"], ".", "  ", "The"}], " ", 
                "likelihood", " ", "is", " ", "specified", " ", "by", " ", 
                "the", " ", "function", " ", 
                RowBox[{
                  RowBox[{"LogL", "[", 
                    RowBox[{
                      StyleBox["data",
                        FontSlant->"Italic"], ",", 
                      RowBox[{
                        StyleBox["{",
                          FontSlant->"Italic"], 
                        RowBox[{
                          SubscriptBox[
                            StyleBox["z",
                              FontSlant->"Italic"], "1"], ",", 
                          "\[Ellipsis]"}], "}"}]}], "]"}], "."}]}]}]}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"StructuredLogLikelihood"],

Cell[TextData[{
  "We fit a model which specifies that the numbers of flies are drawn from a \
negative binomial distribution with variance/mean ratio ",
  Cell[BoxData[
      \(TraditionalForm\`c = 2\)]],
  ", and mean ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^z\)]],
  "; the Log[mean] is to be fitted according to various models."
}], "Text"],

Cell[BoxData[{
    \(\(<< Utilities`RandomNumbers`;\)\), "\[IndentingNewLine]", 
    \(\(LogL[n_, {z_}] := 
        NegativeBinomialLogLikelihood[
          n, {\[ExponentialE]\^z, 2. }];\)\)}], "Input",
  CellLabel->"In[3]:="],

Cell[TextData[{
  "It is important that the function takes as its first argument a ",
  StyleBox["list",
    FontSlant->"Italic"],
  " of independent data points.  It is much faster to calculate the \
likelihood of the list than as a sum of separate calculations: the same \
calculation arises repeatedly when the same observation is repeated."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(tt = 
        Table[Random[Integer, 100], {1000}];\)\), "\[IndentingNewLine]", 
    \({Timing[LogL[tt, {3. }]], 
      Timing[Plus @@ \((\(LogL[{#}, {3. }] &\) /@ tt)\)]}\)}], "Input",
  CellLabel->"In[47]:="],

Cell[BoxData[
    \({{0.0500000000001819`\ Second, 
        149584.72323444398`}, {6.300000000000182`\ Second, 
        149584.72323444427`}}\)], "Output",
  CellLabel->"Out[48]="]
}, Open  ]],

Cell[TextData[{
  "The function ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(LogL\)\([\)\({n\_1, \[Ellipsis]}, {par\_1, 
          par\_2}\)\)\)]],
  "] takes as its second argument a list of parameters; this allows fitting \
of multivariate models.  In the present example, only a single parameter is \
supplied."
}], "Text"],

Cell[TextData[{
  "This gives the log likelihood when the parameter ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " is the sum of a main effect (2), and a density effect {0,1,2,3}.  That \
is, z={2,3,4,5} at densities {1,2,3,4}.  Note that because the mean is \
specified as ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^z\)]],
  " (se above), we are effectively fitting a multiplicative model:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(StructuredLogLikelihood[
      dd, {line, rep, density}, {density}, {2. , {0, 1, 2, 3}}, 
      LogL]\)], "Input",
  CellLabel->"In[12]:="],

Cell[BoxData[
    \(\(-2987.886863630567`\)\)], "Output",
  CellLabel->"Out[12]="]
}, Open  ]],

Cell["\<\
The result is the log likelihood, followed by the list of \
parameters.  The parameter list is supplied as a main effect, followed by one \
array for each model element. The parameter is constructed using \
StructuredParameter[].\
\>", "Text"],

Cell[TextData[{
  "More complicated models can be fitted: for example, we can include an \
additional term due to replicate*line interactions: ",
  Cell[BoxData[
      \(TraditionalForm\`z = z\^0 + z\_d + z\_\(r, l\)\)]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"StructuredLogLikelihood", "[", 
      RowBox[{
      "dd", ",", \({line, rep, density}\), ",", \({density, {rep, line}}\), 
        ",", 
        RowBox[{"{", 
          RowBox[{"2.", ",", \({0, 1, 2, 3}\), ",", 
            RowBox[{"(", GridBox[{
                  {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
                  {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0"}
                  }], ")"}]}], "}"}], ",", "LogL"}], "]"}]], "Input",
  CellLabel->"In[13]:="],

Cell[BoxData[
    \(\(-2987.8868636305597`\)\)], "Output",
  CellLabel->"Out[13]="]
}, Open  ]],

Cell["\<\
Because the replicate*line interaction parameters are here set to \
zero, the same result is obtained.  However, the calculation is slower, \
because extra variables are included in the model.\
\>", "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{"StructuredLogLikelihood", "[", 
              RowBox[{
                StyleBox["data",
                  FontSlant->"Italic"], 
                StyleBox[",",
                  FontSlant->"Italic"], 
                StyleBox["vars",
                  FontSlant->"Italic"], 
                StyleBox[",",
                  FontSlant->"Italic"], 
                RowBox[{
                  StyleBox["{",
                    FontSlant->"Italic"], 
                  RowBox[{
                    SubscriptBox[
                      StyleBox["model",
                        FontSlant->"Italic"], "1"], ",", "\[Ellipsis]"}], 
                  "}"}], ",", 
                RowBox[{"{", 
                  RowBox[{
                    SubscriptBox[
                      StyleBox["pars",
                        FontSlant->"Italic"], "1"], ",", "\[Ellipsis]"}], 
                  "}"}], 
                StyleBox[",",
                  FontSlant->"Italic"], 
                StyleBox["LogL",
                  FontSlant->"Italic"]}], "]"}], 
            RowBox[{
              RowBox[{
              "gives", " ", "the", " ", "log", " ", "likelihood", " ", "for", 
                " ", "a", " ", "list", " ", "of", " ", "parameters", " ", 
                RowBox[{"{", 
                  RowBox[{
                    SubscriptBox[
                      StyleBox["pars",
                        FontSlant->"Italic"], "1"], "\[Ellipsis]"}], "}"}]}], 
              ",", " ", 
              RowBox[{"with", " ", "a", " ", "different", " ", 
                SubscriptBox[
                  StyleBox["model",
                    FontSlant->"Italic"], "i"], " ", "for", 
                " ", \(each . \ \ The\), " ", "likelihood", " ", "is", " ", 
                "specified", " ", "by", " ", "the", " ", "function", 
                " ", \(\(LogL[data, {z\_1, \[Ellipsis]}]\)\(.\)\)}]}]}
          }], TraditionalForm]]]], "DefinitionBox"],

Cell["\<\
We may wish to fit the mean and the variance of the distribution; \
potentially, there may be a different model for each parameter:\
\>", "Text"],

Cell[BoxData[
    \(\(LogL2[n_, {z_, c_}] := 
        NegativeBinomialLogLikelihood[
          n, {\[ExponentialE]\^z, \[ExponentialE]\^c}];\)\)], "Input",
  CellLabel->"In[138]:="],

Cell[TextData[{
  "Here, both the mean z and the variance/mean ratio are specified by a \
multiplicative model: that is, these parameters are given as ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^z, \ \[ExponentialE]\^c\)]],
  "."
}], "Text"],

Cell["\<\
This gives the log likelihood where the first parameter (the mean) \
depends on density, plus a replicate*line interaction, whereas the second \
parameter (the variance/mean ratio) depends only on the density:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"StructuredLogLikelihood", "[", 
      RowBox[{
      "dd", ",", \({line, rep, density}\), 
        ",", \({{density, {rep, line}}, {density}}\), ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"2.", ",", \({0, 1, 2, 3}\), ",", 
                RowBox[{"(", GridBox[{
                      {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
                      {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0"}
                      }], ")"}]}], "}"}], ",", \({2. , {0, 1, 2, 3}}\)}], 
          "}"}], ",", "LogL2"}], "]"}]], "Input",
  CellLabel->"In[139]:="],

Cell[BoxData[
    \(\(-1878.088197474259`\)\)], "Output",
  CellLabel->"Out[139]="]
}, Open  ]],

Cell["\<\
StructuredLogLikelihood[] simply applies f[] to the output from \
StructuredModelReduce[]:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Plus", "@@", 
      RowBox[{"MapThread", "[", 
        RowBox[{"LogL2", ",", 
          RowBox[{"StructuredModelReduce", "[", 
            RowBox[{
            "dd", ",", \({line, rep, density}\), 
              ",", \({{density, {rep, line}}, {density}}\), ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{"{", 
                    RowBox[{"2.", ",", \({0, 1, 2, 3}\), ",", 
                      RowBox[{"(", GridBox[{
                            {"0", "0", "0", "0", "0", "0", "0", "0", "0", 
                              "0"},
                            {"0", "0", "0", "0", "0", "0", "0", "0", "0", 
                              "0"}
                            }], ")"}]}], "}"}], 
                  ",", \({2. , {0, 1, 2, 3}}\)}], "}"}]}], "]"}]}], 
        "]"}]}]], "Input",
  CellLabel->"In[144]:="],

Cell[BoxData[
    \(\(-1878.088197474259`\)\)], "Output",
  CellLabel->"Out[144]="]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{"StructuredMLE", "[", 
              RowBox[{
                StyleBox["data",
                  FontSlant->"Italic"], 
                StyleBox[",",
                  FontSlant->"Italic"], 
                StyleBox["vars",
                  FontSlant->"Italic"], 
                StyleBox[",",
                  FontSlant->"Italic"], 
                RowBox[{
                  StyleBox["{",
                    FontSlant->"Italic"], 
                  RowBox[{
                    SubscriptBox[
                      StyleBox["model",
                        FontSlant->"Italic"], "1"], ",", "\[Ellipsis]"}], 
                  "}"}], ",", 
                RowBox[{"{", 
                  RowBox[{
                    SubscriptBox[
                      StyleBox["pars",
                        FontSlant->"Italic"], "1"], ",", "\[Ellipsis]"}], 
                  "}"}], 
                StyleBox[",",
                  FontSlant->"Italic"], 
                StyleBox["LogL",
                  FontSlant->"Italic"], 
                StyleBox[",",
                  FontSlant->"Italic"], 
                StyleBox[\({j, k}\),
                  FontSlant->"Italic"]}], 
              "]"}], \(maximises\ likelihood\ for\ the\ k' 
              th\ model\ element\ of\ the\ j' th\ \(\(parameter\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"StructuredMLE"],

Cell[TextData[{
  "This maximises likelihood with respect to the first model element, ",
  StyleBox["density",
    FontSlant->"Italic"],
  ",  of the first parameter, "
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"StructuredMLE", "[", 
      RowBox[{
      "dd", ",", \({line, rep, density}\), 
        ",", \({{density, {rep, line}}, {density}}\), ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"2.", ",", \({0, 1, 2, 3}\), ",", 
                RowBox[{"(", GridBox[{
                      {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
                      {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0"}
                      }], ")"}]}], "}"}], ",", \({2. , {0, 1, 2, 3}}\)}], 
          "}"}], ",", "LogL2", ",", \({1, 1}\)}], "]"}]], "Input",
  CellLabel->"In[18]:="],

Cell[BoxData[
    \({{4.394262545914398`, {\(-1.051984883947513`\), \(-0.32328423354213953`\
\), 0.15679714322813787`, 
          1.218471974261515`}, {{0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 
            0, 0, 0, 0, 0, 0}}}, {2.`, {0, 1, 2, 3}}}\)], "Output",
  CellLabel->"Out[18]="]
}, Open  ]],

Cell["\<\
The adjusted set of parameters is returned, along with the log \
likelihood.  The main effect is adjusted so that the parameter arrays have \
mean zero after maximisation.  \
\>", "Text"],

Cell["\<\
This maximises with respect to the second model element, {rep, \
line}, of the first parameter:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"StructuredMLE", "[", 
      RowBox[{
      "dd", ",", \({line, rep, density}\), 
        ",", \({{density, {rep, line}}, {density}}\), ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"2.", ",", \({0, 1, 2, 3}\), ",", 
                RowBox[{"(", GridBox[{
                      {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
                      {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0"}
                      }], ")"}]}], "}"}], ",", \({2. , {0, 1, 2, 3}}\)}], 
          "}"}], ",", "LogL2", ",", \({1, 2}\)}], "]"}]], "Input",
  CellLabel->"In[19]:="],

Cell[BoxData[
    \({{2.9348795059599633`, {0, 1, 2, 3}, {0.04384037650716699`, 
          0.05928173787709001`, \(-0.07265987006656227`\), \
\(-0.15251682134761424`\), \(-0.02791269689391862`\), \(-0.10211098257103757`\
\), 0.03097302801701951`, 0.11208873469836989`, 0.07409687544799204`, 
          0.04491994663100052`, \(-0.03678199791372727`\), 
          0.03300028335679395`, \(-0.05138008284789031`\), \
\(-0.2568862467379869`\), \(-0.04802821156032733`\), \
\(-0.04989148967529866`\), 0.09128215176210919`, 0.14724491074609314`, 
          0.12660457002300407`, 0.03483578454772218`}}, {2.`, {0, 1, 2, 
          3}}}\)], "Output",
  CellLabel->"Out[19]="]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{"StructuredMLE", "[", 
              RowBox[{
                StyleBox["data",
                  FontSlant->"Italic"], 
                StyleBox[",",
                  FontSlant->"Italic"], 
                StyleBox["vars",
                  FontSlant->"Italic"], 
                StyleBox[",",
                  FontSlant->"Italic"], 
                RowBox[{
                  StyleBox["{",
                    FontSlant->"Italic"], 
                  RowBox[{
                    SubscriptBox[
                      StyleBox["model",
                        FontSlant->"Italic"], "1"], ",", "\[Ellipsis]"}], 
                  "}"}], ",", 
                RowBox[{"{", 
                  RowBox[{
                    SubscriptBox[
                      StyleBox["pars",
                        FontSlant->"Italic"], "1"], ",", "\[Ellipsis]"}], 
                  "}"}], 
                StyleBox[",",
                  FontSlant->"Italic"], 
                StyleBox["LogL",
                  FontSlant->"Italic"], 
                StyleBox[",",
                  FontSlant->"Italic"], 
                StyleBox[\({j, MainEffect}\),
                  FontSlant->"Italic"]}], 
              "]"}], \(maximises\ likelihood\ for\ the\ main\ effect\ of\ the\
\ j' th\ \(\(parameter\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"StructuredMLE", "[", 
      RowBox[{
      "dd", ",", \({line, rep, density}\), 
        ",", \({{density, {rep, line}}, {density}}\), ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"2.", ",", \({0, 1, 2, 3}\), ",", 
                RowBox[{"(", GridBox[{
                      {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
                      {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0"}
                      }], ")"}]}], "}"}], ",", \({2. , {0, 1, 2, 3}}\)}], 
          "}"}], ",", "LogL2", ",", \({1, MainEffect}\)}], "]"}]], "Input",
  CellLabel->"In[22]:="],

Cell[BoxData[
    \({{2.9342455176948845`, {0, 1, 2, 
          3}, {{0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0, 0, 0, 0, 
            0}}}, {2.`, {0, 1, 2, 3}}}\)], "Output",
  CellLabel->"Out[22]="]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{"StructuredMLE", "[", 
              RowBox[{
                StyleBox["data",
                  FontSlant->"Italic"], 
                StyleBox[",",
                  FontSlant->"Italic"], 
                StyleBox["vars",
                  FontSlant->"Italic"], 
                StyleBox[",",
                  FontSlant->"Italic"], 
                RowBox[{
                  StyleBox["{",
                    FontSlant->"Italic"], 
                  RowBox[{
                    SubscriptBox[
                      StyleBox["model",
                        FontSlant->"Italic"], "1"], ",", "\[Ellipsis]"}], 
                  "}"}], ",", 
                RowBox[{"{", 
                  RowBox[{
                    SubscriptBox[
                      StyleBox["pars",
                        FontSlant->"Italic"], "1"], ",", "\[Ellipsis]"}], 
                  "}"}], 
                StyleBox[",",
                  FontSlant->"Italic"], 
                StyleBox["LogL",
                  FontSlant->"Italic"]}], 
              "]"}], \(maximises\ likelihood\ for\ the\ whole\ \(\(model\)\(.\
\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox"],

Cell[TextData[{
  "This specifies a likelihood which is a function of the Log[mean] and ",
  Cell[BoxData[
      \(TraditionalForm\`Log[variance\/mean]\)]],
  " of a negative biniomial distribution (see above):"
}], "MathCaption"],

Cell[BoxData[{
    \(\(<< Utilities`RandomNumbers`;\)\), "\[IndentingNewLine]", 
    \(\(LogL2[n_, {z_, c_}] := 
        NegativeBinomialLogLikelihood[
          n, {\[ExponentialE]\^z, \[ExponentialE]\^c}, 
          Compiled \[Rule] True];\)\)}], "Input",
  CellLabel->"In[23]:="],

Cell["\<\
This maximises the likelihood for two parameters; the first \
parameter depends on density and on a {rep,line} interaction, while the \
second depends on density only:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"StructuredMLE", "[", 
      RowBox[{
      "dd", ",", \({line, rep, density}\), 
        ",", \({{density, {rep, line}}, {density}}\), ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"2.", ",", \({0, 1, 2, 3}\), ",", 
                RowBox[{"(", GridBox[{
                      {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
                      {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0"}
                      }], ")"}]}], "}"}], ",", \({2. , {0, 1, 2, 3}}\)}], 
          "}"}], ",", "LogL2"}], "]"}]], "Input",
  CellLabel->"In[39]:="],

Cell[BoxData[
    \({{4.189977078479839`, {\(-0.9586888903099968`\), \
\(-0.28398238577957635`\), 0.05921388266825948`, 
          1.1834573934213135`}, {{0.0032689111924914228`, 
            0.04192619417926831`, \(-0.06330038612068803`\), \
\(-0.21642583547878122`\), \(-0.019550514555830283`\), \
\(-0.07012001035134705`\), 0.03434917252665527`, 0.1023850427568016`, 
            0.11196264515022981`, 
            0.05219999406507832`}, {\(-0.0740820749412691`\), 
            0.027020917669450185`, \(-0.046046221535282`\), \
\(-0.2778260069353985`\), \(-0.021900094743260965`\), \(-0.03653660843308529`\
\), 0.09641699601240843`, 0.12872002654805229`, 0.14038444006166234`, 
            0.08715341293284445`}}}, {0.3355644325706919`, \
{\(-1.1728431487760547`\), \(-1.036921166265824`\), \(-0.4949362609592864`\), 
          2.704700576001165`}}}\)], "Output",
  CellLabel->"Out[40]="]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{"StructuredMLE", "[", 
              RowBox[{
                StyleBox["data",
                  FontSlant->"Italic"], 
                StyleBox[",",
                  FontSlant->"Italic"], 
                StyleBox["vars",
                  FontSlant->"Italic"], 
                StyleBox[",",
                  FontSlant->"Italic"], 
                StyleBox["model",
                  FontSlant->"Italic"], ",", 
                StyleBox["pars",
                  FontSlant->"Italic"], 
                StyleBox[",",
                  FontSlant->"Italic"], 
                StyleBox["f",
                  FontSlant->"Italic"], ",", \(MLE \[Rule] g\)}], 
              "]"}], \(maximises\ likelihood\ for\ the\ whole\ model; \ 
            g[{{\(x\_\(1, 1\)\) \[Ellipsis]} \[Ellipsis]}, {{\(\[Alpha]\_\(1, 
                            1\)\) \[Ellipsis]} \[Ellipsis]}, {\(\[Alpha]\&^\)\
\_1, \[Ellipsis]}]\ is\ a\ function\ which\ gives\ the\ MLE\ for\ a\ \
structured\ \(\(model\)\(.\)\)\)},
          {
            RowBox[{"StructuredMLE", "[", 
              RowBox[{
                StyleBox["data",
                  FontSlant->"Italic"], 
                StyleBox[",",
                  FontSlant->"Italic"], 
                StyleBox["vars",
                  FontSlant->"Italic"], 
                StyleBox[",",
                  FontSlant->"Italic"], 
                RowBox[{
                  StyleBox["{",
                    FontSlant->"Italic"], 
                  RowBox[{
                    SubscriptBox[
                      StyleBox["model",
                        FontSlant->"Italic"], "1"], ",", "\[Ellipsis]"}], 
                  "}"}], ",", 
                RowBox[{"{", 
                  RowBox[{
                    SubscriptBox[
                      StyleBox["pars",
                        FontSlant->"Italic"], "1"], ",", "\[Ellipsis]"}], 
                  "}"}], 
                StyleBox[",",
                  FontSlant->"Italic"], 
                RowBox[{"{", 
                  RowBox[{
                    SubscriptBox[
                      StyleBox["f",
                        FontSlant->"Italic"], "1"], "\[Ellipsis]"}], "}"}], 
                ",", \(MLE \[Rule] {g\_1, \[Ellipsis]}\)}], 
              "]"}], \(maximises\ likelihood\ for\ the\ whole\ model, \ 
            with\ several\ parameters\ estimated\ by\ a\ list\ of\ \
functions\)}
          }], TraditionalForm]]]], "DefinitionBox"],

Cell[TextData[{
  "StructuredMLE[] uses FindMinimum[] to optimise each parameter in turn.  \
This can be slow even for moderate-sized datasets.  If it is possible to find \
a simple formula for the MLE, this can be provided to speed the calculations. \
 The function ",
  Cell[BoxData[
      \(TraditionalForm\`g[{{\(x\_\(1, 
                    1\)\) \[Ellipsis]} \[Ellipsis]}, {{\(\[Alpha]\_\(1, 
                    1\)\) \[Ellipsis]} \[Ellipsis]}, {\(\[Alpha]\&^\)\_1, \
\[Ellipsis]}]\)]],
  " must take as its argument a list of the samples, ",
  Cell[BoxData[
      \(TraditionalForm\`x\+_\_k\)]],
  "; a list of the effects specific to each sample, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\+_\_k\)]],
  "; and a list of the overall effects, ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Alpha]\&^\)\+_\)]],
  ".  This last is necessary with several parameters, because the list  ",
  Cell[BoxData[
      \(TraditionalForm\`{g\_1[], \[Ellipsis]}\)]],
  " returns the MLE for each parameter in turn, the others parameters being \
taken as given."
}], "Text"],

Cell[TextData[{
  "As an example, model the data above using a log normal distribution.  \
Assume that the mean of log numbers is a sum of effects, and the variance of \
log numbers is a product of effects: thus the mean and Log[variance] of log \
numbers are the appropriate parameters in an additive model.  This ensures \
that the the variance remains positive.  Then, the mean Log[numbers] is ",
  Cell[BoxData[
      \(TraditionalForm\`Log[n\&_]\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(n\&_\)\(\ \ \)\)\)]],
  "being the geometric mean number, and the variance in Log[numbers] is ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^lv\)]],
  ". With this lognormal model, it is possible to estimate parameters \
explicitly, which greatly speeds the calculations."
}], "Text"],

Cell["Take log(numbers):", "MathCaption"],

Cell[BoxData[
    \(\(ldd = Log[dd] // N;\)\)], "Input",
  CellLabel->"In[3]:="],

Cell["Define log likelihood for a Gaussian model:", "MathCaption"],

Cell[BoxData[{
    \(\(<< Utilities`RandomNumbers`;\)\), "\[IndentingNewLine]", 
    \(\(L[d_List, {m_, lv_}] := 
        GaussianLogLikelihood[d, {m, \[ExponentialE]\^lv}, 
          Compiled \[Rule] True];\)\)}], "Input",
  CellLabel->"In[28]:="],

Cell[TextData[{
  "where ",
  StyleBox["lc",
    FontSlant->"Italic"],
  " is ",
  Cell[BoxData[
      \(TraditionalForm\`Log[c]\)]],
  "."
}], "Text"],

Cell["\<\
Initial estimates are made just from marginal mean & \
variance:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sp = 
      StructuredInitialParameters[
        ldd, {line, rep, density}, {{density, line}, {density}}, {Mean[#] &, 
          Log[Variance[#]] &}]\)], "Input",
  CellLabel->"In[30]:="],

Cell[BoxData[
    \({{3.9684402997789467`, {\(-0.7451104230071586`\), \
\(-0.06943969770548808`\), 0.2740023645391263`, 
          1.351369390433832`}, {0.003352446938551523`, 
          0.05667089822017246`, \(-0.07431964606889574`\), \
\(-0.250941585286955`\), \(-0.046045212684851844`\), \
\(-0.09192751756807072`\), 0.07460471724941531`, 0.1571196333656122`, 
          0.12170788220172213`, 
          0.04977838363334275`}}, {\(-0.8174410358244136`\), \
{\(-2.7033124555815333`\), \(-2.7828899702635206`\), \(-2.859279955627502`\), \
\(-1.2377866165537301`\)}}}\)], "Output",
  CellLabel->"Out[30]="]
}, Open  ]],

Cell["The MLE is obtained by repeated use of FindMinimum:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[
      np = StructuredMLE[
          ldd, {line, rep, density}, {{density, line}, {density}}, sp, 
          L]]\)], "Input",
  CellLabel->"In[31]:="],

Cell[BoxData[
    \({11.783333333333303`\ Second, {{4.171145706388702`, \
{\(-0.9478158317414485`\), \(-0.272145104159004`\), 0.0712969580726193`, 
            1.148663977827833`}, {\(-0.046814698811987854`\), 
            0.03890428033228046`, \(-0.06710958499062848`\), \
\(-0.25903797763879366`\), \(-0.01856690742251206`\), \
\(-0.050415490622620095`\), 0.07044475751472294`, 0.12675504659942177`, 
            0.1317626974409477`, 
            0.07407787759916924`}}, {\(-3.599512016059737`\), \
{\(-0.2601198388022925`\), \(-0.6314434542474985`\), \
\(-0.6552270219434844`\), 1.5467903149932754`}}}}\)], "Output",
  CellLabel->"Out[31]="]
}, Open  ]],

Cell["The MLE is much more likely than the initial estimates:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(StructuredLogLikelihood[
          ldd, {line, rep, density}, {{density, line}, {density}}, #, 
          L] &\) /@ {sp, np}\)], "Input",
  CellLabel->"In[33]:="],

Cell[BoxData[
    \({467.9558456907913`, 488.32076061642624`}\)], "Output",
  CellLabel->"Out[33]="]
}, Open  ]],

Cell["\<\
The calculation can be greatly speeded by using an explicit formula \
for the MLEs, rather than using FindMinimum[-StructuredLogLikelihood[],\
\[Ellipsis]]:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[
      np2 = StructuredMLE[
          ldd, {line, rep, density}, {{density, line}, {density}}, sp, L, 
          MLE \[Rule] {\(GaussianMLE[#1, #2 /. {m_, 
                          lc_} \[RuleDelayed] {m, \[ExponentialE]\^lc}, 
                    FullOutput \[Rule] False, 
                    Compiled \[Rule] 
                      True]\)\[LeftDoubleBracket]1\[RightDoubleBracket] &, \
\[IndentingNewLine]Log[\(GaussianMLE[#1, #2 /. {m_, 
                            lc_} \[RuleDelayed] {m, \[ExponentialE]\^lc}, 
                      FullOutput \[Rule] False, 
                      Compiled \[Rule] 
                        True]\)\[LeftDoubleBracket]2\[RightDoubleBracket]] \
&}]]\)], "Input",
  CellLabel->"In[36]:="],

Cell[BoxData[
    \({1.033333333333303`\ Second, {{4.171145708344025`, \
{\(-0.9478158315722358`\), \(-0.27214510627056604`\), 0.07129695597404796`, 
            1.1486639818687538`}, {\(-0.04681494106262646`\), 
            0.038904252350754884`, \(-0.06710961557881187`\), \
\(-0.2590378552723213`\), \(-0.01856690539531082`\), \
\(-0.05041548702373148`\), 0.0704447620593506`, 0.12675509511569188`, 
            0.13176272819718943`, 
            0.0740779666098152`}}, {\(-3.599512048319151`\), \
{\(-0.2601194670628039`\), \(-0.6314431756527594`\), \
\(-0.6552277805679947`\), 1.546790423283558`}}}}\)], "Output",
  CellLabel->"Out[36]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(StructuredLogLikelihood[
      ldd, {line, rep, density}, {{density, line}, {density}}, np2, 
      L]\)], "Input",
  CellLabel->"In[37]:="],

Cell[BoxData[
    \(488.3207609127504`\)], "Output",
  CellLabel->"Out[37]="]
}, Open  ]],

Cell["\<\
The same procedure could be used with (say) a negative binomial \
model, using NegativeBinomialMLE[] rather than GaussianMLE[].  However, \
because NegativeBinomialMLE[] itself uses FindMinimum[], rather than an \
explicit formula, there is no gain in speed.  \
\>", "Text"]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
AutoGeneratedPackage->None,
WindowSize->{572, 668},
WindowMargins->{{17, Automatic}, {Automatic, 16}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oQon@3:`8g0dL5N`?P0080001804P000000]P2:001
0000I00000400`<30?l00BL?00400@00000000000000060801T1T00000000000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "StructuredLogLikelihood"->{
    Cell[1922, 59, 1413, 32, 64, "DefinitionBox",
      CellTags->"StructuredLogLikelihood"]},
  "StructuredMLE"->{
    Cell[11876, 344, 1468, 38, 52, "DefinitionBox",
      CellTags->"StructuredMLE"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"StructuredLogLikelihood", 32432, 899},
  {"StructuredMLE", 32548, 902}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 36, 0, 36, "SubsectionIcon"],
Cell[1778, 53, 46, 0, 28, "MathCaption"],
Cell[1827, 55, 92, 2, 27, "Input"],
Cell[1922, 59, 1413, 32, 64, "DefinitionBox",
  CellTags->"StructuredLogLikelihood"],
Cell[3338, 93, 364, 9, 36, "Text"],
Cell[3705, 104, 227, 5, 42, "Input"],
Cell[3935, 111, 356, 7, 52, "Text"],

Cell[CellGroupData[{
Cell[4316, 122, 232, 5, 42, "Input"],
Cell[4551, 129, 180, 4, 20, "Output"]
}, Open  ]],
Cell[4746, 136, 329, 8, 36, "Text"],
Cell[5078, 146, 429, 10, 50, "Text"],

Cell[CellGroupData[{
Cell[5532, 160, 159, 4, 27, "Input"],
Cell[5694, 166, 82, 2, 20, "Output"]
}, Open  ]],
Cell[5791, 171, 253, 5, 36, "Text"],
Cell[6047, 178, 239, 6, 38, "Text"],

Cell[CellGroupData[{
Cell[6311, 188, 508, 11, 63, "Input"],
Cell[6822, 201, 83, 2, 20, "Output"]
}, Open  ]],
Cell[6920, 206, 216, 4, 36, "Text"],
Cell[7139, 212, 2012, 48, 64, "DefinitionBox"],
Cell[9154, 262, 155, 3, 36, "Text"],
Cell[9312, 267, 181, 4, 27, "Input"],
Cell[9496, 273, 258, 6, 36, "Text"],
Cell[9757, 281, 233, 4, 36, "Text"],

Cell[CellGroupData[{
Cell[10015, 289, 638, 14, 63, "Input"],
Cell[10656, 305, 83, 2, 20, "Output"]
}, Open  ]],
Cell[10754, 310, 121, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[10900, 317, 875, 20, 84, "Input"],
Cell[11778, 339, 83, 2, 20, "Output"]
}, Open  ]],
Cell[11876, 344, 1468, 38, 52, "DefinitionBox",
  CellTags->"StructuredMLE"],
Cell[13347, 384, 187, 5, 30, "MathCaption"],

Cell[CellGroupData[{
Cell[13559, 393, 644, 14, 63, "Input"],
Cell[14206, 409, 290, 5, 33, "Output"]
}, Open  ]],
Cell[14511, 417, 197, 4, 36, "Text"],
Cell[14711, 423, 126, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[14862, 430, 644, 14, 63, "Input"],
Cell[15509, 446, 666, 11, 59, "Output"]
}, Open  ]],
Cell[16190, 460, 1426, 37, 52, "DefinitionBox"],

Cell[CellGroupData[{
Cell[17641, 501, 653, 14, 84, "Input"],
Cell[18297, 517, 207, 4, 33, "Output"]
}, Open  ]],
Cell[18519, 524, 1241, 33, 52, "DefinitionBox"],
Cell[19763, 559, 230, 5, 56, "MathCaption"],
Cell[19996, 566, 282, 6, 42, "Input"],
Cell[20281, 574, 198, 4, 42, "MathCaption"],

Cell[CellGroupData[{
Cell[20504, 582, 627, 14, 63, "Input"],
Cell[21134, 598, 891, 15, 72, "Output"]
}, Open  ]],
Cell[22040, 616, 2525, 62, 102, "DefinitionBox"],
Cell[24568, 680, 1077, 24, 98, "Text"],
Cell[25648, 706, 807, 16, 94, "Text"],
Cell[26458, 724, 41, 0, 28, "MathCaption"],
Cell[26502, 726, 80, 2, 27, "Input"],
Cell[26585, 730, 66, 0, 28, "MathCaption"],
Cell[26654, 732, 248, 5, 42, "Input"],
Cell[26905, 739, 151, 8, 24, "Text"],
Cell[27059, 749, 95, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[27179, 756, 207, 5, 42, "Input"],
Cell[27389, 763, 606, 11, 59, "Output"]
}, Open  ]],
Cell[28010, 777, 74, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[28109, 781, 177, 5, 27, "Input"],
Cell[28289, 788, 644, 11, 59, "Output"]
}, Open  ]],
Cell[28948, 802, 78, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[29051, 806, 184, 4, 42, "Input"],
Cell[29238, 812, 100, 2, 20, "Output"]
}, Open  ]],
Cell[29353, 817, 187, 4, 42, "MathCaption"],

Cell[CellGroupData[{
Cell[29565, 825, 754, 15, 87, "Input"],
Cell[30322, 842, 643, 11, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[31002, 858, 160, 4, 27, "Input"],
Cell[31165, 864, 77, 2, 20, "Output"]
}, Open  ]],
Cell[31257, 869, 284, 5, 50, "Text"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

